Reports - Banks and Financial Institutions - World Bank

Publication date: November 18, 2020 53087 mots

- Guyana - A-Pivotal-Moment-for-Guyana-Realizing-the-Opportunities-Systematic-Country-Diagnostic.pdf

121 pages

Please note : This extract may not display a well formed paragraph

... P ub lic D is cl os ur e A ut ho riz ed P ub lic D is cl os ur e A ut ho riz ed P ub lic...

Full report:
https://documents1.worldbank.org/curated/en/691761607528494981/pdf/A-Pivotal-Moment-for-Guyana-Realizing-the-Opportunities-Systematic-Country-Diagnostic.pdf

Reports - Banks and Financial Institutions - World Bank

Publication date: November 16, 2020 93315 mots

- Nigeria FY21-25 - Nigeria-Country-Partnership-Framework-for-the-Period-FY21-FY25.pdf

188 pages

Please note : This extract may not display a well formed paragraph

... i Document of The World Bank Group FOR OFFICIAL USE ONLY Report No. 153873-NG INTERNATIONAL BANK FOR RECONSTRUCTION AND DEVELOPMENT INTERNATIONAL DEVELOPMENT ASSOCIATION INTERNATIONAL FINANCE CORPORATION MULTILATERAL INVESTMENT GUARANTEE AGENCY...

Full report:
https://documents1.worldbank.org/curated/en/526171611619063445/pdf/Nigeria-Country-Partnership-Framework-for-the-Period-FY21-FY25.pdf

Rapports - Gestion de risque - KPMG

Date de publication : 30 octobre 2020 64957 mots

- 30 per cent of global work is completed by automation--a proportion expected to rise to 52 per cent by 2025 - WEF_Future_of_Jobs_2020.pdf

163 pages

NB : cette extraction brute des 30 premiers mots ne forme peut-être pas un paragraphe bien construit

... The Future of Jobs Report 2020 O C T O B E R 2 0 2 0 The Future of Jobs 2 Contents Preface Executive Summary Part 1 Tracking the Future...

Pour voir le rapport :
http://www3.weforum.org/docs/WEF_Future_of_Jobs_2020.pdf

Reports - Defence - Europe Security Defense

Publication date: October 28, 2020 96069 mots

- - budg2021-doc5-txt-2-en.pdf

174 pages

Please note : This extract may not display a well formed paragraph

... EN EN 2021 BUDGETARY PROCEDURE Doc No: 5: (2) ******* 26.10.2020 COMMITTEE ON BUDGETS RAPPORTEURS: PIERRE LARROUTUROU - SECTION III (COMMISSION) OLIVIER CHASTEL - OTHER SECTIONS PARLIAMENT'S POSITION Amendments which have...

Full report:
https://www.europarl.europa.eu/sed/doc/news/flash/24643/budg2021-doc5-txt-2-en.pdf
CQ House Action Reports
Monday, December 21, 2020 72724 mots, p. NA

Fact Sheet No. 116-34: December 21, 2020 - Year-End Funding/Covid Relief Agreement.

Year-End Funding/Covid Relief Agreement

This updated, more detailed Fact Sheet describes the bipartisan agreement on HR 133, Consolidated FY 2021 Appropriations Act.

The measure provides $1.4 trillion in FY 2021 discretionary spending for all 12 annual spending measures. It also includes a $900 billion package of additional relief for individuals, businesses and others adversely impacted by the COVID pandemic, and it contains numerous legislative provisions including an end to surprise medical billing.

Section I

Background & Summary

[NOTE: This more detailed HAR Fact Sheet replaces the abbreviated version originally published on Dec. 21, 2020, when the House voted on the measure only hours after posting the text of the massive agreement.]

Unlike many years past, the failure by Congress this year to enact appropriations bills before the beginning of the new fiscal year on Oct. 1 was not caused by partisan divisions regarding the total level of funding to be provided or the split between defense and non-defense spending; the bipartisan budget deal reached in July 2019 (PL 116-37) set discretionary caps for both FY 2020 and FY 2021.

Rather, this year's congressional appropriations process was primarily disrupted by the coronavirus pandemic, with lawmakers beginning in early March focusing almost exclusively on virus response and relief legislation as the nation grappled with COVID-19 and its impact on the economy.

FY 2021 Appropriations Action

The House resumed work on non-virus legislation in late June once remote voting mechanisms were in place, and in July passed 10 of its 12 FY 2021 appropriations bills (all except Homeland Security and Legislative Branch) through two multi-bill packages (HR 7608 and HR 7617).

While the spending bills reported by the House Appropriations committee technically adhered to the budget caps for FY 2021, Democrats also included an additional $247 billion in emergency spending -- primarily to address issues involving the pandemic and to build or repair the nation's infrastructure as a means of promoting economic recovery.

But in the Senate, GOP plans to mark up their FY 2021 spending bills was halted as the two parties couldn't agree on what amendments could be offered in committee, with Democrats insisting that they be able to offer amendments dealing with the pandemic, police reform and social justice, as well as confederate statues and military base names.

Consequently, no spending bills were considered in either the Senate Appropriations committee or on the Senate floor, leading Congress in September to enact a Continuing Resolution (CR; PL 116-159) to provide stopgap FY 2021 funding for the government at FY 2020 levels through Dec. 11 to get past the November elections.

Post-Election Appropriations Negotiations

After the elections, Senate Republicans in November released drafts of all 12 FY 2021 appropriations bills which reflected their funding and policy priorities, and later that month House and Senate appropriators reached agreement on a set of funding allocations for the 12 annual FY 2021 spending bills and began negotiating the details of each.

Major points of controversy in reaching final agreements included the budgetary treatment of certain veterans spending, the level of spending for President Trump's border wall, and funding for Immigration and Customs Enforcement (ICE) detention capacity.

To provide additional time to complete negotiations and reach agreement, particularly on additional coronavirus relief that was the subject of parallel negotiations, Congress several times extended stopgap government funding through additional CRs.

Initial Coronavirus Relief

As the public health and economic impact of the coronavirus pandemic became apparent in March, with much of the nation shutting down to slow the spread of the disease, Congress reacted quickly by enacting a series of bills that provided some $3 trillion in aid to combat the virus and help impacted businesses and workers and the broader economy.

The key measure enacted was the $2.2 trillion CARES Act (PL 116-136), an economic "rescue" package that among many things provided direct payments to households, expanded unemployment benefits, loans to small businesses that could be forgiven if they kept their employees on payroll (the Paycheck Protection Program, or PPP), and aid to states and to hospitals to respond to the pandemic.

Many of the major support programs in the CARES Act were short-term, however, running only a few months in the belief that once the virus was contained the economy could largely return to normal.

In April after Congress enacted some additional virus relief legislation, Senate Majority Leader Mitch McConnell, R-Ky., called for a "pause" in providing more aid, saying Congress should first evaluate the impact of aid provided to-date. He also stated that liability protections for employers against COVID-related lawsuits would have to be included in any subsequent major package, while many Republicans began expressing concern about the level of spending that had been enacted and its impact on federal deficits and the debt.

Continued Relief Needs / Failed Negotiations

House Democrats, recognizing the pandemic would continue to adversely impact the economy and workers for a much longer period, in mid-May passed a $3.4 trillion aid package (HR 6800, the Heroes Act) which they argued focused more on helping those who were struggling or who had lost their jobs because of the virus' impact on the economy (more than 22 million workers had lost their jobs in March and April). The Heroes bill extended and expanded most of the virus relief benefits previously enacted (such as the extra $600 a week in unemployment benefits) and added numerous new elements -- including more than $900 billion in aid to state and local governments. Republicans considered it little more than a liberal "wish list."

Negotiations over additional aid finally began between Democratic leaders and the White House in late July as the virus continued to surge and the CARE Act's extra $600 a week in unemployment benefits and authority for new aid to small businesses through the PPP were about to expire. At about the same time, Senate Republicans introduced (but never considered) a series of virus response and relief bills valued at an estimated $1 trillion -- although some 20 GOP senators opposed that topline spending because of deficit and debt concerns.

Negotiations faltered, however, after a couple weeks because of differences over the level of extra unemployment aid and aid to state and local governments -- which many Republicans opposed arguing that "mismanaged" state and local governments should not be "bailed out" by federal taxpayers. That opposition remained as House Speaker Nancy Pelosi, D-Calif., offered to reduce the size of a final relief package by more than $1 trillion to meet Republicans "halfway" if they would increase their $1 trillion proposal by another $1 trillion.

After negotiations ended President Trump in early August sought to unilaterally provide some relief through four executive actions -- the centerpiece of which was using FEMA disaster funds to provide an additional $300 a week in extra federal unemployment aid to unemployed workers (which lasted about six weeks for the states that participated). His other actions extended until the end of the year a suspension of student loan payments and a moratorium on evictions of renters, and he also suspended for the remainder of the year the collection of federal payroll taxes (which few businesses chose to implement because employees would have to repay the taxes in the first quarter of 2021).

To demonstrate they did support additional aid, Senate GOP leaders in early September assembled a $650 billion package (the majority of which was offset) to provide an extra $300 a week in unemployment benefits through the end of the year and more money for the PPP. It also included $105 billion for schools, tens of billions for virus testing and vaccines, as well as liability protections for businesses that Democrats opposed. Democrats were firmly opposed to the measure and it fell short of the 60 votes needed to move forward - but 52 Senate Republicans did vote in support.

Bipartisan Proposal & Renewed Negotiations

In an effort to revive negotiations, the 50-member House bipartisan Problem Solvers Caucus in mid-September released a $1.5 trillion proposal that sought to split the difference between the two parties' packages and provide a mix of Democratic and GOP priorities. The White House voiced encouragement and indicated it could support a package costing in that range.

House Democratic leaders, meanwhile, under pressure from moderate Democrats to vote on additional virus relief before the elections, scaled back their Heroes bill to a smaller $2.4 trillion package (HR 925), which the House passed on Oct. 1. That prompted further discussions between Treasury Secretary Steven Mnuchin and Speaker Pelosi, with the White House offering a $1.6 trillion plan that included $250 billion in state and local aid and a $400 per week boost to unemployment through December.

Democrats continued to insist upon a $2 trillion plus package, and the White House on Oct. 9 (three days after President Trump abruptly announced he was ending negotiations) increased its offer to about $1.8 trillion and indicated it could accept a higher number as long as it stays below $2 trillion. Senate Republicans, meanwhile, continued to indicate they couldn't accept any package costing more than $1 trillion, with McConnell reportedly telling Trump that a major deal could divide Republicans.

Negotiations continued throughout the month but halted in late October when the Senate left town, ending any chance of enacting a deal before the elections. Negotiators on both sides blamed the other for failing to reach a deal, with Pelosi saying the president didn't do enough to get GOP support and Mnuchin saying Pelosi had refused to compromise.

Post-Election Negotiations

After the November elections leaders in both parties voiced support for reaching agreement during the lame duck session on a virus relief bill that could be attached to a year-end funding bill -- with Republicans continuing to call for a "targeted" relief bill and Democrats a "comprehensive" measure. Both President Trump and President-Elect Joe Biden also called for Congress to enact a virus relief package before the end of the year, with Biden saying more could be done once he took office.

The desire to reach a deal was driven by the slowing economic recovery from the national shutdown in the Spring, and the surge of COVID infections and deaths to unprecedented levels across the nation. In addition, numerous virus relief policies were scheduled to expire at the end of the year -- which if not renewed would end unemployment benefits for an estimated 12 million Americans, put tens of millions at risk of being evicted from their homes, and threaten the survival of tens of thousands of small businesses. In addition, nationwide there were enormous and growing lines at food pantries as increasing numbers of individuals and families lacked the money to buy groceries.

Bipartisan 'Gang' Proposal

An opportunity for a deal crystalized the first week of December when Democratic leaders abandoned their calls for a $2 trillion package and expressed support for a bipartisan $908 billion framework developed by a group of Republican and Democratic senators along with some House Problem Solver representatives.

The bipartisan plan attracted wide support, even as McConnell sought support for a smaller $500 billion plan and the administration floated its own $916 billion proposal which called for providing another round of direct stimulus checks to taxpayers but with scaled back unemployment benefits. Republicans continued to oppose state and local aid and Democrats the liability protections, however, and McConnell suggested those issues be dropped and considered in the next Congress.

Consequently, in drafting their plan into legislative language the bipartisan group created two separate bills -- one worth $748 billion that included the provisions with broad bipartisan support and the other that contained just the more controversial liability protections for employers and $160 billion in state and local aid.

Final Negotiations & Trump Objections

Because of its broad support, House and Senate leaders used the bipartisan group's $748 billion proposal as the base for negotiating a final agreement -- jettisoning the liability provisions and direct state and local aid but adding in another round of direct stimulus checks, which also had wide support and raised the bill's cost back up to the $900 billion range.

Final negotiations centered on the details of each of the elements, often substantially modifying them and deciding what additional elements to add to the relief package. Among the items that held up a final agreement were efforts by Democrats to funnel more money to state and local governments through FEMA, and ultimately efforts by Republicans to limit the emergency powers of the Federal Reserve. And in addition to a $900 virus relief package, congressional leaders attached numerous other high priority legislative items to the final package.

The massive measure's 5,593-page text was posted early the afternoon of Dec. 21 and hours later the House passed it as a House amendment to the Senate amendment on HR 133, unrelated legislation dealing with U.S.-Mexico relations. To ensure that conservatives and liberals who opposed different elements of the bill wouldn't combine to defeat it, the vote on the measure was divided into two separate votes -- one on four of the FY 2021 spending bills (Defense, Commerce-Justice-Science, Financial Services, and Homeland Security, which was adopted 327-85), and the other on the remaining eight spending bills, the covid-relief package and other legislative provisions (which was adopted 359-53). The Senate that night cleared the measure for the president by a 92-6 vote.

Trump Opposition

Although the White House had indicated that President Trump would sign the measure, the president the following day released a video calling the legislation a "disgrace" and suggested he may not sign the package. He called the $600 stimulus checks "ridiculously low," suggesting $2,000 payments be made to taxpayers instead, and called much of the bill "wasteful spending and much more" citing foreign aid and other spending in the regular appropriations portion of the omnibus package.

The president reportedly had to be talked out of demanding significantly higher stimulus checks during the final weeks of negotiations, since it would have added significantly to the covid relief package's cost and threatened GOP support for the overall measure. (CBO estimated that the additional $1,400 needed to increase checks to $2,000 would cost $464 billion over 10 years.)

Congressional leaders nevertheless sent the enrolled measure down to him at his resort in Florida on Christmas eve, and on Dec. 27 the president signed it into law (PL 116-260) -- although he said "wasteful items" still needed to be removed from the package and that he would soon submit to Congress a package of proposed spending rescissions detailing those items he believes should be cut. He also highlighted a planned House vote the following day on legislation to boost the direct stimulus checks, expressing his support for that action.

(Although the House passed that separate legislation, it was never taken up by the Senate before the end of the 116th Congress. Meanwhile, on Jan. 14, 2021, the Trump administration submitted to Congress a $27.4 billion package of proposed rescissions that Congress is expected to ignore.)

Executive Summary of HR 133

The bipartisan year-end agreement consists of all 12 FY 2021 appropriations measures that provide a total of $1.4 trillion in discretionary spending. It also includes an estimated $900 billion in relief for individuals and businesses adversely impacted by the COVID pandemic, as well as funds for more virus testing and the distribution of vaccines and for aid to schools, transit systems, airlines and other entities.

The measure also contains numerous legislative provisions -- including protections against surprise medical billing, extensions of dozens of tax provisions and healthcare programs, provisions to provide increased oversight of the aircraft certification process in the wake of the Boeing 737 Max disasters, and major authorization bills for water resources development, pipeline and hazardous materials, and U.S. intelligence operations.

FY 2021 Appropriations Bills

The agreement includes a total of $1.4 trillion for the 12 annual FY 2021 appropriations bills -- including $1.3 trillion subject to discretionary budget caps, $77 billion in Overseas Contingency Operations (OCO) funding, $17.3 billion for the disaster relief cap adjustment, $1.9 billion for program integrity initiatives, and $9.6 billion in emergency funding.

Of the emergency funding, $6.5 billion is related to the COVID-19 pandemic, according to appropriators, and the $1.3 trillion subject to caps includes $671.5 billion in base defense spending ($5 billion more than FY 2020) and $626.5 billion in nondefense funding ($20 billion more than FY 2020).

Following are highlights from each bill:

Agriculture -- $23.4 billion in net discretionary spending subject to caps, $217 million more than FY 2020. Factoring out rescissions and other provisions that reduce scored discretionary spending and adding in the mandatory funding provided for a variety of nutrition and farm programs, the measure provides a total of $208.9 billion for FY 2021 -- $52.1 billion (33%) more than FY 2020. It increases funding for food stamps by $46.1 billion (67%), commodity assistance programs by 24% and child nutrition programs by 6%, while also providing modest increases for most farm production programs. It slightly reduces overall funding for rural development programs.

Commerce-Justice-Science -- $71.1 billion in net discretionary spending subject to caps and $604 million in emergency spending, for a total of $71.7 billion in scored discretionary spending. Net capped spending is $2.05 billion less than FY 2020 (reflecting the completion of the Decennial Census). On a programmatic basis, factoring out rescissions and providing funding through other adjustments (such as by limiting spending from the Crime Victims Fund to offset appropriations), the measure provides a total of $76.1 billion for FY 2021 -- including mandatory spending for various items. It increases Justice Department funding by 4%, including for aid to state and local law enforcement, and provides funds to support investigations into police misconduct and create a database to track officer misconduct. It also increases funding for NASA (3%), the NSF (2.5%) and NOAA (2%).

Defense -- $627.3 billion in net spending subject to caps along with $68.7 billion in OCO funding, for a total of $696 billion in scored discretionary funding ($2.6 billion more than FY 2020). Net capped spending is $4.6 billion more than FY 2020 while OCO funding is $2.0 billion less. Overall funding includes $251.0 billion for Pentagon operation and maintenance (1% less than FY 2020) and $162.4 billion for military personnel costs (5% more) which will support a 3% pay increase for military personnel. It funds the newly constituted Space Force and provides more than $10 billion for missile defense. It provides $43.6 billion to procure aircraft (4% more than FY 2020), including $19.5 billion for Navy aircraft ($2.4 billion more than requested) and $20.0 billion for the Air Force ($1.3 billion more). It also provides $23.3 billion for 10 major Navy ships ($3.4 billion more than requested).

Energy-Water -- $49.5 billion in net discretionary spending subject to caps, $1.1 billion (2%) more than FY 2020. On a programmatic basis it provides $51.8 billion ($3.4 billion more than FY 2020) including $2.3 billion for Energy Department science programs categorized as emergency spending that is offset by rescinding $2.3 billion in prior emergency funds. It increases Energy Department funding by 8.5% with a 23% increase for National Nuclear Security Administration weapons activities to fully fund nuclear warhead life extension programs and address a deferred maintenance backlog, and a 4% increase for NNSA nuclear nonproliferation activities. It increases funding for energy efficiency and renewable energy programs by 2.5% and for activities of the Corps of Engineers by 2% -- including a 25% increase for projects to clean up contamination from early U.S. nuclear activities.

Financial Services -- $24.4 billion in net discretionary spending subject to caps, $281 million (1%) more than FY 2020. Incorporating $12.9 billion in offsetting collections that don't count towards scored spending as well as $50 million in emergency funding and $143 million in disaster funding (and factoring out rescissions), the measure provides a total of $37.5 billion in discretionary funding. It also includes $22.9 billion in mandatory funding. It increases by 3% IRS funding by (including a 24% increase to modernize IRS technology) and the CDFI fund (which promotes development in financially underserved areas), and increases funding for various independent agencies such as the FCC (10%), FTC (6%) and SEC (5%). It increases funding for the federal court system by 4% and provides a 1% pay raise for federal civilian employees, but reduces base SBA funding by 8%.

Homeland Security -- $51.9 billion in net discretionary spending subject to caps and $17.1 billion in disaster cap funding as well as $840 million in emergency funds, for a total of $69.9 billion in scored discretionary spending. Net capped spending is $1.41 billion more than FY 2020. Incorporating $5.0 billion in offsetting collections that don't count towards scored discretionary spending and adding in $1.9 billion in mandatory spending and $8.1 billion in spending that is automatically available for fee funded programs, it provides a total of $85.1 billion ($2.6 billion more than FY 2020). It includes $1.4 billion for 56 miles of physical barrier along the U.S.-Mexico border (equal to FY 2020), but reduces funding for ICE removal operations by 7% and provides no funding for additional ICE agents and officers. It increases funding for TSA by 2%, and for the Coast Guard and Secret Service by 1%.

Interior-Environment -- $36.1 billion in net discretionary spending subject to caps and $2.35 billion subject to a fire suppression cap, for a total of $38.5 billion in scored discretionary spending. Net capped spending is $118 million more than FY 2020. The measure also includes $64 million in mandatory funding. It increases EPA by 2%, boosting funding for EPA enforcement, compliance and research and funding a half dozen new state grant programs. Interior and Forest Service funding (excluding wildfire funds) increases by 1% and 2%, respectively, with increases for Fish and Wildlife Service and National Park System operations but a reduction for the Bureau of Land Management. It provides $5.3 billion for fighting wildfires and allocates the full $900 million now permanently available from the Land and Water Conservation Fund as a result of legislation enacted in 2020.

Labor-HHS-Education -- $174.1 billion in net discretionary spending subject to caps, along with $1.9 billion for program integrity initiatives and $1.6 billion in emergency funding, for a total of $177.5 billion in scored discretionary spending. Factoring out certain scorekeeping adjustments (such as $21 billion in rescissions to mandatory programs that offset discretionary spending), it provides a total of $197 billion in discretionary funding, $2.8 billion more than FY 2020. It also provides $971.4 billion in mandatory funding for Medicaid grants to states and other purposes. It increases discretionary HHS spending by 2%, providing a 3% increase to NIH and 2% more to the CDC. Education Department spending increases by 1%, with 4% increases for career, technical and adult education programs and for aid to historically Black and similar colleges. Most Labor Department programs are increased slightly, with apprenticeship programs increasing by 6%.

Legislative Branch -- $5.3 billion in net discretionary spending subject to caps, along with $10 million in emergency funding. The net capped total is $251 million (5%) more than FY 2020. It increases funding for House operations by 8% and for Senate operations by 3%. It also increases funding for the Library of Congress (4%), GAO (6%) and CBO (4%), but reduces funding for the Architect of the Capitol (by 2%). The measure continues a freeze on lawmaker pay.

Military Construction-VA -- $112.8 billion in net discretionary spending subject to caps along with $350 million in OCO funding, for a total of $113.1 billion in net discretionary funding, which when combined with $138.7 billion in mandatory funding for VA pensions and benefits provides a total of $251.8 billion for the year. Net capped funding is 9% more than FY 2020. It provides $8.1 billion (29% less than FY 2020) for base military construction activities and $350 million in OCO funding. For the VA, it provides a total of $243.2 billion of which $104.4 billion is discretionary spending (13% more), including $90.8 billion for VA health care programs (12% more than FY 2020). It provides $18.5 billion for community care programs where veterans receive medical services outside of VA health care facilities, 21% more than FY 2020.

State-Foreign Operations -- $47.7 billion in net discretionary spending subject to caps, along with $8 billion in OCO funding and $5.3 billion in COVID-related emergency funding, for a total of $60.8 billion. Net capped spending is 2% more than FY 2020, while the $55.5 billion in non-emergency spending is $820 million (2%) more. Of the emergency funding, $4 billion is for the GAVI Alliance, which provides vaccines to the world's poorest countries. It increases funding for bilateral economic assistance (2% more), including for the Global Health program and Economic Support Fund. It also increases funding for contributions to international organizations (2%) and programs to improve maternal and child health and fight infectious diseases (3%). It reduces funding for multilateral assistance by 2%, and also slightly reduces funding for international security assistance and for international peacekeeping.

Transportation-HUD -- $75.4 billion in net discretionary spending subject to caps ($1.1 billion more than FY 2020), along with $718 million in emergency spending and $61.4 billion in obligation authority from the highway and aviation trust funds, for a total of $136.8 billion (also $1.1 billion more than FY 2020). It increases funding for the Transportation Department by less than 1% with highway, transit and Amtrak funding remaining essentially flat. Funding for the FAA is increased by 2% and the Federal Motor Carrier Safety Administration by 10%. It increases funding for the Housing and Urban Development Department by 1% overall, with more substantial increases for Public and Indian Housing (7%), Community Planning and Development (4%), and other major housing programs (7%).

COVID Relief

The agreement includes a COVID relief package that provides an estimated $900 billion in economic relief for individuals and businesses impacted by the coronavirus pandemic, as well as funding for virus testing and vaccine distribution. Of the total, $184.3 billion is provided through emergency appropriations. CBO and JCT estimate the covid package will increase the deficit by $868 billion over 10 years.

Aid to Individuals

Similar to the CARES Act, the measure provides one-time direct payments (technically tax rebates) to families of up to $600 for both adults and children -- but also makes these direct payments available to mixed-status households (where one of the parents does not have a Social Security number), and makes that eligibility retroactive to CARES Act payments.

It extends into early April 2021 federal unemployment benefits under the Pandemic Emergency Unemployment Compensation program (the PEUC, which provides benefits for those who have exhausted their state benefits) and the Pandemic Unemployment Assistance program (the PUA, which provides benefits to gig workers, contractors and others not eligible for state unemployment programs). And through March 14 it provides an additional $300 per week enhanced federal benefit on top of other unemployment benefits.

Other aid to individuals includes the following:

Rental Assistance -- Provides $25 billion for financial aid to renters experiencing financial hardship due to the pandemic, with the aid to be used for rent payments, utility and energy bills, and other housing expenses.

Eviction Moratorium -- Extends through Jan. 31, 2021 the eviction moratorium implemented by the Centers for Disease Control and Prevention (CDC), to give President Biden a chance to further extend the moratorium.

Nutrition Aid -- Increases monthly food stamp benefits by 15% through June 30, 2021; makes other modifications to SNAP eligibility to boost nutrition aid; and provides nearly $600 million for several other food aid programs.

Aid to Businesses

The agreement extends the Paycheck Protection Program (PPP), allowing the SBA to guarantee new forgivable PPP loans through March 31, 2021. It expands eligibility for PPP loans to tourism boards, visitors bureaus, and certain nonprofits, as well as to local newspapers and TV and radio stations, and it expands the business expenses for which loans can be forgiven. It also allows businesses with 300 or fewer employees that have sustained a 25% loss in revenue that previously received a PPP loan to receive a "second draw" of up to $2 million.

It appropriates $284.5 billion for the PPP and $50 million for SBA oversight and audits of PPP loans.

The measure also extends through June 30, 2021, the temporary employee retention tax credit that allows employers to claim a tax credit on employer-paid Social Security payroll taxes to help offset the costs of keeping employees on payroll. For 2021, it makes the tax credit more generous and expands the number of businesses that can utilize it.

Other aid to businesses includes the following:

EIDL Grants -- Extends through Dec. 31, 2021, the SBA's Economic Injury Disaster Loan (EIDL) Advance Grant program, and provides $20 billion to create a targeted EIDL grant for certain small businesses in low-income communities.

Aid to Live Venues -- Provides $15 billion for grants to small live venue operators, theatrical producers, museums, and independent movie theaters that meet SBA size requirements and have experienced a 25% reduction in revenues.

Farmers & Fisheries -- Provides $11.2 billion for support to farms and other agricultural producers, distributors, and processing facilities affected by the COVID-19 pandemic; and separately provides $400 million to support dairy producers, $100 million for specialty crops, almost $360 million for a variety of other farm and food activities, and $300 million for aid to fisheries businesses and communities.

The measure provides $9 billion for Treasury to invest in community development financial institutions (CDFIs) and minority-owned depository institution (MDIs) that provide loans and grants to mostly small, minority-owned businesses, as well as $3 billion for grants and other aid to CDFIs to support economic recovery efforts in local communities.

Community Support

The agreement provides funds to state and local governments and to various private entities to help address the economic damage caused by the coronavirus pandemic -- including $82 billion to help schools, students, teachers and families with immediate needs related to the pandemic, including to help return to in-class instruction.

It provides $10 billion for grants to child care providers; $14 billion to help maintain public transit operations; $1 billion to cover Amtrak losses; $10 billion to replace lost revenues by state and local highway agencies; $16 billion for aid to aviation companies to maintain payroll and employee benefits; $2 billion to support airport operations and businesses; and $2 billion for other U.S. transportation providers (including motorcoaches).

It also provides $7 billion for a variety of broadband internet activities -- including to help expand broadband deployment; to help low-income families pay for home internet service; and to remove Chinese equipment currently being used by wireless internet companies.

Health Care, Testing & Vaccine Distribution

The agreement appropriates some $63 billion for the Health and Human Services Department (HHS) to support various pandemic-related public health activities -- including research, development, manufacturing and distribution of vaccines and therapeutics; diagnostic testing and contact tracing; and other coronavirus activities.

The total includes $20 billion for the Biomedical Advanced Research and Development Authority (BARDA) for the manufacturing and procurement of vaccines and therapeutics; $8.75 billion for the CDC to support public health agencies in distributing, administering and tracking coronavirus vaccinations to ensure broad-based distribution and access; $25.4 billion for virus testing and contact tracing and to reimburse eligible health care providers; $3.3 billion for the Strategic National Stockpile; $1.25 billion for NIH research and clinical trials on the long-term effects of COVID-19 and the continued development of more rapid diagnostics; and $4.25 billion to address mental health and substance abuse issues associated with the pandemic.

Other Legislation

The agreement includes a wide variety of major authorizations and other legislation that was added to the year-end omnibus package. CBO and JCT estimate that the additional provisions combined will increase the deficit by $175 billion over 10 years.

Surprise Medical Billing

To shield patients from surprise medical bills, the measure establishes a series of protections that limit patient out-of-network costs to the same amount they would pay for in-network care in cases where patients have no choice, and that provide patients with advance information about the cost of the care if they choose an out-of-network provider. Under the measure, unless the patient is notified of the out-of-network costs and consents to them, health care providers are prohibited from billing the patient for the balance not covered by insurance. It also establishes a process for health insurance plans and health care providers and facilities to determine how much the plans will pay providers and facilities for out-of-network services provided, requiring negotiations and subsequent binding arbitration if needed.

Tax Extenders

The agreement extends almost 40 different temporary tax provisions -- with some being made permanent, some extended for five or two years, and some just for a single year.

Tax provisions made permanent include those that allow all people, regardless of age, to deduct qualified unreimbursed medical care expenses that exceed 7.5% of adjusted gross income, and the reduced federal excise tax rate and simplified recordkeeping requirements for small craft brewers, wineries and distilleries first enacted as part of the 2017 tax law. Five-year extensions include a provision that allows individuals to exclude from gross income any debt forgiveness attributable to the sale of a primary residence whose mortgage was "underwater." One-year extensions include production tax credits for onshore wind power and the energy efficient home construction credit.

The measure also includes numerous other tax provisions, many intended to help provide pandemic-related relief. Those include extending a CARES Act provision that allows individuals to deduct up to $300 in cash contributions to churches and other charitable organizations, regardless of whether they itemize deductions, and making the full cost of meals a deductible business expense for two years. It also includes a number of tax provisions to help individuals and businesses in presidentially declared disaster zones.

Health Care Extenders & Other Health Provisions

The measure extends for roughly three years numerous federal health care programs administered by the Health and Human Services Department (HHS), including public health programs and Medicare and Medicaid programs, and it extends through FY 2021 current funding for the Temporary Assistance for Needy Families (TANF) and other related programs. It eliminates through FY 2023 scheduled reductions to Medicaid Disproportionate Share Hospital (DSH) payments, but provides for greater reductions in FY 2026 and FY 2027.

It also authorizes a campaign to increase awareness and knowledge regarding vaccines and to combat vaccine misinformation; includes numerous provisions to improve health care transparency (including by banning gag clauses between providers and health plans so that enrollees, plan sponsors and referring providers can access cost and quality data on health care providers); and seeks to expand access to health care (including by eliminating patient cost-sharing requirements for Medicare beneficiaries with respect to colorectal cancer screening tests where a polyp is detected and removed).

Major Authorizations

The agreement includes a number of major authorization bills, including the following:

Aircraft Certification Reform -- Modifies the FAA's aircraft safety and certification process, in particular the authority of aircraft manufacturers such as Boeing to approve and certify parts of their own aircraft, limiting what can be delegated to a manufacturer to certify. It authorizes funding over five years for the FAA to improve the safety and oversight of its certification system and to recruit and retain engineers, safety inspectors and other FAA employees tasked with overseeing safety. It also strengthens whistleblower protections with regard to the reporting of safety issues or violations, and imposes fines for manufacturers who fail to disclose all critical safety information related to an aircraft.

Water Resources Development Act (WRDA) -- Authorizes new water projects for construction by the Corps of Engineers and modifies the budgetary treatment of spending from the Harbor Maintenance Trust Fund so certain amounts are not counted against annual spending caps. It also increases the share of inland waterway construction project funding that will come from the general fund of the Treasury, with funding from the Inland Waterways Trust Fund to be reduced accordingly, and creates a new process to deauthorize previously authorized projects.

Pipelines & Hazardous Materials -- Reauthorizes the Pipeline and Hazardous Materials Safety Administration (PHMSA) through FY 2023. It increases the required number of full-time employees with pipeline subject matter expertise to finalize outstanding rulemakings, and provides recruitment and retention incentives. Rules to be finalized include those that address drug and alcohol testing for operators and pipeline contractors who work for multiple operators in multiple states, and that require operators of gas distribution pipelines to conduct leak detection and repair programs to meet gas pipeline safety standards and protect the environment.

Intelligence Authorization -- Authorizes classified amounts in FY 2021 for U.S. intelligence agencies and intelligence-related activities of the U.S. government for general intelligence operations (including signals intelligence), clandestine human intelligence programs and analysis, and covert action programs, as well as research and development and projects to improve information dissemination. It includes provisions to strengthen cyber defenses, protect supply chains, and provide additional resources and capabilities for responding to cyber-attacks, and prioritizes the collection and analytic capabilities against both China and Russia.

Other Provisions

The agreement includes numerous provisions to promote the development of clean and renewable energy over the next five years by authorizing various Energy Department programs and activities -- including the development of wind, solar, hydropower, geothermal, marine and other clean energy sources, the development of carbon capture and greenhouse gas reduction technologies, and initiatives that will increase energy efficiency and improve and modernize the nation's electric grid.

It also includes numerous other provisions, including those that do the following:

USMCA Corrections -- Makes technical corrections to the United States-Mexico-Canada Agreement (USMCA) to ensure the trade deal reflects the intentions of Congress and the three signatory nations, including by restoring NAFTA treatment to Foreign Trade Zones (FTZs) by the border.

Immigration & Border Provisions -- Extends several visa programs, including for physicians serving in underserved areas, and includes several border provisions such as extension of the U.S. Customs and Border Protection's entry donation program under which the agency accepts private donations to improve or expand inspection facilities at U.S. border crossings.

Foster Care -- Bolsters state foster care programs by providing additional funding and waiving state matching requirements for transitional programs, and seeks to prevent children from becoming homeless by prohibiting states from forcing a child to leave foster care solely because they reached the age of 18 and by allowing individuals that recently left foster care to voluntarily return.

Higher Education / FAFSA -- Simplifies the Free Application for Federal Student Aid (FAFSA) used to help determine eligibility for student aid and streamlines the financial data verification process by using data from the IRS; increases the availability of federal student loans to certain students; and expands eligibility for the Pell Grant program.

Miners' Health Benefits -- Authorizes the Treasury Department to transfer general revenue monies to multiemployer health benefits plans run by the United Mine Workers of America to cover retirees who would lose their health benefits due to future bankruptcies by coal mine operators.

E-Cigarette Online Sales -- Requires purchasers of any "electronic nicotine delivery system" to verify their age at the time of delivery, in order to make it harder for minors to purchase e-cigarettes online (except for FDA-approved tobacco cessation products), and prohibits the delivery by U.S. mail of e-cigarettes.

U.S. Foreign Relations -- Restores the government of Sudan's sovereign immunity from civil suits related to terrorism in U.S. courts and guarantees compensation to victims of the 1998 East Africa embassy bombings through the Victims of State Sponsored Terrorism Fund. It also includes provisions addressing policy with respect various other nations, including Taiwan, Tibet, Belarus, Mexico, and Central American nations.

References: "Covid Relief" & "Other Legislation" Sections:

Karin Fuog ([email protected]) -- unemployment insurance, tax rebates, health care, surprise billing, tax extenders, health care extenders, WRDA, PHMSA

Daniel Peake ([email protected]) -- USPS, broadband, funeral expenses, energy, immigration, Smithsonian, government operations, REAL ID, telecom

Robert Tomkin ([email protected]) -- education, child care, transportation, intelligence, trade

Greg Tourial ([email protected]) -- small business, Paycheck Protection Program, agricultural assistance, housing & rental assistance, community development, Federal Reserve, financial services, housing

By Greg Tourial [email protected]

Section II

Agriculture

This section describes the provisions of the agreement on HR 133, Consolidated FY 2021 Appropriations Act, that provide full-year funding for the Agriculture Department, the Food and Drug Administration, and related federal agencies.

The agreement provides $23.4 billion in net discretionary spending subject to budget caps according to appropriators, $217 million more than FY 2020 and $3.7 billion more than requested. Factoring out rescissions and other provisions that reduce scored discretionary spending, and adding in the mandatory funding provided for a variety of nutrition and farm programs, the measure actually provides a total of $208.9 billion for FY 2021 -- $52.1 billion (33%) more than FY 2020.

It increases funding for farm and conservation programs by 11%, while it provides slightly less than FY 2020 levels for agricultural programs such as research, marketing, and food inspections (although it increases funding for both animal and plant health inspections and safety inspections by 2%). It also provides slightly less for rural development programs.

It provides $145.7 billion for domestic food programs (49% more than FY 2020), including $114.0 billion in mandatory spending for the Supplemental Nutrition Assistance Program (SNAP; formerly known as food stamps), $25.1 billion in mandatory spending for child nutrition programs, and $6.0 billion in discretionary funds for the Special Supplemental Nutrition Program for Women, Infants and Children (WIC), as well as $2.2 billion for international food assistance programs.

Finally, it increases total funding for the Food and Drug Administration by 2%.

Agriculture, Farm Production & Conservation Programs

The agreement provides $43.4 billion for USDA farm and agriculture support programs, including mandatory funds to reimburse federal crop insurance and Commodity Credit Corporation (CCC) activities, as well as land conservation programs. The total is 11% more than FY 2020.

Within the total, $292 million is provided for the Farm Production and Conservation Business Center, a centralized operations office that provides administrative support to USDA component agencies and programs in this mission area. That amount includes almost $61 million transferred from the CCC and certain other programs.

Corporations / Federal Crop Insurance

The Commodity Credit Corporation is a government-owned entity, managed by a board of directors, that funds most major commodity support programs through the Farm Service Agency, including marketing assistance loans, loan deficiency payments and fixed (direct) payments to farmers. The CCC is authorized each year to receive appropriations to reimburse "net realized losses," or any losses that the corporation cannot offset. The amounts needed to reimburse the CCC vary widely from year to year, depending on crop market prices and other factors.

The measure provides $31.8 billion for the CCC, 21% more than FY 2020, to reimburse the CCC for expenditures incurred in previous fiscal years to finance farm price supports, export promotion, disposition of surplus commodities and other programs.

The Federal Crop Insurance Corporation is a government-owned entity, managed by the Agriculture Department's Risk Management Agency, that provides crop insurance protection to farmers and other agricultural entities. The agreement provides $8.7 billion for the Federal Crop Insurance Fund, 12% less than FY 2020 to carry out the federal crop insurance program. It also appropriates $60 million for the Risk Management Agency to administer the federal crop insurance program.

Farm Service Agency

The Farm Service Agency (FSA) administers the major commodity programs financed by the CCC, the Conservation Reserve Program and several loan programs, including farm-operating and farm ownership loans. The agreement provides a total of $1.4 billion for FSA salaries and expenses, including a direct appropriation of $1.1 billion and $294 million in transfers from programs administered by the agency.

Farm Loans

The Farm Service Agency, using the Agricultural Credit Insurance Fund, offers a variety of loans to farmers, including farm-operating, farm ownership, American Indian tribal land acquisition and boll weevil eradication loans. The measure provides $307 million for ACIF administrative expenses, of which $294 million of this amount is transferred to the FSA.

The agreement appropriates $68 million in up-front subsidies (23% less than FY 2020) to support an overall loan level of $9.9 billion -- 17% more than FY 2020. The vast majority (97%) of the overall loan level for FY 2021 would go toward farm ownership loans that help farmers acquire, enlarge or develop their lands, and farm-operating loans which help pay for essential expenses such as the purchase of livestock, equipment and seed.

Specifically, the measure sets a total loan level of $3.8 billion for farm-operating loans, including $2.1 billion in unsubsidized loan guarantees ($158 million more than FY 2020) and $1.6 billion in direct loans ($83 million more). For farm ownership loans, the loan level is set at $5.8 billion -- including $2.5 billion in direct loans and $3.3 billion in loan guarantees.

The measure maintains FY 2020 loan levels for Indian tribe land acquisition ($20 million), guaranteed conservation loans ($150 million), boll weevil eradication ($60 million), and emergency loans ($38 million). It also sets a $34 million loan limit for a relending program established in the 2018 Farm Bill (PL 115-334) that provides loans to intermediary lenders to help resolve ownership and succession on farmland with multiple owners, and it authorizes a $5 million loan limit for a program that assists Indian tribes and tribal members obtain loans to purchase fractionated land titles.

Conservation Programs

The Agriculture Department administers a number of conservation programs that help private landowners reduce erosion, improve soil and water quality and quantity, improve and conserve wetlands, and enhance fish and wildlife habitat. Most of these programs receive mandatory funding through the Commodity Credit Corporation (CCC).

The measure provides $1.0 billion for discretionary programs and activities, slightly more than FY 2020 levels. The total includes $832 million for core private lands conservation activities, $175 million for the watershed flood and prevention program, and $10 million for the watershed rehabilitation program.

Agricultural Research, Inspections, and Marketing

The agreement provides a total of $7.5 billion for Agriculture Department farm inspection and food safety activities, farming and agricultural research and education, agricultural marketing and departmental administration.

Safety & Inspection Activities

Animal & Plant Health Inspection Service

The Animal and Plant Health Inspection Service (APHIS) conducts inspection and quarantine activities to protect animals and plants from diseases and pests. The agreement provides $1.1 billion for APHIS operations -- 2% more than FY 2020. Within the APHIS total, the measure provides $366 million for animal health activities, $363 million for plant health, $133 million for wildlife services, $35 million for regulatory services, $42 million for emergency management, $40 million for safe trade, and $34 million for animal welfare. Appropriators note that the agreement provides increased funding for programs to combat antimicrobial resistance, chronic wasting disease, cotton pests, and specialty crop pests.

In addition, the measure provides $635 million in emergency funding for APHIS agricultural quarantine and inspections. While USDA customs inspections of imported crops and livestock is normally funded by user fees, disruptions to trade as a result of the COVID-19 pandemic has left this fund nearly depleted.

Food Safety & Inspection Service

The agreement provides $1.1 billion -- 2% more than FY 2020 -- for the Food Safety and Inspection Service, which enforces laws requiring meat and poultry products to be wholesome, unadulterated and properly packaged and labeled. Appropriators say this funding level will support additional inspections at more than 6,400 processing facilities across the country.

Agricultural Research & Education

The agreement provides almost $3.3 billion for agricultural research and education activities, $125 million more than FY 2020 according to House appropriators.

Agricultural Research Service

The Agricultural Research Service (ARS) conducts basic and applied research in a number of fields, including animal, plant, soil, water and air sciences; entomology; agricultural engineering; nutrition; consumer use; marketing; and eradication of narcotic-producing plants.

The agreement provides $1.5 billion for ARS operations and expenses -- 5.5% more than FY 2020. It provides another $36 million for ARS buildings and facilities, 81% less than FY 2020, when additional amounts were provided to address maintenance backlogs at ARS facilities.

National Institute of Food & Agriculture

The measure appropriates $1.6 billion for the National Institute of Food and Agriculture (NIFA) -- 3% more than FY 2020. The institute works in partnership with universities to advance research, extension activities and higher education in the food, agricultural, human and environmental sciences. Extension activities refer to Agriculture Department instructions, demonstrations and publications relating to agricultural practices and home economics, and other education activities in communities.

Within the total, it provides $993 million for NIFA's research and education activities, including: $435 million for the agriculture and food research initiative; $259 million for the Hatch grant program; $73 million for research, $26 million for grants, and $10 million for scholarships at 1890 institutions; $36 million for the McIntyre-Stennis Cooperative Forestry Act; and $40 million for sustainable agriculture research and education. For NIFA extension activities, it provides $538 million --2% more than FY 2020.

In addition, the measure separately provides $10 million for NIFA to support NIFA centers of excellence at partner colleges and universities; $2 million to establish an Agriculture Business Innovation Center at a qualifying historically black college or university; and $5 million for a pilot program to provide grants to nonprofit organizations for programs that create farming and ranching opportunities for veterans.

Other Research Agencies

The agreement provides $184 million for the National Agricultural Statistics Service, which conducts hundreds of surveys every year and prepares reports covering virtually every aspect of U.S. agriculture, and $85 million to the Economic Research Service (ERS), which conducts research programs to inform public and private decision-making on economic and policy issues involving food, farming, natural resources and rural development.

Marketing

The Agricultural Marketing Service (AMS) administers programs that promote the domestic and international marketing of U.S.-grown crops and commodities, including cotton, tobacco, poultry, dairy, fruits and vegetables, and livestock. The agreement provides $1.7 billion for the agency -- 3% less than FY 2020, including $188 million for marketing services and $61 million for administrative expenses, to be fully offset by collected fees.

The total also includes $1.4 billion in so-called Section 32 funds, which are derived from the previous year's customs duties and used by USDA for programs to support agricultural producers by purchasing surplus commodities. Of the total, $485 million is allocated to purchase commodities for school lunch programs; $389 million is for fresh fruits and vegetables (Another $21.3 billion from the Section 32 account is transferred to the Food and Nutrition Services for Child Nutrition Programs).

Department Administration

For Agriculture Department administration, the measure appropriates $480 million -- 2% more than FY 2020 -- including $47 million for the Office of the Secretary; $67 million for the chief information officer, of which $56 million is for cybersecurity; $45 million for the office of general counsel; and $23 million for the Civil Rights Office.

The total also includes $46 million to begin relocating USDA employees out of the Goodfellow Federal Center in St. Louis, due to environmental hazards at the site.

Rural Housing & Development

The Agriculture Department administers a number of loan and grant programs to provide assistance in rural areas for single and multifamily housing, community facilities and infrastructure, and business development. The agreement provides $3.2 billion for the department's rural development activities (slightly less than FY 2020 levels), of which $714 million is for salaries and expenses, including a direct appropriations of $264 million (the remainder is provider via transfer from other rural development accounts).

The measure also authorizes a $38.1 billion overall loan level for various rural development loans -- slightly more than FY 2020.

Rural Housing Service

The Agriculture Department's Rural Housing Service helps rural residents and communities by providing loans to construct, repair or improve affordable housing and farm facilities, as well as rental assistance to help low-income families. The measure appropriates a total of $2.1 billion for the Rural Housing Service (1% more than FY 2020). The funding supports a total loan level of $28.6 billion (equal to FY 2020).

Within that total, it provides $70 million as the up-front credit subsidy to support $25.3 billion in loans for the Rural Housing Insurance Fund -- including $25.0 billion in loans for single-family homes. It provides for $230 million in multifamily housing loan guarantees, $40 million in rental housing loans, $28 million in housing repair loans, and $28 million for farm labor housing loans.

It also provides an up-front credit subsidy to support $3.3 billion in direct community facility loans and loan guarantees, and it provides funding for rural housing grants -- including farm labor housing grants ($10 million), rural housing assistance grants ($45 million), mutual and self-help housing grants ($31 million), community facility grants ($32 million), and payments for the multifamily housing revitalization program ($28 million).

Finally, the measure includes $1.4 billion for the Rental Assistance Program, under which payments are made to the owners of rental housing to cover the difference between the tenant's payment and the approved rental rate established for the unit, and $40 million for rural housing vouchers.

Rural Business-Cooperative Service

The Rural Business-Cooperative Service provides loans to businesses and cooperatives located in rural communities. The measure appropriates $97 million for grants and the up-front credit subsidy to support up to $1.1 billion in loans from the Rural Business-Cooperative Service.

Of that total, up to $1 million in guaranteed business and industry loans could be made under the Rural Business Program, while the Rural Business Program could also issue $37 million in rural business development grants. Other loan levels include $50 million under the Rural Economic Development Loans program, $19 million under the Intermediary Relending Program Fund (which aims to improve economic conditions and create jobs in rural communities by providing 1% low-interest loans to local intermediaries that re-lend to businesses), and $20 million under the Rural Energy for America Program.

Separately, the measure provides $2 million for a pilot program to help rural hospitals improve their operations.

Rural Utilities Service

The Rural Utilities Service (RUS) provides funding and support services for electric, telephone, water and waste utilities in rural communities. The agreement provides for a loan level of up to $8.4 billion (a slight increase from FY 2020), and it appropriates $754 million for loan subsidies and grants that may be provided to rural communities (4% less than FY 2020). (However, it separately provides $635 million for a broadband financing pilot program authorized in 2018; see below.)

For rural water and waste disposal infrastructure, the measure supports up to $1.4 billion in direct loans and $50 million in loan guarantees, both equal to FY 2020. It appropriates $621 million for water grants and assistance -- including $463 million for rural community water and waste disposal grants and $35 million for water and waste system technical assistance.

For Rural Electrification and Telecommunications programs, the agreement authorizes a loan level of up to $6.3 billion (equal to FY 2020) -- including $5.5 billion in direct loans for electric projects and $750 million in guaranteed underwriting, as well as $690 million in subsidized loans for telecommunications projects. Separately, the agreement appropriates an additional $11 million for the Rural Energy Savings Program, which provides loans for energy efficiency improvements of rural homes and businesses, and $10 million for a USDA pilot program to fund renewable energy projects in rural areas.

For the Rural Broadband Program, it appropriates $2 million to support up to $12 million in direct loans. It also provides $35 million for rural broadband grants and $60 million for grants to improve access to telemedicine and distance learning in rural areas. (The agreement rescinds $12 million in prior year unobligated funds for telemedicine and distance learning to offset new appropriations).

Separately, the agreement provides an additional $635 million for the RUS ReConnect program, a pilot program created in 2018 that provides loans and grant funding to assist states, local and tribal governments, nonprofit corporations, or private companies deploy or upgrade broadband infrastructure in rural areas lacking access to adequate service. The total includes $531 million in direct appropriations and $104 million from the RUS revolving electrification fund.

Food & Nutrition Programs

The agreement funds the Agriculture Department's domestic food assistance and nutrition programs, as well as international food aid programs. Additional SNAP funding and other emergency food assistance is provided within the COVID-19 relief section of the agreement.

Domestic Food Programs

The measure provides a total of $145.7 billion for domestic food assistance programs, including the Supplemental Nutrition Assistance Program (SNAP, previously known as food stamps), the school lunch and breakfast programs, and the Special Supplemental Nutrition Program for Women, Infants and Children (WIC).

Overall funding for these programs, which are primarily mandatory funding (only WIC is discretionary), is $47.7 billion (49%) more than FY 2020.

Supplemental Nutrition Assistance Program

SNAP helps low-income people and families purchase food by means of electronic cards or paper vouchers that can be used in retail stores. The federal government pays for 50% of the administrative costs, with state governments covering the other half. The Agriculture Department estimates that at the end of 2019 there were 37 million people enrolled in SNAP, at an average cost of $121 per person per month. Although exact data is not yet available, a slowed economy brought on by COVID-19 job losses has led to an estimated 43 million people now enrolled in SNAP. In fiscal 2020, SNAP, formerly known as the food stamp program, received $67.8 billion. The Trump administration's fiscal 2021 request for the program called for $180 billion in cuts over 10 years.

The agreement provides a total of $114 billion in mandatory funding for SNAP, or 40% more than FY 2020. House Democrats say this increase will cover the enhanced allotments authorized by the Families First Coronavirus Response Act (PL 116-127).

The funding total includes $101.8 billion in SNAP benefits, $3 billion in contingency funding, and $6.7 billion in administrative costs. It also includes $2.0 billion in funding for Puerto Rico's Nutrition Assistance Programs, as well as funding for includes nutrition assistance for American Samoa, the Northern Mariana Islands, and Indian Reservations.

Child Nutrition Programs

The measure appropriates $25.1 billion -- 6% more than FY 2020 -- in mandatory funding for various child nutrition programs that provide nutritious foods to preschool children and children in elementary and secondary schools.

The largest accounts within the total are $13.5 billion for the school lunch program, $5.0 billion for the school breakfast program, and $4.0 billion for the child- and adult-care food program. The total also includes $42 million for demonstration projects to develop methods of providing access to food for children during the summer when schools are not in session and $30 million for grants to school districts to purchase school cafeteria equipment.

Separately, it provides one-time appropriations of $12 million for grants and technical assistance to implement "farm to school" programs that improve access to local foods in eligible schools, and $6 million for School Breakfast Program Expansion grants, which assist low-income schools to expand their school breakfast programs.

Women, Infants & Children

The Special Supplemental Nutrition Program for Women, Infants and Children (WIC) provides assistance to children up to 5 years of age and to pregnant, postpartum and breast-feeding women who are nutritionally at risk because of inadequate nutrition and income. WIC provides them with food packages containing nutritional supplements that are typically lacking in eligible participants' diets. Food packages are provided through health clinics, redeemable vouchers at retail food stores and other approved methods.

The agreement provides $6.0 billion in discretionary funding for WIC -- equal to FY 2020 levels. The total includes $90 million for breastfeeding support counseling and $14 million for infrastructure.

Finally, the measure rescinds $1.3 billion in unobligated prior year WIC funding, which is used to offset spending elsewhere in the agreement.

Commodity Assistance Program & Administrative Funding

The measure appropriates $427 million for Commodity Assistance Programs (19% more than FY 2020), which provide foods purchased by the USDA to vulnerable populations. This total includes $325 million for the Commodity Supplemental Food Program (which provides assistance to senior citizens), $80 million for the Emergency Food Assistance Program (which provides foods to food banks and other nonprofit groups), and $21 million for the Farmers Market Nutrition Program.

It also provides $156 million for the administration of nutrition programs.

Foreign Aid/Commodity Export Programs

The agreement rejects administration proposals to eliminate the Food for Peace and McGovern-Dole programs, instead appropriating $2.2 billion for USDA foreign food aid and related programs -- 1.5% more than FY 2020.

The department's international programs are administered by the Foreign Agricultural Service (FAS), which helps maintain and expand foreign markets for U.S. agricultural products by analyzing foreign production, markets and policies. The agency also is responsible for developing special export programs and trying to secure international trade conditions that are favorable to U.S. products. The agreement provides $222 million for FAS salaries and expenses.

The measure appropriates $1.7 billion for Title II of the Food for Peace Program (also known as PL 480), which provides surplus agriculture commodities to developing nations (Title I of the program provides commodities on credit terms, while Title II provides free commodities to foreign governments to combat malnutrition and meet other emergency requirements).

The measure also provides $230 million for the McGovern-Dole International Food for Education and Child Nutrition Program, which provides donations of U.S. agricultural products, as well as financial and technical assistance, for school feeding and maternal and child nutrition projects in low-income, food-deficit countries that are committed to universal education.

Independent Agencies

The agreement also funds certain independent agencies, including the U.S. Food and Drug Administration and the Farm Credit Administration (FCA).

Food & Drug Administration

The Food and Drug Administration (FDA), which is in the Health and Human Services Department, regulates food, cosmetics, human and animal drugs, and medical devices. Funding for the FDA includes both direct appropriations and funding from user fees.

The agreement provides the FDA with a direct appropriation of $3.2 billion and it assumes $2.8 billion in user fees -- thereby providing the FDA with a total of nearly $6.0 billion in funding for operations in FY 2021 (2% more than FY 2020). According to appropriators, the agreement provides $9 million to improve the cybersecurity of medical devices and $5 million for efforts to develop coherent a regulatory framework from legal cannabis-derived substances, including CBD. The agreement also directs the FDA to develop a plan to identify and block imports from foreign countries that don't allow access to FDA inspectors.

Separately, the agreement provides $13 million for FDA buildings and facilities.

Farm Credit Administration

The measure imposes a limitation of $80 million on the expenses of the Farm Credit Administration, which provides credit and related services for all creditworthy and eligible persons in agriculture and rural America.

Other Provisions

The agreement provides almost $63 million for certain USDA offices, programs, and initiatives that were authorized or modified by the 2018 Farm Bill (PL 115-334), including:

Dairy -- $22 million for grants to promote innovations in the dairy sector and $1 million for a program to help make dairy products available to recipients of SNAP benefits.

Socially Disadvantaged Farmers -- $5 million to provide outreach and training to socially disadvantaged farmers and ranchers, veteran farmers

and ranchers, and beginning farmers and ranchers.

Urban Farming -- $7 million for the Office of Urban Agriculture and Innovative Production to encourage and promote urban, indoor, and other emerging agricultural practices.

Hemp -- Includes language to ensure that industrial hemp can be transported, processed, sold and used within and outside the United States, and it extends through the end of calendar department's industrial hemp marketing pilot program, first authorized by the 2018 Farm Bill, through the end of calendar year 2021.

Finally, the measure prohibits the USDA from modifying the formula for determining "persistent poverty counties," when awarding rural development funds (10% of funds must be allocated to counties where at least 20% or more of its population has been living in poverty for the past 30 years, as defined in the census, i.e. the 10-20-30 rule).

<p> By Greg Tourial [email protected]

Section III

Commerce-Justice-Science

This section describes the provisions of HR 133, Consolidated FY 2021 Appropriations Act, that provide funding for the Commerce and Justice departments and federal science agencies.

The agreement provides a net total of $71.1 billion in discretionary spending subject to caps and $604 million in emergency spending, for a total of $71.7 billion in scored discretionary spending. According to Senate appropriators, the net capped spending is $2.05 billion less than FY 2020 (reflecting the completion of the Decennial Census) but $2.2 billion more than requested.

On a programmatic basis, factoring out rescissions and providing funding through other adjustments (such as by limiting spending from the Crime Victims Fund to offset appropriations), the measure actually provides a total of $76.1 billion for FY 2021 -- including mandatory spending for the fees and expenses of federal witnesses, death benefits for law enforcement officers, and certain federal employee benefits contributions.

It increases funding for the Justice Department by 4% and provides increases for most law enforcement agencies, including a 4% increase in assistance for state and local law enforcement. The total includes $25 million spread across various accounts to support investigations into police misconduct, with an additional $5 million to establish a database to track officer misconduct.

It provides 41% less funding for the Commerce Department, although this is largely due to the decrease in funding for the Census Bureau following the completion of the 2020 Census (without the Census Bureau, funding for the rest of the Commerce Department is increased by 2.5%). It increases funding for NOAA by 2%, including additional funds for climate research and weather satellites.

Finally, it provides a 3% increase in funding for NASA and a 2.5% increase in funding for the National Science Foundation.

Justice Department

The measure provides a net total of $33.8 billion for the Justice Department and its component agencies -- 4% more than comparable FY 2020 funding. Within the total, $389 million is counted as mandatory spending; the remaining $33.4 billion is discretionary. It also rescinds $410 million in prior year unobligated funds from the Justice Department, including $188 million from the DOJ working capital fund, $142 million from state and local law enforcement programs, and $80 million from the FBI.

The total includes $119 million for departmental administration, $111 million for the department inspector general, and $34 million for Justice Information Sharing Technology programs that allow the department to coordinate IT infrastructure investments.

In the wake of national protests last summer following the death of George Floyd, a Black man killed while in police custody, the agreement includes a number of provisions to address police misconduct. Across the Justice Department, $25 million is allocated for investigations of patterns or practice of misconduct by state and local police departments, and to take enforcement actions as necessary ($10 million within the funding for the Civil Rights Division, $10 million in the U.S. Attorneys Offices account, and $5 million within the FBI total).

The agreement also directs the Justice Department to allocate up to $5 million from various department accounts to establish a task force on law enforcement oversight to coordinate the detection and referral of complaints related to alleged law enforcement misconduct, while another $5 million is directly appropriated to create a federal database to track excessive use of force complaints and other officer misconduct.

The agreement directs the department to take the lead in developing de-escalation and use of force training for law enforcement agencies, and to recommend model guidelines and standards for law enforcement accreditation. The department is also directed to review its own use-of-force policies.

FBI

The agreement appropriates a total of $10.3 billion in base funding for the FBI, $361 million or 4% more than FY 2020 (separately, the measure appropriates $179 million in emergency funding for the FBI response to the COVID-19 pandemic).

For FBI salaries and expenses, the measure provides $9.7 billion or 3% more than FY 2020. Funding is provided for missions to counter terrorism, protect national security, and meet cyber threats -- as well as efforts to investigate public corruption, organized crime, financial crimes, and human trafficking. Of the salaries and expenses total, $5.8 billion is for FBI counterintelligence and national security activities. The measure provides $125 million FBI's National Instant Criminal Background Check System (NICS), and increases funding for grants to help states improve their submissions into the NICS system (see below).

The measure also provides $566 million for FBI construction -- 17% more than FY 2020 -- to support modernization of facilities and to allow the agency to address its highest priorities outside the national capital area. The agreement encourages the FBI to work with the General Services Administration to submit a prospectus to Congress for a new, fully-consolidated headquarters that complies with prior Congressional directives. (Construction of a new FBI headquarters in the Washington D.C. region has been delayed partly because of President Trump's desire to maintain the headquarters at its current site opposite the Trump Hotel on Pennsylvania Ave. in the District).

DOJ Legal Activities

For Justice Department legal activities, the measure provides $3.6 billion (4% more than FY 2020), including $2.3 billion for U.S. Attorneys offices (4% more than FY 2020).

The total includes $960 million for general legal activities, which provides funding for the department's Civil Division, Criminal Division, Civil Rights Division, Tax Division, Environment and Natural Resources Division, Office of the U.S. Solicitor General, and the Office of Legal Counsel. It also provides $185 million for the Justice Department Antitrust Division, of which $150 million is derived from offsetting fee collections, resulting in a net appropriation of $35 million.

The total also includes $270 million for fees and expenses of witnesses (treated as mandatory spending), $18 million for salaries and expenses of the Community Relations Service (13% more), $2 million for the Foreign Claims Settlement Commission, and $232 million for the United States Trustee System Fund (2% more), of which $360 million would be offset through fee collections for a net reduction in appropriation of $86 million. It provides $21 million from the DOJ Assets Forfeiture Fund to provide rewards to informants in federal drug cases, purchase evidence, or refit law enforcement vehicles; and it appropriates $17 million from the Vaccine Injury Compensation Trust Fund.

The agreement provides a total of $13.5 million for Justice Department activities under the 2016 Emmett Till Unsolved Civil Rights Crimes Reauthorization Act (PL 114-325), which allows DOJ and the FBI to review cold cases involving possible racially motivated homicides prior to 1980. Within the legal activities account, $5 million in Civil Rights Division funding and $1.5 million in Community Relations Service funding is allocated for these investigations. (Another $5 million is included within the FBI total, while the measure also provides $2 million for grants to state and local law enforcement agencies.)

Separately, outside the legal activities account, the measure provides $117 million for the department's National Security Division, 7% more than FY 2020.

DEA, ATF, and Other Law Enforcement

The measure provides $2.3 billion in net funding for activities of the Drug Enforcement Administration (DEA), 2% more than the FY 2020 level, while a separate $460 million derived from the diversion control fund would be available for DEA's Diversion Control Program to prevent controlled substances from being illegally diverted for illicit uses (thereby making a total of $2.8 billion available to the DEA for FY 2021). In addition to that amount, the agreement provides $50 million to construct a new DEA drug testing laboratory in the New England region.

The agreement provides $1.5 billion for the Bureau of Alcohol, Tobacco, Firearms and Explosives (ATF) -- 6% more than FY 2020. It continues to prohibit any functions, missions or activities of the ATF from being transferred to other federal agencies or departments. The measure includes language continuing to prohibit federal agents from facilitating the transfer of an operable firearm to any individual associated with a drug cartel (the so-called "Fast and Furious"provision).

The U.S. Marshals Service would receive $3.6 billion, 7% more than FY 2020. The amount includes $1.4 billion for salaries and expenses, $1.9 billion for federal prisoner detention, and $15 million for construction. The agreement separately appropriates $125 million in emergency funding for response to the COVID-19 pandemic.

The measure provides $7.8 billion for the Bureau of Prisons, slightly more than FY 2020. The vast majority of funds are for salaries and expenses, while $127 million is provided for buildings and facilities -- 59% less than FY 2020. Within the total, $409 million is allocated for activities authorized by the 2019 First Step Act (PL 115-391) to provide programming for incarcerated individuals aimed at reducing recidivism. A separate $300 million is provided to help the Federal Prison System respond to the COVID-19 pandemic.

Finally, the measure provides $550 million for Interagency Crime and Drug Enforcement activities (equal to FY 2020) and $14 million for the United States Parole Commission (2% more).

Immigration Judges

The agreement provides $734 million for administrative reviews and appeals of immigration cases by the Executive Office for Immigration Review (EOIR) -- 9% more than FY 2020. Of that amount, $4 million would be derived from fee collections for a net appropriation of $730 million.

Under the measure, $25 million within the total is available for the Legal Orientation Program, which provides information regarding the immigration court process to individuals facing possible deportation proceedings. The measure also directs EOIR to update its policy on video court proceedings to ensure that consistent guidelines are followed during the COVID-19 pandemic.

State and Local Law Enforcement

The agreement appropriates $3.0 billion for state and local law enforcement programs -- $107 million (4%) more than the FY 2020 level -- including $2.5 billion for the Office of Justice Programs (OJP)

Within the OJP total, $1.9 billion is appropriated for state and local law enforcement assistance grants and programs, including $394 million for anti-opioid abuse programs; $100 million for programs under the 2007 Second Chance Act (PL 110-199) to help state and local governments and nonprofit organizations reduce recidivism and improve outcomes for people returning from prison; $90 million for community trust initiatives to improve police-community relations (including $35 million for body cameras); $85 million for grants to states to upgrade criminal and mental health records for the FBI's National Instant Criminal Background Check System (NICS); $79 million for school violence prevention; $189 million for grants to assist state and local law enforcement reduce DNA and other forensic testing backlogs (including $48 million for programs to help communities reduce backlogs of untested sexual assault kits); and $8 million to help state and local law enforcement investigate and prosecute hate crimes and provide relevant training and outreach, with a separate $2 million for grants to state and local law enforcement to assist with the investigation and prosecution of racially motivated cold cases.

The OJP total also includes $346 million for juvenile justice programs and $82 million for research. It also includes $144 million in funding for public safety officer benefits, including $25 million for disability and education benefits (the remaining $119 million is for officer death benefits, which is counted as mandatory spending).

The $3.0 billion total for state and local law enforcement also includes the following:

Community Oriented Policing Services (COPS) -- $386 million, or 13% more than FY 2020 for the COPS program, which supports local community policing efforts. The total includes $237 million for hiring grants, $53 million for school safety programs, and $50 million for anti-drug task forces.

Office on Violence Against Women -- $513 million, or 14% more than FY 2020 (of which $435 million is provided by transfer from the Crime Victims Fund for a net appropriation of $79 million). The total provided includes $215 million for grants to combat violence against women, $41 million for victim services, and $40 million for grants to provide transitional housing assistance to victims of domestic violence or sexual assault.

Commerce Department

The measure provides a net total of $8.9 billion for the Commerce Department -- $6.3 billion (41%) less than comparable FY 2020 funding and $597 million more than requested. The large decrease in funding is largely due to the reduction in appropriations for the Census Bureau following completion of the 2020 Decennial Census. The agreement provides $128 million for departmental administration.

NOAA

The measure appropriates a total of $5.4 billion for the National Oceanic and Atmospheric Administration (NOAA), or 1.5% more than FY 2020 funding.

Most of those funds, $3.8 billion, are for NOAA operations, research and facilities (2% more than FY 2020). The measure provides an additional $246 million for operations funding for fisheries activities as a transfer from the Fishery Products and Research fund (financed by customs duties on seafood imports) and another $18 million is derived from prior year unobligated balances, for a total programmatic operations funding level of $4.1 billion.

That amount includes $1.1 billion for operations and activities of the National Weather Service (NWS); $620 million for the National Ocean Service; $965 million for the National Marine Fisheries Service; $571 million for the Office of Ocean and Atmospheric Research (OAR, including $182 million for climate research); $292 million for operation of NOAA's environmental satellite systems; and $254 million for marine and aircraft operations.

Within the National Ocean Service, the agreement provides $3.5 million increase for the coral reef program, $5.5 million in additional funds to combat harmful algal blooms, and a $2 million increase for research on sea level rise, according to House appropriators.

The agreement also provides $1.5 billion for NOAA procurement, acquisition and construction (including $13 million recovered from prior year funding), of which $1.2 billion is allocated for NOAA satellites and associated systems. House appropriators note this amount will fully fund efforts to procure future weather satellites essential for accurate forecasting.

Finally, the measure authorizes a loan limit of $124 million for the Fisheries Financial Program Account, which provides long-term financing for fishing vessels, fishery facilities, and other fishery related expenses. Because this program typically generates a net positive return for the federal government, it does not require appropriated funds. The Congressional Budget Office (CBO) estimates the loan limit established by this bill will generate $7.6 million in funding that can be used to offset appropriations elsewhere.

NIST

The measure appropriates $1.0 billion for the National Institute of Standards and Technology (NIST), a slight increase from FY 2020.

The total includes $788 million to support core NIST scientific and technical research and services, such as cybersecurity research and research on greenhouse gases. The agreement directs NIST to maintain at least FY 2020 funding levels for cybersecurity and Internet of Things research and to increase funding for research on artificial intelligence by $6.5 million.

It also provides $167 million for industrial technology services, which provide training and technical assistance to U.S. manufacturers -- including through the Manufacturing Extension Partnership (MEP) program -- and $80 million for construction of research facilities.

Census Bureau

The agreement appropriates $1.1 billion for the Census Bureau -- $6.5 billion or almost six times smaller than FY 2020.

The total includes $818 million for periodic censuses, though appropriators anticipate that prior year funds will be available for the bureau to continue work related to the 2020 Decennial Census for a total programmatic level of $1.6 billion in FY 2021. Within one year of enactment, the bureau must report to Congress on its operations during the 2020 Census.

The agreement provides another $288 million to the bureau for current surveys and programs.

ITA and Other Commerce Agencies

The measure provides $541 million for the International Trade Administration, of which $11 million would be derived from fee collections (for a net appropriation of $530 million, or 4% more than FY 2020). This includes $341 million for U.S. export promotion activities.

It also provides $133 million (4% more) for the Bureau of Industry and Security, the agency responsible for overseeing numerous U.S. export controls. Within the total for the ITA and BIS, up to $15 million is provided to process exemptions requests for aluminum and steel tariffs imposed by the Trump administration on U.S. importers.

The measure rejects the president's proposal to terminate the Economic Development Administration and its economic development assistance programs, instead providing $306 million (4% million more than FY 2020) for assistance programs and $346 million overall for the EDA. Within the total, $120 million would be provided for EDA's public works program, and $38 million in assistance to economically distressed regions.

The agreement provides the requested $3.7 billion for the Patent and Trademark Office (PTO), all of which would be offset through fee collections. The amount is 7% more than the FY 2020 level.

The agreement also provides the following:

Bureau of Economic and Statistical Analysis -- $112 million, 4% more.

NTIA -- $46 million for the National Telecommunications and Information Administration, 13% more.

Minority Business Development Agency -- $48 million, 14% more.

Science

The measure appropriates $31.8 billion for science-related agencies -- 3% more than the FY 2020 level.

NASA

The agreement provides $23.3 billion for NASA -- 4% more than FY 2020.

The total includes $6.6 billion for NASA's exploration account (9% more than FY 2020), including funding to support the Artemis manned lunar missions. This includes $1.4 billion for the development of the Orion capsule, $2.6 billion for launch systems, and $850 million for the development of lunar lander systems. The agreement also provides $4.0 billion for NASA space operations, including operation of the International Space Station (4% less), and $1.1 billion for space technology (equal to FY 2020).

The agreement includes $7.3 billion for NASA's science account (2% more than FY 2020). Within the account, Earth science would receive $2.0 billion, which Democratic appropriators say would enable better information about the Earth and its changing climate. That account also includes $2.7 billion for planetary science and $415 million for the James Webb Space Telescope.

It includes $2.9 billion for NASA safety, security and mission services (1% more than FY 2020); $829 million for NASA's aeronautics program (6% more); and $390 million for NASA construction and environmental compliance and restoration activities (5% more).

Finally, the measure rejects the administration's proposal to eliminate NASA's Science Technology Engineering and Math (STEM) programs, instead providing $127 million --6% more than FY 2020.

National Science Foundation and Other Science Agencies

The agreement appropriates $8.5 billion for the National Science Foundation (NSF) -- 2.5% more than FY 2020.

The vast majority of that total, $6.9 billion, is for NSF research and related activities. Of NSF research funding, $71 million is for defense research and $60 million for cybersecurity scholarship programs. The agreement directs NSF to expand its support research at minority-serving institutions, including Historically Black Colleges and Universities. It also directs the foundation to report to Congress on the recent collapse of the Arecibo radio telescope in Puerto Rico.

The measure provides $241 million for major research equipment and facilities construction; $968 million for education and human resources, and $345 million for agency operations and award management.

Finally, the agreement provides $5.5 million for the White House Office of Science and Technology Policy and $1.9 million for the National Space Council, both equal to FY 2020 levels.

Other Agencies

The agreement also appropriates funds for the following independent agencies:

Legal Services Corporation -- $465 million (6% more than FY 2020), to provide attorneys and legal aid to low-income people. The president proposed to terminate the LSC, and requested just $18 million to wind down its activities.

Equal Employment Opportunity Commission -- $404 million, 4% more).

International Trade Commission -- $103 million, 4% more.

Office of the U.S. Trade Representative -- $70 million (1% more) including $15 million appropriated from the Trade Enforcement Trust Fund.

Commission on Civil Rights -- $13 million, or 20% more than FY 2020. The commission, established by the Civil Rights Act of 1957, is an independent, bipartisan, fact-finding agency directed by eight part-time commissioners.

Marine Mammal Commission -- $4 million, 4% more than FY 2020.

State Justice Institute -- $7 million, or 7% more than FY 2020.

Other Provisions

The measure continues a requirement that federal agencies review the supply chain risk for secure and sensitive IT systems before acquiring such systems. It also requires agencies to develop a mitigation strategy for any identified risks and to conduct an assessment of any risk of cyber-espionage or sabotage associated with the system.

The measure includes the following policy restrictions:

Guantanamo Detainees -- Bars the use of funds to transfer detainees located at the U.S. Naval Station at Guantanamo Bay, Cuba, to the United States, or to build any facility in the United States to house such individuals.

Partnerships with China -- Forbids the Commerce Department, NASA, the National Science Foundation and the Office of Science and Technology Policy to engage in bilateral activities with China or a Chinese-owned company or effectuate the hosting of official Chinese visitors at certain facilities under most conditions.

Medical Marijuana -- Continues a provision that prohibits the Justice Department from using funds to prevent U.S. states and territories, including the District of Columbia, from implementing laws that authorize the use, distribution, possession, or cultivation of medical marijuana.

By Robert Tomkin [email protected]

Section IV

Defense

This section describes the provisions of HR 133, FY 2021 Omnibus Appropriations and Coronavirus Relief Act, that provide funding for programs and activities of the Defense Department.

The agreement provides a total of $696 billion in discretionary funding for the Defense Department for FY 2021 -- $2.6 billion more than FY 2020 but $2.1 billion less than the president's request. The total includes $627.3 billion in base spending subject to discretionary caps ($4.6 billion more than FY 2020 but $2.1 billion less than requested) and $68.7 billion in OCO funding ($2.0 billion less than FY 2020 and equal to the request).

Within the total (including OCO), it provides $251 billion for operation and maintenance (1% less than FY 2020), $162.4 billion for personnel (4% more than FY 2020), $142.9 billion for procurement (2% less), and $107.5 billion for research and development (2% more). It provides funding for the newly constituted Space Force and more than $10 billion for the Missile Defense Agency. It provides $9.6 billion for procurement of 96 new F-35 planes (17 aircraft more than requested) and $23.3 billion for major Navy ships ($3.4 billion more than requested).

The measure does not contain a House provision that would have required the Army to rename installations, facilities, roads and streets that bear the name of Confederate leaders and officers. President Trump vetoed the FY 2021 Defense Authorization partly because it contains a similar directive.

It also does not limit the transfer of military equipment to state and local law enforcement agencies under the Pentagon's so-called "1033" program, but instead directs the department to follow similar limits contained in the authorization, nor does it contain House provisions that would have prohibited the use of funds to construct a wall on the U.S. border with Mexico; barred funding for explosive nuclear weapons tests or limited the Defense Department's role in the development of nuclear weapons; or repealed the 2001 and 2002 Congressional authorizations for the use of force that have been used to justify U.S. military actions since 9/11 (PL 107-40 and PL 107-243).

Unless otherwise noted, funding levels for programs are for FY 2021, do not include advanced funding, and do not include additional funds provided in the OCO section of the agreement. (For more detailed description of all the programs summarized below, see House Action Reports Conference Summary No. 116-3, December 7, 2020, Defense Authorization for FY 2021.)

The House committee, in its report, noted that the department consistently does not comply with many of the reporting requirements contained in prior Defense Appropriations Acts, and that such reports are often submitted beyond the deadline or not at all -- which the committee said "reinforces the dismissive attitude" toward oversight exhibited by the department. It also stated that the department has repeatedly approached the expenditure of funding without regard to congressional intent or the purpose for which funding has been appropriated.

Noting that the department has benefitted from large budget increases since FY 2017, the committee noted that growth has been "accompanied by a decline in transparency and cooperation with Congress," stating that "when coupled with the department's disturbing actions over the past two years to fund the border wall, the contravention of the constitutional authority of the United States Congress has now become habitual." That, the committee said, is both "unacceptable and unsustainable."

Missile Defense

The agreement provides $10.5 billion for various missile defense programs within the Missile Defense Agency (MDA), including funding for Ground-Based Midcourse Defense (GMD), European missile defense and cooperative programs with Israel. The total is $1.3 billion more than the request, and includes $130 million to accelerate hypersonic defense programs and $133 million in unrequested funds for a new missile defense radar system for Hawaii.

The measure directs the MDA Director, within 30 days of enactment, to provide Congress with updated acquisition and spend plans for MDA's FY 2021 appropriations.

Terminal Defense/THAAD

The agreement appropriates $578 million for Terminal High Altitude Area Defense (THAAD) launchers and tooling and test equipment -- $83 million more than requested for an 8th THAAD battery. It also includes $150 million in unrequested funds for an extra ground based interceptor and $243 million in unrequested funds for associated radar.

THAAD is a rapidly deployable, ground-based missile defense system with the capability to defend against short- and medium-range ballistic missiles during their late midcourse and terminal phases. THAAD systems have been deployed to South Korea in response to North Korea's ballistic missile testing.

Aegis

The measure provides $877 million for research and development of the Aegis ballistic-missile defense system, and $538 million for Aegis procurement. It also includes $318 million ($100 million more than requested) for the SM-3 (Standard Missile) Block IIA interceptor, which is being co-developed with Japan.

Aegis is a mobile, deployable system that can destroy missiles both above and within the atmosphere and that can be forward-deployed. The sea-based program is both an integrated single-ship system and a ship-to-ship network and is meant to be the centerpiece of the new missile defense system proposed for Europe; under current plans, 41 specially equipped Aegis warships are supposed to be ready for ballistic-missile defense this year, including four in the Japanese Maritime Self-Defense Force.

Israeli Cooperative Programs

The measure appropriates the requested $500 million for cooperative missile defense programs with Israel, including $200 million for procurement and $300 million for research and development.

Israel, partly with financial help from the United States, has been developing one of the world's most advanced missile defense systems -- including variants of the "Arrow" long-range anti-missile system to counter conventional or chemical warheads from Iran; a short-range ballistic-missile defense against long-range artillery rockets and short-range cruise missiles ("David's Sling"); and the "Iron Dome" defense against short-range projectiles fired from the Gaza Strip and southern Lebanon.

Space Force

The FY 2020 Defense Authorization established a United States "Space Force" as a component within the Air Force Department, which like the Marine Corps within the Navy Department is led by a four-star commander.

Space Launches

The agreement provides $996 million ($47 million less than requested) for procurement within the National Security Space Launch (NSSL) program -- a competition to develop a new family of medium- and heavy-lift launchers to perform missions currently conducted by the Delta, Atlas, Titan 2 and Titan 4 rockets.

It also provides $551 million for research and development and directs the Air Force secretary to provide a detailed transition plan on how the Space Force intends to manage program and mission risks during the program's transition (it previously was the Evolved Expendable Launch Vehicle (EELV) program).

GPS

The Air Force is upgrading the 34 on-orbit satellites that constitute the worldwide Global Positioning System. The new GPS III satellites have redundant digital atomic clocks and military signals more resistant to jamming and spoofing from potential adversaries. The department also is trying to develop advanced microchips with accelerometers, clocks and other features that can provide GPS-like capabilities without access to the signals from the GPS system now in orbit.

The measure provides $598 million to procure two GPS IIIF spacecraft, and $779 million for research and development.

Next Generation Overhead Persistent Infrared

The Space Force is in the process of fielding its first defendable missile warning satellite system -- the Next Generation Overhead Persistent Infrared (OPIR) system -- using so-called Section 804 rapid acquisition authority that allows it to bypass certain steps in the acquisition process to field the system more quickly. The Air Force has budgeted $12.9 billion through 2025 for the program, which is designed to replace Space Based Infrared Systems (SBIRS) satellites and will be comprised of five missile-warning satellites in geosynchronous Earth orbit, including two in an orbit that passes over the Earth's poles.

The agreement provides the requested $2.3 billion for the program, and it directs the Cost Assessment and Program Evaluation director to provide the congressional defense committees with its most recent analyses and cost estimates for the program.

Aircraft

The agreement appropriates $43.6 billion for aircraft across the services, 4% more than the FY 2020 level.

The total includes $19.5 billion for Navy aircraft ($2.4 billion more than requested); $20.0 billion for Air Force planes ($1.3 billion more than requested); and $4.1 billion for Army aircraft ($383 million more). The totals include OCO funding.

F-35 Joint Strike Fighter

The agreement appropriates $9.6 billion for procurement of 96 new F-35 Joint Strike Fighters ($2 billion more than requested for 17 additional aircraft), as well as $1.7 billion for continued research and development on the aircraft.

The F-35 JSF is a multirole fighter aircraft that is supposed to be based on a common airframe and components for use by the Air Force, Navy and Marine Corps -- although the program has experienced numerous difficulties and is behind schedule and over budget.

The measure continues to prohibit the delivery of F-35 aircraft to Turkey, which was removed from the F-35 program because it acquired the Russian-made S-400 air defense system (which could enable Russian trainers to learn how to shoot down the F-35 if also flown by Turkey).

F/A-18 E/F Super Hornet

The agreement appropriates $1.7 billion for 24 new F/A-18E/F Super Hornet aircraft, and $953 million for modifications to existing planes.

The F/A-18E/F fighter is the Navy's main fighter aircraft and was supposed to end production in 2017. But because of production delays in the Navy's carrier-based F-35C, the Navy has continued to buy new Super Hornets.

Next-Generation Aircraft

The agreement appropriates the requested $2.8 billion for continued development of what is now called the Long-Range Strike-B (B-21) program, a stealth bomber capable of carrying nuclear weapons that could be flown by remote control.

It also provides $904 million to begin research and development of a next-generation fighter jet to replace the F-35 JSF after it ends production sometime around 2037.

Other Aircraft

The agreement also appropriates the following:

Aerial Refueling Tankers -- $2.7 billion for 15 new KC-46A Pegasus aircraft, which is the Air Force's next-generation aerial refueling aircraft and uses commercial, off-the-shelf Boeing 767-200 airliners modified for air refueling.

Presidential Aircraft -- $801 million to continue research and development of a new presidential aircraft to replace the current Air Force One by 2024, and $578 million for procurement of five new presidential helicopters.

P-8A Multimission Maritime Aircraft (Poseidon) -- $1.6 billion for nine unrequested Poseidon multimission maritime surveillance aircraft.

C-130 Hercules Transport -- $797 million for the procurement of eight unrequested C - 130J Hercules cargo aircraft for the reserves. The C-130 has been the military's primary cargo and personnel transport since 1956, with basic and specialized versions meant to perform many differing roles.

F-15E/X Fighter -- $1.2 billion for 12 new F-15EX fighter aircraft, the latest generation of F-15 aircraft which are mostly used by the Air National Guard.

V-22 Osprey -- $1.4 billion for 15 V-22 aircraft for the Navy and Air Force, six more than requested.

E-2D Hawkeye -- $786 million for five Navy E-2C Hawkeye aircraft, which provides long-range radar surveillance, command and control of fighter aircraft, communications relay and tactical data exchange. The total is $160 million more than requested for one additional plane.

Drones

Unmanned aerial vehicles (UAVs) or unmanned aerial systems (UASs) have been used extensively to provide firsthand reconnaissance and targeting of opposition forces without placing lives at risk, and proved particularly valuable in Afghanistan and elsewhere by identifying and tracking enemy targets and conducting missions too dangerous for manned aircraft. The slow-moving aircraft are vulnerable to more sophisticated anti-aircraft fire that would be expected from more technologically advanced opponents, however. For other missions, other systems are being developed, such as cheap, lightweight (as little as 5 ounces) micro or nano drones that will have the capacity to swarm over and within their targets -- including in dense urban environments.

The appropriators direct the Army secretary to report to Congress within 120 days of enactment on the Army's management plan and assessment of counter C-UAS requirements.

Global Hawk & U-2

The Global Hawk is a high-altitude, long-endurance unmanned aerial reconnaissance aircraft that provides high-resolution, near-real-time imagery of large geographic areas. The program includes RQ-4A aircraft, as well as larger and more capable RQ-4Bs which are almost as large as a Boeing 737. (The "R" is the department's designation for reconnaissance; "Q" stands for unmanned aircraft system.)

The Air Force also continues to fly the U-2 "Dragon Lady" spy plane, a manned aircraft with superior sensors that the Air Force says remains a cost-effective platform for signals intelligence and imagery collection. The Air Force recently flew a U-2 using artificial intelligence.

The agreement prohibits the use of funds to retire RQ-4 aircraft as proposed by the department, and it appropriates $129 million for Air Force RQ-4 research and development. It also provides $111 million to refurbish U-2s to combat-ready status and $37 million for U-2 research and development.

Reaper

The MQ-9 Reaper, which is the larger and more capable successor to the MQ Predator, can be armed with up to 3,000 pounds of precision-guided bombs or Hellfire missiles and primarily engages in "hunter killer" missions like those that have killed a number of terrorists in Yemen and Iraq. The Air Force wanted to end production of the Reaper in FY 2021 and did not request any funding for new aircraft.

The agreement provides $344 million for 16 MQ-9s in the OCO account, as well as $251 million for MQ-4 Triton Navy aircraft that are primarily used for surveillance.

Aircraft Carrier UAV

The agreement appropriates $257 million for the Carrier Based Aerial Refueling System (CBARS) program (also known as MQ-25 Stingray) -- an unmanned system to conduct automated aerial refueling of other carrier-based aircraft, as well as provide some intelligence, surveillance and reconnaissance capability.

Helicopters

The agreement appropriates the following for the purchase or development of military helicopters:

UH-60 Blackhawk -- $862 million for 42 new UH-60M multiuse Black Hawks for the Army and Guard, $119 million more than requested for six additional aircraft.

UH AH-64 Longbow Apache -- $792 million to upgrade 50 AH-64 Apache attack helicopters to the Longbow configuration. The Apache Longbow is the Army's upgraded heavy-attack helicopter.

CH-53K Super Stallion -- $1.1 billion ($294 million more than requested) for seven new King Stallion heavy-lift transport helicopters for the Marine Corps to carry armored vehicles, equipment and personnel deep inland from a sea-based center of operations, as well as $406 million for research and development.

HH-60W Whiskey -- $910 million for 16 new 60-Whiskey combat rescue helicopters, which are used for medical evacuations, civil search-and-rescue, humanitarian aid, disaster relief, and insertion or extraction of combat forces.

CH-47 Chinook -- $321 million for 11 new CH-47 Chinook troop transport helicopters, as well as $50 million in the OCO account. The total is $160 million more than requested for five additional CH-47F aircraft.

Navy Shipbuilding

The Navy currently has 283 deployable warships, including aircraft carriers, submarines and amphibious support ships, with about half deployed away from their home ports. The Navy also has close to 170 support ships that are part of the Military Sealift Command and Ready Reserve Force.

The agreement provides $23.3 billion for 10 major Navy ships, $3.4 billion more than requested, including the following:

New Attack Submarine -- $4.6 billion, including $2.3 billion in unrequested funds for a second Virginia-class submarine.

New Ballistic Missile Submarine -- $4.1 billion for long-lead components and advanced procurement for the new Columbia-class missile boat, and $307 million for research and development.

Aircraft Carriers -- $2.6 billion for the new carrier program, and $1.9 billion for refueling overhauls of existing ships. It also provides $17 million to begin procurement of the long lead items associated with refueling the Harry S. Truman, which the Navy had wanted to decommission.

FFG Frigate -- $1.1 billion for one FFG Frigate, which is a new class of multimission guided-missile frigates succeeding the troubled Littoral Combat Ship.

DDG-51 Destroyer -- $3.2 billion for the next two DDG-51 vessels.

Amphibious Ship -- $1.1 billion for landing platforms/docks (LPD), an amphibious warfare vessel that embarks, transports and lands elements of a landing force for expeditionary warfare missions.

Appropriators note that information provided by the Navy in response to last year's funding bill regarding the Navy's Surface Capability Evolution Plan (SCEP) was incomplete, and they direct the assistant secretary of the Navy (research, development and acquisition) to provide updated acquisition strategies for each element of the Navy's SCEP with the FY 2022 budget request.

Combat Vehicles & Troop Protection

In the past decade, the Army began the process of transforming itself into a more strategically responsive force as part of the department's campaign to transform the military into a faster, lighter force. The transformation is partly a function of "asymmetric" adversaries like the Islamic State taking the battle to cities where traditional weapons like heavy tanks and air power are less effective in the midst of dense civilian populations being used as human shields.

The agreement includes the following:

Abrams Tanks -- $968 million to upgrade 89 Abrams tanks to the M1A2 configuration, an upgraded, fully digitized 72-ton Abrams tank with night vision capabilities.

Joint Light Tactical Vehicle -- $1.3 billion for new JLTVs for the Army and Marines. The vehicle is meant to replace the Humvee combat-support utility vehicle with a family of more survivable vehicles with greater payload.

Stryker -- $1.2 billion for Stryker Double V-hull upgrades and other modifications, $317 million more than requested for 105 additional upgraded vehicles. The double V-shaped hull model better dissipates the force of roadside explosions.

Missiles & Munitions

The agreement appropriates $6.4 billion for the procurement of missiles and $5.1 billion for ammunition.

Hypersonic Weapons

Hypersonic weapons operate at exceptionally high speeds with high maneuverability, making them challenging to track and difficult to intercept. The department is developing an air-launched Hypersonic Conventional Strike Weapon (HCSW) for both fighter and bomber aircraft platforms. Both Russia and China are trying to develop similar weapons, and currently there are no international agreements to control hypersonics. Besides the air launched versions, the Navy is pursuing the Conventional Prompt Strike (CPS), a submarine-launched boost-glide weapon set to enter service in 2025, while the Army is seeking a truck-launched model.

The agreement provides $768 million for the Navy's CPS and $861 million for the Army's Long Range Hypersonic Weapon ($60 million more than requested), as well as other amounts throughout the agreement.

Long Range Stand Off Weapon

The agreement appropriates the president's request of $385 million for development of the Long-Range Standoff Weapon (LRSO), a cruise-missile-like system -- $89 million less than requested.

The Pentagon is in the process of retiring its Air-Launched Cruise Missiles (which can carry both nuclear and conventional warheads). Concerns have been raised that potential adversaries have fielded large numbers of theater ballistic missiles and ground-launched land-attack cruise missiles, while the United States is prohibited from fielding such systems by the INF Treaty. China, in particular, possesses a large and growing inventory of these long-range ground-launched weapons that could threaten targets as far away as Guam.

Minuteman Modernization / Ground Based Strategic Deterrent

The United States currently deploys more than 400 Minuteman intercontinental ballistic missiles, and under the current nuclear modernization program the Air Force plans to replace the Minuteman with the Ground Based Strategic Deterrent (GBSD) system. The agreement appropriates $1.45 billion for the GBSD, $70 million less than requested.

National Guard & Reserve

The measure provides $950 million in unrequested funds for the National Guard and Reserves. The funds will allow Guard and Reserve components to procure high-priority equipment that may be used for both combat missions and their missions in support of state governors, as well as to ensure full interoperability with the active duty force.

Overseas Contingency Operations

The agreement appropriates the requested $68.7 billion for Overseas Contingency Operations (OCO) associated with the war in Afghanistan and other counterterrorism operations such as the fight against ISIS. The total is $2.0 billion (3%) less than FY 2020.

The House committee report noted that the OCO request for FY 2021 once again included a total of $16 billion for regular non-war-related activities, and that with the possibility of significantly fewer deployed U.S. servicemembers in Afghanistan the activities funded in the past by OCO could very well be supported within base accounts in the future. Consequently, the committee said the department should cease requesting funding for the OCO accounts after this fiscal year, stating that "the OCO experiment has been an abject failure and has given the department a budgetary relief valve that has allowed it to avoid making difficult decisions."

Islamic State

The agreement appropriates $710 million in OCO funding for Iraqi, Kurdish, and other forces in Syria engaged in the fight against the Islamic State. The total includes $510 million for forces in Iraq and $20 million for those in Syria. The total is $135 million less than requested and $49 million less than FY 2020.

The measure continues the requirement that the Defense secretary ensure those forces are appropriately vetted and receive commitments from them to promote respect for human rights and the rule of law. And it prohibits the use of funds to establish permanent U.S. bases in Iraq or Afghanistan, or to exert U.S. control over Iraq or Syria oil resources.

Afghan Security Forces

The agreement provides $3.0 billion to train and equip Afghanistan's national army and other security forces, including the national police -- $968 million less than requested. The total includes $1.2 billion for the Afghan Army, $836 million for the Air Force, $602 million for Afghanistan's national police, and $1.3 billion for Afghan special security forces (although the measure assumes an "undistributed reduction" of $968 million across the accounts). The measure rescinds $1.1 billion in FY 2020 funding for Afghan forces.

It prohibits funds from being used to pay the expenses of any member of the Taliban to participate in any meeting that does not include the participation of members of the Afghan government, or that restricts the participation of women. It provides $20 million for the recruitment and retention of women in Afghan's security forces.

It restricts the obligation of funds unless the Defense secretary, in consultation with the secretary of State, certifies that Afghan forces are controlled by a civilian, representative government that is protecting human rights and women's rights and preventing terrorists and terrorist groups from using Afghan territory to threaten the security of the United States and its allies. It prevents payments to so-called "ghost soldiers" by prohibiting funds for Afghanistan security personnel who are not enrolled in the Afghanistan Personnel and Pay System. It also requires quarterly reports to Congress on the current conditions of the conflict, including metrics related to the peace agreement and an assessment of whether the Taliban is adhering to its commitments.

Finally, in response to reports that Russian military intelligence units secretly offered bounties to Taliban-linked militants for killing U.S. and coalition forces in Afghanistan, the measure directs the Defense secretary, in coordination with the National Intelligence director, to report within 30 days of enactment on Russia's malign activities in Afghanistan.

Ukraine

The agreement provides $275 million for assistance to the military and national security forces of Ukraine to aid its efforts to fend off Russian military incursions ($25 million more than requested) and directs the Defense secretary to inform Congress if funds have not been obligated within 60 days of notification.

Under the measure, the Ukraine aid could be used for training, equipment, lethal weapons of a defensive nature, logistics support, supplies and services, intelligence support, and for replacing any weapons or defensive articles provided to Ukraine from the U.S. military's inventory. It prohibits the use of funds to procure or transfer man-portable air defense systems (i.e., shoulder-fired anti-aircraft missiles) to Ukraine because of the threat they could pose to civil aviation, but allows up to $50 million for lethal weapons -- including coastal defense and anti-ship missile systems.

However, 50% of U.S. aid would be withheld unless the Defense secretary and secretary of State certify progress in Ukraine towards certain reforms -- including instituting civilian control of the military, cooperation and coordination with Ukrainian parliamentary efforts to exercise oversight of the Defense Ministry and military forces, and improvements in sustainment capabilities, inventory management, and security of sensitive foreign technologies.

Defense Security Cooperation Agency

The agreement provides a total of $2.2 billion for the Defense Security Cooperation Agency (DSCA), including $1.5 billion in OCO funding. At least $500 million of DSCA funding must be used for assistance to Jordan in its fight against ISIS, including aid to provide security along its border with Syria and Iraq.

The DSCA provides financial and technical assistance, transfer of defense material and training and services to allies, and promotes military-to-military contacts. It also coordinates global security cooperation programs and handles the Defense Department's Foreign Military Sales and Financing programs.

European Deterrence Initiative

The agreement provides funding in various accounts for the European Deterrence Initiative (formerly the European Reassurance Initiative), which was started by the Obama administration to bolster the defense of NATO allies after Russia's military incursions in Crimea and Ukraine. The Initiative involves keeping some U.S. troops in countries along Russia's border, with funds also used for pre-positioned equipment, additional intelligence, surveillance and reconnaissance, training range capacity and capability, and partnership programs between the U.S. and its allies.

The total includes $169 million for a Baltic Security Initiative to support Estonia, Latvia and Lithuania.

Operation & Maintenance

Operation and Maintenance (O&M) constitutes the largest segment of defense spending, accounting for more than one-third of total military expenditures. Although O&M -- which includes funding for training, supplies and equipment maintenance -- is considered the department's "readiness" account, it also includes funds for the Defense Department's administrative functions, environmental restoration, cooperative threat-reduction efforts and humanitarian assistance, as well as many other programs.

The agreement provides $192.2 billion in its regular accounts to operate and maintain U.S. forces and to maintain materials and facilities worldwide in FY 2021. It also provides $58.8 billion in O&M spending as part of the OCO portion -- bringing the measure's overall O&M appropriation to $251.0 billion. The combined total is $2.3 billion (1%) less than the FY 2020 enacted level.

The measure provides $100 million in unrequested funds to bolster the defense industrial base and supply chain and $301 million in unrequested funds to enhance readiness -- including extra flying hours, tank miles, and steaming days; equipment, aviation, and ship depot maintenance; training; spare parts; and base operations.

It also provides an additional $116 million for upgrades to childcare facilities and $284 million for upgrades to schools on military bases, and requires the Defense secretary to provide a notification when a foreign base is open or closed.

Drug Interdiction

The agreement provides $914 million for drug interdiction activities of the U.S. military, $145 million (19%) more than requested. For the first time in many years, the measure does not provide funds in the OCO section, most of which were for anti-drug operations in Afghanistan.

Within the total, $194 million is for National Guard counterdrug programs that work with state and local law enforcement within the United States, and $128 million is for military drug demand reduction efforts, including drug testing. The National Guard total is $100 million more than requested.

Nunn-Lugar

The agreement provides $360 million for the Cooperative Threat Reduction program, known as CTR or Nunn-Lugar, to assist in the continued denuclearization and demilitarization of the states of the former Soviet Union. The total is $122 million more than requested, and it restores funding for a program to prevent biological weapons proliferation that the administration had wanted to cut.

Military Personnel

The agreement appropriates $162.4 billion for military personnel, including costs of pay, allowances, bonuses, survivor benefits and permanent change-of-station moves -- $7.1 billion (5%) more than the FY 2020 level but $1.1 billion less than requested. The total includes $4.6 billion in the OCO account and $8.4 billion in Tricare payments.

Force Levels & Military Pay Raise

The measure funds a total of 1,351,500 active duty personnel in FY 2021 -- equal to the president's request and 12,000 more than the FY 2020 level. The total includes 485,900 for the Army (5,900 more than FY 2020), 347,800 for the Navy (7,300 more), and 184,100 for the Marine Corps (2,100 less). The total also includes 327,266 for the Air Force, and for the first time, 6,434 for the newly formed Space Force (most of whom were previously in the Air Force).

It also funds the president's request for 802,000 Guard and Reserve forces -- 1,200 more than the FY 2020 level.

The agreement's funding supports an across-the-board 3.0% pay increase for military personnel, equal to the president's request. It also funds the extension of certain special pay and bonuses for active-duty and reserve personnel, as well as 100% of troop housing costs.

Defense Department Dependent Schools

The measure provides $3.0 billion for Defense Department dependent schools, which now educate more than 100,000 military children each year. The total includes $13 million in the OCO account.

It also provides $50 million in unrequested funds for Impact Aid as well as $20 million for Impact Aid for children with disabilities. The Education Department's Impact Aid program provides supplementary funds to school districts nationwide in order to support the education of nearly 600,000 children of servicemembers.

Sexual Harassment

The measure provides $323 million for Sexual Assault Prevention and Response programs, including $40 million for the Special Victims' Counsel Program across the services and $4 million for a sexual trauma treatment pilot program. The total is $45 million more than requested.

It prohibits the use of funds for federal contracts in excess of $1 million unless the contractor agrees that it will not require employees or independent contractors to use arbitration to resolve any complaint involving sexual assault or harassment. Contractors must also certify that each covered subcontractor agrees to do the same.

Extremist Ideologies

The measure directs the Defense secretary to update his report on military personnel and extremist or criminal groups that was submitted to Congress on Jan. 24, 2020. The updated report must describe all new policy and personnel actions that have been taken along with information on the types of extremist or criminal groups involved in such personnel actions.

Defense Health Program

After 9/11, the military health care system became one of the fastest-growing parts of the defense budget due to a general rise in medical costs, greater use by military retirees and their dependents, and congressionally imposed increases in benefits. In recent years, however, modifications have been made to modestly reduce the department's health care budget.

The agreement appropriates $34.1 billion for defense health care programs (including $365 million in OCO funding) -- $776 million (2%) less than FY 2020 but $608 million (2%) more than requested. The total includes $16.0 billion for care in the private sector, $9.2 billion for in-house care, and $2.1 billion for information management.

It also includes $1.6 billion for research and development ($919 million more than requested), including $513 million in unrequested funds for cancer research and $175 million in unrequested funds for traumatic brain injury (TBI) and psychological health research and development.

Cancer Research

The agreement includes $150 million in unrequested funds for research and treatment related to breast cancer, and $110 million for basic and clinical research on prostate cancer. It also provides $50 million for kidney cancer research, $35 million for ovarian cancer research, $20 million for lung cancer research, and $10 million for pancreatic cancer research.

In addition, it provides $115 million for a Peer-Reviewed Cancer Research Program that researches cancers not addressed in the department's current breast, prostate, ovarian and lung cancer research programs. The funds are for research in the following areas: bladder cancer, brain cancer, colorectal cancer, listeria vaccine for cancer, liver cancer, lymphoma, melanoma and other skin cancers, mesothelioma, pancreatic cancer, stomach cancer, and cancer in children, adolescents and young adults.

Other Health Research Programs

The measure also funds the following activities: $175 million for the peer reviewed psychological health and traumatic brain injury research program; $22 million for the Gulf War Illness Peer-Reviewed Research Program; $24 million for HIV/AIDS programs, including $8 million for global HIV prevention efforts; $7 million for tickborne disease research; $40 million for ALS ("Lou Gehrig's disease") research; $40 million for spinal cord research; $15 million for autism research; $15 million for Alzheimer's disease research; $20 million for vision research and $10 million for hearing restoration research; and $12 million for reconstructive transplant research.

Biological Threats

In its report, the House committee noted it is encouraged by the progress of the Defense Threat Reduction Agency in developing a prototype sensor that enables real-time detection of aerosolized biological agents. It therefore directed the Joint Program Executive Office for Chemical, Biological, Radiological and Nuclear Defense to report within 90 days of enactment on efforts to fund, test, and field such a sensor.

Environmental Provisions

The agreement appropriates $1.5 billion ($430 million more than requested) to rectify contamination caused by past actions, ensure current compliance, and prepare a more environmentally sensitive military establishment for the future. Much of the added funding is to clean up perfluorinated compounds (PFAS) that have seeped into water supplies on many military bases.

The measure requires semi-annual reports on PFAS cleanup efforts, and it encourages the Defense secretary to study the financial and environmental impacts of composting shredded government documents.

Separately, it provides $1.1 billion to destroy chemical agents and munitions -- $159 million more than the request.

Climate Change

The House committee report noted that the Defense secretary is required to submit a report which contains a list of the top ten most climate-vulnerable bases within each service, and which provides a cost estimate to mitigate the risks at each of these bases. It stated that the department is working with the Army Corps of Engineers to develop a tool to meet this requirement, and said it expects the secretary to update the congressional defense committees with any changes to the anticipated date of completion for the tool and report.

It also directed the service secretaries to report to Congress within 90 days of enactment with a plan to conduct energy resiliency studies on military installations.

Other Defense Funding

The agreement also appropriates the following:

Humanitarian Assistance -- $148 million for international humanitarian assistance, $38 million more than requested. Activities under the program include foreign disaster and emergency assistance relief, as well as the provision of excess nonlethal supplies.

Office of Economic Adjustment -- $214 million to aid communities that are adversely affected by defense program changes, including base closures or realignments, base expansions, and contract or program cancellations. The total includes $50 million to assist communities in adjusting their noise mitigation plans.

Civil-Military -- $281 million for civil-military programs that aim to improve the life skills and employment potential of youths who drop out of secondary school by providing military-based training from the Guard.

POW/MIA -- $154 million for the Pentagon's Prisoner of War/missing persons office, $25 million more than requested.

Radio/TV -- $220 million for the Armed Forces Information Service, including funding for the Stars and Stripes newspaper which the administration wanted to defund.

Naval Investigative Service -- $748 million for the Naval Investigative Service.

Inspector General -- $399 million for the Pentagon's Office of Inspector General, including $24 million in the OCO account.

Historically Black Colleges & Universities -- $81 million ($50 million more than requested) for science programs at historically black colleges and universities and other minority institutions.

Mobile Nuclear Reactor -- $70 million to develop a mobile micro nuclear reactor.

Guantanamo & Other Funding Prohibitions

The agreement continues statutory restrictions on the transfer of detainees from the detention facility at the U.S. Naval Station, Guantanamo Bay, Cuba, and specifically restricts the transfer of Khalid Sheik Mohammad and others. And it prohibits the use of funds to close or realign Guantanamo or to modify facilities in the United States to house such prisoners. The House-passed bill did not contain the restrictions.

The measure also continues prohibitions on the use of funds for numerous other activities as well, including to provide aid to North Korea unless specifically appropriated; to develop a nuclear armed interceptor for use in a missile defense system; to purchase from non-U.S. suppliers any supercomputers, foreign anchors, mooring chains, ball bearings or certain steel; or to enter into any business arrangements with the Russian defense contractor Rosoboronexport.

It continues to bar the National Security Agency from targeting U.S. persons under authorities granted in the Foreign Intelligence Surveillance Act (FISA), and it includes a new provision to prohibit the use of funds to decommission two Littoral Combat Ships.

Finally, the measure directs the Air Force to work with the National Institutes of Health to seek alternative arrangements for the housing and care of chimpanzees currently residing at Holloman Air Force Base in New Mexico. Beginning in the 1950s, the Air Force began maintaining a chimpanzee "colony" at the base to conduct aeronautical and space research.

Rescissions

The agreement rescinds a total of $5.1 billion in previously appropriated funds, including $3.2 billion in base defense funding and $1.9 billion from the OCO account. The total includes $1.1 billion from the Afghanistan Security Forces Fund and $400 million from the Counter-ISIS Train and Equip Fund.

<p> By Daniel Peake [email protected]

Section V

Energy-Water

This section describes the provisions of HR 133, Consolidated FY 2021 Appropriations Act, that provide funding for the Energy Department, Army Corps of Engineers, Bureau of Reclamation and related agencies.

The agreement provides $49.5 billion in net discretionary spending subject to caps, $1.1 billion (2%) more than FY 2020 and $6.9 billion more than requested according to appropriators. On a programmatic basis, however, it provides $51.8 billion for FY 2021 -- $3.4 billion more than FY 2020 -- as it includes $2.3 billion for the Energy Department's science account that is categorized as emergency spending (but which is offset by rescinding $2.3 billion in unobligated emergency spending from the 2009 economic stimulus and recovery law).

Of the total non-emergency spending provided, $27.5 billion is for defense-related activities ($3.3 billion more than FY 2020) and $21.9 billion is for nondefense activities ($2.1 billion less than FY 2020).

Of the total regular appropriation, $39.6 billion is for the Energy Department -- $1.0 billion (3%) more than FY 2020 funding. It provides $15.4 billion for weapons activities (23% more than FY 2020), and $2.3 billion for nuclear nonproliferation activities (4% more). A total of $6.4 billion is provided for defense environmental cleanup activities, a 3% increase.

The Energy Department total also includes $7.0 billion for science activities ($6 million more than FY 2020) and $1.5 billion for nuclear energy activities (1% more than FY 2021). It keeps funding for core fossil fuel energy research and development programs the same (providing $750 million), while increasing funding for energy efficiency and renewable energy programs by 2.5% and Advanced Research Projects Agency-Energy, ARPA - E, by $2 million-- both of which the administration wants to dramatically cut or eliminate.

For the Army of Engineers it provides $7.8 billion, $145 million more than FY 2020. It also provides $1.7 billion for activities of the Interior Department's Bureau of Reclamation ($11 million more than FY 2020), and provides no funding to continue efforts to restart work on the Yucca Mountain nuclear waste repository (none was requested).

The measure bars the reorganization of the Army Corps of Engineers or the transferring of corps functions to other agencies, but permits the transfer of funds from the Western Area Power Administration to the Bureau of Reclamation for environmental stewardship and endangered species recovery purposes.

Army of Engineers

The Army of Engineers is responsible for civil flood control, navigation and ecosystem restoration projects. The committee, in its report, notes that in addition to building and maintaining flood protection infrastructure that prevents almost $9 in damage for every dollar spent, the maintains 1,067 harbors and 25,000 miles of commercial channels serving 40 states, which is critical to U.S. commerce and international economic competitiveness.

The measure provides $7.8 billion for operations, investigations and construction -- $145 million (2%) more than FY 2020.

According to the committee, an estimated $1.7 billion of regular spending in the bill for the ' activities would be eligible for reimbursement from the Harbor Maintenance Trust Fund -- $50 million more than FY 2020 -- which makes use 92% of all estimated annual revenues from the fund. However, it rejects the administration's request to change the structure of the agency's account, including the creation of two new accounts -- the Harbor Maintenance Trust Fund and Inland Waterways Trust Fund -- and shifting a variety of studies and projects from one account to another.

Operation & Maintenance

The Operation and Maintenance account provides funding for the to clear and maintain U.S. harbors and inland waterways, including through dredging, and to operate and maintain lock and dam facilities around the country.

The measure provides $3.9 billion for waterway operation and maintenance for hundreds of specified projects, $60 million more than FY 2020.

Water Project Construction

The measure provides general construction funding for projects relating to navigation, flood and storm damage mitigation and aquatic ecosystem restoration that have been authorized by Congress and approved by the and are identified in the explanatory statement accompanying the bill.

Specifically, it provides $2.7 billion for general water project construction, $12 million (2%) more than FY 2020 funding. It includes nine new study starts and seven new construction starts.

Of the total, at least $59 million must be for new navigation infrastructure for locks not on the inland waterways system and -owned bridges, $40 million for projects with riverfront development components, $29 million to address drainage in urban areas, and $25 million for multistate ecosystem restoration programs.

Separately, the measure provides $380 million for specified Mississippi River waterway-related projects, $5 million more than FY 2020.

Other Activities

The measure provides $210 million for the regulatory program, which oversees activities affecting U.S. waters, including wetlands, in accordance with various laws -- including the 1899 Rivers and Harbors Appropriation Act, the Clean Water Act, and the 1972 Marine Protection, Research, and Sanctuaries Act. The amount provided is equal to FY 2020 funding.

It appropriates $250 million for the continued cleanup of certain low-level radioactive materials and mixed wastes located at Energy Department sites that were contaminated during the nation's past efforts to develop atomic weapons. The amount provided is 25% more than FY 2020 funding. The measure rejects the administration's proposal to transfer the account to the Energy Department.

Finally, the measure provides $153 million for general investigations, under which the Corps conducts studies to determine the feasibility of constructing a water project, $2 million more than FY 2020. It also provides $35 million for training programs to prepare for and respond to floods, hurricanes and other natural disasters, equal to FY 2020.

Energy Department

The agreement appropriates a total of $39.6 billion for Energy Department programs and activities for FY 2021, $1.0 billion (3%) more than current funding and $4.5 billion (13%) more than requested. The measure rejects the deep cuts proposed by the president to science and applied energy programs.

Within the total provided for the department, almost half ($19.7 billion) is for nuclear weapons activities conducted by the National Nuclear Security Administration (NNSA) -- including nuclear weapons management and development, nonproliferation activities, and research on naval nuclear reactors. Another $6.4 billion is for continued environmental cleanup of defense facilities where nuclear weapons activities were conducted as well as non-defense nuclear facilities. For non-defense science and energy programs conducted by the department, it provides $12.4 billion, $2.2 billion (15%) less than FY 2020.

The measure increases funding over current levels for nuclear weapons activities, Energy Department science programs, nuclear nonproliferation programs, and for energy efficiency, renewable-energy programs, the naval reactor program, and defense environmental cleanup activities. It keeps funding level for non-defense environmental cleanup activities and fossil fuel energy research, and provides no funding for restarting the license application for the Yucca Mountain nuclear waste repository.

DOE Military Nuclear Programs

The National Nuclear Security Administration (NNSA) is a semiautonomous agency within the Energy Department that is responsible for the development, maintenance and disposal of U.S. nuclear weapons, and for preventing the proliferation of weapons of mass destruction. NNSA accounts include weapons activities, defense-oriented nuclear proliferation and naval reactors.

For the measure's regular spending it provides $19.7 billion for the NNSA, $3.0 billion (18%) more than FY 2020 funding.

Weapons Activities

Within the NNSA total, the bill provides $15.3 billion for nuclear weapons activities, 23% more than FY 2020 funding.

The administration's FY 2021 budget request proposed a new structure for Weapons Activities. The plan would replace work funded within Directed Stockpile Work and Research, Development, Test and Evaluation with three new elements: Stockpile Management; Production Modernization; and Stockpile Research, Technology, and Engineering. While the committee did adopt some of the proposed changes, it says it only made modifications where it believes additional oversight and monitoring are necessary.

The measure includes $4.3 billion for stockpile management work including maintenance, operations, surveillance, dismantlement, and weapon acquisition programs -- including life extensions, modifications, and alterations. (Much of this work was previously funded within the former Directed Stockpile Work.)

Other major elements of the NNSA's production modernization program include $2.5 billion to restore and modernize the capability to produce primaries, secondaries, and non-nuclear components. (Portions of Production Modernization were previously funded within the former Directed Stockpile Work.) At least $7 million of this total must be used for workforce development and training partnerships with Historically Black Colleges and Universities, Hispanic-Serving Institutions, and Tribal Colleges and Universities in South Carolina and New Mexico to support plutonium pit production.

It includes $2.8 billion for Stockpile Research, Technology, and Engineering to strengthen science-based stockpile stewardship capabilities to annually certify and assess the stockpile. (Portions of this account were previously funded within the former Research, Development, Test, and Evaluation.) It also includes $4.1 billion for nuclear weapons infrastructure and operations (28% more than FY 2020) -- including $733 million (26% more than FY 2020) for modernizing (recapitalizing) the nation's nuclear weapons infrastructure.

The administration did not request, nor does the bill provide funding to modify the W76 warhead to a "low-yield" W-76-2 variant. Last year's bill provided $10 million for the warhead, which reportedly was deployed on submarine ballistic missiles earlier this year.

The 2018 Nuclear Posture Review called for the department to begin producing a new low-yield (5 to 7 kiloton) variant, the W76-2. (The bomb dropped on Hiroshima was 15 kilotons.) The Trump administration wants to produce such warheads to better deter countries such as Russia and China. (Supporters of such weapons claim they are a better deterrent than existing nuclear weapons, most of which are so destructive adversaries know the U.S. is unlikely ever to use them, while critics of the low yield bombs argue they could make use of such nuclear weapons more likely in certain situations, which could trigger a nuclear war.)

Nuclear Nonproliferation Programs

Nonproliferation programs seek to prevent the development and spread of nuclear weapons worldwide. Some of these programs are designed specifically to secure and decommission weaponry and technology of the former Soviet Union.

The bill appropriates $2.3 billion for NNSA defense nuclear nonproliferation activities, $95 million (3%) more than FY 2020.

The total for non-proliferation includes $429 million for global material security programs and activities ($86 million more than FY 2020), $148 million for nonproliferation and arms control activities ($8 million more than FY 2020), $602 million for defense nuclear nonproliferation research and development (13% more), $401 million for material management and minimization (10% more), and the requested $378 million for the department's nuclear counterterrorism and incident response program to respond to and mitigate nuclear and radiological incidents worldwide (1% more than FY 2020).

Naval Reactors

The measure provides the requested $1.7 billion for the agency's naval reactor program, $36 million (2%) more than FY 2020. The department's naval reactor program is responsible for all aspects of naval nuclear propulsion, including technology development, reactor operations, and disposal. It fully funds the request to develop the Columbia-class submarine, to refuel the S8G prototype, and continue the Spent Fuel Handling Recapitalization Project.

The total includes $568 million for naval reactors development (10% more than FY 2020), $531 million for reactor operations and infrastructure (4% less than FY 2020), and the $334 million for construction projects, including $330 million for the department's spent nuclear fuel handling recapitalization project.

Other Defense Activities

The total includes $12 million in additional funds to defend the U.S. energy sector against the evolving threat of cyber and other attacks in support of the resiliency of the nation's electric grid and energy infrastructure.

DOE Environmental Cleanup Activities

The bill provides a total of $7.6 billion for a variety of Energy Department programs focused on environmental cleanup of both former government sites as well as civilian nuclear sites. The total provided is $131 million more than FY 2020 funding.

The largest portion, $6.4 billion, is for the general defense environmental cleanup program, which focuses on the cleanup of contaminated areas, primarily at current and former Defense Department sites. That funding is $171 million more than FY 2020.

Within that amount, it provides $2.5 billion for cleanup activities in and around the Hanford site in Washington state ($926 million for the Richland Operations Office and $1.6 billion for the Office of River Protection), $1.5 billion for the Savannah River site in South Carolina, $434 million for the Idaho National Laboratory, $475 million for the Oak Ridge Tennessee facility, $313 million for the Waste Isolation Pilot Plant in New Mexico, and $343 million for various National Laboratories and associated facilities.

It provides $319 million for the cleanup and remediation of civilian nuclear sites (equal to FY 2020 levels) and $841 million ($40 million less) from the Uranium Enrichment Decontamination and Decommissioning Fund for the continued cleanup of non-defense gaseous diffusion plants at Portsmouth, Ohio; Paducah, Ky.; and Oak Ridge, Tenn.

DOE Energy Programs

The measure includes a total of $12.4 billion for a variety of energy programs conducted by the Energy Department (including the department's science programs). That total is $2.2 billion more than FY 2020.

It funds the Advanced Research Projects Agency-Energy (ARPA-E) research program at $427 million -- $1 million more than FY 2020. ARPA-E supports research and related projects attempting to rapidly develop energy technologies that are too risky to attract substantial private investment but are capable of significantly changing the energy sector to address energy-related economic and security challenges. ARPA-E support is usually provided through partnerships with universities that supply personnel and assist in project and research funding.

Science

The measure provides $7.0 billion for the Energy Department's science account -- $26 million more than FY 202. The account funds the department's work on basic energy research, nuclear physics, biological and environmental sciences, fusion and other related endeavors.

The total includes $4.7 billion through a regular appropriation and $2.3 billion in emergency funding. The overall total includes $1.0 billion for research on advanced scientific computing, including $475 million or Exascale Computing Initiative construction. Exascale computers would exceed the existing generation of supercomputing power by 10,000% and provide computing power necessary to meet future national security, scientific and health care needs.

The bill's science research funding also includes $1.9 billion for basic energy sciences ($3 million more than FY 2020); $794 million for high energy physics ($20 million less); $691 million for nuclear physics ($31 million more); $672 million for fusion energy sciences ($1 million more); $240 million for science laboratories infrastructure (20% less); and $753 million for biological and environmental research ($3 million more).

Energy Efficiency & Renewable Energy

The measure provides $2.9 billion for the Energy Department's energy efficiency and renewable-energy account -- $72 million (2.5%) more than FY 2020. It includes $20 million to bring cybersecurity into early-stage technology research and development so that it is built into new technology.

Fossil Fuels

The measure provides $750 million for research and development of fossil fuels, including ways to make the use of such fuels more efficient and sustainable. The total is equal to FY 2020 funding.

Nuclear Energy

The measure provides $1.5 billion for nuclear power development and research, $13 million more than FY 2020 funding. Nuclear energy funding includes multiple programs, such as spacecraft propulsion systems, cancer treatment technology and reactor technologies.

The total includes $945 million for research and development activities, including $309 million for Fuel Cycle Research (1% more than FY 2020) and $208 million for reactor concept research (22% less).

The measure includes no funding to continue efforts to restart work on the Yucca Mountain nuclear waste repository, for which no funds were requested.

Instead it directs the department to continue site preparation activities at stranded sites, to evaluate the re-initiation of regional transport, and undertake transportation coordination efforts, and the statement of managers accompany the bill encourages the department to include planning for the removal of spent nuclear fuel from sites located near cities and Indian reservations.

Strategic Petroleum Reserve

The Strategic Petroleum Reserve (SPR) is an emergency oil supply depository located in Texas and Louisiana that contains light, sweet crude oil. The reserve was created after the oil embargo of 1973 and 1974 and is intended to provide the federal government with an emergency oil supply during a disruption in commercial oil supplies.

The measure appropriates $188 million for continued operations and maintenance of the SPR, $7 million less FY 2020 funding.

It forbids the department from establishing any new regional petroleum product reserves unless funding for such a proposed regional reserve is explicitly requested in advance in an annual budget submission and approved by Congress.

Finally, the measure separately provides the requested $13 million for remaining activities related to naval petroleum and oil shale reserves ($1 million less than the FY 2020 level), but it rejects the administration's proposal to terminate the Northeast Home Heating Oil Reserve, providing $7 million for the program. The heating oil reserve is intended to ensure that home heating oil supplies are available for northeastern states during times of very low inventories or significant threats to heating oil supplies.

Other DOE Activities

The measure provides $127 million for the Energy Information Agency, a quasi-independent agency in the Energy Department responsible for providing timely, objective, and accurate energy-related information to Congress, the executive branch, state governments, industry, and the public. The amount provided is equal to current funding.

It also provides $259 million for administrative expenses of the Energy Department, 2% more than current funding. After miscellaneous revenues and funding from other defense activities are factored in, the bill provides a net appropriation of $166 million.

Power Marketing Administration

The measure provides the requested $100 million in net funding for regional power marketing administrations, slightly more than FY 2020.

The total includes a net $89 million in funding for the Western Area Power Administration (WAPA) that serves 15 states, and a net $10 million for the Southwestern Power Administration (SPA) that serves six states -- where all but those amounts for each power administration's operations and maintenance budget would be covered through power sales and other income.

The bill allows $844 million in actual spending by the WAPA and $116 million in spending by the SPA.) In the case of the Southeastern Power Administration, which serves 11 states, power sales and other revenue would cover its entire $77 million budget.

Bureau of Reclamation

The Bureau of Reclamation is charged with developing water supplies and reclaiming arid lands in the Western United States. The bureau, which is part of the Interior Department, is responsible for more than 475 dams and 337 reservoirs and supplies water to 31 million people and 10 million acres of farmland in 17 western states. It also supplies hydroelectric power, and is the second largest supplier of hydropower behind the Army of Engineers.

The measure provides $1.7 billion for activities of the Bureau of Reclamation, $10 million more than FY 2020 and $542 million (33%) more than requested.

Most of the regular total, $1.5 billion, is for activities that support the development, construction, management and restoration of water and related natural resources. That amount is $9 million (2%) less than FY 2020 funding.

Central Valley Project Restoration Fund

The measure provides the requested $56 million for the Central Valley Project Restoration Fund, $1 million more than FY 2020 levels.

The fund was established to provide money from project beneficiaries for habitat restoration, improvement and acquisition in the Central Valley Project area in California. Funds are derived from a collection of revenue sources, including voluntary water transfers and tiered water pricing, as well as mitigation and restoration payment collections.

California Bay-Delta Ecosystem Restoration

The bill provides $33 million for the California Bay-Delta Ecosystem Restoration account, which funds the federal share of restoration activities being developed for the San Francisco Bay/Sacramento-San Joaquin Delta by a federal-state partnership. The total is equal to both current funding and to the request.

Central Utah Project

The bill appropriates $21 million for continued work on the Central Utah Project, a large Interior Department water infrastructure project designed to provide irrigation and municipal water and to restore wildlife habitats. The amount provided is $1 million more than provided in FY 2020.

The measure authorizes funding for fish, wildlife and recreation mitigation and conservation; establishes an account in the Treasury for the deposit of these funds and of other contributions for mitigation and conservation activities; and establishes a Utah Reclamation Mitigation and Conservation Commission to administer funds in that account.

The total includes $18 million for project construction, $2 million for transfer to the Utah Reclamation Mitigation and Conservation Account for use by the Utah Reclamation Mitigation and Conservation Commission, and $2 million for program expenses.

Independent Agencies

Nuclear Regulatory Commission

The measure provides $831 million for salaries and expenses of the Nuclear Regulatory Commission (NRC), $11 million less than FY 2020 funding. Most of the commission's funding, however, would be offset by receipts from user fees paid by nuclear utilities and other entities regulated by the commission. It is assumed that the commission would receive $710 million from such receipts, resulting in a net appropriation of $123 million. The NRC's inspector general, meanwhile, would receive $13 million, all but $2 million of which would be offset by agency revenues.

Federal Energy Regulatory Commission

The measure provides the requested $404 million for the Federal Energy Regulatory Commission, $22 million more than FY 2020. All of the commission's funding would be offset by fees paid by regulated energy companies and providers, resulting in no net appropriation.

Other Offices & Regional Commissions

The bill appropriates $180 million for the Appalachian Regional Commission, $5 million more than FY 2020. Of the total, $10 million is directed towards high-speed broadband deployment in distressed counties within the Central Appalachian region that have been most negatively impacted by the downturn in the coal industry and $5 million for economically distressed counties within the North Central and Northern Appalachian regions.

The agreement provides $30 million for the Delta Regional Authority and $15 million Denali Commission (both equal to 2020). For the Northern Border Regional Commission, it provides $30 million (20% more than FY 2020).

The measure also provides $31 million for the Defense Nuclear Facilities Safety Board, which is equal to FY 2020 funding.

By Greg Tourial [email protected]

Section VI

Financial Services

This section describes the provisions of HR 133, Consolidated FY 2021 Appropriations Act provide full-year funding for the Treasury department and IRS, the federal courts and White House, and various independent agencies.

The agreement provides $24.4 billion in net discretionary funding subject to budget caps, $281 million (1%) more than comparable FY 2020 funding. Incorporating $12.9 billion in offsetting collections that don't count towards scored discretionary spending as well as $50 million in emergency funds and $143 million in disaster funding (and factoring out rescissions), the measure actually provides a total of about $37.5 billion in programmatic discretionary funding. It also includes $22.9 billion in mandatory funding, including salaries for federal judges and contributions for federal employee retirement benefits.

It increases funding for both the Treasury Department and the IRS by 3%, including a 24% increase for IRS technology modernization and 3% more for the CDFI fund, which promotes development in financially underserved areas. It also increases funding for the federal court system and for the Executive Office of the President each by 4%, and rejects the president's proposal to reorganize White House anti-drug trafficking programs. Additionally, it increases the federal payment to the District of Columbia by 2%, including a major increase for D.C. emergency planning and security costs.

The measure provides a 2% increase for General Service Administration (GSA) building construction, repairs, and operations, and it rejects the Trump administration's plan to merge the Office of Personnel Management (OPM) with the GSA, providing OPM with a 9% funding increase. It also provides funding increases for a number of independent federal agencies, including the Federal Communications Commission (10%), the Federal Trade Commission (6%), the Securities and Exchange Commission (5%), the National Archives and Records Administration (5%), and the Consumer Product Safety Commission (2%). It decreases base level funding for the Small Business Administration by 8%.

The agreement provides a 1% pay raise for federal civilian employees, while eliminating automatic statutory pay increases for the Vice President and other senior political appointees.

Treasury Department/IRS

The measure provides a total of $13.5 billion for Treasury programs and activities -- 3% more than FY 2020 -- and it increases funding for most Treasury and IRS programs and activities. It rejects the administration's request to move the U.S. Secret Service, which became part of the Homeland Security Department (DHS) when that department was created in 2003, back to the Treasury Department.

Internal Revenue Service

The vast majority (89%) of funding provided to the Treasury Department goes to the IRS, which would receive $11.9 billion, or 3.5% more than FY 2020.

The agreement provides $2.5 billion (2% more than FY 2020) for taxpayer services, including forms and publications, tax return processing, advocacy and services to assist taxpayers. Within this amount, $30 million is provided for tax assistance programs, $11 million for the Tax Counseling for the Elderly Program, $13 million for low-income taxpayer clinic grants, and $211 million for operating expenses of the IRS Taxpayer Advocate Service.

The IRS total includes $5.2 billion (4% more) for IRS enforcement activities, including the examination of tax returns, settling taxpayer appeals regarding their returns, monitoring employee pension plans, and reviewing the tax-exempt status of organizations and collecting unpaid taxes. The total also includes $3.9 billion (3% more) for IRS operations support, including shared service support related to facilities services, rent payments, printing, postage, security, strategic planning, communications and liaison, finance, human resources, research, information technology and telecommunications. Finally, the measure includes $220 million (24% more) to support efforts to modernize key IRS business systems.

The measure continues a number of provisions that restrict IRS activities, including those that prohibit the targeting of groups for regulatory scrutiny based on their ideological belief or of individuals for exercising their First Amendment rights.

Unlike the House-passed version of the bill, it continues language prohibiting the Treasury or IRS from using funds to issue any rules on the definition of tax-exempt social welfare organizations, also known as Section 501(C))(4) organizations. (Some government accountability activists argue that current IRS reporting requirements effectively allow individuals to use these groups to donate "dark money" for political purposes without having to disclose their personal information to the IRS).

Other Treasury Offices

The agreement funds various offices within the Treasury Department that deal with a variety of issues, including U.S. finances and debt, imposing financial sanctions against entities, and promoting economic development.

Bureau of the Fiscal Service -- $346 million for the Bureau of the Fiscal Service, (1.5% more than FY 2020). The office was established in 2012 and performs the accounting, borrowing, collections, payments and shared services functions of the federal government. It collects most of the non-tax debt owed to the federal government and is responsible for all public debt operations and for promoting the sale of U.S. securities.

Terrorism Office -- $175 million for the Office of Terrorism and Financial Intelligence (3% more). The office enforces economic and financial sanctions against terrorist groups, drug traffickers, and rogue nations and provides intelligence and counterintelligence services for the department, including analysis of terrorist financing. The total includes $3 million to enforce sanctions for human rights abuses.

FinCEN -- $127 million for the Financial Crimes Enforcement Network (1% more). The network supports federal, State, local, and international law enforcement agency investigations of money laundering and other financial crimes, and is responsible for implementing anti-money laundering allegations.

Alcohol/Tobacco/Trade -- $124 million for the Alcohol and Tobacco Tax and Trade Bureau (4% more than FY 2020). The bureau enforces laws to regulate lawful activities relating to alcohol products and tobacco.

Foreign Investment/CFIUS -- $20 million (equal to FY 2020) for the Committee on Foreign Investment in the United States. The committee coordinates federal policy on foreign investment in the United States and monitors its impact. CFIUS is comprised of nine Cabinet members, two ex officio members, and other appointees (as needed) who assist the President in overseeing the national security risks of foreign investment on the national economy. The amount is partly offset by $5 million in user fees for a net appropriation of $15 million.

CDFI Fund -- $270 million (3% more than FY 2020) for the Community Development Financial Institutions Fund. The fund provides grants, loans, equity investments and technical assistance on a competitive basis to new and existing CDFIs such as community development banks, community development credit unions, and housing and micro-enterprise loan funds that support lending in underserved communities. Within the total, $167 million is for financial and technical assistance grants, $17 million for Native Initiatives, $23 million for healthy food financing initiatives, $26 million for the Bank Enterprise Award program, and $29 million for administrative expenses. The measure requires at least 10% of appropriated funds to be used for awards to support investments in "persistent poverty counties."

Treasury Administration & Other Activities

The measure appropriates a total of $677 million for the Treasury Department's departmental offices (this amount includes the aforementioned funding for both the terrorism office and CFIUS). Of the total, $231 million is for general Treasury Department salaries and expenses, 2% more than FY 2020. The total also includes $18 million for the department's Cybersecurity Enhancement Account (equal to FY 2020) and $6 million for the Treasury Department's systems and capital investments account (both equal to FY 2020).

Separately, the measure provides $25 million for the Treasury Department to begin the process of digitizing records for unclaimed savings bonds going as far back as World War II. Making it easier to search these records in a digital format could help bond owners redeem more than $24 billion in bonds, according to appropriators.

It also continues several policy provisions from previous years, including a prohibition on using funds to redesign the One Dollar bill and a prohibition on consolidating the U.S. Mint (which produces coins) and the Bureau of Engraving and Printing (which produces paper currency) without the approval of Congress.

Inspectors General

The agreement provides $41 million for the Treasury Department's Inspector General, equal to FY 2020.

It provides $170 million for the Treasury Inspector General for Tax Administration (TIGTA), equal to FY 2020. The office conducts audits and investigations to assess the operations and programs of the IRS.

It also provides $19 million for the Special Inspector General for the Troubled Asset Relief Program (TARP), 14% less than FY 2020. This office was created by the 2008 Emergency Economic Stabilization Act (PL 110-343) to coordinate the audits and investigations of Treasury assets under TARP.

Judiciary

The agreement provides $8.2 billion for the operation of the federal court system, including salaries of judges, magistrates, support personnel and other expenses of the federal judiciary -- 4% more than FY 2020. Of the total, $47 million is for the salaries of Supreme Court justices and other federal judges, which counts as mandatory spending.

Supreme Court

The measure provides $98 million for the salaries and expenses of the Supreme Court (including $3 million for the Justices' salaries), 8% more than FY 2020. A separate $11 million appropriation (32% less than FY 2020) is provided for care of the buildings and grounds, which are supervised by the Architect of the Capitol.

Federal Courts and Judicial Services

The agreement appropriates $5.9 billion for the U.S. Courts of Appeals, U.S. District Courts, Bankruptcy Courts, Federal Claims Court, as well as probation and pretrial services (4% more than FY 2020). This amount includes $469 million in mandatory spending for the salaries of judges.

Separately, it provides 3% increases for both the U.S. Court of Appeals for the Federal Circuit ($37 million in FY 2021, including $3 million for mandatory judges' salaries) and the U.S. Court of International Trade ($22 million in FY 2021, including $2 million for judges' salaries). Another $1.3 billion is provided for defender services, and $664 million is provided for court security, and $33 million is provided for juror fees.

The measure extends certain temporary federal judgeships in several court districts and it continues a pilot program for the U.S. Marshals Service to provide security at federal courthouses.

Other Judicial Operations

The measure also provides $96 million for Administrative Office of the U.S. Courts, which provides administrative and management support to U.S. courts; $29 million for the Federal Judicial Center, which improves the management of federal judicial dockets and court administration; and $20 million for the U.S. Sentencing Commission, which reviews and revises sentencing guidelines and practices for the federal criminal justice system.

White House/Executive Office of the President

The agreement appropriates $759 million for the White House and the Executive Office of the President -- 4% more than FY 2020.

The President & White House Operations

The measure provides $195 million for the White House, 9% more than FY 2020. Within that total, it provides $55 million for core White House staff and administrative services that directly support the president (the president's $450,000 salary is provided elsewhere as a separate mandatory expense). Another $8 million is provided for presidential transition activities (in addition to other funds provided to the General Services Administration; see below).

The total includes $100 million (6% more than FY 2020) for general administrative services to the overall Executive Office of the President, including financial, personnel, library, information management and general office services; as well as $16 million (17% more) for operating expenses of the White House residence, including $2.5 million for White House repair and restoration activities. It also provides $12 million for the staff of the National Security Council and Homeland Security Council, and $4 million for the president's Council of Economic Advisers.

Additionally, the agreement provides $5 million for the Vice President's office and staff, (8% more than FY 2020), of which $302,000 is for the operating expenses of the vice president's residence.

Office of Management & Budget

The measure provides $107 million for the Office of Management and Budget (OMB), 5% more than FY 2020. OMB assists the president in the discharge of budgetary, economic, management and other executive responsibilities.

Drug-Related Programs

The measure appropriates a total of $437 million for the Office of National Drug Control Policy (ONDCP), which is responsible for developing policies, objectives and priorities for the National Drug Control Program. The total is 3% more than FY 2020.

Within the total, the measure provides $290 million (2% more than FY 2020) for the High Intensity Drug Trafficking Areas (HIDTA) Program -- rejecting the administration's proposal to shift the program's activities to the Drug Enforcement Administration (DEA). The program provides assistance to federal, state and local law enforcement units operating in areas that are most adversely affected by drug trafficking and have been designated as high-traffic areas.

It also provides $128 million (5% more than FY 2020) for other federal drug control programs -- including $102 million for the drug free communities program, $14 million for anti-doping activities, and $5 million for grants to help communities fight prescription drug abuse.

Other Federal Agencies

The agreement funds a wide range of other federal agencies, including the Office of Personnel Management, the General Services Administration (GSA), the Small Business Administration, the Securities and Exchange Commission, and the Federal Communications Commission.

General Services Administration

GSA operations are funded primarily through monies from the Federal Buildings Fund, which derives most of its revenue from rents paid to the GSA by federal agencies. The GSA then uses funds from the Building Fund to pay for the construction and repair of federal buildings, the rent for private buildings that house federal agencies, and for various building operation and maintenance activities. GSA also receives funding from other sources, including direct appropriations.

The agreement estimates that the Federal Buildings Fund will receive $10.4 billion in rental income, and it provides for the release of $9.1 billion of that amount for building repairs and alterations, installment payments, rent, and building operations and maintenance. The $9.1 billion in allowed expenses from the fund is 2% more than FY 2020. (The difference between the fund's income and expenses allowed is scored as savings that is used to offset spending elsewhere in the measure.)

Under the measure, spending from the Federal Buildings Fund would be used for rental of private space to house federal agencies ($5.7 billion), building operations ($2.5 billion), construction and acquisition ($230 million), and building repairs and alterations ($577 million) -- including $204 million for major repairs and alterations (55% less than FY 2020).

The agreement directs the GSA to report to Congress on the construction of a new FBI headquarters in the D.C. metro area. (Construction of a new FBI headquarters in the Washington D.C. region has been delayed partly because of President Trump's desire to maintain the headquarters at its current site opposite the Trump Hotel on Pennsylvania Ave. in the District).

In addition to amounts from the Federal Buildings Fund, the measure directly appropriates $300 million for other GSA operations, accounts, and activities. That includes $64 million (equal to FY 2020) for the Office of Government-Wide Policy, which establishes guidelines and conducts and evaluation activities; $49 million (equal to FY 2020) for GSA's Operating Expenses account; $4 million for the pensions and related expenses of former presidents, and $10 million for activities related to the Presidential Transition in FY 2021.

Office of Personnel Management

The Office of Personnel Management (OPM) is responsible for management of federal human resources policy and oversight of the merit civil service system. It is also responsible for administering the retirement, health benefits and life insurance programs affecting most federal employees, retired federal employees and their survivors.

The measure rejects the Trump administration's proposal to eliminate OPM as a separate agency and merge its functions with the General Services Administration (GSA), and it includes language prohibiting funds from being used to reorganize OPM or transfer any of its functions to the GSA or the OMB. Instead it provides $330 million for the agency's salaries and expenses (a 9% increase), as well as $32 million for OPM's inspector general (6% more).

Small Business Administration

The measure provides $922 million in base funding for the Small Business Administration (SBA) -- 8% less than FY 2020 -- including $270 million for salaries and expenses. (Additional SBA assistance for small businesses is provided within the COVID relief section of the agreement).

Of the total, $20 million is provided for the credit subsidy for SBA business loans and loan guarantees under the SBA Microloan and 7(a) loan program, while the agreement sets the total loan authorization for the 7(a) loan program at $30 billion. It also provides $160 million for administrative costs.

Another $168 million is provided for the administrative costs of SBA disaster loan program, which is mostly financed by the repayment of loans. Within this amount, $143 million is available through a disaster budget cap adjustment for major disasters.

The agreement also provides includes $272 million for the SBA Entrepreneurial Development Programs (EDP), which provides training, counseling and resources to assist small-business owners compete in global markets. This amount includes $136 million for Small Business Development Centers, $23 million for Women's Business Centers, $20 million for the State Trade Expansion Program, and $12 million for the SCORE mentorship program.

Securities & Exchange Commission

The agreement provides $1.9 billion for the Securities & Exchange Commission (SEC) -- 4% more than FY 2020 -- including $19 million for the replacement lease on the SEC's headquarters in Washington, D.C., and $13 million to cover relocation costs for the SEC's San Francisco regional office. All funds are offset by fees and collections, resulting in no net appropriation.

The primary mission of the SEC is to protect investors, maintain the integrity of the securities markets and ensure that adequate information on the capital markets is made available to market participants and policymakers.

Unlike the House-passed bill, the agreement continues to prohibit the SEC from issuing a rule to require publicly traded companies to disclose political contributions, contributions to tax exempt organizations, or dues paid to trade associations.

Commodity Futures Trading Commission

The measure provides $268 million for the Commodity Futures Trading Commission (CFTC), which is responsible for regulating and managing the U.S. futures and options markets. The total provided is $19 million (3%) less than FY 2020.

(Appropriations for the CFTC alternate each year between the Financial Services and Agriculture spending bills, and for FY 2020 was provided through the Agriculture bill.)

Federal Communications Commission

The measure provides $374 million for the Federal Communications Commission (FCC) -- 10% more than FY 2020 -- all of which would be derived from offsetting collections.

Federal Trade Commission

The mission of the Federal Trade Commission (FTC) is to enforce a variety of federal antitrust and consumer protection laws. Appropriations for both the Antitrust Division of the Department of Justice and the FTC are partially financed with Hart-Scott-Rodino Act pre-merger filing fees. The FTC's appropriation is also partially offset by Do-Not-Call registry fees.

The agreement provides $351 million for the FTC, 6% more than FY 2020. It is estimated that $169 million of that amount would be offset by collected fees, for a net direct appropriation of $182 million.

National Archives & Records Administration

The National Archives and Records Administration (NARA) is responsible for management of the federal government's archives and records, services to the public, operation of presidential libraries, review for declassification of classified security information, and the preservation, storage, and management of digital federal records.

The measure provides $398 million for NARA operating expenses -- 5% more than FY 2020. That total provides $9.5 million for repairs and restoration and $6.5 million for the National Historical Publications and Records Commission Grants program.

Separately, another $50 million in emergency funding is provided by the measure for NARA's Record Center Revolving Fund to offset the loss of user fees that typically fund the center as a result of the COVID pandemic. The agreement allows these funds to be used to accelerate the processing of military service record requests.

U.S. Postal Service

The U.S. Postal Service is a self-financed, semi-autonomous entity whose operations are funded primarily through postage rates paid by consumers. Congress, however, each year provides funds to the Postal Service to cover the costs of revenue forgone on free and reduced-rate mail for the blind and overseas voters.

The agreement includes $55 million in such payments for the Postal Service Fund (2% less than FY 2020) as well as $250 million for the Postal Service's inspector general (equal to FY 2020). The measure continues to direct USPS to issue semipostal charity stamps, which are sold above their postal value to raise funds for international wildlife conservation and research into Alzheimer's disease.

A separate appropriation of $17 million (2% more than FY 2020) is provided out of the Postal Service Fund for the Postal Regulatory Commission, a separate government agency that maintains USPS ratemaking systems, measures its performance, and conducts oversight and enforcement actions.

Other Independent Agencies

Funding for other independent agencies is provided as follows:

Federal Election Commission -- $71 million (equal to FY 2020) for administering the disclosure of campaign finance information and enforcing limitations on contributions and expenditures.

Consumer Product Safety Commission -- $135 million for the CPSC (2% more than FY 2020). The independent federal regulatory agency is responsible for reducing the risk of injury associated with consumer products. The agreement prohibits the agency from implementing new safety standards for off-road recreational vehicles until after the National Academy of Sciences completes a study on these vehicles.

Election Assistance Commission -- $17 million for the commission (12% more than FY 2020 for base operations, however no funds are appropriated for new EAC grants in FY 2021). The commission was established to improve the administration of elections in the United States by developing voluntary voting systems guidelines, certifiying and testing voting systems, and providing election assistance grants to states.

Merit Systems Protection Board -- $47 million for activities of the board in maintaining the Civil Service merit system, equal to FY 2020.

Federal Labor Relations Authority -- $27 million (7% more than FY 2020) for the agency that serves as a neutral arbiter in the labor activities of the federal workforce.

Office of Government Ethics -- $19 million (6% more than FY 2020) for the office that oversees executive branch policies to prevent conflicts of interest and to ensure high ethical standards.

Office of Special Counsel -- $30 million (7% more than FY 2020) for investigations into federal employee allegations of prohibited practices, providing a channel for whistle-blowers and enforcing the Hatch Act.

Selective Service System -- $26 million (4% less than FY 2020) for activities of the service to continue its draft registration activities.

U.S. Tax Court -- $56 million for activities of the Tax Court (6% more than FY 2020).

Public Buildings Reform Board -- $3.5 million for the board, which was established by the 2016 Federal Assets Sale & Transfer Act (PL 114-287) to identify opportunities for the federal government to reduce its inventory of underutilized property. The board did not receive any appropriations in FY 2020 after lawmakers noted that the board did not explain how they were using their FY 2019 funding.

The measure rejects the administration's proposal to place the Consumer Financial Protection Bureau under the appropriations process. This independent agency, which has authorities to make regulations, supervise private businesses, and enforce federal consumer protection laws, is directly funded through the Federal Reserve System.

Mandatory Items and General Provisions

The agreement provided for a total of $22.9 billion in mandatory spending, including $477 million for salaries of Supreme Court justices and other federal judges and an estimated $22.4 billion for other appropriated mandatory accounts where authorizing language requires the payment of funds.

These mandatory funds include payments for federal employee and retiree health benefits, the civil service retirement and disability fund, federal employee life insurance benefits, and judicial retirement funds. This total also includes $450,000 for the president's salary.

Policy Provisions

The agreement provides a 1% pay raise for federal civilian employees according to House appropriators. However, it eliminates automatic statutory pay increases for the Vice President and other senior political appointees.

It also includes a range of policy provisions, many of which have been included in past appropriations laws, including limitations on certain expenses and requirements for reprogramming funds, and a requirement that all federal computers purchased with these funds block the viewing of pornography. It continues a prohibition on the funding of abortions under federal employee health benefit plans and through multi-state qualified health plans negotiated by OPM that are offered under the 2010 health care law (exceptions are provided where the life of the mother would be endangered, or if the pregnancy is the result of rape or incest).

Unlike the House-passed bill, the agreement does not allows federal agencies to employ "Dreamers" (U.S. residents that came into the country as children without proper immigration status) who hold employment authorizations under the Deferred Action for Childhood Arrivals (DACA) program. It also continues to prohibit federal agencies from requiring businesses soliciting a federal contract to disclose their political contributions or expenditures.

District of Columbia

The agreement provides $735 million in federal payments to the District of Columbia for FY 2021 -- 3% more than FY 2021.

Within the total, it provides $250 million for the D.C. court system, which includes $15 million for the D.C. Court of Appeals, $126 million for the Superior Court, $79 million for the general court system, and $30 million for capital improvements. The agreement also provides $246 million for D.C. Court Services and Offender Supervision Agency, $46 million for defender services in D.C. courts, and $46 million for the Public Defender Service.

For D.C. education, it provides $52.5 million for the school improvement account, under which scholarships are provided for low-income youth to attend private schools, and $40 million to help college-bound District residents offset out-of-state college tuition costs. Another $600,000 is provided for tuition assistance for D.C. National Guard members.

The measure also provides $4 million for HIV/AIDS Prevention activities, and $8 million to the D.C. Water and Sewer Authority to continue implementation of a long-term development plan, on the condition that the authority provide a 100% matching payment.

Finally, the measure provides $38.4 million for D.C. emergency planning and security costs, an $18 million (113%) increase that reflects the additional anticipated costs of the Presidential Inauguration in January 2021. (An additional $13 million was provided for D.C. emergency planning and security in PL 116-159, the continuing resolution enacted in September.

The agreement continues provisions from previous years' bills that prohibit the D.C. government from using federally provided funds to establish clean needle exchange programs, and prohibit D.C. from using funds to legalize marijuana use, and prohibit D.C. from using any funds to provide abortion, except in certain cases.

By Daniel Peake [email protected]

Section VII

Homeland Security

This section describes the provisions of HR 133, Consolidated Appropriations Act for FY 2021, that provide funding for the Homeland Security Department.

The agreement provides a net total of $51.9 billion in discretionary spending subject to caps and $17.1 billion subject to the cap adjustment for disaster funding, as well as $840 million in discretionary spending -- for a total of $69.9 billion in scored discretionary spending. According to appropriators, net capped spending is $1.41 billion more than FY 2020 but $195.5 million less than requested. Of the total, $2.55 billion is classified as defense spending.

On a programmatic basis, after incorporating $5.0 billion in offsetting collections that don't count towards scored discretionary spending, factoring out the offsetting impact of rescissions, and adding in $1.9 billion in mandatory spending as well as $8.1 billion in spending that is automatically available through fees collected by certain agencies, the measure actually provides a total of almost $85.1 billion for homeland spending for FY 2021 -- $2.6 billion more than FY 2020 and $14.4 billion more than requested.

The measure includes $1.4 billion for 56 miles of physical barrier along the U.S.-Mexico border (the same spending as last year). It also reduces spending on Immigration and Customs Enforcement's removal operations by 7%, provides no funding for additional ICE agents and officers, and funds an average of 34,000 detention beds.

It increases funding for the Coast Guard by $879 million, including funding for new vessels and aircraft, while also increasing funding for Secret Service protective operations and for the Transportation Security Administration. It provides $21.7 billion for FEMA, including $17.1 billion for the Disaster Relief Fund, and rejects administration proposals to cut FEMA grants programs as well as FEMA education, training and exercise activities.

Security, Enforcement & Investigations

The agreement provides a total of $49.9 billion in net discretionary funding for security, enforcement and investigation activities of the Homeland Security Department -- including funding for Customs and Border Protection (CBP), Immigration and Customs Enforcement (ICE), the Transportation Security Administration (TSA), and the Coast Guard and Secret Service.

That total net discretionary spending is $1.4 billion (2%) more than comparable FY 2020 funding. An additional $3.2 billion in discretionary spending for those activities would be offset by certain offsetting collections ($314 million more than FY 2020), and it is estimated that another $3.1 billion for certain activities would be available through the collection of various fees. The measure also provides $1.9 billion in mandatory funding.

Customs & Border Protection

The measure provides a total of $15.0 billion for Customs and Border Protection (including $239 million through offsetting collections) -- $123 million (1%) more than FY 2020. In addition, another $2.4 billion would be available through fee-funded programs ($48 million less than FY 2020), bringing CBP funding for FY 2021 to a total of $17.7 billion, $275 million more than FY 2020. The measure also includes $840 million in emergency funding to offset the loss of customs and immigration fee revenue due to the pandemic.

Border Security

The agreement provides $4.9 billion for CBP border and security operations, $49 million (1%) less than FY 2020.

That total includes $4.1 billion for operations of the U.S. Border Patrol, $132 million more than FY 2020. It includes $717 million for assets and support (3% more than FY 2020 funding) and $62 million more for training and development (a 3% increase). No funding is available for the hiring new border patrol agents and other law enforcement officers.

It provides $1.2 billion for CBP's Integrated Operations activities, including air and marine operations, intelligence and international affairs. Actual CBP air and marine operations would receive $318 million, 1% more than FY 2020, while funding for assets and support for those operations would receive $586 million, 6% more than FY 2020.

The measure also provides $1.8 billion for CBP procurement, construction and improvements activities -- including $1.5 billion for border security assets and infrastructure, a $4 million increase. Of that funding, $1.375 billion is for construction of 56 miles of barriers along the U.S. border with Mexico, as part of President Trump's proposed border "wall." However, no funding may be used to construct fencing in Bentsen-Rio State Park, the National Butterfly Center, the Santa Ana Wildlife Refuge, the Lower Rio Grande Wildlife Refuge between Brownsville, Texas and the Gulf of Mexico, and historic cemeteries. CBP must provide an expenditure plan before any funding can be used for border security construction and acquisition.

According to CBP data as of Jan. 4, of the 452 miles of border wall completed during the Trump administration, 372 miles of it replaced dilapidated or previously existing barriers. The remaining 80 miles of barrier was constructed in places where nothing existed previously.

The procurement and construction total also includes $119 million for new aircraft and sensors ($66 million less than FY 2020).

Other CBP Activities

The measure provides $5.0 billion for CBP's trade and travel operations, $180 million (4%) more than FY 2020 funding. Within the total, $3.2 billion is for CBP's domestic operations (4% more than FY 2020), $148 million for its international operations (3% more), and $1.0 billion is for assets and support (3% more).

It also provides $1.9 billion for general CBP mission support, $20 million (2%) more than FY 2020.

Fee-Funded Activities

In addition to the amounts appropriated in the measure, CBP is expected to receive $2.4 billion in fees that will be used to conduct various activities. Those include $794 million in user fees for immigration inspections, $681 million in fees for passenger inspections, and $582 million for inspections by the Animal and Plant Health Inspection Service.

Immigration & Customs Enforcement

The agreement provides a total $8.0 billion for Immigration and Customs Enforcement -- $107 million (1%) less than FY 2020. In addition, another $377 million would be available through fee-funded programs ($57 million more than FY 2020), bringing ICE funding for FY 2021 to a total of $8.4 billion.

The measure provides no funding for additional officers but provides funding for an average of 34,000 detention beds.

Immigration Enforcement

The total includes $4.1 billion for immigration enforcement and removal activities, $310 million (7%) less than FY 2020.

Within that total, $2.8 billion is for ICE's custody operations, $306 million (10%) less than FY 2020. That funding would provide for an average of 34,000 detention beds.

The total includes $145 million for ICE's fugitive operations ($6 million more than FY 2020) and $278 million for ICE's criminal alien program ($13 million more). The criminal alien program would support the addition of 31 new communities to the 287(g) program, through which ICE works with state and local law enforcement to identify criminal aliens.

Other ICE Activities

The agreement provides $2.1 billion for homeland security investigations by ICE, $96 million (5%) more than FY 2020. ICE's Homeland Security Investigations (HSI) unit is responsible for disrupting and dismantling transnational criminal threats facing the United States. HSI special agents also conduct national security investigations targeting violations of the nation's customs and immigration laws.

Within the total, $1.9 billion is for domestic investigations, $85 million (5%) more than FY 2020. High-priority mission areas include activities at the Child Exploitation Unit at the Cyber Crime Center and Operation Angel Watch; commercial fraud and intellectual property rights enforcement; anti-proliferation; gangs and transnational criminal organizations; cybercrimes investigations; and anti-terrorism activities. That total also includes $187 million for foreign investigations through offices in 46 counties (4% more than FY 2020) and $98 million for intelligence (4% more).

The measure also provides $1.3 billion for general ICE mission support (3% more than FY 2020), $314 million for legal proceedings (8% more) and $98 million for procurement and construction (more than double FY 2020).

Fee-Funded Activities

In addition to the amounts appropriated in the measure, ICE is expected to receive $377 million in fees that will be used to conduct various activities. Those include $135 million in user fees for immigration inspections, and $187 million in fees for student exchange and visitor services.

Transportation Security Administration

The agreement appropriates $8.0 billion for the Transportation Security Administration ($3.0 billion to be derived through offsetting collections) -- $144 million (2%) more than FY 2020. In addition, another $359 million would be available through fee-funded programs ($123 million more than FY 2020) and $250 million in mandatory funding is provided, bringing TSA funding for FY 2021 to a total of $8.6 billion, $267 million more than FY 2020.

Aviation Screening

The bulk of TSA funding is for aviation screening activities for which $5.5 billion is provided -- $116 million (2%) more than FY 2020. Of that total, $3.0 billion would be provided as an offsetting collection through aviation passenger screening fees. The measure rejects the administration proposal to increase those fees to raise another $560 million.

Within that total, $3.8 billion is for TSA's screener workforce ($97 million more than FY 2020), $226 million for the screening partnership program (slightly more than FY 2020), and $236 million is for screener training and related activities ($8 million less than FY 2020).

The total for aviation screening also includes $478 million for screening technology maintenance (2% more than FY 2020), $170 million for canine teams, $116 million for privatized screening through the Secure Flight program ($1 million more than FY 2020), and $652 million for airport management (2% more).

Other TSA Security Activities

The measure provides $765 million for federal air marshals (1% more than FY 2020) and $20 million for the Federal Flight Deck Officer and Flight Crew Training program, which allows pilots to voluntarily carry firearms for the purpose of defending the flight deck against 9/11-style attacks (18% less than FY 2020). It provides $107 million for screening air cargo (2% more than FY 2020), and $238 million for TSA's aviation regulatory activities (3% more).

The agreement provides $76 million for intelligence activities and operation of the Transportation Security Operations Center ($1 million less than FY 2020), $45 million for TSA vetting activities for secure transportation credentials (13% less than FY 2020), and $142 million for TSA's surface transportation security programs (1% more).

The measure appropriates $134 million for TSA procurement and construction activities, $24 million (22%) more than FY 2020 and also includes the requested $30 million for TSA research and development activities, $6 million more than FY 2020 funding.

Fee-Funded Activities

In addition to the amounts appropriated in the measure, TSA is expected to receive $359 million in fees that will be used to conduct various activities. Those include $251 million in user fees for the TSA PreCheck program, and $70 million for issuing Transportation Worker Identification Cards for access to secure areas.

Coast Guard

The measure provides a total of $12.8 billion for the Coast Guard -- which is one of the nation's five armed services but also has non-military responsibilities -- including $11.0 billion in discretionary spending and $1.9 billion in mandatory spending for Coast Guard retirement pay. It also includes no OCO funding. The discretionary total is $811 million (8%) more than FY 2020.

Coast Guard Operations

Of the discretionary total, $8.5 billion is for Coast Guard operating expenses -- $304 million (4%) more than FY 2020. The amount includes $4.2 billion for military pay and allowances and $1.1 billion for civilian pay and benefits, and $237 million for training and recruiting (12% more than FY 2020). It also includes $993 million for operating funds and unit-level maintenance (7% more than FY 2020) and $1.7 billion for intermediate- and depot-level maintenance (15% more than FY 2020).

Acquisition, Construction & Other Activities

The agreement includes $2.3 billion for Coast Guard capital acquisition, construction and improvement programs, $492 million (28%) more than FY 2020.

Of the total, $1.5 billion is for ships ($536 million more than FY 2020), including $31 million for a National Security Cutter, $546 million for a new offshore patrol cutter, and $260 million for a fast response cutter. It provides $312 million for various aircraft accounts ($193 million, or 38% less than FY 2020) -- including $120 million for HC - 130J aircraft and the acquisition of an additional HC - 130J aircraft.

It also provides $59 million for other equipment (14% less than FY 2020) and $363 million for shore facilities and aids to navigation (77% more).

Outside of the acquisition accounts, the measure provides $131 million (5% more than FY 2020) for reserve training, and $21 million for Coast Guard environmental compliance and restoration activities (6% more than FY 2020).

Secret Service

The measure appropriates $2.4 billion for the Secret Service, $22 million (1%) more than FY 2020. The administration's request included funding the agency through the Financial Services appropriations bill, which was rejected by Congress.

The total for FY 2021 includes $1.0 billion for Secret Service protection activities ($1 million more than FY 2020) -- including $819 million for protecting persons and facilities (8% more than FY 2020) and $727 million for Secret Service field operations, $23 million (3%) more than FY 2020 -- including for investigating the following: currency counterfeiting; financial crimes such as access device fraud, financial institution fraud, identity theft, and computer fraud; and computer-based attacks on financial, banking, and telecommunications infrastructure. It also provides support for investigations related to missing and exploited children.

The agreement provides $509 million for general mission support (2% more than FY 2020) and $52 million for procurement and construction activities ($14 million less than FY 2020).

FEMA / National Protection Directorate

The agreement provides a total of $24.0 billion for Homeland Security Department activities focused on national protection, preparedness, response and recovery, including the Federal Emergency Management Agency (FEMA) and the department's National Protection and Programs Directorate.

The total provided (which includes $238 million in offsetting collections), is $582 million (2%) less than FY 2020.

FEMA

The measure provides $21.9 billion for FEMA (including $238 million in offsetting collections) -- $592 million (3%) less than FY 2020. It rejects the administration's proposal to substantially cut many FEMA grant programs.

The total provided for FEMA includes $4.7 billion in regular appropriations and $17.1 billion designated as disaster relief funding under the BCA's disaster relief cap.

It includes $1.1 billion for general FEMA operations and support, 2% more than FY 2020. Within that amount, it provides $155 million for preparedness and protection activities (5% more than FY 2020) and $43 million for mitigation activities (4% more). It also provides $248 million for response and recovery activities ($9 million more than FY 2020), including $38 million for the Urban Search and Rescue Response System, and $508 million for general FEMA mission support (slightly more than FY 2020).

It provides $106 million for FEMA procurement and construction activities, $27 million less than FY 2020.

FEMA Disaster Relief

The measure provides a total of $17.1 billion for FEMA's Disaster Relief Fund, which is used to cover disaster assistance programs and to coordinate the federal response to presidentially declared disasters, including assistance to state and local governments. The total includes no funding in base disaster relief funding and instead all of its funding is subject to the BCA's disaster relief cap (and not the measure's regular budget cap), which together is $721 million less than the enacted FY 2020 level.

FEMA Grants & Other Aid

The measure provides a total of $3.0 billion for FEMA grants and aid to states and local governments -- $124 million (4%) more than FY 2020.

For FEMA training, exercises, and similar activities to help state and local governments prepare for, and respond to, terrorism and natural disasters, the measure provides $288 million -- $7 million more than FY 2020. It rejects the administration's proposal to terminate funding for the National Domestic Preparedness Consortium and for Continuing Training Grants, but maintains FY 2020 funding for those programs. It provides $19 million for the National Exercise Program, $22 million for the Emergency Management Institute, $49 million for the U.S. Fire Administration, and $67 million for the Center for Domestic Preparedness.

National Flood Insurance & Flood Mapping

The agreement provides the requested $204 million for the National Flood Insurance Fund ($2 million less than FY 2020), all of which is offset through the collection of insurance premiums.

The fund supports the National Flood Insurance Program (NFIP), which provides federal flood insurance for properties located in flood-prone areas where the community has voluntarily agreed to institute floodplain management and land use control measures that minimize the risk of flooding and mitigate potential flood damage. Of the total provided, $191 million is for floodplain management and mapping and $14 million is for mission support.

CISA

The measure provides a total $2.0 billion for the Cybersecurity and Infrastructure Security Agency -- $9 million more than FY 2020. The agency focuses on activities to enhance the security and resilience of U.S. infrastructure against terrorist attacks, cyber events, natural disasters, and other large-scale incidents.

The total includes $93 million for agency operations, including $44 million for threat hunting, $43 million for the Continuous Diagnostic and Mitigation program, and $21 million for the National Cybersecurity Protection System.

Other Homeland Activities

Science & Technology Directorate

The agreement appropriates $766 million for the department's Science and Technology Directorate, $28 million (4%) more than FY 2020. The office is responsible for promoting the development and deployment of cutting-edge technologies and new capabilities to improve homeland security, such as the development of countermeasures to terrorist threats, including those involving weapons of mass destruction.

Of the total, $444 million is for research, development and innovation, $22 million (5%) more than FY 2020. It includes $45 million for university programs, $4 million more than FY 2020.

The total also includes $19 million for laboratory facilities (no funding was provided in FY 2020), which would prevent the closure of three laboratories operated by the directorate -- the National Urban Security Technology Laboratory, the Chemical Security Analysis Center, and the National Biodefense Analysis and Countermeasures Center.

Countering Weapons of Mass Destruction

The agreement appropriates $402 million for the Countering Weapons of Mass Destruction Office, $30 million (7%) less than FY 2020. The office is responsible for coordinating the department's efforts to develop a global nuclear detection architecture, as well as a domestic system to detect attempts to bring nuclear and radiological material into the United States.

The total includes $65 million for research and development activities, including on detection capabilities (5% less than FY 2020). It also includes $87 million for procurement and construction activities (26% less than FY 2020), including $61 million for large scale detection systems (34% less than FY 2020) and $27 million for human portable radiation/nuclear detection systems (slightly less).

U.S. Citizenship & Immigration Services

U.S. Citizenship and Immigration Services (USCIS) is responsible for the immigration services and benefit functions that were handled by the Immigration and Naturalization Services before creation of the Homeland Security Department.

For FY 2021, a total of $5.1 billion would be available for USCIS, of which $4.9 billion would be derived from fees charged by the agency. The total available for the agency is $208 million (4%) more than FY 2020.

Fee-funded services include $2.0 billion for district operations, $827 million for service center operations, $372 million for asylum, refugee and international operations, and $37 million for verifying an immigrant's eligibility for certain federal benefits. The measure prohibits USCIS from granting any immigration benefit unless that individual has completed and passed a background check.

Federal Law Enforcement Training Center

The measure appropriates $340 million for salaries and expenses of the Federal Law Enforcement Training Center, $11 million (3%) less than FY 2020. Of the total, $284 million is for training and $30 million is for mission support.

Other Departmental Management Accounts & Provisions

The measure appropriates $1.6 billion for general Homeland Security Department operations, $50 million more than FY 2020.

The total includes $206 million for the Office of the Secretary and Executive Management (15% more than FY 2020) and $1.6 billion for the department's management directorate (3% more than FY 2020). Within that larger amount, it provides $4.5 million for the Undersecretary for Management; $89 million for the Chief Financial Officer; $501 million for the Chief Information Officer; $107 million for the Chief Procurement Officer; and $135 million for the Chief Security Officer.

It also provides $299 million for the department's general intelligence, analysis and operations (5% more than FY 2020), and $190 million for the Office of the Inspector General which must continue its program of unannounced inspections of immigration detention facilities and ensure that the results of the inspections and other reports and notifications related to custody operations activities are posted on a publicly available website.

By Daniel Peake [email protected]

Section VIII

Interior-Environment

This section describes the provisions of HR 133, Consolidated FY 2021 Appropriations Act, that provide funding for the Interior Department, EPA and related agencies.

The agreement provides a net total of $36.1 billion in discretionary spending subject to caps and $2.35 billion in subject to its own fire suppression cap adjustment, for a total of $38.5 billion in scored discretionary spending. According to appropriators, the net regular capped spending is $118 million more than FY 2020 and $4.5 billion more than requested. Total discretionary spending under the measure is $218 million (0.5%) more than comparable FY 2020 spending and $4.5 billion (13%) more than requested. The measure also includes $64 million in mandatory funding.

The measure rejects the administration's proposed 26% cut to EPA and instead increases funding by 3% to $9.2 billion, and boosts EPA funding for enforcement, compliance, and research as well as a half dozen new state grant programs. It provides a total of $13.7 billion for the Interior Department ($186 million above comparable FY 2020 funding) with most agencies receiving increases, including the National Park Service ($44 million), U.S. Geological Survey ($45 million), and U.S. Fish and Wildlife Service ($22 million) -- but it cuts funding for the Bureau of Land Management by $28 million.

It provides $7.4 billion for the U.S. Forest Service, including $3.5 billion in core Forest Service activities and $4.0 billion for fighting wildfires. The combined Interior and Forest Service wildfire budgets would provide a total of $5.3 billion for fighting wildfires -- $104 million more than comparable FY 2020 funding.

The measure also increases funding for American Indian programs administered by the Bureau of Indian Affairs (9% more than FY 2020) and the Indian Health Service (3% more).

Environmental Protection Agency

The agreement provides $9.2 billion in discretionary appropriations for EPA -- $180 million (2%) more than FY 2020 funding and $2.5 billion (38%) more than requested.

The measure rejects the deep reductions proposed by the administration for EPA activities, instead increasing funding for most EPA programs, including Superfund cleanups and state and tribal assistance grants. The joint explanatory material accompany the measure encourages the agency to investigate any linkages between exposure to pollution and increased risk for adverse health outcomes from communicable respiratory diseases, such as COVID-19.

EPA Enforcement & Environmental Management Activities

The agreement appropriates $2.8 billion for EPA environmental programs and management accounts, through which EPA performs its general environmental oversight activities -- $98 million (4%) more than FY 2020.

Within this account, it increases funding for numerous enforcement and associated activities, including: EPA enforcement actions ($248 million, 3% more than FY 2020); EPA's compliance activities ($103 million, 1% more than FY 2020); EPA clean air activities ($282 million, 3% more than FY 2020); EPA activities under the Resource Conservation and Recovery Act ($119 million, 5% more than FY 2020); and water-related activities to protect human health ($108 million, 6% more than FY 2020 and 10% more than requested).

It also increases funding for legal, science, regulatory and economic reviews (providing $106 million, 2% more than FY 2020), EPA's toxics risk review and prevention activities ($94 million, 3% more), EPA's pesticide licensing activities ($109 million, 2% more) and the underground storage tanks program ($11 million, 4% more).

The measure rejects the administration's proposal to eliminate funding for all but three of EPA's geographic programs that fund environmental restoration and preservation initiatives for specified areas. Instead, it increases funding for all programs, providing a total $542 million, $32 million (6%) more than FY 2020. Those receiving increases include the Great Lakes Restoration Initiative ($330 million, $10 million more than FY 2020); the Chesapeake Bay initiative ($88 million, $3 million more); and nine others the administration proposed to terminate, including the San Francisco Bay and Long Island Sound programs, which would receive 51% and 45% increases, respectively.

EPA Grant Programs

The EPA oversees numerous grant and funding programs that offer assistance to states, Native American tribes and municipal governments for environment-related infrastructure and cleanup projects, or for specific categories of projects, such as air quality management, brownfields cleanup and wetland programs.

The measure provides $4.3 billion for these EPA state and tribal assistance grants -- $68 million (2%) more than FY 2020.

For infrastructure assistance grants, it provides a base total of $3.2 billion, $44 million (1%) more than FY 2020. Included in this total is $1.6 billion for the Clean Water State Revolving Fund and $1.1 billion for the Drinking Water State Revolving Fund, both equal to current funding.

It rejects administration proposals to end or virtually eliminate grants for water infrastructure along the U.S.-Mexico border and for Alaska Native villages, increasing funding for Mexico border grants by $5 million to $30 million and Alaska Native grants by $7 million to $36 million. Funding for Brownfields projects would be increased slightly to $91 million, while sewer overflow control grants would see a more than 40% increase to $40 million.

For categorical grants, it provides a total of $1.1 billion for EPA -- $23 million more than FY 2020. Increases would be provided for pollution control grants (which would receive $30 million for FY 2021), state and local air quality management grants ($230 million), public water system supervision grants ($112 million), and hazardous waste financial assistance ($102 million). Funding would be essentially flat for Brownfields grants ($46 million) and nonpoint source pollution grants ($177 million).

WIFIA Program

The measure provides $65 million for the Water Infrastructure Finance and Innovation Act (WIFIA) program, which helps finance long-term, low-cost supplemental loans for the construction of regionally and nationally significant water infrastructure projects. The total is $5 million more than provided for FY 2020.

Within the total provided, $5.5 million could be used to cover administrative expenses of the program and the remaining $59.5 million would be used to subsidize direct loans.

Superfund

The agreement provides $1.2 billion for EPA's Hazardous Substance Superfund -- $21 million (2%) more than FY 2020.

Of the total, $809 million in base funding is for hazardous-waste site cleanup activities ($14 million more than FY 2020) with most cleanup-related accounts being funded at or above FY 2020 levels.

The measure also provides $174 million for EPA Superfund enforcement activities (3% more than FY 202) and $129 million for operations and administration of the program (a small increase). Separately, it provides $92 million for activities associated with the cleanup of underground storage tanks through the Leaking Underground Storage Tank (LUST) Trust Fund, less than $1 million more than FY 2020.

Science & Technology

The agreement provides $729 million in funding for EPA's science and technology programs -- $13 million (2%) more than FY 2020. It keeps funding level or increases funding for most activities.

Within the total, it provides $119 million for the clean air program ($2.5 million more than FY 2020), $14 million for enforcement activities (3% more), and $36 million for homeland security activities (8% more).

For research programs, it provides $95 million for air and energy issues, $127 million for chemical safety and sustainability, $112 million for safe and sustainable water resources, and $133 million for sustainable and healthy communities. Each program was increased by $1 million compared to FY 2020.

The joint explanatory statement notes that within various EPA accounts $53 million in additional funding (more than double existing funding) is provided for scientific and regulatory work needed to establish drinking water and cleanup standards for Per- and Polyfluoroalkyl Substances (PFAS) chemicals. Those chemicals, which are in a wide range of consumer products but most notoriously are in firefighting foams and have seeped into the groundwater in some areas, including near numerous military installations.

Interior Department

The agreement provides a total of $13.7 billion for the Interior Department and related agencies. The total includes $13.7 billion in discretionary funding subject to caps and $310 million for fighting wildfires under a separate wildland fire suppression cap adjustment. It also includes $64 million in mandatory funding. The discretionary total is $186 million more than FY 2020 and $1.7 billion more than requested when excluding changes being made by Congress to the Land and Water Conservation Fund (LWCF).

(Under separate legislation cleared by Congress (PL 116-152), funding for the LWCF will become mandatory and will no longer count against discretionary caps. For FY 2020, $495 million in discretionary funding was providing for the LWFC.)

When excluding the changes to the LWCF, the measure increases funding for many agencies, programs and activities of the Interior Department, including, the U.S. Geological Survey, and the U.S. Fish and Wildlife Service, but cuts spending for the National Park Service, the Bureau of Land Management, the Bureau of Ocean Energy Management, and the Bureau of Safety and Environmental Enforcement.

Major Interior Agencies & Bureaus

National Park Service

The measure provides $3.1 billion for the National Park Service -- $255 million (7.5%) less than FY 2020. When excluding changes to the LWCF, the agency would receive $44 million less than FY 2020, according to the House Appropriations Committee.

The vast majority, $2.7 billion, is for operation and maintenance of national parks, $111 million (4%) more than FY 2020. Included in that amount is $901 million for facility operations and maintenance ($42 million, or 5%, more than FY 2020).

The total also includes $224 million for Park Service construction projects, $165 million (42%) less than FY 2020. Of that amount, $132 million ($151 million less than FY 2020) is for specific projects detailed in the Park Service's budget.

The measure provides no funding for land acquisition and includes a rescission of $2 million ($208 million was provided in FY 2020), since funding is mandatory under the LWCF changes. It does, however, encourage the National Park Service to prioritize funding to support establishment of greenways, parks, trails and other outdoor recreation facilities in honor of America's veterans.

It also provides $74 million for national recreation and preservation activities ($3 million more than FY 2020) and $144 million for Historic Preservation Fund activities ($26 million more). Of that total, $71 million would go to state historic preservation offices.

Finally, the measure includes an unrequested $15 million for the Centennial Challenge to fund joint public-private infrastructure investments in honor of the National Park Service's centennial -- equal to FY 2020 funding.

Bureau of Land Management

The measure provides $1.3 billion in discretionary funding for Bureau of Land Management (BLM) activities -- $60 million (4%) less than FY 2020. It also includes $36 million in mandatory spending. When changes are made to the LWCF, comparable funding would be reduced by $28 million compared to FY 2020.

Within the total, it provides $1.2 billion for BLM land management programs, 1% less than FY 2020. That amount includes $199 million for managing energy and mineral activities on BLM lands ($1.5 million more than FY 2020), including $16 million for coal mining (equal to FY 2020), $140 million for oil and gas activities (equal funding), and $31 million for renewable energy (1% more).

The land management total also includes $133 million for resource protection and maintenance (equal to FY 2020), $189 million for wildlife and fisheries management ($2 million more), $77 million for recreation management ($1 million more), and $116 million for wild horse and burro management (14% more).

The appropriators note that $66 million of funding is to be used for sage grouse conservation and that $46 million is for the National Landscape Conservation System -- which consists of about 35 million acres designated by Congress and the president to conserve special features.

The measure provides $18 million for the Multinational Species Conservation Fund. The fund provides technical and financial assistance to local communities, wildlife authorities, and non-governmental organizations in foreign countries for on-the-ground conservation work to protect African and Asian elephants, rhinoceroses, tigers, great apes, and marine turtles, and their habitats. The total is $3 million (20%) more then FY 2020.

The agreement also provides $115 million for managing certain lands in Oregon known as Oregon and California grant lands (2% more than FY 2020) and provides no funding for BLM land acquisition activities given the changes to the LWCF ($32 million was appropriated in FY 2020). It also rescinds $5 million from that account.

U.S. Fish & Wildlife Service

The agreement provides a total of $1.6 billion for the U.S. Fish and Wildlife Service (FWS) -- $60 million (4%) less than FY 2020. When excluding changes to the LWCF, the appropriators note that FY 2021 funding would be $22 million more than FY 2020.

The vast majority, $1.4 billion, is for FWS resource management activities, including management of critical habitat, fisheries and endangered species. That amount is 1% more than FY 2020.

Resource management funding includes $504 million ($1.5 million more than FY 2020) for operating the National Wildlife Refuge System, $70 million for habitat conservation (slightly less than FY 2020), and $48 million for migratory bird management (slightly more). It includes the requested $25 million to stop the spread of Asian carp into the Great Lakes, of which $3 million is to be used to perfect the combined use of contract fishing and deterrents to extirpate Asian carp, including grass carp, and $3.5 million is to prevent the spread of quagga and zebra mussels in the West.

It also includes $207 million for fish and aquatic conservation activities ($1 million more than FY 2020), of which $66 million is to operate the national fish hatchery system. The agreement prohibits the termination or closure of any national fish hatchery, and no hatchery could be downsized or terminated without advance consultation with affected states.

Consistent with changes to the LWCF program, the measure provides no funding for land acquisition activities ($67 million was provided in FY 2020).

U.S. Geological Survey

The agreement provides $1.3 billion to the U.S. Geological Survey, the federal government's largest earth-science research agency -- $45 million (3.5%) more than FY 2020 funding.

The total includes no funding for land resources activities ($166 million was provided in FY 2020) due to changes in the LWCF.

It provides $259 million for various USGS ecosystems studies and activities (52% more than FY 2020). The committee rejects the administration's proposal to restructure the accounts noting in its report that the changes would reduce program and funding transparency.

The total also includes $263 million for USGS water resources activities (12% more than FY 2020), including $101 million (20% more than FY 2020) for the agency's groundwater and streamflow information program. USGS is the primary source of data on the nation's surface and ground water resources.

Finally, $175 million is provided for the agency's natural hazards programs (3% more than FY 2020). That amount includes $30 million for the volcano hazards program and $85 million for the earthquake hazards program.

The explanatory materials note that $26 million is to be used for continued development and expansion of the ShakeAlert West Coast earthquake early warning (EEW) system including capital costs associated with the buildout of the system.

Interior Department Regulatory Agencies

Bureau of Ocean Energy Management

The Bureau of Ocean Energy Management (BOEM) is the primary authority for permitting offshore energy exploration and extraction activities.

The measure provides $193 million for BOEM activities, $4 million less than FY 2020 funding. Approximately $63 million of the funding is assumed to be provided through fees and receipts collected on oil and natural gas leases on the outer continental shelf, resulting in a net appropriation of $128 million after a $2 million rescission.

Bureau of Safety and Environmental Enforcement

The Bureau of Safety and Environmental Enforcement (BSEE) is responsible for enforcing offshore environmental regulations as they relate to energy extraction and exploration. BSEE is also responsible for oil spill research and response plan development.

The measure provides $194 million for core BSEE activities in FY 2020, $1 million more than FY 2020 funding. It also provides $15 million for BSEE oil spill research activities, equal to current funding. About $74 million is assumed to be provided through lease payments, and fees, resulting in a net total appropriation of $110 million after a $10 million rescission.

Office of Surface Mining, Reclamation & Enforcement

The Office of Surface Mining, Reclamation and Enforcement regulates surface coal-mining operations to ensure that the environment is protected during those operations and that the land is adequately reclaimed once mining is completed.

The agreement provides $223 million for the office, $35 million (14%) less than FY 2020.

The measure provides $118 million for state grants under the Abandoned Mine Reclamation Fund. Overall, it provides a total of $130 million for various activities under the Abandoned Mine Reclamation Fund -- $35 million (13.5%) less than current funding.

Other Interior Activities

The measure also funds several other activities within the Interior Department (including for fighting wildfires and for certain American Indian programs, both of which are discussed in other sections below).

Payments in Lieu of Taxes Program

The Payments in Lieu of Taxes (PILT) program provides federal payments to local governments that have large tracts of federal land that can't be locally taxed, in order to help those governments carry out vital services such as firefighting and police protection, as well as construction of public schools and roads. First authorized in 1976, the program usually makes annual payments of mandatory funding for tax-exempt federal lands administered by the BLM, the National Park Service, the U.S. Fish and Wildlife Service, the U.S. Forest Service and for federal water projects and some military installations.

The measure provides "such sums as may be necessary" for the program through FY 2021, which are estimated to provide a total of $500 million.

Land and Water Conservation Fund (LWCF)

Because of changes that make the program a mandatory funding program, the agreement does not contain discretionary funding for the fund but rather provides allocations for the estimated $900 million which will be made available for FY 2021.

The fund is financed primarily from royalties from offshore oil and gas leasing, and is supposed to be used by federal, state and local governments to help acquire or preserve lands and waters for recreational and other purposes.

Office of Insular Affairs

The measure provides $115 million to the Office of Insular Affairs, $4 million (3%) more than FY 2020. Of that total, $28 million is mandatory funding.

The Office of Insular Affairs administers U.S. responsibilities with respect to its four territories -- Guam, American Samoa, the U.S. Virgin Islands and the Commonwealth of the Northern Mariana Islands -- as well as the three freely associated states (the Federated States of Micronesia, the Republic of the Marshall Islands and the Republic of Palau) and provides certain assistance.

U.S. Forest Service & Wildfire Funding

The Agriculture Department's U.S. Forest Service manages 193 million acres of national forests and grasslands in 44 states and Puerto Rico. The National Forest System includes 155 national forests, 20 national grasslands, 20 national recreation areas, a national tallgrass prairie, and six national monuments. Forest Service lands are managed for multiple uses, including timber production, recreation, wilderness, minerals, grazing, fish and wildlife habitat management, and soil and water conservation.

The measure provides a total of $7.4 billion for the U.S. Forest Service, $10 million less than FY 2020. Almost half the funding for the Forest Service, however, is for fighting wildfires (see below).

Core Forest Service Activities

The measure provides $3.5 billion for core (non-wildfire) Forest Service activities -- $324 million (10%) more than FY 2020 funding. According to House appropriations, after taking into account the LWCF changes, the amount is $78 million more than comparable FY 2020 funding.

Within the total for core Forest Service activities, $1.8 billion is for operation and maintenance of the national forest system -- including $180 million for hazardous fuels reduction activities, $383 million for forest products management, $35 million for recreation, heritage and wilderness activities, $29 million for vegetation and watershed management, $21 million for wildlife and fish habitat management, $13 million for minerals and geology management, and $5 million for grazing management. The total funding is $171 million (9%) less than FY 2020 funding.

Much of the agencies responsibilities have been shifted to a new Fire Service Operations account which constitutes activities previously supported through the cost pool structure, as well as other general activities of the agency.

For state and private forestry the agreement provides $267 million, which includes $48 million for cooperative forestry (60% less than FY 2020) and $46 million for forest health management (54% less). The total is $80 million less than FY 2020 funding.

For Forest and Rangeland research, which receives $259 million, the funding represents an increase of $36 million under FY 2020, while the $140 million provided for capital improvements and maintenance represents a programmatic decrease of $315 million compared to FY 2020. Because of changes to the LWCF, no funding is provided for land acquisition ($79 million was provided in FY 2020).

Forest Service / Interior Department Wildfire Funding

The measure provides a total of $5.3 billion for fighting wildfires, including $1.3 billion in Interior Department funding and $4.0 billion in Forest Service funding. Of those amounts, $310 million of the Interior wildfire funding and $2.0 billion in Forest Service wildfire funding is covered by the fire suppression cap adjustment and does not count towards the base discretionary cap.

The appropriators note than the funding includes a shift of $387 million to non-fire Forest Service activities due to the budget restructure and the creation of the Forest Service Operations Account. After adjusting for this shift, the agreement provides a programmatic increase of $104 million for wildfire management.

The total includes $499 million for wildland fire preparedness ($152 million Forest Service and $347 million Interior) and $1.4 billion for wildland fire suppression operations, including funds under the cap adjustment ($1.0 billion Forest Service and $384 million Interior). The total also includes $259 million in Interior funding for other operations -- including $220 million for fuels management and $20 million for burned area rehabilitation.

In the explanatory material, the appropriators note that returning fire to the landscape can be a successful tool for reducing wildfire risk and encourage the agency to improve its use of prescribed fire practices. They also direct the service to include the number of acres treated using prescribed fire at the end of each fiscal year, as well as the costs associated with such activities.

Native American Programs

The agreement increases funding for the American Indian programs administered by the Interior Department and Health and Human Services (HHS) Department.

Bureaus of Indian Affairs & Indian Education

The measure appropriates $3.5 billion for the operation of American Indian programs administered by the Bureau of Indian Affairs (BIA) and the Bureau of Indian Education within the Interior Department, including social services, education, employment development, law enforcement and natural resources development. The total provided is $282 million (9%) more than FY 2020.

The Bureau of Indian Affairs delivers services to about 1.9 million American Indians and Alaska Natives, including the operation of 183 schools and the administration of 55 million acres of land held in trust for individuals or tribes.

Under the measure, the Bureau of Indian Education would receive $1.2 billion, of which $973 million would be for education programs. It also provides $264 million for school and facilities construction, repair and improvements, 4% more than FY 2020.

The measure funds the new Office of Special Trustee for American Indians at $108 million for FY 2020. The office, established by the Indian Trust Asset Reform Act (PL 114-178), is responsible for managing the approximately 55 million surface acres of land, 57 million acres of subsurface mineral interests, and approximately $5.5 billion held in trust by the federal government on behalf of American Indians, Alaska Natives, and federally recognized Indian Tribes.

For the Bureau of Indian Affairs (BIA) the bill provides $2.2 billion, of which $1.6 billion is for operation of Indian programs -- $39 million more than FY 2020. Within the BIA funding, the measure provides $341 million for tribal government support (2% more than FY 2020), $449 million for public safety and justice (3% more), and $161 million for human services activities (3.5% more).

The measure also provides $129 million for BIA construction activities, $2 million more than FY 2020.

Indian Health Service

The Indian Health Service (IHS) within HHS provides health care to American Indians through 28 hospitals, 61 health care centers and 34 health stations. Through contracts with the service, tribes operate 17 additional hospitals, 249 health centers, six school health centers, 70 health stations and 164 Alaska village clinics.

The measure provides $6.2 billion for the Indian Health Service -- $189 million (3%) more than FY 2020.

The total includes $3.9 billion for clinical services ($33 million less than FY 2020), including $2.2 billion ($87 million less than FY 2020) for the operation of hospitals and health clinics. That clinical services total also includes $73 million for the Indian Health Care Improvement Fund to help reduce health care disparities across the IHS system, equal to FY 2020.

Within the IHS's preventive health program, the measure provides $93 million for public health nursing, $63 million for community health representatives, and $21 million for health education (all slightly more than FY 2020). The administration proposed to terminate health education and cut community health representatives by almost two-thirds.

The measure also provides $918 million for maintenance and construction of Indian Health facilities ($6 million more than FY 2020), including $259 million for health care facilities construction, equal to FY 2020.

Other Agencies

The agreement provides $78 million for the Agency for Toxic Substances and Disease Registry within HHS (2% more than FY 2020), and it provides $82 million for the National Institute of Environmental Health Sciences within the National Institutes of Health (slightly more than FY 2020).

It also provides the following:

NEA & NEH -- $168 million each for the National Endowment for the Arts and the National Endowment for the Humanities, each $5 million (3%) more than FY 2020.

Smithsonian -- $1.0 billion for the Smithsonian Institution, $15 million (1%) less than FY 2020, including $6 million for the institution's Latino initiatives and the Smithsonian Latino Center and $6 million for the American Women's History Initiatives.

National Gallery of Art -- $176 million for the National Gallery, 2% more than FY 2020.

Kennedy Center -- $40 million for the John F. Kennedy Center for the Performing Arts (7% less than FY 2020).

Holocaust Museum -- $61 million for the U.S. Holocaust Memorial Museum, 2% more than FY 2020.

Dwight D. Eisenhower Memorial Commission -- $1 million for salaries and expenses at the recently opened Eisenhower Memorial Commission.

Section IX

Labor-HHS-Education

This section describes the provisions of HR 133, Consolidated FY 2021 Appropriations Act, that provide funding for programs and activities of the Labor, Health and Human Services, and Education departments, as well as several related agencies.

The agreement provides a total of $174.1 billion in discretionary spending subject to regular budget caps for programs and activities of the Health and Human Services (HHS), Education and Labor departments and related agencies, as well as $1.9 billion subject to cap adjustments for program integrity initiatives and $1.6 billion in emergency funding. However, once certain offsets and adjustments are also factored in (including $21 billion in rescissions to mandatory programs that offset discretionary spending), the measure provides a total of $197 billion in discretionary "programmatic" funding for use by the departments and agencies, according to House appropriators -- $2.8 billion more than comparable FY 2020 funding and $19.2 billion more than requested. (Senate Appropriators calculate the programmatic total at $198.1 billion.)

It also provides $971.4 billion in mandatory funding for FY 2021 for Medicaid grants to states, Social Security Supplemental Security Income benefit payments, and other purposes. (Total funding available for FY 2021 includes $24.8 billion in discretionary funding and $164.2 billion in mandatory funding provided in prior appropriations bills. The measure includes a total of $197.5 billion in advance funding for future years: $24.8 billion in advance discretionary funding and $172.7 billion in mandatory funding.)

For HHS for FY 2021 the measure provides a total of $97.0 billion (2% more than FY 2020) in discretionary spending according to appropriators, including a 3% increase for NIH and 2% increases for the Centers for Disease Control and Prevention (CDC), the Health Resources and Services Administration, and the Substance Abuse and Mental Health Services Administration.

For the Education Department it increases overall discretionary spending by 1% to $73.5 billion, providing 1% increases for Title I Education grants to help the disadvantaged, special education programs, and school innovation and improvement. It increases funding for rehabilitation services by 2%, for career, technical and adult education by 4%, and aid for institutions of higher education that primarily serve Black, Hispanic and other underserved populations by 4%. The maximum Pell Grant is increased by $150 in FY 2021 to $6,495.

Finally, it provides $12.5 billion in discretionary funding for the Labor Department (1% more than FY 2020), with 1% increases for programs to provide job training skills and assistance to youth and adults and dislocated workers, and for state unemployment insurance and employment service operations. Funding for apprenticeship programs would increase by 6%.

Health and Human Services Department

The agreement provides $96.5 billion in discretionary spending for FY 2021 for programs and activities of the Health and Human Services (HHS) Department, according to the Appropriations Committee, $2.1 billion more than FY 2020.

It also provides more than $900 billion in mandatory funding for FY 2021 (including advance funding from previous years) for items such as Medicaid grants to states and payments to health care trust funds.

It rescinds $375 million of unobligated balances in the nonrecurring expenses fund and $21.0 billion of unexpended balances from three accounts in the Children's Health Insurance Program (CHIP), which are used to offset increases in discretionary spending above cap levels.

Public Health Service Programs

The agreement provides $64.9 billion for programs and activities of HHS Public Health Service agencies for FY 2021 -- including the Centers for Disease Control (CDC), National Institutes of Health (NIH), Health Resources and Services Administration (HRSA), and Substance Abuse and Mental Health Services Administration (SAMHSA).

The public health service total is 3% more than the comparable FY 2020 total.

National Institutes of Health

The agreement provides $42.9 billion (3% more than FY 2020) for the National Institutes of Health (NIH).

The total includes $560 million for the Brain Research through Application of Innovative Neurotechnologies (BRAIN) Initiative established by the 21st Century Cures Act (PL 114-255), 12% more than FY 2020.

It provides $3.9 billion for the National Institute on Aging (10% more than FY 2020); $6.6 billion for the National Cancer Institute, $2.5 billion for the National Institute of Neurological Disorders and Stroke, and $1.6 billion for the National Institute of Child Health and Human Development (all 2% more than FY 2020); and $3.7 billion for the National Heart, Lung and Blood Institute and $2.1 billion for the National Institute of Diabetes and Digestive and Kidney Diseases (both 1% more).

It also provides $6.1 billion for the National Institute of Allergy and Infectious Diseases (3% more) -- of which $220 million is for research on a universal influenza vaccine (10% more than FY 2020).

The measure provides $12.5 million to support research on the prevention of gun violence, which would be multi-institute research to be undertaken in conjunction with the CDC.

Centers for Disease Control & Prevention

The agreement provides a total of $7.9 billion for activities of the Centers for Disease Control and Prevention (CDC), 2% more than FY 2020 funding.

It provides $821 million for immunization and respiratory disease activities (4% more than FY 2020), including $201 million for influenza planning and response activities (14% more). It also provides $842 million for CDC public health preparedness response activities (2% more).

It provides $1.3 billion for CDC's HIV/AIDS, viral hepatitis, sexually transmitted diseases and tuberculosis prevention activities (3% more than FY 2020), including $105 million for an initiative to reduce new HIV infections by 90% by 2030.

The CDC total also includes $1.3 billion for CDC's chronic disease prevention and health promotion activities (3% more than FY 2020); $592 million for public health scientific services (2% more); $593 million for CDC's global health activities (4% more); $648 million for emerging and zoonotic infectious diseases (2% more); and $345 million for the National Institute for Occupational Safety and Health (1% more) which develops criteria for occupational safety and health standards.

Health Resources & Services Administration

The agreement provides $7.5 billion (2% more than FY 2020) for programs and activities of HHS's Health Resources and Services Administration (HRSA).

The total includes $5.7 billion (1% more than FY 2020) for community health centers (of which $4.0 billion is mandatory funding).

It provides $1.2 billion (2.5% more) for programs aimed at addressing shortages of health professionals, with most individual programs funded at FY 2020 levels -- but 7% more being provided for interdisciplinary community-based programs and the nursing education and retention program, and 8% more provided for the nursing workforce diversity program.

For HRSA's maternal and child health programs it provides $975 million (3% more than FY 2020) -- including $713 million for the Maternal and Child Health block grant (4% more) and $128 million for the Healthy Start program (2% more).

It provides $2.4 billion for Ryan White HIV/AIDS programs with all programs receiving funding equal to FY 2020 except the Domestic HIV Initiative, which is increased 5% to $105 million.

Finally, it provides $286 million for Title X family planning programs (equal to FY 2020) and $330 million for rural health programs (3.5% more) -- including a 17% increase for rural telehealth programs.

Substance Abuse & Mental Health Services Administration

The agreement provides $6.0 billion for programs and activities of the Substance Abuse and Mental Health Services Administration (SAMHSA), 2% more than FY 2020.

The total includes $3.9 billion for substance abuse treatment programs (1% more than FY 2020), including $1.9 billion for substance abuse block grants to states and $1.5 billion for state opioid response grants.

For SAMHSA mental health programs, the measure provides a total of $1.8 billion (7% more than FY 2020) -- including $758 million for community block grants (5% more), $125 million for children's mental health services (equal to FY 2020), and $250 million for certified community behavioral health clinics (25% more).

Agency for Healthcare Research and Quality

The measure provides $338 million for the Agency for Healthcare Research and Quality (AHRQ), equal to FY 2020. AHRQ funds activities such as medical expenditures panels, surveys and research on health care costs and outcomes with the goal of producing evidence to make health care safer, more accessible, equitable and affordable. The administration requested no funding for the agency.

Centers for Medicare & Medicaid Services

The Centers for Medicaid and Medicare Services (CMS) oversees those two entitlement programs and also is responsible for administering portions of the 2010 health care overhaul (ACA; PL 111-148 and PL 111-152). All of its funding is mandatory spending or comes from the Medicare Trust Fund.

The agreement provides a total of $3.7 billion from the Medicare Trust Fund for CMS management activities, equal to FY 2020.

It also provides $807 million (3% more than FY 2020) from the Medicare Trust Fund for health care fraud and abuse control activities carried out by CMS, the HHS Inspector General, and the Justice Department.

Medicare & Medicaid

The agreement provides a total of $453.8 billion in mandatory funding (including advance funds from last year) for grants to states for the joint federal-state Medicaid program, 10% more than comparable FY 2020 funding. It also provides $148.7 billion in advance mandatory funding for FY 2022.

That state grant total for FY 2021 includes $425.7 billion for the federal share for Medicaid benefits, $23.2 billion for state and local administration of the program, and $5.0 billion for vaccines for children.

The measure also provides $439.5 billion in mandatory funding for payments to Medicare's trust funds for various programs and purposes in FY 2021, 7% more than FY 2020.

Families & Children / LIHEAP

The agreement provides a total of $41.2 billion for programs and activities of HHS's Administration for Children & Families -- 4% more than FY 2020 and 18% more than requested.

Separately, outside of the bill's HHS title, it also provides $638 million in emergency funding for HHS grants to carry out a Low-Income Household Drinking Water and Wastewater Emergency Assistance Program.

Head Start / Family Services

Within the total, $13.0 billion (1% more than FY 2020) is for various children and family services programs, including $10.7 billion (1% more than FY 2020) for the Head Start program, which provides comprehensive early childhood services to children and families from before birth through age 5.

It provides $275 million in unrequested funds for preschool development grants (equal to FY 2020), as well as $90 million for child abuse state grants (equal to FY 2020), $117 million for runaway and homeless youth (3% more), and $269 million for child welfare services (equal to FY 2020).

It also provides $745 million (1% more than FY 2020) for community services block grants and $183 million for family violence prevention and services (4% more).

Child Care & Development Block Grant

The measure provides $5.9 billion for the child care and development block grant (1% more than FY 2020). Child Care and Development Block Grants gives states, territories and tribes funding to provide direct financial assistance to low-income working families and families taking school or training so that the adults can access child care; the grants can also be used to improve the quality of child care for all children.

Refugee & Entrant Assistance

The agreement provides $1.9 billion for HHS refugee and entrant assistance programs, slightly more than FY 2020. Of that total, $1.3 billion is for unaccompanied alien children, $354 million is for transitional and medical services, and $207 million is for refugee support services (all equal to FY 2020).

Mandatory Family/Children Programs

The agreement provides $4.4 billion in mandatory funding for FY 2021 (including advance funding from prior years) for state child-support enforcement programs to help promote safe and stable families (3.5% more than comparable FY 2020 funding). It also provides $1.4 billion in advance funding for FY 2022 for this account.

It provides $10.0 billion in mandatory funding (including advance funding from prior years) for foster care and adoption assistance programs -- including $5.8 billion for foster care (10% more than FY 2020), $3.8 billion for adoption assistance (30% more), and $271 million for guardianship programs (25% more). It provides $3.0 billion in advance funding for such activities for FY 2022.

It also provides $1.7 billion in mandatory funding (equal to FY 2020) for the Title XX social services block grant program.

LIHEAP

The measure provides $3.75 billion for the Low-Income Home Energy Assistance Program (LIHEAP), $10 million more than FY 2020. Program funds are distributed entirely through formula grants.

Administration for Community Living

The measure provides $2.3 billion for HHS's Administration for Community Living (2% more than FY 2020). ACL coordinates the efforts of the Administration on Aging, the Administration on Intellectual and Developmental Disabilities and the HHS Office on Disability to increase access to community supports and to focus attention and resources on the needs of older individuals and people with disabilities throughout their lifespan.

The total includes $1.6 billion in grants to states for programs that serve aging individuals and individuals with disabilities (1% more than FY 2020) -- including $952 million for nutrition programs (2% more) and $393 million for home and community-based supportive services programs (1% more).

It also includes $183 million for various programs to help those with developmental disabilities (2% more than FY 2020) and $267 million for Workforce Innovation and Opportunity Act programs (1% more).

Office of the Secretary

The agreement provides a total of $4.4 billion for programs and activities of HHS' Office of the Secretary, 3% more than FY 2020.

The total includes $551 million for general departmental management (1% more than FY 2020) and $80 million for HHS's office of inspector general (equal to FY 2020).

Public Health & Social Services Emergency Fund

The measure includes a total of $2.8 billion for the Public Health and Social Services Emergency Fund (4% more than FY 2020). The fund supports a comprehensive program to prepare for and respond to the health and medical consequences of public health emergencies, including bioterrorism, and it also supports HHS cybersecurity efforts.

Included in the total is $287 million for pandemic flu preparedness (10% more than FY 2020), $770 million for Project Bioshield (5% more), $705 million for the Strategic National Stockpile (equal to FY 2020) and $597 million for the Biomedical Advanced Research and Development Authority (6% more).

It also includes $281 million for hospital preparedness cooperative agreements (2% more than FY 2020), and $63 million for the national disaster medical system (10% more).

Education Department

The agreement provides $73.8 billion in discretionary funding for programs and activities of the Education Department for FY 2021, according to appropriators -- 1% more than FY 2020 and $7 billion more than requested. It also provides $3.7 billion in mandatory funding for vocational rehabilitation state grants.

It provides a total of $40.6 billion for K-12 programs (including the Individuals with Disabilities Education Act) according to appropriators ($498 million more than FY 2020), $2.5 billion for higher education programs ($66 million more) and $24.5 billion for federal student aid programs ($25 million more), and $2 billion for career, technical and adult education programs ($70 million more).

The measure strikes from current law a prohibition on the use of appropriated funds to bus students or teachers as a means of reducing segregation in schools.

Education for the Disadvantaged

The measure rejects the administration's proposal to consolidate all Education for the Disadvantaged accounts into a single block grant for states and instead provides $17.2 billion for Title I Education Grants and associated programs (including advance funding from previous years), 1% more than FY 2020. It also provides $10.8 billion in advance funding for FY 2022.

Of the total for FY 2021, $16.5 billion is for Title I grants to local school districts to help disadvantaged children become proficient in reading and math (1% more than FY 2020). More than one-third of this total, $5.7 billion, is for basic grants to local school districts.

Impact Aid

The measure provides $1.5 billion (1% more than FY 2020) for Impact Aid grants to school districts with military installations to support the education of children of U.S. servicemembers as well as schools with students who live on Native American land. Families living on military bases or on tribal lands do not pay property tax, which leaves schools that educate the children of these families without a source of income.

School Improvement & Safe School Programs

The agreement provides $5.4 billion for a variety of school improvement programs (including advance funding from previous years), 1% more than FY 2020. It also provides $1.7 billion in advance funding for FY 2022.

Within the total for FY 2021, $1.3 billion is for 21st Century Community Learning Centers (1% more than FY 2020), which funds after-school and before-school centers for children, $1.2 billion is for student support and academic enrichment programs (1% more), and $2.1 billion is for state grants to support effective instruction (0.5% more).

The total also includes $378 million for state education performance assessments (equal to FY 2020), $188 million for rural education (1% more), and $107 million for education of homeless children and youth (5% more).

Separately, the agreement provides $217 million for Safe Schools and Citizenship Education programs (3% more than 2020), which support low-income, high poverty schools as well as certain school safety programs. Of this amount, $81 million is for Promise Neighborhoods and the remaining amounts are used for the SEL Initiative, below.

Innovation & Improvement Programs

The agreement provides $1.1 billion for a variety of programs intended to foster innovation and educational improvement, 1% more than FY 2020.

The total includes $440 million for grants for charter schools (equal to FY 2020), $109 million for magnet schools (2% more than FY 2020), and $200 million for teacher incentive grants (equal to FY 2020). It also includes $194 million for the Education Innovation and Research (EIR) program (2% more).

The measure uses $203 million from several accounts for the Social-Emotional Learning (SEL) initiative that was created in the FY 2020 appropriations act to address student social, emotional and cognitive needs and provide "whole child" approaches to education. Specifically, it draws $67 million from EIR grants, $106 million from the School-Based Mental Health Services Grants Program, and $30 million from full-service community schools program.

Indian Education

The agreement provides $181 million for Indian Education programs, slightly more than FY 2020.

Of that total, $105 million is for grants to local education agencies to improve primary and secondary school programs that serve Native American students, including preschool children, and $76 million is for special federal programs for Indian children and national activities.

Special Education, English Language Acquisition & Rehabilitation

The agreement provides a total of $14.1 billion (1% more than FY 2020) for special education programs (including advance funding from prior years) -- of which $13.8 billion is for special education grants to states (1% more than FY 2020). The measure also provides $9.3 billion in advance funding for FY 2022.

It provides a total of $797 million for English language grants to states, 1% more than FY 2020.

For rehabilitation services it provides a total of $3.8 billion (2% more than FY 2020) -- including $3.7 billion in mandatory spending for vocational rehabilitation state grants, which help individuals with mental and physical disabilities prepare for and engage in gainful employment. It provides $23 million in unrequested discretionary funds for supported employment state grants.

The rehabilitation total also includes $33 million for independent living services for older blind individuals (equal to FY 2020) and $17 million for the Helen Keller National Center for Deaf/Blind Youth and Adults (6% more), and separately the measure provides $34 million for the American Printing House for the Blind (6% more than FY 2020), $82 million for the National Technical Institute for the Deaf (2.5% more), and $140 million for Gallaudet University in Washington, D.C. (2% more).

Higher Education & Financial Aid

The agreement provides $24.5 billion for student financial aid programs, primarily for Pell Grants, $25 million more than FY 2020.

Specifically, it provides $22.5 billion in discretionary funding for Pell Grants and increases the maximum Pell Grant by $150 in FY 2021 to $6,495. The measure rescinds $28 million of mandatory Pell funding.

The total for student financial aid also includes $1.2 billion for federal work-study grants (1% more than FY 2020) and $880 million for supplemental educational opportunity grants (2% more). The measure also provides $1.9 billion to administer student aid programs.

For other higher education programs, the agreement provides a total of $2.5 billion (3% more than FY 2020). That total includes $789 million for a variety of programs intended to strengthen colleges that serve certain minority populations (4% more than FY 2020), including $338 million for Historically Black College and Universities (HBCUs). Separately it provides $48 million for the HBCU Capital Financing Program for repair and renovation of facilities at HBCUs (4% more), and $251 million for Howard University in Washington, D.C. (5% more).

The higher education total also includes $1.1 billion for TRIO programs that help low-income and first-generation college students plan, prepare for and succeed in college (0.6% more than FY 2020), as well as $368 million for the GEAR UP program that provides grants to provide students with skills, encouragement and scholarships to pursue postsecondary education (1% more).

It also includes $55 million (4% more than FY 2020) for a program to provide child care for parents who are attending post-secondary schools and $52 million (4% more) for Teacher Quality Partnerships, which improves the quality of teachers in high-need schools through model teacher preparation and residency programs.

Adult Career & Technical Training

The agreement provides $2.0 billion (4% more than FY 2020) for career, technical and adult education programs for FY 2021 (including previously appropriated amounts). It also provides $791 million in advance appropriations for FY 2022.

Of the total for FY 2021, $1.3 billion (4% more than FY 2020) is for basic grants to states and $675 million (3% more) is for state grants for adult education activities such as literacy education.

Other Activities

The agreement provides $642 million (3% more than FY 2020) for the Institute of Education Sciences to support education research, statistics, dissemination, evaluation and assessment activities.

It also provides $624 million for management activities of the Education Department, slightly more than FY 2020. Within that total, $430 million is for salaries and expenses, $131 million is for the Office of Civil Rights, and $63 million is for the department's Inspector General.

Labor Department

The agreement provides $12.5 billion in discretionary spending for programs and activities of the Labor Department in FY 2021, according to appropriators, including advance appropriations from prior years. The discretionary total is 1% more than FY 2020 and $1.4 billion more than requested.

The measure rescinds $435 million in unobligated funds from the H-1B visa program (which allows companies in the United States to temporarily employ foreign workers in occupations that require highly specialized knowledge).

Employment & Training Administration

The measure provides a total of $10.0 billion for programs and activities of the Employment and Training Administration, 0.5% more than FY 2020.

Training & Employment Services

The total includes $3.7 billion (1% more than FY 2020) for programs that provide job training skills and assistance to youth and adults, as well as to dislocated workers.

Of that funding, $2.8 billion is for grants to states -- including $863 million for adult employment and training programs $921 million for youth training programs, and $1.1 billion for dislocated worker assistance (all about 1% more than FY 2020).

Another $818 million (3% more than FY 2020) is for national programs -- including $281 million for dislocated worker assistance (4% more than FY 2020), $100 million for the reintegration of ex-offenders (2% more), $94 million for migrant- and seasonal-worker programs (2% more), $97 million for Youth Build activities (2% more), and $185 million for apprenticeship programs (6% more). The agreement provides that those funds may only be used for registered apprenticeships.

Job Corps & Older Americans

The agreement provides $1.7 billion for the Job Corps, the nationwide network of residential facilities that provide training, job placement and support services to at-risk young adults. That is slightly more than FY 2020.

Separately, the measure provides $405 million for community service employment for older Americans, equal to FY 2020.

Unemployment Insurance & Employment Services

The measure provides $3.4 billion to fund State Unemployment Insurance and Employment Service Operations activities, 1% more than FY 2020.

The total includes $2.4 billion to support state operations of unemployment insurance programs and $117 million for state re-employment eligibility assessments (both equal to FY 2020).

The total also includes $670 million for employment service grants to states (slightly more than FY 2020), and $63 million for One-Stop Career Centers (equal to FY 2020). It includes $78 million for foreign labor certification activities -- $58 million for federal administration (5.5% more) and $20 million for grants to states (42% more).

Separately, the agreement provides $925 million in emergency funding for unemployment insurance.

Worker Protection Agencies

The agreement provides $592 million for the Occupational Safety and Health Administration (OSHA, 2% more than FY 2020) -- including $2239 million for federal enforcement activities (3% more than FY 2020), $110 million for state programs (1% more), and $19 million for whistleblower enforcement (3% more).

It provides $380 million for administration, salaries and expenses of the Mine Safety and Health Administration (MSHA), including $261 million for mine safety and health enforcement (with all MSHA accounts equal to FY 2020).

It provides $246 million for the department's wage and hour division (WHD), 2% more than FY 2020. The division enforces federal minimum wage, overtime pay, recordkeeping and child labor requirements of the Fair Labor Standards Act, as well as enforcing other worker protections under additional laws.

Finally, it provides $106 million for the Office of Federal Contract and Compliance Programs (equal to FY 2020), which ensures equal employment opportunity in the federal contracting community, and $44 million for the Office of Labor Management Standards (3% more).

Departmental Management / Other Labor Programs & Agencies

The agreement provides $349 million for salaries and other general administrative expenses at the Labor Department, with all accounts being funded at the FY 2020 level except the Women's Bureau, which would receive a $1 million increase to $15 million.

Separately, it provides $27 million (8% more than FY 2020) for modernization of the department's information technology, and $91 million (equal to FY 2020) for the department's Inspector General.

It also provides the following for other Labor Department agencies and activities:

Workforce Innovation and Opportunity Act -- $5.4 billion (1% more than FY 2020) for programs and activities under WIOA.

Veteran Employment and Training -- $316 million (2% more than FY 2020) for those veteran employment and training activities, with $180 million for state grants (equal to FY 2020), a 5% increase for the Homeless Veterans Reintegration program, and a 7% increase for the Transition Assistance program.

Bureau of Labor Statistics -- $655 million for the BLS, equal to FY 2020. Within that total, $228 million is for employment statistics activities and $216 million is for price and cost-of-living research (both 3% more than FY 2020).

Employee Benefits Security Administration -- $181 million (equal to FY 2020) for the EBSA, which is responsible for the security of retirement, health and other workplace-related benefits of working Americans.

Pension Benefits Guaranty Corporation -- $465 million (3% more than FY 2020) for administrative expenses of the PBGC, which protects the retirement incomes of nearly 35 million American workers in almost 25,000 private-sector defined benefit pension plans.

Worker Compensation Programs

The agreement provides a total of $857 million in mandatory funding for various workers' compensation programs administered by the Labor Department, 6% more than FY 2020.

These programs include the Black Lung Disability Trust Fund, which pays black-lung compensation, medical- and survivor-benefit expenses when no responsible mine operator can be assigned liability ($383 million for benefit payments, 5% more than FY 2020); special benefit payments for disabled coal miners ($55 million, 57% more); the Energy Employees Occupational Illness Compensation Fund for Energy Department employees and contractors who suffer from diseases such as cancer or chronic silicosis as a result of their work with nuclear weapons ($63 million, 5% more); and federal employee compensation benefits ($237 million, 2% more).

Related Agencies

Corporation for National & Community Service

The measure provides $1.1 billion for the Corporation for National and Community Service, including for AmeriCorps and the Volunteers in Service to America (VISTA) program -- 1.5% more than FY 2020 and $1 billion more than requested.

The total includes $521 million for several national and community service programs, including $455 million for AmeriCorps (6% more than FY 2020) which addresses community needs in education, public safety, health and the environment, and which the administration proposed to terminate.

It provides $97 million for the VISTA program (4% more than FY 2020), which provides capacity building for small, community-based organizations that combat poverty; its members establish and expand housing, employment, health and economic development programs.

It also provides $225 million for the Senior Volunteers Corps (2% more than FY 2020), a collection of programs to connect older individuals with opportunities to contribute their skills and expertise to community projects and organizations. The programs include foster grandparents and senior companions.

Corporation for Public Broadcasting

As is traditionally done for the Corporation for Public Broadcasting, the measure provides only two-year advance funding for the CPB, in this case providing $475 million for FY 2023.

CBP funding for FY 2021 ($445 million) was provided by the FY 2019 appropriations law, and the FY 2020 appropriations law provided $465 million that will be available for FY 2022.

The measure also provides $20 million for public television interconnection systems in FY 2021.

Social Security Supplemental Security Income (SSI) Program

The agreement provides for the Social Security Administration to use $60.1 billion in FY 2021 from the Social Security Trust Fund (including prior advance appropriations) for the Supplemental Security Income (SSI) Program -- including $55.5 billion in payments to SSI beneficiaries and $4.5 billion to administer the program.

That total also includes $45 million for beneficiary services and $86 million for research and demonstration activities. The measure also provides a $19.6 billion advance appropriation for the program for FY 2022.

The measure also allows for the use of $11.4 billion from the trust fund for administrative expenses in FY 2021, and it provides $1.6 billion for program integrity activities ($7 million less than comparable FY 2020 funding).

National Labor Relations Board & Other Agencies

The agreement appropriates $274 million for the National Labor Relations Board (NLRB), equal to FY 2020.

The Railroad Retirement Board, Federal Mine Safety and Health Review Commission and Occupational Safety and Health Review Commission also would be funded at FY 2020 levels, while funding would be increased by 2% for the Institute of Museum and Library Services and the National Mediation Board and by 3% for the Federal Mediation and Conciliation Service and Medicare Payment Advisory Commission (MedPAC).

<p> By Greg Tourial [email protected]

Section X

Legislative Branch

This section describes the provisions of HR 133, Consolidated FY 2021 Appropriations Act, that provide funding for the legislative branch.

The agreement provides $5.3 billion in net discretionary spending subject to caps, along with $10 million in emergency funding for operations of the House of Representatives and the Senate, joint House-Senate items and legislative branch entities such as the Library of Congress, the Capitol Police, the Government Accountability Office (GAO) and the Government Printing Office (GPO). The cap total is $251 million (5%) more than the FY 2020 level.

It provides a net increase of 8% for House administration and offices and 3% for Senate operations. It increases funding for the Library of Congress (4%), the Government Accountability Office (6%) and the Congressional Budget Office (4%). It decreases net funding for the Architect of the Capitol by 2% and provides $2 million in additional funds for the Jan. 21 Presidential Inauguration.

The agreement continues a freeze on pay for members of Congress and provides funding to support cybersecurity needs at Legislative Branch agencies, according to appropriators.

House Operations

The agreement appropriates a total of 1.5 billion for operations of the House of Representatives in FY 2021 --8% more than FY 2020. The total is partly offset by $4 million in rescissions of prior year funds from various account.

Leadership Offices

It provides $29 million in total for Democratic and Republican leadership offices and party caucuses, equal to FY 2020.

For the majority leadership, the measure provides $8.3 million for the speaker of the House, $2.9 million for the majority leader, $2.4 million for the majority whip and $2.3 million for the Democratic Caucus.

Funding for the minority leadership would also be at FY 2020 levels, with $8.3 million for the minority leader, $2.2 million for the minority whip and $2.3 million for the Republican Conference

Members and Committees

The measure appropriates $640 million for members' representational allowances, 4% more than FY 2020. This account funds each member's staff salaries, office expenses and official mail costs. It provides that unspent amounts remaining in members' accounts be used for deficit or debt reduction. The measure contains no funds for members' salaries, which are paid out of a permanent appropriation for the compensation of members.

Additionally, the agreement increases the total amount of a House staffer's student loan debt that may be forgiven under the House student loan repayment program from $60,000 to $80,000.

For House committee salaries and expenses, the measure provides $163 million, a 2% increase. Of that total, $25 million would be for the Appropriations Committee.

Finally, an additional $11.4 million is provided for compensation of House interns.

Other House Expenses

The measure appropriates $261 million for functions performed by the various House officers and employees (12% more than the FY 2020 level), including $32 million for the Clerk of the House (4% more), $23 million for the Office of the Sergeant at Arms (15% more), $177 million for the chief administrative officer (15% more), and $12 million for the Office of Legislative Counsel (equal to FY 2020).

Separately, the measure provides $374 million for the House's allowances and expenses account, which funds supplies, administrative costs, federal tort claims, official mail and the government's share of retirement, health care and unemployment compensation payments for House employees. The total is 16% more than FY 2020 levels. The vast majority the total, $335 million, is for the government's contributions for employee benefits.

Finally, another $2 million is provided to establish the House Modernization Initiatives Account, which can be used to fund recommendations made by the Select Committee on the Modernization of Congress.

Senate Operations

The agreement appropriates $999 million in net funding for Senate operations in FY 2021 -- 3% more than the FY 2020 level.

The measure provides $223 million for the salaries of officers and employees of the Senate, 3% more than FY 2020. Included in this total is $89 million for the Office of the Sergeant at Arms and the Doorkeeper, $27 million for the Office of the Secretary, $5.5 million for the offices of the majority and minority leaders, $3.5 million for the offices of the majority and minority whips, and $16 million for the Appropriations Committee. It also provides $69 million for agency contributions.

For contingent expenses of the Senate, the measure appropriates $769 million (3% more than FY 2020). That total also includes $133 million for inquiries and investigations and $461 million for benefits and salaries for senators' staff and office expenses, while $6 million is provided to pay Senate interns. Unspent amounts remaining in senator's accounts would be used for deficit or debt reduction.

Additionally, the agreement increases the total amount of student loan debt that may be forgiven under the Senate student loan repayment program from $40,000 to $80,000.

Separately, it provides $6.7 million for the Senate Legislative Counsel (4% more than FY 2020) and $1.2 million for the Senate Legal Counsel (equal to FY 2020).

Joint House-Senate Items

The agreement appropriates a total of $21.5 million for certain items jointly operated by the House and Senate, 2% more than FY 2020.

Within the total, the Joint Committee on Taxation receives $12 million (3% more than FY 2020) and the Joint Economic Committee $4 million (equal to FY 2020). Another $1.5 million (2% more) is provided for the Office of Congressional Accessibility Services, which coordinates services for individuals with disabilities, including members of Congress, staff, and visitors, in the Capitol complex.

Office of the Attending Physician

The agreement provides $3.9 million for the Office of the Attending Physician for baseline funding needs, including medical supplies, equipment, expenses and allowances. It also provides the attending physician with an additional $5 million to remain available until expended to respond to COVID-19, including testing.

Inaugural Ceremonies

The measure provides $2 million in additional for the Joint Congressional Committee on Inaugural Ceremonies (The FY 2020 appropriations measure provided $1.5 million in funding for the committee). The additional funds will help the committee prepare to host the Presidential Inauguration during the COVID-19 pandemic, including covering the cost of COVID testing for the all attendees, guests, and support staff at the ceremonies.

Capitol Police

The measure appropriates a total of $516 million for the Capitol Police -- 11% more than FY 2020.

The total includes $424 million for salaries and benefits and $91 million for general expenses, with a portion of the increased salary funding to be used to hire additional personnel. Within the total, $2 million is provided for the department to provide security to members in the D.C. area as warranted by risk-based analysis.

The measure directs the Capitol Police to consult with the Justice Department in order to implement evidence-based training on use-of-force and de-escalation required by the agreement for federal law enforcement. Appropriators, in their explanatory material, also direct the Capitol Police to include with future budget submissions information on USCP workforce diversity and steps taken to promote a diverse Capitol police force.

Appropriators continue to instruct the Capitol Police not to enforce a 1876 law regarding protection of the Capitol's grounds, including turf and grass, with regard to snow sledders, in order to maintain good relations in the "family-style neighborhood the Capitol shares with the surrounding community."

Finally, the measure increases the total amount of a Capitol Police Officer's student loan debt that may be forgiven from $60,000 to $80,000.

Architect of the Capitol

The measure appropriates $675 million in net funding for the Architect of the Capitol (AOC) for continued maintenance, operation, development and preservation of the Capitol complex. The total is 2% less than comparable FY 2020 funding.

Within the total, $35 million is provided for operations and maintenance of the Capitol building (50% less than FY 2020), and $25 million for the Capitol Visitor Center (2% more than FY 2020).

It provides $127 million for general operations and construction (6% more than FY 2020); $90 million for Senate office buildings (1% more); and $139 million for operation, maintenance and care of House office buildings (9% less than FY 2020) -- of which $9 million is derived from the House Office Building Fund for a net appropriation of $130 million. Within that amount, $62 million is available for continued restoration and renovation work on the Cannon Office Building.

It also provides $83 million for Library of Congress buildings and grounds (50% more than FY 2020), $21 million for the Botanic Garden (30% more), $21 million for care and improvement of the Capitol grounds (37% more), $46 million for Capitol Police buildings (17% less), and $108 million for the Capitol power plant (1% less, $10 million of which would be paid for through offsetting collections).

Congressional Agencies

Government Accountability Office

The measure provides $692 million for activities of the Government Accountability Office (GAO), 6% more than FY 2020. The measure's funding is offset by the collection of $25 million in reimbursements for conducting financial audits of government corporations and rental of space in the GAO building, resulting in a net appropriation of $668 million. The agreement directs the GAO to use the additional funding to increase the size of its science and technology staff.

Separately, the agreement provides another $10 million in emergency funding to the GAO for specifically audits and oversight of federal COVID-19 response and recovery efforts.

Library of Congress

The agreement provides a net total of $757 million for various activities of the Library of Congress -- 4% more than FY 2020 -- including $523 million for library salaries and expenses (unlike previous appropriations measures, it does not authorize the Library to use receipts to provide additional funding for salaries and expenses).

It also provides $93 million for activities of the U.S. Copyright Office within the Library, 2% more than FY 2020. It allows the office to spend $42 million of the receipts it collects and $3 million in prior year unobligated balances, thereby reducing the measure's net appropriation to the office to $49 million. The agreement also provides $60 million (2% more) for the National Library Service for the Blind and Print Disabled, a free national reading program for blind and physically handicapped residents of the United States and U.S. citizens living abroad.

Additionally, the total includes $125 million for the Congressional Research Service (CRS), 4% more than FY 2020, which is directed to hire additional staff to strengthen its science and technology research capacity to better provide better analysis to lawmakers on emerging issues. and $60 million for the Books for the Blind program.

Government Publishing Office

The measure appropriates $117 million for activities of the Government Publishing Office (GPO), equal to FY 2020.

Of the total provided, $78 million is for the printing and binding of specific congressional documents -- including bills, committee reports, hearing transcripts, committee prints, the Congressional Record and other such documents. It also provides $32 million for other public printing activities, and allows GPO's business operations revolving fund to receive $6.7 million.

Other Offices and Activities

Congressional Budget Office -- $57 million for CBO activities, 4% more than the FY 2020 level.

Office of Congressional Workplace Rights -- $7.5 million (18% more) for the OCWR (known as the Office of Compliance before 2018), which is responsible for ensuring congressional compliance with various labor and employment laws and administers the existing dispute resolution process for cases of harassment or discrimination.

Open World Leadership Center Trust Fund -- $6 million for the center (equal to FY 2020), which brings emerging leaders from Russia and other Eurasian countries to "experience American democracy and civil society in action."

John C. Stennis Center for Public Service Training and Development -- $430,000 for the center, equal to FY 2020

Pay Freeze & Other Provisions

The measure includes language to continue the freeze on the pay of members of Congress, thereby preventing a statutory pay increase for FY 2021. A freeze on lawmakers' salaries has been in place since 2010.

It also continues certain restrictions that have been included in recent Legislative Branch Appropriations Acts, including the following:

Plastic Waste -- Requires Legislative Branch agencies and officers to coordinate with food service providers to eliminate or reduce plastic waste, including plastic drinking straws.

Congressional Record -- Prohibits the delivery of printed copies of the Congressional Record to House members' offices.

Telecomm Equipment -- Prohibits the acquisition of telecommunications equipment produced the Chinese technology companies Huawei or ZTE, or any other systems designed as "high-impact" or "moderate-impact" as defined by the National Institution of Standards and Technology.

Unlike the version of the FY 2021 Legislative Branch bill introduced in the House, the agreement does not permit legislative branch agencies to employ "Dreamers" (U.S. residents who came into the country as children without proper immigration status) who have work authorizations under the Obama-era Deferred Action for Childhood Arrivals (DACA) program.

Section XI

Military Construction & Veterans Affairs

This section describes the provisions of HR 133, Consolidated FY 2021 Appropriations Act, that provide funding for military construction and for programs and activities of the Veterans Affairs (VA) Department.

The agreement appropriates a total of $113.1 billion in net discretionary funding for FY 2021 for military construction, VA medical programs and other programs and related agencies, and $138.7 billion in mandatory funding for VA pensions and other benefits -- thereby providing a total of $251.8 billion for the year. The discretionary total includes $112.8 billion subject to caps and $350 million in Overseas Contingency Operations (OCO) funding. The measure also rescinds $525 million in prior year funding.

The total funding available for FY 2021 includes $218.6 billion in advance VA funding for FY 2021 provided by prior-year appropriations laws; the agreement includes $239.5 billion in advance VA appropriations for FY 2022 ($94.2 billion discretionary and $145.3 billion mandatory).

The measure provides a net total of $8.1 billion for base military construction activities, 29% less than FY 2020 but $250 million more than requested. It also provides $350 million in OCO military construction funding for the European Reassurance Initiative.

For the VA, it provides a net total of $243.2 billion for FY 2021 -- including $104.4 billion in net discretionary spending and $138.7 billion for mandatory VA benefits. The discretionary total is $11.9 billion (13%) more than FY 2020. Within the VA total, it provides $90.8 billion for VA health care programs, 12% more than FY 2020, including a 10% increase for VA medical services.

Military Construction

The agreement provides a net total of $8.1 billion for base military construction spending in FY 2021 -- $3.3 billion (29%) less than FY 2020 but $250 million more than requested. (On a programmatic basis it provides $8.3 billion, with a $269 million rescission in prior year funding reducing the scored cost.) Separately, it provides $350 million in OCO funding for military construction projects in Europe, 46% less than FY 2020 OCO funding.

Of the total provided, $475 million is for military construction projects that were not included in the president's official budget request, but which are part of each military service's "unfunded priority list" or are near completion and need additional funds.

Military construction accounts provide funds for new construction, construction improvements, planning and design, and host nation support. Projects funded by these accounts include facilities for operations, training, maintenance, research and development, supply, medical care and force protection, as well as unaccompanied housing, utilities infrastructure and land acquisition.

Core Military Construction

The agreement appropriates $6.3 billion for core military construction activities -- $2.5 billion (29%) less than FY 2020.

It provides $5.0 billion for construction activities for the active military services, 35% less than FY 2020. Within that total it provides $629 million (47% less than FY 2020) for the Army; $1.7 billion (30% less) for the Navy and Marine Corps; $616 million (63% less) for the Air Force; and $2.0 billion (14% less) for defensewide projects.

It provides a total of $596 million for construction activities for National Guard and Reserve components, 8% more than 2020.

It also provides a total of $475 million for military construction projects that were either not included in the president's request but were on the military's "unfunded priority list" or need additional funding to be completed ($309 million and $166 million, respectively). The total is about one-third of the amount provided for comparable purposes in FY 2020.

Family Housing

The agreement appropriates a total of $1.3 billion for family and military personnel housing -- 1% more than 2020.

Within that total, it provides $119 million (16% less than FY 2020) for Army housing construction and $352 million (2% less) for operation and maintenance; $43 million (10% less) for Navy and Marine Corps construction and $346 million (9% more) for operation and maintenance; $97 million (6% less) for Air Force construction and $317 million (7% more) for operations and maintenance; and $55 million (4% less) for defensewide housing operation and maintenance.

It also includes $60 million for the Family Housing Improvement fund to address mold, vermin and lead in military family housing, almost double the FY 2020 funding.

Other Military Construction

The agreement appropriates $173 million for the North Atlantic Treaty Organization (NATO) Security Investment Program, slightly more than FY 2020.

It provides $480 million for continued activities under the 1990 and 2005 base realignment and closure (BRAC) rounds -- 21% more than FY 2020 and 60% more than requested. Funding for both the 1990 and 2005 BRAC accounts are provided in a single line item.

Separate from the regular military construction accounts, the measure provides the requested $350 million in Overseas Contingency Operations (OCO) funding for construction-related activities for the European Reassurance Initiative, 36% less than FY 2020. It provides no OCO funding for other overseas military construction projects, for which $100 million was provided in FY 2020.

Veterans Programs

The VA serves more than 43 million people: nearly 20 million veterans and 24 million family members of living veterans or survivors of deceased veterans. The department employs more than 400,000 people, making it one of the largest federal employers.

For the VA the agreement provides a net total of $243.2 billion -- including $104.4 billion in discretionary funding for health care and other services and $138.7 billion in mandatory spending for veterans pensions and benefits. (The measure rescinds $256 million in prior-year VA funding.)

Of the total for FY 2021, $218.6 billion represents advance discretionary and mandatory appropriations for FY 2021 provided by prior-year appropriations laws. The measure provides $239.5 billion in advance appropriations for FY 2022 -- $94.2 billion in discretionary funding for VA's medical accounts and $145.3 billion for mandatory VA benefits.

Veterans Health Programs

The VA operates the largest federal medical care delivery system in the United States. It will treat an estimated 7.2 million patients in 2021 in its 148 hospitals, 116 residential rehabilitation programs, 135 nursing homes, 300 Vet Centers, 80 mobile Vet Centers and 765 outpatient clinics.

The agreement provides a total of $90.8 billion in funding for health care programs of the Veterans Health Administration (VHA) in FY 2021 -- 12% more than comparable FY 2020 funding.

Another $4.4 billion for VA health care will be provided from reimbursements that the VA collects from veterans and other insurers (so-called medical care cost recovery collections) for non-service-connected care that the VA provides to veterans, 18% more than FY 2020 collections.

The total for FY 2021 includes $87.6 billion in advance FY 2021 appropriations from prior years and $3.1 billion in regular appropriations. For FY 2022, the measure provides $94.2 billion in advance appropriations for VA health care accounts.

Medical Services

The medical services account provides funding for medical services to eligible veterans and beneficiaries in VA medical centers, outpatient clinics, contract hospitals, state homes and outpatient programs on a fee basis.

The agreement provides a total of $56.7 billion for VA medical services for FY 2021 -- 10% more than FY 2020. Of that total, $56.2 billion is provided through advance funding from prior-year appropriations; the measure includes a $58.9 billion advance appropriation for FY 2022.

Within the total, $10.2 billion is for mental health programs, of which $313 million is for suicide prevention outreach. Another $1.9 billion is for programs to prevent veteran homelessness and $1.3 billion to sustain and increase telehealth capacity.

The total also includes $661 million for gender-specific care for women, including $1 million for peer support programs for women veterans; $504 million for opioid prevention and treatment programs; $74 million for the Whole Health initiative; and $10.6 billion for long-term care.

The Medical Care Collections Fund (MCCF), established by the Balanced Budget Act of 1997 (PL 105-33), receives reimbursements from veterans and other insurers for non-service connected care that the VA provides to veterans -- with the funds then used for VA medical care and services. The measure estimates that in FY 2021, $4.4 billion will be collected and available for use by the VA.

The measure provides for a transfer of $18 million from the MCCF and $323 million from the Medical Services Account to the Joint Defense-VA Departments Medical Facilities Demonstration Fund for operation of combined medical facilities under that 2010 demonstration program.

Other Programs

The agreement provides $18.5 billion for FY 2021 for the medical community care account, which was created in FY 2017 to consolidate into a single appropriation all community care programs under which the VA pays for medical care provided to veterans by private health care professionals outside of the VA's medical network.

That total is 21% more than FY 2020 and includes $17.1 billion in advance funding provided by prior-year appropriations law; the measure provides $20.1 billion in advance appropriations for FY 2022. Another $784 million would be available for medical community care and VA medical services for FY 2021 via a transfer of funds from the MCCF.

It provides a total of $8.2 billion for VA medical support and compliance activities -- 12% more than FY 2020. Of that total, $7.9 billion is provided through a prior-year advance appropriation; the measure includes a $8.4 billion advance appropriation for FY 2022.

It provides $6.6 billion for VA medical facilities -- 7% more than FY 2020. Of that total, $6.4 billion is provided through a prior-year advance appropriation; the measure includes $6.7 billion in advance appropriations for FY 2022.

Finally, it appropriates $815 million for medical, rehabilitative and prosthetic research for FY 2021 -- 2% more than the FY 2020 level.

Veterans Benefits Administration

In addition to veterans medical benefits provided by the Veterans Health Administration, the VA provides veterans compensation and pensions as well as readjustment benefits to eligible veterans through the Veterans Benefits Administration (VBA).

The agreement provides a total $142.1 billion for the Veteran's Benefit Administration for FY 2021 -- including $138.7 billion in mandatory spending for veterans compensation and pensions, readjustment benefits and housing loans, and $3.2 billion in discretionary funding for VBA operating expenses. The FY 2021 funding for mandatory VA benefits is 11% more than the FY 2020 level, while the discretionary funding for operating expenses is 2% more.

Of the VBA total, $131.0 billion is provided through prior-year advance mandatory appropriations; the measure includes a $145.3 billion advance mandatory appropriation for FY 2022 for VA benefits.

Veterans Compensation & Pensions

This account provides funds for service-connected compensation payments to 5.7 million veterans, survivors and dependents, and pension payments for over 393,000 veterans and survivors. It provides educational assistance for nearly 950,000 individuals and interment services for 137,000 veterans and family members. According to the committee, the average cost per compensation case for veterans in 2021 is estimated at $19,974 and the average pension payment is projected to be $14,186.

The agreement provides $124.4 billion for veterans service-connected compensation benefits and pensions for FY 2021 -- 13% more than 2020 funding. Of that total, $118.2 billion is provided through advance appropriations from prior spending acts; the measure includes a $130.2 billion advance mandatory appropriation for FY 2022.

Readjustment Benefits

The measure provides $12.6 billion for veterans readjustment benefits for FY 2021, all of which is advance appropriations from prior spending bills. The total is 11% less than FY 2020 funding.

Funding in this account provides education and training assistance to veterans and service personnel; vocational rehabilitation; special housing and transportation grants to certain disabled veterans; and educational assistance to eligible dependents of deceased and seriously disabled veterans, as well as dependents of servicemembers who were captured or are missing in action. More than 80% of the funds support the Post-9/11 GI bill.

The measure provides a $14.9 billion advance mandatory appropriation for FY 2022.

Veterans Insurance & Indemnities

The agreement provides $131 million in mandatory funding to finance veterans insurance programs for certain veterans of World War I, World War II and the Korean War, as well as the veterans mortgage life insurance for those veterans who have a grant for specially adapted housing.

The total provided is 2% more than 2020, and includes $129 million in prior-year appropriations; the measure includes $137 million in advance mandatory appropriations for FY 2022.

VA Housing Benefit Program

The measure provides $204 million in discretionary funding for administrative expenses under the VA Home Loan Guaranty program (2% more than FY 2020), and it provides $1.7 billion in mandatory funding for the credit subsidy to support VA home loan guarantees.

Loan guarantees under the program are made to servicemembers, veterans, reservists and single surviving spouses for the purchase of homes, condominiums and manufactured homes, as well as for refinancing loans. Under the program, the VA guarantees part of the total loan, permitting the purchaser to obtain a mortgage with a competitive interest rate, even without a down payment. With a VA guarantee, the lender is protected against loss, up to the amount of the guarantee, if the borrower fails to repay the loan.

The agreement sets a $500,000 cap on direct loans for specially adapted housing.

VA Department Administration

The measure provides a total of $10.2 billion for general VA administrative and other expenses -- 21% more than FY 2020 but 1% less than requested. Within that total, $366 million (3% more than FY 2020) is for general administration of the VA Department and $228 million is for the Office of the Inspector General (9% more than FY 2020).

The total includes the requested $4.9 billion for VA information technology (12% more than FY 2020), as well as $2.6 billion for continued development and implementation of a new VA electronic health record ($1.1 billion, or 75%, more than FY 2020).

It includes $1.3 billion (7% more than 2020) for major modernization projects and the alteration and improvement of VA facilities where the project is estimated to cost $20 million or more, and $390 million (2% less than FY 2020) for "minor" projects estimated to cost below that threshold. It includes $90 million for construction of state extended care facilities, equal to FY 2020.

It also includes $352 million (7% more than FY 2020) for VA's National Cemetery Administration -- which supports operation and maintenance of 156 national cemeteries, 11 cemeteries transferred from Army and 33 other cemeterial installations -- and $45 million (equal to FY 2020) for grants for the construction of veterans cemeteries.

Finally, it provides $196 million for the Board of Veterans Appeals, 8% more than FY 2020.

Other Related Agencies

In addition to funding military construction and the VA, the measure funds four other agencies and accounts.

Arlington National Cemetery

The Army secretary is responsible for the administration, operation and maintenance of Arlington National Cemetery and the Soldiers' and Airmen's Home National Cemetery. In addition to its principal function as a national cemetery, Arlington is the site of approximately 3,000 non-funeral ceremonies each year and has approximately 4 million visitors annually.

The agreement provides $82 million for the two cemeteries in FY 2021 -- 1% more than FY 2020 and $11 million more than requested. All of funding provided is for salaries and expenses; no funding was requested or provided for construction.

Court of Appeals for Veterans Claims

The measure includes $37 million for the U.S. Court of Appeals for Veterans' Claims, 5% more than 2020.

The court reviews appeals from claimants seeking review of a benefit denial by the VA. It has the authority to overturn findings of fact, regulations and interpretations of law.

Armed Forces Retirement Home

The Armed Forces Retirement Home consists of two retirement communities: one in Washington, D.C., and the other in Gulfport, Miss.

The measure provides $75 million for the Armed Forces Retirement Home, equal to FY 2020. The total includes $22 million from the general fund of the Treasury, rather than the trust fund that supports the retirement communities. Expenditures from the trust fund have exceeded revenues for several years.

American Battle Monuments Commission

The measure provides $84 million for salaries and expenses of the American Battle Monuments Commission, equal to FY 2020 and $9 million more than requested.

The commission administers and maintains cemeteries and war memorials located overseas and in the United States to commemorate the sacrifices of those who lost their lives in combat since World War I. It maintains 25 cemetery memorials and 26 monuments, memorials and markers.

<p> By Robert Tomkin [email protected]

Section XII

State-Foreign Operations

This section describes the provisions of the conference agreement on HR 133, Consolidated FY 2021 Appropriations Act, that provide funding for foreign operations and the State Department.

The agreement provides a total of $60.8 billion in discretionary funding for foreign operations and the State Department in FY 2021 -- including $47.7 billion subject to discretionary caps (2% more than FY 2020), $8 billion in Overseas Contingency Operations (OCO) funding, and $5.3 billion in COVID-related emergency funding.

Excluding the emergency COVID funding, it provides a total of $55.5 billion in regular discretionary and OCO funding -- $820 million (2%) more than comparable FY 2020 funding and $10.8 billion (24%) more than requested, according to House appropriators.

The measure rejects most of the major spending reductions proposed by President Trump, whose budget would have reduced foreign spending by almost 22%. It includes $5.9 billion for the President's Emergency Plan for AIDS Relief (PEPFAR), including $1.6 billion for the Global Fund. It also includes $4 billion in emergency funding for the GAVI Alliance, a fund that provides vaccines to the world's poorest countries.

It provides $3.3 billion in security assistance for Israel, $1.7 billion for Jordan, $1.4 billion for Egypt, and $200 million for the Palestinian people in the West Bank and Gaza. It provides $770 million for Eastern Europe, including Ukraine, $319 million more than requested. It also provides at least $506 million for the countries of Central America, including the Northern Triangle countries of Guatemala, Honduras and El Salvador.

The largest tranche of funding is for the Bilateral Economic Assistance title of the measure -- $26.5 billion, 2% more than FY 2020 and $6.7 billion more than requested -- which includes funding for global health programs, development assistance, economic support aid, migration and refugee assistance, and international disaster assistance. Within that title $3.5 billion is for the general Development Assistance account and $3.15 billion is for the Economic Support Fund, both of which provide funding for a wide range of activities, including direct aid to nations. The measure rejects the administration's proposal to consolidate those two accounts into a single Economic Support and Development Fund at a reduced overall level.

Security Assistance

The agreement includes a total of $9.0 billion for international security assistance to nations -- slightly less than FY 2020 funding and $1.4 billion more than requested.

The account total includes $1.4 billion for international narcotics control and law enforcement programs and activities ($375 million, or 37%, more than requested), $441 million for voluntary contributions to international peacekeeping operations (56% more than requested; see "Peacekeeping," below), $889 million for international nonproliferation, anti-terror and demining efforts (18% more than requested), and $113 million for the International Military Education and Training program (IMET; 8% more than requested). IMET is part of the overall U.S. security assistance program; through it the U.S. government provides training to military students and soldiers from foreign armies.

It also provides $6.2 billion for the Foreign Military Financing Program, under which aid is provided to Israel, Egypt and other nations (see Bilateral Aid, below). The totals provided for Israel and Egypt ($4.6 billion combined) is equal to the request, while the remainder for other nations is $579 million more than requested.

The agreement also provides other security-related funding through various accounts, including a total of $100 million for a Prevention and Stabilization Fund established by last year's The Global Fragility Act to try and prevent violence and conflict that can become a breeding ground for terrorism.

Aid to Specific Nations

The agreement provides aid to a wide range of specified nations -- including aid from both programs in the Bilateral Economic Assistance title of the measure and the Foreign Military Financing Program in the International Security Assistance title.

Israel

The measure provides $3.3 billion in military assistance for Israel. All of the funds are in the form of military financing grants through the Foreign Military Financing program, and would be provided to Israel as cash grants within 30 days of enactment. Of the total, $805 million could be used for purchases or research and development in Israel; the remainder must be spent on U.S. goods and services.

It also requires the secretary of State to report on instances of anti-Israel bias at the United Nations, including identification of the agencies and entities where such bias has been demonstrated in the past.

Egypt

The measure appropriates $1.4 billion in aid for Egypt, including $1.3 billion for military grants through the Foreign Military Financing program and $125 million in economic assistance. The economic aid includes $40 million for higher education, including $15 million for scholarships at not-for-profit institutions for Egyptian students with high financial need. It also includes $2 million for International Military and Education Training (IMET). President Trump objected to the measure's aid to Egypt in some of his tweets opposing the overall agreement.

The measure withholds 20% of the military aid until the secretary of State certifies that Egypt has taken steps to advance democracy and human rights in Egypt, including to govern democratically and protect religious minorities and the rights of women. The secretary could waive the requirement if he certifies doing so is in U.S. national security interests. However, the agreement also withholds 5% of any funds released under the waiver until the secretary reports that the Egyptian government has fairly compensated U.S. citizen April Corley for severe injuries she sustained during an attack on her tour group by Egyptian armed forces on Sept. 13, 2015.

Palestinians

U.S. assistance to the Palestinians has fluctuated considerably over the past decade, largely due to the militant group Hamas's forcible takeover of the Gaza Strip in June 2007. After that, U.S. aid to the Palestinian Authority (PA) government in the West Bank headed by President Mahmoud Abbas increased, but has been subject to numerous restrictions and oversight requirements because of concerns that U.S. funds might be diverted to Palestinian terrorist groups like Hamas.

The measure provides $75 million for security assistance programs for the West Bank and $75 million for the humanitarian and development needs of the Palestinian people in the West Bank and Gaza Strip.

It also provides $50 million for the new Nita M. Lowey Middle East Partnership for Peace Fund, which authorizes people-to-people exchanges and economic partnerships between Israelis and Palestinians.

Jordan

The measure provides at least $1.7 billion for Jordan, equal to the FY 2020 level. The total includes $1.1 billion in general economic support assistance, $425 million in military aid, and $85 million in development aid. In February 2018, the United States and Jordan signed a memo of understanding to give Amman at least $1.275 billion a year annually over the next five years.

Jordan is host to hundreds of thousands of Syrian refugees in addition to more than 2 million Palestinian refugees who have been in the country for decades. Additional humanitarian aid for Syrian refugees in Jordan is provided through other accounts in this measure; the defense appropriations bill also includes funding for Jordan to fight the Islamic State.

Ukraine Aid & Other Responses to Russian Aggression

The agreement provides $453 million for Ukraine and restricts assistance to any country that recognizes the Russian annexation of Crimea or any other territory in Ukraine. The Ukraine total includes economic assistance, military aid, counter-drug assistance, and funds to counter the influence of Russian media in the region. (The Defense Appropriations bill also provides funding for weapons for Ukraine in response to Russia's continued actions in Ukraine.)

It provides $290 million for the Countering Russian Influence Fund, which aid countries in Europe and Eurasia in enhancing the capacity of their security forces, including the modernization of NATO partners. The funds may also be used by the Baltic states for cyber and democracy programs to counter Russian influence and aggression. The total includes $150 million for military aid, $50 million for International Narcotics Control and Law Enforcement, and $85 million for economic aid -- including $20 million to strengthen democracy and civil society in Central Europe, including for transparency, independent media, rule of law, minority rights, and programs to combat anti-Semitism.

The measure also provides $132 million for Georgia and it restricts assistance to any country that recognizes the independence of, or establishes diplomatic relations with, the Russian occupied Georgian territories of Abkhazia and Tskhinvali Region/South Ossetia. The Assad regime in Syria recognized such territories in May 2018.

China

The agreement provides $300 million in various accounts for a new Countering Chinese Influence Fund, including development assistance and funds to counter Chinese disinformation.

It prohibits the use of funds to support projects associated with China's Belt and Road Initiative or any dual-use infrastructure projects of China. It also restricts the export of U.S. satellites to China and places additional restrictions on doing business with certain entities in Hong Kong controlled by the People's Liberation Army of China.

Colombia

The agreement provides $461 million for Colombia, $13 million more than FY 2020. The total includes anti-drug and economic support aid, as well as at least $36 million for rule of law and human rights activities. No funds could be used to support the Revolutionary Armed Forces of Colombia (FARC), which has concluded a peace agreement with the Colombian government.

Other Bilateral Aid

The measure also includes the following aid to individual countries.

Mexico -- $159 million, including $100 million for international narcotics control and law enforcement.

Venezuela -- $33 million for democracy and rule of law programs in Venezuela.

Cambodia -- $86 million for various programs (President Trump singled out aid to Cambodia when he tweeted out his objections to foreign aid in the overall agreement).

Central American Migrants

The Obama Administration launched the U.S. Strategy for Engagement in Central America to promote stability and economic development, and it significantly increased aid to the region. The Trump Administration has maintained the Strategy but has placed more emphasis on preventing illegal immigration, combating transnational crime, and generating export and investment opportunities for U.S. businesses, according to the Congressional Research Service (CRS).

After criticizing the lack of cooperation of certain Central American governments in helping to stem the flow of migrants to the United States, the White House in March 2019 ordered the suspension of approximately $450 million in fiscal 2017 and 2018 development and humanitarian assistance to the "Northern Triangle" countries of El Salvador, Guatemala and Honduras. Much of the aid was restored in Oct. 2019 after those countries pledged to reduce the number of asylum seekers heading to the U.S. border.

The agreement provides $506 million from a variety of accounts to fund the Strategy, slightly less than current funding. The funds are to be used to implement a prevention and response strategy focused on border security and the reintegration of migrants, as well as the causes of migration. They are also to be used to support families, counter gangs and drug cartels, and to professionalize police forces in those nations. The total includes $45 million to combat corruption and $25 million to counter gender based violence.

However, 50% of such assistance to the governments of El Salvador, Guatemala and Honduras would be withheld until it is certified that they have met certain requirements related to governance, corruption and human rights.

Health Programs

The agreement provides a total of $9.2 billion for global health programs -- $104 million (1%) more than FY 2020 and $3.2 billion (53%) more than requested -- of which $3.3 billion would be provided through the US Agency for International Development (USAID).

HIV/AIDS Prevention

The United States supports efforts to fight AIDS and related diseases through two major global programs created in 2003: the Global Fund to Fight AIDS, Tuberculosis and Malaria, and a U.S. program called the President's Emergency Plan for AIDS Relief (PEPFAR) initiated by President George W. Bush. Since that time, the United States has contributed more than half of all international funds for global HIV/AIDS prevention and treatment programs, including approximately 33% of the Global Fund's resources alone.

In 2003, only 50,000 Africans received anti-retroviral drugs; today, close to 12 million are receiving anti-retroviral treatment. PEPFAR programs have trained nearly 220,000 new health care workers to deliver HIV and other health services, while 85.5 million people received HIV testing and counseling. PEPFAR programs also care for more than 6.4 million orphans and vulnerable children, while over 2 million babies born to HIV-positive mothers have been born HIV-free.

The agreement's total for global health programs includes almost $6.3 billion to combat HIV/AIDS, including $5.9 billion for PEPFAR -- of which $1.6 billion is for the Global Fund. The PEPFAR total is equal to FY 2020 and $2.1 billion (55%) more than requested.

Maternal & Child Health

The global health total also includes $856 million for various programs and activities to promote the health of mothers and children in less developed nations -- including $290 million for the GAVI Alliance, a fund that provides vaccines in the world's poorest countries, and $65 million for polio prevention programs.

Coronavirus Aid

The agreement includes an additional $4 billion in emergency funding within the State-Foreign Operations measure for international coronavirus-related activities under global health programs, including for the procurement and delivery of vaccines to be administered by USAID and made available as a contribution to the GAVI Alliance.

Abortion / International Family Planning

Within the total for global health programs, the agreement provides $575 million for family planning, equal to the FY 2020 level.

It does not contain House provisions that would have repealed the administration's May 2017 expansion of Mexico City anti-abortion restrictions, which critics call the "Global Gag Rule," or bill provisions that would have barred the use of current or prior years funding to carry out the base Mexico City restrictions.

In January 2017, President Trump reinstated so-called Mexico City restrictions on U.S. international family-planning funding. Those restrictions prohibit U.S. international family-planning funding from being provided to any private, nongovernmental or multilateral organization that uses its own funds to directly or indirectly (through counseling or referral) perform abortions in a foreign country -- except in instances of rape or incest, or when the woman's life is in danger.

Other Provisions

The measure continues the so-called Tiahrt Amendment, which ensures that family-planning programs are voluntary; the so-called Helms Amendment, which bans foreign aid from being spent on abortions; and the so-called Kemp-Kasten Amendment, which prohibits funds to organizations that the president determines support coercive abortion or involuntary sterilization.

It provides $32.5 million (equal to FY 2020) for the U.N. Population Fund (UNFPA, for which the president requested no funds). The measure prohibits such funds from being used in China. That funding is subject to Kemp-Kasten restrictions and may not be provided if the president determines the UNFPA supports or participates in the management of a program of coercive abortion or involuntary sterilization. Critics of UNFPA have long claimed that the fund supports such programs in China, and the Trump administration withheld such funding in FY 2017.

Humanitarian Assistance

The agreement provides a total of $7.8 billion for humanitarian assistance to address crises around the world resulting from large scale displacement and instability. The total is equal to FY 2020 and $1.6 billion more than requested.

That total includes $4.4 billion for international disaster assistance, including $1.7 billion in OCO funding. The total is roughly equal to FY 2020. The administration did request funding, but as part of a proposed International Humanitarian Assistance account that appropriators rejected.

The total also includes $3.4 billion (equal to FY 2020) for international migration and refugee assistance, in particular the costs of the U.S. response to humanitarian crises resulting from armed conflict such as in Africa, the Middle East, South Asia and South America.

State Department Operations & Related Agencies

The agreement includes a total of $16.7 billion to support the operations and activities of the State Department in 190 countries -- $116 million more than FY 2020 and $2.8 billion (19%) more than requested. The measure supports diplomatic efforts to enhance peace and stability around the globe and it authorizes the State Department to exceed the cap on U.S. peacekeeping contributions.

Within the total, $6.1 billion is for embassy and associated security, equal to the FY 2020 enacted level. Appropriators say those funds will address needs at more than 275 diplomatic and consular facilities overseas, including facility upgrades and security personnel, and will support more than 3,100 regional security officers and 40,000 guards to provide perimeter security and access control at U.S. diplomatic facilities.

The measure prohibits the use of State Department or USAID funds to pay for private email accounts or servers, and it requires the two entities to ensure that all departing employees turn over all official communications before they leave. It also prohibits first-class travel by U.S. government employees.

Separately, the agreement appropriates $1.7 billion for USAID operations, including administering U.S. foreign aid and global health programs. That total is $48 million more than FY 2020 and $120 million (8%) more than requested.

International Organizations

The State total includes $1.5 billion (including $96 million in OCO funding) for assessed contributions for membership in international organizations and programs, not including assessed peacekeeping dues. The total is $32 million more than FY 2020 and $540 million (56%) more than requested.

In addition to the United Nations and its affiliates, organizations for which contributions are assessed include the North Atlantic Treaty Organization, Pan American Health Organization, the Organization of American States and other inter-American organizations, the International Atomic Energy Agency, and the International War Crimes Tribunals for Rwanda and the former Yugoslavia.

The measure also includes $388 million in voluntary contributions to other international organizations through the Office of the President. The administration requested no funds.

Education & Cultural Exchange Programs

The agreement provides $740 million for State Department education and cultural exchange programs, $10 million more than FY 2020 and $430 million more than requested. The total includes $277 million for Fulbright student and scholar exchanges in over 160 countries, and $117 million for the Citizen Exchange Program.

According to appropriators, it also provides $950 million for basic education programs to improve the quality of and access to equitable education, as well as funding for higher education programs, including new partnerships between U.S. and foreign institutions. That total is $75 million more than FY 2020, and it includes $125 million for multilateral partnerships in education.

Democracy Programs

The agreement provides $2.4 billion for programs and activities to promote democracy in other nations, $17 million more than FY 2020 and $867 million more than requested, according to appropriators.

The total includes $300 million for the National Endowment for Democracy, equal to FY 2020 and $233 million more than requested. It also provides $291 million in unrequested funds for the Democracy Fund, an increase of $17 million above the FY 2020 level.

International Broadcasting

The agreement provides $803 million for international broadcasting operations, such as Voice of America, Radio Free Europe and Middle East Television, including Al-Hurra and Radio Sawa. The total is $7.4 million (1%) less than the FY 2020 level.

The total includes funding to counter the growing influence and disinformation of China and Russia.

Other Activities

The measure also provides funding for the following:

Peacekeeping -- $1.5 billion for assessed international peacekeeping activities, $70 million less than FY 2020. The total is $377 million more than requested. International peacekeeping activities are currently ongoing in the Middle East, South Asia, Central and East Africa, Haiti, Western Sahara and the Balkans. It also provides, through international security aid accounts, $441 million for voluntary contributions to international peacekeeping operations ($17 million less than FY 2020).

Peace Corps -- $411 million for the Peace Corps, equal to FY 2020 and $9 million more than requested. It also directs the Peace Corps to ensure that all volunteers who need feminine hygiene products have access to them, regardless of country of service.

Environment -- $320 million for biodiversity efforts ($229 million more than requested), $135 million for sustainable landscapes, and $101 million to combat wildlife trafficking ($67 million more than requested). It also includes $179 million for renewable energy and $75 million to address ocean plastic pollution.

International Commissions -- $99 million for the United States-Mexico International Boundary and Water Commission and $63 million for international fisheries commissions. The organizations are responsible for boundary, water and resource issues along U.S. borders and adjacent waters.

Religious Freedom -- $20 million for programs on religious freedom, $9 million for the Ambassador-at-Large for International Religious Freedom, and $4.5 million for the U.S. Commission on International Religious Freedom.

Emergency Funding

The agreement includes a total of $5.3 billion in emergency funding for various activities within the State-Foreign Operations measure that don't count against discretionary caps.

In addition to the $4 billion for coronavirus vaccine procurement and distribution and other activities under global health programs, it provides $300 million for consular and border security programs to make up reductions in consular and other State Department fees caused by the pandemic.

It also provides nearly $1 billion for activities associated with Sudan, including $150 million for the Sudan Claims Resolution Act (which is also in the agreement; see Section XV, Other Provisions) which guarantees victims of the 1998 East Africa embassy bombings through the Victims of State Sponsored Terrorism Fund. In addition, it provides $700 million in additional emergency funding for the Economic Support Fund for support to Sudan (of which $100 million could be used for programs and activities under the measure's Global Health Programs and Transition Initiatives), and $120 million for the IMF's heavily indebted poor countries debt relief program -- with that amount to be applied towards Sudan's debt.

Development Banks

The agreement funds several international and U.S. financial institutions that help finance projects that promote economic development, particularly in developing nations, including the following:

World Bank --$1.3 billion for the bank, $96 million less than FY 2020 but $140 million more than the request. The total includes $140 million for the bank's global environment facility, for which no funds were requested.

Other International Financial Institutions -- $47 million for the Asian Development Fund, $171 million for the African Development Fund, and $33 million for the International Fund for Agricultural Development.

Millennium Challenge Corporation -- $912 million for the Millennium Challenge program, $7 million more than FY 2020. The U.S. development program provides aid to countries that meet certain standards -- including attacking corruption, respecting human rights, adhering to the rule of law, investing in health and education, encouraging economic freedom, and maintaining sound budget policies..

U.S. International Development Finance Corporation -- $569 million for the U.S. government development bank that has assumed the activities of the former Overseas Private Investment Corporation. The total is $270 million more than FY 2020.

Other Provisions

Finally, the measure provides funding for the following activities:

Human Trafficking -- At least $77 million to work with nongovernmental organizations and partner governments to prevent human trafficking, prosecute traffickers and provide necessary services for victims.

Organized Crime --$68 million to combat international organized crime.

UNICEF -- $139 million in voluntary contributions for the U.N. Children's Fund (UNICEF), including $5 million to combat female genital mutilation.

Wildlife Trafficking -- $50 million to combat wildlife poaching and trafficking, including funds to combat rhinoceros poaching.

Racism & Anti-Semitism -- $1 million for the State Department's Office to Combat and Monitor Anti-Semitism.

Finally, the measure reduces aid to any country whose diplomatic personnel have unpaid parking fines in the District of Columbia and New York City by 110% of the total amount owed to the two cities.

<p> Section XIII

Transportation-HUD

This section describes the provisions of HR 133, Consolidated FY 2021 Appropriations Act, that provides funding for transportation, infrastructure and low-income housing assistance programs.

The agreement provides a total of $136.8 billion for the Transportation and Housing and Urban Development (HUD) departments and related agencies for FY 2021 -- $1.1 billion more than FY 2020 and $16.2 billion more than requested.

That total includes $74.7 billion subject to regular caps on discretionary spending, $718 million in emergency spending, and $61.4 billion in obligation authority from the highway and aviation trust funds. The $75.4 billion net total in discretionary spending is $1.1 billion (1%) more than comparable FY 2020 funding, according to appropriators.

The measure provides a total of $86.7 billion for the Transportation Department -- including both discretionary spending obligation authority from transportation trust funds -- 0.6% more than FY 2020. It increases funding for the Federal Motor Carrier Safety Administration (10%), the Federal Aviation Administration (2%) and the Federal Railroad Administration (1%). Funding for the Federal Highway Administration and Federal Transit Administration would remain essentially flat. It also provides $23 million in emergency payments to air carriers for essential air service.

It provides $49.6 billion for the Housing and Urban Development Department (1% more than FY 2020), and increases funding for Public and Indian Housing by 7%, for Community Planning and Development by 4%, and for other major housing programs by 7%. Of amounts provided for Section 8 tenant-based rental assistance, $695 million is classified as emergency spending.

Transportation Department

The agreement provides a net total of $86.7 billion for programs and activities of the Transportation Department -- including $61.4 billion in obligation authority from federal highway, transit and aviation trust funds. The total available for the department is 0.6% more than comparable FY 2020 funding and $1.1 billion (1%) more than requested.

Federal Highway Administration

The measure provides $49.1 billion for programs and activities of the Federal Highway Administration (FHWA) -- $166 million less than FY 2020.

It allows up to $46.4 billion in funding obligations from the Highway Trust Fund for federal-aid highway programs, equal to FY 2020. Another $739 million in contract authority that is exempt from the obligation limit (equal to 2020 funding) would also be available -- thereby providing a total program level of $47.1 billion for the regular federal-aid highway program in FY 2021, most of which is distributed by formula.

It also appropriates $2.0 billion from the general fund of the Treasury for certain highway infrastructure programs that would be distributed through a combination of formula and discretionary awards -- with almost $1.1 billion to be used for a bridge replacement and rehabilitation program and $641 million for continued development of "alternative fuel" corridors across the nation, including electric vehicle charging infrastructure. The total provided for highway infrastructure programs is $166 million less than the FY 2020 level.

Mass Transit

The agreement provides a total of $13.0 billion for the Federal Transit Administration (FTA) -- $47 million more than FY 2020. The total includes $10.2 billion from the Mass Transit Account of the Highway Trust Fund and a net appropriation of $2.8 billion from the general fund of the Treasury.

The measure allows up to $10.2 billion in obligations from the Mass Transit Account of the Highway Trust Fund for various transit formula grant programs, equal to FY 2020. Formula grant programs funded under this account include urbanized area formula grants, bus and bus facility formula grants, state of good repair grants, formula grants for rural areas, and mobility for seniors and persons with disabilities.

It appropriates $516 million for transit infrastructure grants (1% more than FY 2020) and $2.0 billion (2% more) for Capital Investment Grants to build or improve rail and other fixed-guideway transit systems.

It also provides $150 million for grants to the Washington Metropolitan Area Transportation Authority (Metro) to address safety deficiencies and maintain the capital's subway system. The amount provided is equal to both FY 2020 and the request.

Federal Aviation Administration

The agreement provides $18.0 billion for programs and activities of the Federal Aviation Administration (FAA), 2% more than FY 2020. The total includes $3.35 billion in obligation authority from the Airport and Airway Trust Fund for airport grants.

The measure provides $11.0 billion for FAA operations (3% more than FY 2020) -- including $8.2 billion (3% more) for air traffic control operations, $1.5 billion for aviation safety activities (5% more), and $63 million (2% more) for continued implementation of the NextGen air traffic control system.

It allows up to $3.35 billion (12% more than FY 2020) to be obligated from the Airport and Airway Trust Fund for federal grants-in-aid for airport planning, construction and development under the Airport Improvement Program (AIP). It also provides an additional $400 million in unrequested funding from the general fund of the Treasury for grants for high priority airport construction projects, equal to comparable FY 2020 funding.

It provides $3.0 billion from the Airport and Airway Trust Fund for the FAA's facilities and equipment program (1% less than FY 2020), to fund the procurement and installation of new equipment and for the construction and modernization of facilities in the national airway system, including aids to navigation, radar and communications systems, air traffic control centers and airport control towers.

For the FAA's long-term research, engineering and development program, it provides $198 million (3% more than FY 2020) from the aviation trust fund.

Separately, the agreement provides $142 million (12% less than FY 2020) within the Office of the Transportation Secretary for the Essential Air Service (EAS) program, which subsidizes airline carriers for service to smaller communities. It also provides $23 million in emergency funding for EAS to make up the overflight fees from aircraft crossing U.S. airspace that will be lost due to the COVID-19 pandemic.

Railroads / Amtrak

The agreement provides $2.8 billion for the Federal Railroad Administration (FRA), 1% more than FY 2020, of which $2.0 billion is for Amtrak. In addition to administering grants for Amtrak, the FRA regulates rail safety, administers railroad assistance programs and conducts research and development.

The $2.0 billion for Amtrak (formally the National Railroad Passenger Corporation) is equal to FY 2020 (but $1.1 billion more than requested) and includes $700 million for Amtrak's Northeast Corridor operations and $1.3 billion for Amtrak's National Network.

For other activities of the Federal Railroad Administration, the measure provides: $235 million (5% more than FY 2020) for FRA operations and safety activities; $41 million (1% more) for research and development; $200 million (equal to FY 2020) for state of good repair grants; and $375 million (15% more) for grants under the Consolidated Rail Infrastructure and Safety Improvement program.

BUILD & Other Infrastructure Grants

The agreement provides $1 billion for National Infrastructure BUILD grants (previously called TIGER grants) made by the secretary of transportation, equal to both FY 2020 and the request.

Under the program, which is funded through the Office of the Secretary, competitive grants are provided for a wide variety of transportation and intermodal projects that seek to improve the nation's freight and passenger transportation networks, with federal grants covering 80% of a project's costs. The measure allows the secretary to incur higher federal cost-shares for projects in rural areas and in areas of persistent poverty.

The measure rescinds and reappropriates $340 million for National Infrastructure Investments, thus extending the availability of that previously appropriated funding.

It also provides an unrequested $100 million for a new transportation demonstration program under the Office of the Secretary to provide grants to expand intermodal and multimodal freight and cargo transportation infrastructure -- particularly with respect to maritime ports and former military airports now classified as general aviation airports. Appropriators say the secretary "is expected to facilitate capital investments that seek to capitalize on and streamline connections between aviation, maritime, rail, and highway infrastructure."

National Highway Traffic Safety Administration

The agreement provides a total of $989 million for NHTSA activities, essentially equal to FY 2020. The total includes $778 million from the Highway Trust Fund and $211 million in general appropriations.

Of the trust fund money, $623 million is provided for various grant programs -- including $280 million for highway safety grants, $286 million for national priority safety programs, and $31 million for high-visibility enforcement (all equal to FY 2020).

It provides a total of $349 million for NHTSA operations and research, including $194 million from the general fund and $155 million from the Highway Trust Fund. The total is slightly more than FY 2020.

In addition, the measure provides $17 million (equal to FY 2020) from the general fund for safety programs to address impaired driving and railroad-highway grades.

Federal Motor Carrier Safety Administration

The agreement provides $748 million for FMCSA, which oversees federal truck and bus safety enforcement programs. FMCSA also is responsible for ensuring that commercial Mexican vehicles entering the United States under the North American Free Trade Agreement and its successor U.S.-Mexico-Canada Agreement (USMCA) meet all U.S. hazardous-material and trucking safety regulations. The total provided is 10% more FY 2020 funding, and all of the funding comes from the Highway Trust Fund.

The total includes $328 million for Motor Carrier Safety Operations and Programs (14% more than FY 2020), and $420 million for Motor Carrier Safety Grants (7% more).

Maritime Administration

The agreement provides a total of $1.2 billion for programs and activities of the Maritime Administration (MarAd) -- 12% more than FY 2020.

Within the total, $314 million (5% more than FY 2020) is for MarAd's maritime security program, which provides annual payments to operators of U.S.-flag merchant ships engaged in U.S.-foreign commerce in order to help maintain the U.S.-flag merchant fleet and preserve it for national security needs.

Another $156 million is for MarAd operations and training (2% more than FY 2020), and it provides $433 million (26% more) for state maritime academy operations,

It also provides $230 million (2% more than FY 2020) for port infrastructure development, $20 million (equal to FY 2020) for aid to small shipyards, and $10 million for the new cable security fleet program -- under which aid will be provided to support a fleet of two U.S.-flag cable vessels and thereby maintain a U.S. presence in the international underwater cable services market for national security purposes.

Pipeline & Hazardous Materials Safety Administration

The agreement provides a total of $288 million for programs and activities of the Pipeline & Hazardous Materials Safety Administration (PHMSA), 2% more than FY 2020.

Within the total, the measure provides $29 million for operational expenses (19% more than FY 2020), $62 million for hazardous-materials safety activities (2% more) and $28 million for emergency preparedness grants (equal to FY 2020).

It provides $168 million (equal to FY 2020) for continued enforcement of federal pipeline safety regulations and grants to support state pipeline safety programs -- including $137 million to be derived from the Pipeline Safety Fund, $23 million from the Oil Spill Liability Fund, and $8 million from the Underground Natural Gas Storage Facility Safety Fund.

Finally, it provides an additional $1.0 million for hazardous materials emergency response training for emergency responders.

Office of the Secretary

The agreement provides $1.4 billion for activities of the Office of the Secretary of Transportation (of which $1.2 billion is for BUILD grants, new transportation demonstration grants, and EAS payments, as described above).

For departmental administrative purposes, the measure provides $126 million for general salaries and expenses (10% more than FY 2020), with all offices getting increases. It provides $23 million for the department's research and technology office (9% more than FY 2020), $22 million for cybersecurity initiatives (47% more), and $9 million for planning, research and development (14% less than FY 2020).

It also allows up to $320 million (equal to FY 2020) to be spent from the Working Capital Fund to support the department's shared services initiative in information technology.

Housing & Community Development

The measure provides $49.6 billion for programs and activities of the Housing and Urban Development Department (HUD) for FY 2021 -- $561 million (1%) more than FY 2020 and $12.4 billion more than requested.

The Federal Housing Administration (FHA) and Ginnie Mae also collect certain payments and fees that are scored as offsetting receipts, and which are used by appropriators to provide funding for programs and activities that is not counted toward the measure's discretionary spending cap. Appropriators project that together, FHA and Ginnie Mae for FY 2021 would collect a total of $10.7 billion in offsetting receipts that are used to fund other programs under the measure.

Public & Indian Housing Programs

The agreement appropriates $34.8 billion for HUD public and Indian housing programs for FY 2021 -- 7% more than FY 2020 and $6.3 billion more than requested.

Within that total, $25.8 billion (8% more than FY 2020) is for tenant-based rental assistance under the Section 8 program, through which housing vouchers are provided by public housing authorities to low-income individuals and families. The total for Section 8 vouchers for FY 2021 includes $4 billion in advance appropriations included in last year's spending measure; the agreement provides a similar $4 billion advance appropriation for FY 2022. Of the total, $695 million is classified as emergency spending that doesn't count against discretionary caps.

Of the amounts provided for Section 8 Tenant-Based Assistance, $23.1 billion (7% more than FY 2020) is for the renewal of expiring Section 8 vouchers, $116 million (55% more) is for tenant protection vouchers for families displaced from project-based units as a result of relocation or renovation, $314 million (37% more) is for Section 811 mainstream vouchers and renewals for the nonelderly disabled to find housing, $25 million (equal to FY 2020) is for additional family unification vouchers, and $40 million (equal to FY 2020) is for additional vouchers for vulnerable veteran households. In addition, $43 million is provided for new vouchers to reduce homelessness among families with children, the unsheltered, veterans and survivors of domestic violence, and $2.2 billion (9% more than FY 2020) is for the administrative fees of local public housing authorities.

The agreement consolidates into a single account the public housing capital fund and the public housing operating fund, providing a total of $7.8 billion -- 5% more than comparable funding for FY 2020.

It provides $200 million for HUD's Choice Neighborhood program (14% more than FY 2020) and $155 million for self-sufficiency programs (19% more) -- with the entire $25 million increase going to core family self-sufficiency programs (thereby providing $105 million, a 31% increase).

It also provides $825 million (equal to FY 2020) for Native American Housing block grants, most of which ($647 million; slightly more than FY 2020) is for Native American Housing formula grants. It also provides $2 million for Native Hawaiian Housing block grants, equal to FY 2020.

Other Major Housing Programs

The agreement provides $14.6 billion (7% more than FY 2020) for other major housing programs administered by HUD's Office of Housing.

The vast majority ($13.5 billion, 7% more than FY 2020) is for Section 8 project-based rental assistance under which local housing authorities provide rental subsidies to landlords who enter into contracts with HUD and rent their properties to low-income families -- with the subsidies covering the portion of rent that is not paid by the tenant. The assistance is therefore tied to a property, rather than an individual.

Of that funding, $13.1 billion is for the renewal of expiring contracts and $350 million is for contract administrators. The total includes $400 million in advance appropriations included in last year's spending measure; the agreement provides a similar $400 million advance appropriation for FY 2022.

The measure also provides $855 million (8% more than FY 2020) for the Section 202 housing program for the elderly. The program provides capital grants to eligible private nonprofit organizations to finance the acquisition, rehabilitation or construction of housing intended for low-income elderly, as well as project-based rental assistance contracts to support operational costs for such units.

And it provides $227 million (12% more than FY 2020) for the Section 811 program, which provides eligible nonprofit organizations with capital grants to acquire, rehabilitate or construct supportive housing for individuals with disabilities, as well as project-based rental assistance for such units.

Finally, it appropriates almost $78 million for housing counseling assistance, 46% more than the FY 2020 level.

Community Planning & Development Programs

The agreement provides $8.3 billion for programs under HUD's Office of Community Planning and Development -- 4% more than FY 2020 and $5.2 billion more than requested.

Within that total, $3.5 billion (1% more than FY 2020) is for community development activities financed by HUD's Community Development Fund, through which money is provided to state and local governments as well as other entities -- primarily through formula Community Development Block Grants (CDBG). It includes $25 million to support stable transitional living environments for individuals in recovery from substance misuse disorder.

The total also includes $1.35 billion (equal to FY 2020) for the HOME Investments Partnership program, which provides funding to state and local governments, tribes and insular areas to expand the supply of affordable housing, and $3.0 billion (8% more) for HUD homeless-assistance programs to provide permanent and transitional housing for homeless families and individuals.

It provides $430 million (5% more than FY 2020) for the Housing Opportunities for Persons with AIDS program, under which aid is provided to state and local governments to develop comprehensive long-term strategies for meeting the housing needs of people with AIDS and their families, and $60 million (9% more) for the Self-Help and Assisted Homeownership Program (SHOP) account.

Finally, it allows up to $300 million in loan guarantees through the Community Development Loan Guarantees (Section 108) program, which underwrites private market loans to cover economic development, housing rehabilitation, public facilities and large-scale physical development projects.

Federal Housing Administration

The Federal Housing Administration (FHA) promotes the issuance of home loans by providing federal mortgage insurance on loans made by approved lenders. As in the past, the FHA's income from insurance premiums exceeds its expenses, resulting in a "negative subsidy" that is used to offset appropriations made by the measure for other programs. The agreement estimates that FHA will raise $9.1 billion in net receipts for FY 2021.

The Mutual Mortgage Insurance Program account covers FHA's unsubsidized mortgage insurance programs, primarily the single-family-home mortgage program and the cooperative-housing insurance program, which provides mortgages for certain cooperative housing projects. The measure permits the FHA to guarantee up to $400 billion (equal to FY 2020) in loans and to offer up to $1 million in direct loans. It appropriates $130 million for administrative expenses, equal to FY 2020.

The FHA General and Special Risk Program Account funds a wide variety of special purpose single-family and multifamily mortgage insurance programs, including those for riskier properties. The measure limits the guarantee loan commitments to $30 billion (equal to FY 2020) in loans made under the General and Special Risk Program, and to offer up to $1 million in direct loans.

Government National Mortgage Association

The Government National Mortgage Association, also known as Ginnie Mae, guarantees investors the timely payment of principal and interest on securities that are backed by federally insured or federally guaranteed mortgage loans, including those issued by the FHA or the Veterans Affairs Department.

The agreement limits to $1.3 trillion the guarantee commitments that may be made by Ginnie Mae (more than double the FY 2020 limit) and it provides $34 million for administrative expenses. The measure estimates that Ginnie Mae will generate $1.4 billion in net receipts, most of which is used by the agreement to offset other appropriations.

Other HUD Activities

The agreement appropriates $1.5 billion for HUD management and administration (5% more than FY 2020) -- including $577 million for general administrative support offices (2% more) and $905 million (7% more) for HUD's various program offices (such as the Public and Indian Housing office and Community Planning and Development office). It provides $300 million (7% more than FY 2020) for HUD information technology activities, and $137 million (almost 1% less than FY 2020) for the office of the inspector general.

For HUD's Healthy Homes and Lead Hazard Control program, under which grants are provided to state and local governments to perform lead hazard reduction activities in housing occupied by low-income families, the measure provides $360 million (24% more than FY 2020) and it increases administrative funding for the program office by 15%.

It provides $105 million (7% more than FY 2020) for research and technology activities carried by HUD's Policy Development and Research Office, and increases administrative funding for that program office by 29%.

Fair housing programs and activities are funded at $73 million (a 3% increase), with HUD's Fair Housing and Equal Opportunity Office receiving a 6% increase to $80 million.

Related Agencies & Other Provisions

The agreement provides $38 million for salaries and expenses of the Surface Transportation Board, 1% more than FY 2020. The measure assumes the board will collect $1.25 million in user fees in FY 2021, which would reduce the agency's appropriation to a net total of $36 million.

It also funds certain other independent agencies as follows:

National Transportation Safety Board -- $118 million for the NTSB (7% more than FY 2020), which is responsible for investigating transportation accidents and developing recommendations to prevent accidents, including aircraft and railroad accidents.

Neighborhood Reinvestment Corporation -- $165 million for the corporation (4% more than FY 2020), which helps local communities create partnerships between residents and representatives of the public and private sectors.

Federal Maritime Commission -- $30 million for the FMC (8% more than FY 2020), which is responsible for regulating and overseeing U.S. foreign shipping trades in order to protect U.S. shippers.

<p> Section XIV

COVID Relief

This section describes the provisions of the agreement on HR 133, Consolidated FY 2021 Appropriations Act, which provide an estimated $900 billion in economic relief for individuals and businesses impacted by the coronavirus pandemic as well as funding for virus testing and vaccine distribution.

Among its provisions, it extends pandemic-related unemployment benefit programs and provides an additional $300 per week in benefits, it provides $600 direct payments to most taxpayers and dependent children, and it authorizes additional forgivable loans to small businesses under the Paycheck Protection Program (PPP) and allows certain small businesses who previously received a PPP loan to receive another one.

It also extends the moratorium on evictions of renters and establishes a program to help struggling families and individuals pay their rent; increases food stamp benefits and provides for other food aid; provides aid to schools to help them adapt to the pandemic and facilitate the return of in-school teaching, as well as aid to child care providers; provides funding to transit systems and other financially strapped modes of passenger transportation, including aid to airline workers; and provides additional funding for coronavirus testing and tracing and for the acquisition and distribution of coronavirus vaccines.

Of the total aid and relief provided, $184.3 billion is provided through emergency appropriations for a variety of purposes. The Congressional Budget Office (CBO) and Joint Committee on Taxation (JCT) estimate that the agreement's COVID economic relief provisions will increase the deficit by $868 billion over 10 years.

Aid to Individuals

The agreement provides continued direct aid to individuals adversely affected by the economic impact of the coronavirus pandemic through several means -- including by extending pandemic unemployment benefits to those who have lost their jobs and direct "stimulus" checks to most all individuals and families, by extending the moratorium on evictions and providing rental assistance, and by providing additional food aid to those in need.

Direct 'Stimulus' Payments to Individuals

Similar to the CARES Act (PL 116-136), the agreement provides one-time direct payments (technically tax rebates) to families of up to $600 for adults and children.

Adults with adjusted gross incomes (AGI) of up to $75,000 ($150,000 for married couples filing jointly) will receive the full $600 payment ($1,200 for a married couple); above these levels payments are phased out.

To be eligible for the payments, adults must have a work-eligible Social Security number and not be claimed as a dependent of any other taxpayer. Adults who have no income, or whose income is derived from non-taxable means-tested benefit programs, also are eligible for the full payments.

Unlike the CARES Act, the measure provides these payments to mixed-status households (those where one parent and the child have Social Security Numbers but the other parent does not) and it makes this eligibility retroactive to the $1,200 ($500 for children) direct payments provided by the CARES Act.

(CBO and JCT estimate these provisions, along with provisions extending tax credits for sick and family leave (below) will cost $163.5 billion over 10 years.)

Extend Unemployment Insurance

The CARES Act established several federal pandemic-related unemployment programs to help those who lost their jobs because of the pandemic -- a $600 per week enhanced federal benefit paid on top of an individual's regular state unemployment benefit (which expired at the end of July); 13 weeks of emergency unemployment benefits at the state rate for those who exhaust their regular state benefits (most states provide just 26 weeks of benefits); and a new unemployment benefit program for "gig" workers, the self-employed, and others who generally are not eligible for state unemployment benefits (the Pandemic Unemployment Assistance program, or PUA). Those emergency extended benefit and PUA programs were scheduled to expire the week after Christmas.

The agreement provides for 11 weeks a $300 per week enhanced federal benefit to be paid to individuals on top of other unemployment benefits (beginning the last week of December through March 14, 2021) -- and it also extends both the gig-worker PUA program and the extended federal benefit program for those who have exhausted state benefits (formally called the Pandemic Emergency Unemployment Compensation program, or PEUC).

Under the measure, eligibility for both the PUA and PEUC is extended through March 14, and individuals receiving benefits under those programs as of March 14 could continue to receive benefits through April 5 as long as they had not reached their maximum number of weeks of benefits.

It extends by 11 weeks the maximum time an individual may receive federal unemployment benefits under either the PUA or PEUC programs. Specifically, it increases the limit for the gig-worker PUA program from 39 to 50 weeks, and the extended benefit PEUC program from 14 to 24 weeks (which when combined with the typical 26 weeks of state benefits will equal a total of 50 weeks of benefits).

To prevent fraud in the gig-worker PUA program, it requires states to verify or validate the identity of program applicants and requires new applicants and individuals already receiving PUA benefits to submit documentation to substantiate employment or self-employment.

It also provides a new federal benefit: an additional $100 per week for unemployed individuals who had earned both wage and self-employment income, but whose base unemployment insurance benefit is low because the state does not take into account the self-employment they had been earning. That benefit is to be provided through March 14, 2021, as are the following -- some of which originated in the Families First Coronavirus Response Act (FFCRA; PL 116-127):

Similar unemployment benefits for railroad workers;

Federal reimbursement to states that provide unemployment benefits immediately upon individuals filing claims (most states require individuals to wait a week before receiving benefits), although it reduces the reimbursement to half the first week's claim;

Federal support to cover half the costs of unemployment benefits for state and local government employees as well as nonprofit organizations, half the cost of temporary state short-time compensation programs, and the whole cost of short-time compensation programs established in state law;

Full federal funding for the Extended Benefits (EB) unemployment program for high-unemployment states (that program, which is in permanent law, normally requires states to pay half the cost); and

Flexibility in state personnel standards to allow states to hire temporary staff -- and to temporarily rehire retirees and former staff -- to help expedite the processing of unemployment applications and claims.

Finally, the measure allows states to waive the requirement that individuals repay excess unemployment benefits if the overpayments were caused by a mistake by the state, and it requires states to have in place methods to address situations where individuals receiving unemployment refuse to return to work or refuse an offer of suitable work, including through an employer-notification system.

(The measure's unemployment provisions are estimated to cost $119.2 billion over 10 years.)

Rental Assistance & Eviction Moratorium

The agreement provides $25 billion for FY 2021 for grants to states, territories, tribes, and local governments to provide financial assistance to renters who are experiencing financial hardship due to the COVID-19 pandemic -- with the aid to be used for rent payments, utility and energy bills, and other housing expenses.

Specifically, rental assistance is available for households with incomes less than or equal to 80% of the area median income, that have one or more household members who qualify for unemployment benefits, or that can demonstrate a risk of homelessness. Priority is to be given to households whose incomes do not exceed 50% of area median income and individuals that have been unemployed for more than 90 days.

Funds are to be distributed by proportional allocation to states, local governments and the District of Columbia, with a minimum allocation of $200 million per state. Localities with populations greater than 200,000 can apply for a grant directly. Of the total, $400 million is allocated to U.S. territories and $800 million is reserved for grants to tribal governments and native Hawaiian communities.

Under the program, renters and landlords may apply for assistance directly, and assistance provided to an individual or household can equal up to 12 months of rent (including both forward rent payments and retroactive arrears), though applicants must reapply for the assistance every three months. Rental assistance received through this program is not to be treated as income for purposes of calculating an individual or household's eligibility for other federal benefits or for tax purposes.

Finally, the measure extends through Jan. 31, 2021 the eviction moratorium implemented by the Centers for Disease Control and Prevention (CDC) in September pursuant to President Trump's executive action in August. The extension through January gives President Biden a chance to further extend the moratorium.

Nutrition Assistance

To help address increased food needs during the pandemic, the agreement increases monthly food stamp benefits by 15% through June 30, 2021, and it provides that any federal pandemic unemployment compensation received by an individual or household is not to be treated as income for purposes of determining food stamp eligibility (formally the Supplemental Nutrition Assistance Program, or SNAP).

It also suspends work requirements for SNAP-eligible college students who are unable to participate in work-study programs due to the pandemic; provides $100 million to cover state SNAP administrative costs; and provides $614 million for additional emergency nutrition assistance grants to those U.S. territories that don't participate in SNAP (Puerto Rico, American Samoa, and the Northern Mariana Islands).

The Families First Coronavirus Response Act established the Pandemic-EBT program to provide supplemental nutrition benefits to families whose children are eligible for free or reduced price meals at school, but whose schools are closed due to the COVID-19 pandemic. The agreement allows states to provide these benefits to families receiving SNAP benefits for children under the age of six who live in areas where child care facilities are closed or operating with reduced attendance -- without the need to verify that an individual child is enrolled in such a child care facility.

The measure also does the following:

Directs the Agriculture Department to provide such sums as necessary to reimburse states for emergency COVID-related operational costs incurred from March through June 2020 by schools that participate in federally funded school meal programs and institutions that participate in the Child and Adult Care Food Program;

Provides $400 million to the Emergency Food Assistance Program (TEFAP), which provides food banks and other local agencies with USDA-purchased foods, of which up to $80 million may be used to assist food banks with the distribution of commodities;

Provides $13 million for the Commodity Supplemental Food Program, which provides direct food assistance to low-income seniors; and

Provides $175 million for Health and Human Services Department (HHS) senior nutrition services, including Meals on Wheels, of which $7 million is for tribal nutrition programs.

(The above nutrition provisions, along with $12.7 billion in agricultural aid, are estimated to cost $25.7 billion over 10 years.)

Paid Sick & Family Leave

The agreement extends through March 31, 2021, the refundable payroll tax credits for employers who provide paid sick and family leave to their employees -- but it does not extend the requirement that businesses provide such paid leave.

The original mandate and tax credit was established by the FFCRA in March to ensure that workers (particularly hourly workers) who contract the coronavirus or need to take care of family members who have the virus are able to take time off from work, and to help employers offset the cost of providing such coronavirus-related sick and paid leave. This tax credit extension is intended to encourage employers to continue providing such paid leave during the first three months of the year. (JCT in December estimated the extension would cost $2.1 billion.)

The measure provides that for self-employed individuals, when computing the tax credit for such leave, they be allowed to use their average self-employment income from 2019 rather than 2020.

It also authorizes federal agencies to reimburse contractors for the costs of paid leave during the COVID-19 pandemic for periods when contractors are temporarily unable to work because of facility closures or other restrictions.

Funeral Expenses

The agreement requires FEMA to provide aid to states to help families with funeral expenses in cases where the deaths were caused by COVID, appropriating $2.0 billion for such aid. The measure's explanatory materials note that FEMA had refused to provide such aid.

The measure also requires FEMA to waive the 25% state match that is otherwise required for such aid.

Bankruptcy Protections

Outside of the measure's covid-relief division, the agreement temporarily amends the Bankruptcy Code to provide additional relief to individuals and businesses directly impacted by the COVID-19 pandemic, and it creates procedures to ensure that relief payments and mortgage forbearances granted under the CARES Act and future COVID-19 legislation can be properly implemented under the Bankruptcy Code.

It exempts recovery rebate checks from an individual's bankruptcy estate so that they are protected from creditors, ensures that individuals who have completed all of their plan payments but who may have missed three or fewer mortgage payments due to COVID-19 can still obtain the benefit of a Chapter 13 discharge, and ensures that debtors seeking the benefit of the CARES Act's provisions on mortgage forbearance and eviction moratoria are not denied CARES's protections because they have been bankrupt.

It also incentivizes landlords and vendors to enter into flexible payment terms with businesses. Under existing law, landlords and vendors who enter into flexible payment terms with businesses can be forced to return future payments because the terms were not "in the ordinary course." The measure protects future payments from being clawed back from landlords and vendors, but only to the extent such payments do not include any fees, penalties, or interest in an amount greater than the amount of fees, penalties, or interest the business would have owed had it not entered into the flexible payment terms

Aid to Businesses

The agreement reauthorizes aid to businesses through the Paycheck Protection Program and extends other temporary authorities to help small businesses in particular stay afloat and retain their workers.

Paycheck Protection Program

The CARES Act established the Paycheck Protection Program (PPP) to provide small businesses with loans that could be fully forgiven if employers used loan amounts for payroll and other eligible expenses such as rent and utilities. The CARES Act initially provided $349 billion for the program, but that amount was later supplemented by an additional $321 billion (PL 116-139), which increased the program's overall loan limit to $659 billion. After the program's authorization expired on June 30, Congress authorized (PL 116-147) new loans to be issued until August 8.

However, concerns over loan forgiveness requirements and how and when the loan could be used discouraged many businesses from taking PPP loans even after the program's authorization was increased -- leaving the Small Business Administration (SBA) with roughly $138 billion in unused funds for the program.

PPP Extension & Expansion

The agreement extends the PPP program, reauthorizing the SBA to guarantee new PPP loans through March 31, 2021, and appropriating $284.5 billion for the program (as well as another $50 million for SBA oversight and audits of PPP loans). Under the measure, the program's total authorization since establishment under the CARES Act increases by $147.5 billion to a total of $806.5 billion. (The measure also rescinds $146 billion in unobligated balances of PPP and SBA Debt Relief program funding.)

It allows businesses that previously received a PPP loan to receive a "second draw" equal to 2.5 times their average monthly payroll cost in 2019, with a maximum amount of $2 million. (Food and accommodation businesses are eligible for a second loan of up to 3.5 times average monthly payroll). Eligibility for second loans is limited to companies with 300 or fewer employees that have sustained a 25% loss in revenue for any quarter of 2020 compared to the same quarter in 2019, and have used or will use the full amount of their original PPP loan.

It also opens the PPP to tourism boards, visitors bureaus, and 501(c)(6) non-profit organizations such as local chambers of commerce and other membership-based associations -- as long as the organization employs fewer than 300 employees, does not receive more than 15% of its revenue from lobbying activities, and does not spend more than 15% of its budget on lobbying (PPP funds can not be used for lobbying). In addition, local newspapers, radio stations, and TV news channels that meet existing SBA size standards are eligible for PPP loans (including companies that have more than one physical location as long as each location meets the program's size and revenue requirements and funding is not transferable between locations), as are housing cooperatives with fewer than 300 employees and non-profits and religious organizations.

Publicly-traded companies, political and political advocacy groups, and professional sports leagues are not be eligible for PPP loans, nor are think tanks or any entity affiliated with China or a Chinese-owned entity.

Of the amounts appropriated for PPP loans, at least $35 billion must be used for initial PPP loans, with the remainder to be used for either initial or second draw loans. SBA must set aside $15 billion in initial PPP loans for businesses with fewer than 10 employees or loans of less than $250,000 in low income areas, while $25 million is set aside for such borrowers for second loans. It also sets aside $15 billion for loans originated by community financial institutions and minority-owned financial institutions, and another $15 billion for loans originated by banks and credit unions with less than $10 billion in assets.

The measure modifies the program to allow loans to be forgiven if used for operational costs such as human resources, accounting, and payroll software; property damage from riots, vandalism, and looting that occurred in 2020 not otherwise covered by insurance; supplier costs that were incurred before the award of the PPP loan; and COVID-19 related employee protection measures required by OSHA -- including physical barriers, filtration systems, facemasks, and other protective equipment. It also clarifies that a borrower that spends PPP funds on tax deductible business expenses may still claim those expenses as tax deductions.

Finally, to increase flexibility for businesses, PPP borrowers are allowed to choose a period between eight and 24 weeks after the loan's origination date during which to use the PPP funds and have them forgiven.

PPP Administrative Provisions

The agreement directs the SBA to create a simplified one-page loan forgiveness application for PPP loans of less than $150,000 and it exempts borrowers with loans between $150,000 and $2 million from certain reporting requirements, though those loan forgiveness applicants are required to maintain documentation for auditing purposes. It clarifies that an employer must have been in operation as of Feb. 15, 2020, to receive a PPP loan.

It clarifies that interest on PPP loans must be calculated on a non-compounding, non-adjusting basis; extends fee waivers through the life of a PPP loan; establishes a process for debtors in bankruptcy to apply for PPP loans; simplifies the documentation required for self-employed individuals to apply for PPP loans; and modifies and clarifies the reimbursement process for lenders that originate PPP loans. It requires any company applying for a PPP loan to disclose to the SBA if the president, the vice president, the head of an executive department, a member of Congress, or an immediate relative of such an individual has a controlling interest in that small business.

The measure establishes a standard definition of a "seasonal employer" for PPP purposes as a business that operates for seven or fewer months of the year or makes more than 2/3 of its annual revenue in any six months of the prior year. It also allows a seasonal employer to chose any 12 week period between Feb. 15, 2019 and Feb. 15, 2020 for purposes of calculating the seasonal revenue (this provision only applies to PPP loans that have not yet been forgiven).

Finally, it clarifies that amounts authorized for the PPP are distinct from amounts appropriated for the SBA 7(a) loan program, thereby ensuring continued operation of the 7(a) program regardless of the PPP's authorization status.

(CBO and JCT estimate that the PPP and other SBA provisions (below) will cost $301.9 billion over 10 years, primarily from guaranteeing additional PPP loans.)

Other Business Support

Employee Retention Tax Credit

Outside of the measure's covid-relief division, the agreement extends through June 30, 2021, the temporary employee retention tax credit established under the CARES Act that allows employers to claim a tax credit on employer-paid Social Security payroll taxes for 2020 -- which employers can use to help offset the costs of keeping employees on payroll during the pandemic.

For 2021, it increases the tax credit rate from 50% to 70% of qualified wages and increases the per-employee limit from $10,000 per year to $10,000 per quarter. It expands the number of businesses that can claim the credit by making employers with 500 or fewer employees eligible (up from 100 employees) and by providing that employers must show a 20% decline in year-over-year gross receipts (rather than 50%).

It also allows employers to use prior quarter gross receipts to determine eligibility for the program; removes the 30-day average wage limitation, which will allow employers to claim the tax credit on bonus pay; makes the tax credit available to certain public entities; and allows new employers who were not in existence for all or part of 2019 (and therefore cannot make a comparison with pre-pandemic gross receipts) to be eligible for the credit.

Finally, the measure makes retroactive certain modifications to the program as established by the CARES Act, including by allowing employers who receive Paycheck Protection Program (PPP) loans to use the tax credit for wages that were not paid for with forgiven PPP funds.

(JCT in December estimated that the measure's employee retention tax credit provisions would cost $26.9 billion over 10 years.)

EIDL Grants, Live Venue Aid & Other Small Business Support

In addition to the PPP, the agreement extends several other SBA programs enacted as part of the CARES Act, including the Economic Injury Disaster Loan (EIDL) Advance Grant under which applicants for an EIDL may rapidly receive a cash grant of up to $10,000 that does not have to be repaid, and it establishes a new grant program to aid small live venues such as theaters and museums.

Specifically, it extends the authorization for the EIDL grant program through Dec. 31, 2021, and repeals a requirement that the amount of an EIDL grant be deducted from PPP loan forgiveness if they also received a PPP loan. And it provides $20 billion to create a targeted EIDL grant for small businesses in low-income communities that applied for but did not receive an EIDL grant or that received less than the $10,000 maximum grant.

It provides $15 billion to provide grants to small live venue operators, theatrical producers, museums, independent movie theaters, and talent agents that meet SBA size requirements and had experienced at least a 25% reduction in revenues because of the pandemic. In implementing the program, SBA during the first two weeks must prioritize aid to entities that experienced a 90% revenue loss, and in the next two weeks must prioritize aid to those with 70% revenue loss. Recipients may receive a grant of up to $10 million and a secondary grant of half the amount initially received, with the funds to be used for payroll, rent, utilities and personal protective equipment. Of the total, $2 billion is set aside for businesses with fewer than 50 employees. Grant recipients are also eligible for PPP loans.

It also provides $3.5 billion to extend temporary debt relief for SBA-backed loans so small businesses with SBA loans continue to receive financial relief -- although the SBA may pay only up to $9,000 a month in principal and interest (P&I) rather than the entire amount. Specifically, all borrowers with SBA 7(a), 504 and Microloans made before the CARES Act receive an additional three months of relief beginning in Feb. 2021, and those considered to be underserved (i.e., the smallest or hardest hit by the pandemic, including as food service and accommodation, arts and entertainment, and educational and personal care services) get an additional five months relief through Sept. 2021. Newer loans are to receive six months of similar debt relief from February through September.

The agreement also does the following with respect to SBA loan programs:

Waives lender and borrower fees on 7(a) and 504 loan programs through Sept. 30, 2021;

Increases the maximum federal cost share of a 7(a) loan, including a community advantage loan, to guarantee 90% through Oct. 1 (below the CARES Act's 100% guarantee, but higher than the normal 85% maximum);

Increases the maximum amount of an SBA Express Loan from $350,000 to $1 million through Oct. 1, and increases from 50% to 75% the federal cost share for all express loans below $350,000 during that time (the bill appropriates $1.9 billion to cover the federal costs for the fee waivers and other program changes above);

Authorizes the SBA to establish a 504 Express Loan program to provide loans of less than $500,000 through Sept. 30, 2023.

Expands the SBA Microloan program by increasing the maximum loan to an intermediary lender from $6 million to $10 million; waives certain fees and increases federal cost share of microloans through March 31; and provides additional grants to intermediary lenders that provide technical assistance in rural areas. It appropriates $57 million for the program; $50 million for grants to lenders who provide technical assistance to borrowers, and $7 million for loan subsidies.

The measure also extends through June 30, 2021, the waiver of matching funds requirements for Women's Business Centers, and it appropriates $25 million for minority business development centers under the Minority Business Development Agency to provide assistance to minority-owned small businesses.

Aid to Farmers & Fisheries

The agreement provides $11.2 billion to the Agriculture Department for support to farms and other agricultural producers, distributors, and processing facilities affected by the COVID-19 pandemic -- with at least $1.5 billion to be used to purchase foods and agricultural products and make grants and loans to midsized food processors and distributors, and up to $1 billion to be used for payments to contract livestock and poultry farmers who experienced revenue loss due to COVID-19 related contract changes.

The USDA Secretary also must make supplemental payments to farmers through the Coronavirus Food Assistance Program, as well as payments to farmers who were forced to euthanize livestock and poultry due to market disruptions.

Separately, it provides $100 million in emergency funding for speciality crop block grants; $100 million for USDA programs to support regional and local farm distribution and markets; $75 million for a program to support the purchase of fresh produce in low-income communities; $75 million for programs to support socially disadvantaged farmers and ranchers and beginning farmers and ranchers; $28 million for grants to state agriculture departments to support existing stress assistance programs; and $20 million for nutrition research.

To assist dairy farmers and distributors affected by COVID-related market disruptions, the measure provides $400 million to establish a program to reimburse dairy processors who donate to non-profits any products they are unable to sell, and it directs the USDA to provide supplemental payments through the Dairy Margin Coverage Program (a form of insurance for dairy producers) to participating producers whose policy covered less than 5 million pounds of dairy production in a calendar year.

It provides $60 million through FY 2023 for the department to make grants of up to $200,000 to meat and poultry processing facilities to make improvements and comply with federal health, safety, and labeling standards necessary under federal meat inspection laws. Recipients must provide non-federal matching funds to be awarded a grant.

Finally, in addition to Agriculture Department farm and associated aid, the measure provides $300 million to the National Oceanic and Atmospheric Administration (NOAA) for disaster assistance for fishery businesses and communities harmed by the pandemic, of which $30 million is allocated for tribal fisheries and $15 million is reserved for states bordering the Great Lakes.

CDFIs & Minority-Owned Institutions

The agreement establishes emergency programs to support access to credit to, and investments in, low- and moderate-income and minority communities that have been disproportionately impacted by the pandemic.

It appropriates $9 billion to allow the Treasury Department to directly invest in community development financial institutions (CDFIs) and minority-owned depository institution (MDIs) to support their efforts to provide loans, grants, and forbearance for small businesses, minority-owned businesses, and consumers that are disproportionately affected by the economic impacts of the pandemic.

Specifically, Treasury is to purchase preferred stock or other financial instruments issued by eligible financial institutions serving low and moderate-income communities; this authority expires six months after the end of the federally declared COVID-19 emergency. Participating banks must repay the Treasury within 10 years, unless the Treasury issues rules establishing new terms.

Program applicants must provide Treasury with an investment and lending plan that describes how it will address community development needs. An applicant must also demonstrate that at least 30% of its lending in the past 2 years was made to low and moderate income borrowers, or to other targeted populations defined by the CDFI fund. During an initial period to be determined by the Treasury, $4 billion of the $9 billion provided is to be set aside for CDFIs and MDIs that have less than $2 billion in total assets, of which 50% must be allocated for institutions with less than $500 million in assets.

Grant Aid

The measure also appropriates $3 billion to provide grants and other aid to CDFIs to support economic recovery efforts in local communities. Of the total, $1.25 billion is to remain available through FY 2021 to make formula grants to CDFIs in impacted communities, while the remaining $1.75 billion is available until expended for grants to help CDFIs expand investments in low-income areas and minority communities. Within the second amount, $1.2 billion is set aside for assistance to minority-lending institutions.

In addition to these programs, the measure directs Treasury to consider other activities to help support financial institutions in communities that have disproportionately suffered from the COVID-19 pandemic and its economic impacts, to provide funding to eligible institutions that serve low-income communities, and to support minority-owned or minority-serving financial institutions.

Federal Reserve & Treasury Lending Facilities

The CARES Act provided the Treasury Department with $500 billion to support efforts to help stabilize the economy during the COVID-19 pandemic. Of the total, $454 billion was authorized to support Federal Reserve lending programs, either by guaranteeing Fed loans or directly investing in special-purpose vehicles, i.e., shell companies use to facilitate Federal Reserve purchases of qualifying debt from lenders. The remaining $46 billion was reserved to make direct and guarantee loans to the airline industry and certain national-security related companies (then expected to be Boeing).

The Fed programs, formally known as "credit facilities," included the Main Street Lending Program to provide capital to banks who make loans to qualifying small and midsized businesses, and another credit facility to buy state and municipal bonds to provide capital to cash-strapped local governments. As of November, the various Fed and Treasury lending programs had not been used much, leaving some $429 billion of the $500 billion unspent.

On Nov. 19, Treasury Secretary Stephen Mnuchin asked the Federal Reserve to return the unspent CARES Act funds to the Treasury, a position generally shared by many House and Senate Republicans who say they are wary of an expansion of the Fed's traditional role into direct investment in private businesses. Democrats, meanwhile, argued that Congress should not constrain the Federal Reserve's options until after the COVID crisis has passed.

The agreement permanently rescinds $429 billion of the $500 billion appropriated by the CARES Act to the Treasury's Exchange Stabilization Fund (ESF) to support Federal Reserve credit facilities and for Treasury lending and investment activities involving the airline industry and defense-related industries.

Of the amount not rescinded, it rescinds on Jan. 9, 2021, any unobligated balances that are not needed to meet the commitments made by the Treasury under the CARES Act by Dec. 31 -- although $130 million is reserved for continuing administration and oversight activities.

Bar Identical Fed Facilities

The measure also prohibits the Federal Reserve after Dec. 31, 2020, from making any new investments or loans under a credit facility established by the CARES Act, and it prevents Treasury from using the ESF to reestablish any such Federal Reserve credit facility that is identical (except for the Term Asset-Backed Securities Loan Facility, or TALF).

However, it clarifies that the Federal Reserve fully retains the authority it had prior to enactment of the CARES Act to establish credit facilities -- which negotiators in their explanatory materials say would allow for the establishment of substantially similar Fed facilities using ESF funds in the future.

Community Support

The agreement provides funds to state and local governments and to various private entities to help address the economic damage caused by the coronavirus pandemic.

It also extends until the end of 2021 the deadline for state and local governments to use the $150 billion provided by the CARES Act to cover the direct costs of coronavirus response activities. The deadline was Dec. 31, 2020, and unless extended state and local governments would have lost access to remaining funds.

Education Aid

The agreement provides a total of $82 billion to help schools, students, teachers, and families with immediate needs related to the COVID-19 pandemic, including to return to in-class instruction.

K-12 & Higher Education Aid

The total includes $54.3 billion for K-12 schools to help them with facility repairs and improvements -- including heating, ventilation, and air conditioning systems projects to improve indoor air quality in school facilities and facilitate in-school attendance by students. The aid may also be used to address learning loss among students -- including among low-income students, children with disabilities, English learners, racial and ethnic minorities, students experiencing homelessness, and children and youth in foster care. Aid may be provided by formula to states and local school districts.

It includes $22.7 billion for higher public and private education, including those that serve students enrolled exclusively in distance education. Funding is to be distributed by a formula that takes into account head count and full-time equivalent enrollment, although $1.7 billion is reserved for Historically Black Colleges and Universities, Hispanic Serving Institutions, and certain other institutions, and a separate $20 million is for Howard University and another $11 million is for Gallaudet University.

Discretionary & Other Aid

The total also includes $4.1 billion for governors to spend at their discretion, with $2.8 billion specifically for private and parochial schools. The measure prohibits non-public-school funds from being used for financial assistance to scholarship-granting organizations or for vouchers, tuition tax credit programs or education savings accounts.

Finally, it includes $819 million for outlying areas and Bureau of Indian Education-operated and funded schools and Tribal Colleges and Universities; $28 million for the Institute of Education Sciences to cover the coronavirus related costs of implementing National Assessment of Educational Progress (NAEP) assessments; $11 million for the National Technical Institute for the Deaf; and $50 million total for student aid administration, program administration, and the Office of the Inspector General.

The measure also includes funding elsewhere in the covid relief division (see below) for expanding access to broadband internet, including funds dedicated to enhance educational connectivity and distance learning.

Child Care

The agreement provides $10 billion for pandemic relief related grants for child care providers, that are to be provided through the Health and Human Service (HHS) Department's Child Care and Development Block Grant (CCDBG) program. (The agreement's Labor-HHS-Education Appropriations division includes $5.9 billion for regular CCDBG activities.)

Under the measure, these supplemental grants are to be available to child care providers that are either currently open or temporarily closed due to COVID-19, regardless of whether they had previously received funding through the existing CCDBG program. Providers may use the grants for a variety of purposes, including personnel costs; sanitization and cleaning; personal protective equipment; fixed costs, including mortgage obligations, rent, utilities and insurance; and modifications to child care services as a result of the pandemic.

The measure also provides $250 million for Head Start providers to ensure they are able to continue safely serving low-income children and families throughout the pandemic.

Transportation Systems

The agreement provides funding to support U.S. airlines and airports, mass transit systems and state and local highway departments, as well as Amtrak -- all of which have been adversely impacted by the pandemic.

U.S. Airlines & Airports

The CARES Act provided $32 billion for aid to aviation companies to maintain payroll and employee benefits -- including $25 billion in aid to passenger air carriers, $4 billion for cargo air carriers, and $3 billion for contractors such as ground crews and caterers. Under that law, airlines had to maintain employees on the job through the end of August; when September arrived and no additional federal aid was provided, airlines furloughed tens of thousands of employees.

The agreement provides a total of $16 billion for additional grants to pay airline and contract employees, including $15 billion for airline employees and $1 billion for contract employees.

Under the measure, funding to airlines generally must be distributed proportional to the amounts provided by the CARES Act, with airlines and contractors required to recall involuntarily furloughed employees and provide them with backpay -- and refrain from future involuntary layoffs or furloughs (or reducing pay and benefits) until March 31, 2020. Airlines are required, to the extent reasonable and practicable, to maintain air service through March 1, 2022, as it was before March 1, 2020; they are prohibited from paying dividends or making other capital distributions with respect to their common stock until March 31, 2020; and they must limit the total compensation of airline executives until Oct. 1, 2022.

Separately, it also provides an additional $2 billion for grants to support the operations and personnel cost of airports, including economic relief for retailers and concessionaires at airports and for assistance to communities with small airports.

Public Transit

The measure provides $14 billion for public transit operators to help maintain service during the pandemic and ensure that the public has access to transportation to jobs, medical treatment, food, and other essential services. Funds may be used for operating and capital expenses to help sustain transit jobs and preserve access to vital transportation networks.

Transit systems across the country, including Washington, New York and others, have proposed sweeping cuts to service if Congress does not provide help. (Public transit received $25 billion in the CARES Act, but that money was quickly exhausted.)

It also provides $50 million and spending flexibility for paratransit providers.

Highways

The agreement provides $10 billion to support state and local transportation agencies to replace lost revenues needed for operations, preventive and routine maintenance, personnel costs and debt service payments.

Specifically, it provides $9.8 billion for Surface Transportation Block Grants for States, $115 million for the Tribal Transportation Program, $36 million for Puerto Rico, and $9 million to the Territorial Highway Program.

Amtrak

The measure provides $1.0 billion for Amtrak operating assistance to cover revenue losses related to coronavirus. The total includes $655 million for the Northeast Corridor and $345 million for its national networks. (Amtrak received $1 billion in the CARES Act.)

It requires Amtrak to recall workers as passenger rail service is restored, bars Amtrak from replacing any furloughed workers with contractors, and prevents further reductions in long-distance rail service. In addition, the measure provides $28 million to assist states and commuter rail providers in making required payments to Amtrak.

Other Transportation

It provides $2 billion in aid for other U.S. transportation service providers -- including motorcoach and bus operators, school bus companies, and U.S. flag passenger vessel operators such as passenger ferries.

The motor coach industry is currently operating at less than 10% of 2019 levels, according to the American Bus Association.

It also extends for an additional year the availability of Motor Carrier Safety Assistance Program (MCSAP) grants awarded in FY 2019 and FY 2020 by the Federal Motor Carrier Safety Administration (FMCSA).

Expand Broadband Access

The agreement provides a total of $7 billion for a variety of broadband internet activities -- including to help expand broadband deployment; to help pay for home internet service; to help connect tribal and rural communities and students as well as faculty and staff of minority colleges and universities; and to remove foreign equipment that is currently being used by wireless internet companies.

The total includes $3.2 billion to help low-income families pay for broadband service through a newly created fund within the Federal Communications Commission. The fund is to provide a $50 per month benefit per household ($75 for those on tribal lands) for internet access to those who qualify for Lifeline low-income mobile phone service, free or reduced school lunch, or who are recently unemployed. It also may be used for the cost of less expensive computers and tablets.

It includes $1.3 billion for two new grant programs within the National Telecommunications and Information Administration. The first, funded at $1 billion, is for tribal governments for broadband deployment, telehealth, distance learning, broadband affordability, and digital inclusion on tribal lands. The other is a $300 million broadband deployment program to support the deployment of broadband infrastructure to areas that lack broadband, especially rural areas, with grants to be issued to qualifying partnerships between state and local governments and fixed broadband providers.

It also includes $285 million for a pilot program to promote broadband access and adoption at Historically Black colleges or universities, Tribal colleges and universities, and other minority-serving institutions. The program is to be conducted by a newly created Office of Minority Broadband Initiatives within NTIA.

Other FCC Broadband Activities

The total also includes $250 million for the FCC's COVID-19 telehealth activities, and $65 million for the FCC to complete national broadband maps so the government can effectively disperse funding to areas that need it most.

Finally, it includes $1.9 billion for the FCC's Secure and Trusted Reimbursement Program which helps communications providers pay the costs of removing unsecure telecommunications equipment from their networks -- in particular equipment manufactured by Chinese companies Huawei and ZTE that are considered to pose a national security threat. The measure includes language to ensure that smaller telecommunications providers and public or private educational institutions are prioritized for such reimbursements.

Health Care, Testing & Vaccine Distribution

The agreement appropriates some $63 billion for the Health and Human Services Department (HHS) to support various pandemic-related public health activities -- including research, development, manufacturing and distribution of vaccines and therapeutics; diagnostic testing and contact tracing; and other coronavirus activities -- as well as mental health and substance abuse prevention and treatment activities. (A separate $10 billion in HHS funding for child care is described above.)

HHS Virus Activities

Within the total, $8.75 billion is for the Centers for Disease Control and Prevention (CDC) to support federal, state and local public health agencies in distributing, administering, monitoring and tracking coronavirus vaccinations to ensure broad-based distribution and access. Of that amount, $4.5 billion is for grants to states and localities, and $300 million is for a targeted effort to distribute and administer vaccines to high-risk and underserved populations -- including racial and ethnic minority populations and rural communities.

It provides $20 billion for the Biomedical Advanced Research and Development Authority (BARDA) for the manufacturing and procurement of vaccines and therapeutics, and the medical supplies to administer them, and $3.3 billion for the Strategic National Stockpile.

Another $25.4 billion is for the Public Health and Social Services Emergency Fund for virus testing and contact tracing and to reimburse eligible health care providers for COVID-19 public health emergency related expenses or lost revenues. Specifically, $22.4 billion is for testing and tracing, including $2.5 billion for a targeted effort to improve testing capabilities and contact tracing in high-risk and underserved populations, including racial and ethnic minority populations and rural communities. Meanwhile, $3 billion is to reimburse hospital and health care providers for expenses or lost revenue attributable to the pandemic.

It also provides $1.25 billion for the National Institutes of Health to support research and clinical trials on the long-term effects of COVID-19 as well as the continued development of more rapid diagnostics.

And it provides $55 million for the U.S. Food and Drug Administration (FDA) to facilitate the development and review (both pre-market and post-market) of medical countermeasures, devices, therapies and vaccines to combat the coronavirus. That funding also supports medical supply chain monitoring and other public health research and response investments.

Substance Abuse & Mental Health

The HHS virus relief total includes $4.25 billion for programs and activities of the Substance Abuse and Mental Health Services Administration to address mental health and substance abuse issues associated with the pandemic.

Specifically, it provides $1.65 billion for the Substance Abuse and Prevention Treatment Block Grant; $1.65 billion for the Mental Health Services Block Grant; $600 million for Certified Community Behavioral Health Clinics; $50 million for suicide prevention programs; $50 million for Project AWARE to support school-based mental health for children; $240 million for emergency grants to states; and $10 million for the National Child Traumatic Stress Network. At least $125 million must be allocated to Native American tribes across a variety of programs.

Other Pandemic-Related Health Provisions

The agreement provides $100 million for HHS's Administration for Community Living to address abuse, neglect, and exploitation of the elderly that occur, including adult protective service and long-term care ombudsman activities.

It provides a one-time, one-year 3.75% increase in Medicare reimbursements to physicians, in part to provide relief during the COVID-19 public health emergency.

It also provides for a three-month delay, through March 31, 2021, of annual Medicare sequester payment reductions required under the 2010 Budget Control Act.

(CBO estimates the two Medicare payment provisions above will increase direct spending by $5.9 billion.)

Miscellaneous Tax & Other Provisions

The agreement gives workers whose payroll taxes were deferred since September under President Trump's August executive order until the end of 2021 to pay those back to the federal government; those deferred taxes originally were due by the end of April 2021.

It provides that the purchase of personal protective equipment and other supplies to prevent the spread of COVID-19 by teachers are eligible expenses for the educator expense tax deduction, and it excludes from a college student's gross income emergency financial aid grants under the CARES Act so that income won't reduce the student's educational tax credits.

The measure allows the IRS and Social Security Administration to share information regarding which taxpayers are beneficiaries under the Supplemental Social Security (SSI) and Social Security Disability Insurance (SSDI) programs and are therefore not subject to the IRS's private debt collection program, as provided under the Taxpayer First Act (PL 116-25).

It also gives employers certain flexibility regarding the transfer of retiree health and life costs from the company's pension plan to a retiree health benefits or life insurance account, in order to address stock market volatility caused by the coronavirus pandemic.

Forgive Postal Service Loan

The CARES Act increased the borrowing authority of the Postal Service by $10 billion to $25 billion, and during the COVID-19 emergency it eliminated the $3 billion limit on the amount of new debt it may incur during any single year. Treasury subsequently conditioned the provision of that $10 billion loan on the Postal Service providing to the administration proprietary information about their largest private-sector contracts, such as UPS, FedEx and Amazon.

The agreement provides that the $10 billion borrowed by the U.S. Postal Service does not need to be repaid, and it cancels the agreement the agency made with Treasury to receive that funding.

It also requires the postal service's board of governors to submit a plan to Congress addressing the long-term solvency of the agency.

Job Corps

The agreement waives certain statutory requirements regarding enrollment and eligibility for Job Corps students during the COVID public health emergency.

Specifically, it waives drug testing for students who enroll in Job Corps virtually, and allows students who turn 25 during the pandemic to remain eligible if they enroll within six months of enactment.

<p> Section XV

Other Legislation

This section describes those provisions of HR 133, Consolidated FY 2021 Appropriations Act, that constitute a wide variety of major authorizations and other legislation that was added to the omnibus package.

The agreement includes provisions to protect patients from surprise medical bills and to determine how much an out-of-network health care provider should be paid by a health insurance plan, and it extends authorities for numerous public health, Medicare and Medicaid programs. It also extends numerous temporary tax provisions, making some permanent and extending others for multiple years -- including by making permanent reduced tax rates for beer, wine and liquor and allowing anyone who itemizes to deduct annual medical expenses that exceed 7.5% of adjusted gross income.

It also includes a wide variety of other provisions, including those that authorize funding and establish policies for U.S. intelligence agencies for FY 2021; that authorize new water projects for construction by the U.S. Army Corps of Engineers and exempt from budget caps the spending of certain balances from the Harbor Maintenance Trust Fund; that reauthorize pipeline safety and other activities of the Pipeline and Hazardous Materials Safety Administration; that require the Federal Aviation Administration (FAA) to exert greater control of the aircraft certification process in response to the Boeing 737 Max disasters; and that address issues involving the USMCA trade agreement.

The Congressional Budget Office (CBO) and Joint Committee on Taxation (JCT) estimate that all the added provisions combined will increase the deficit by $175 billion over 10 years.

Surprise Medical Billing

Surprise medical bills happen when a patient sees a doctor that they did not choose -- either because of emergency care at an out-of-network hospital, or because an out-of-network doctor not chosen by the patient treats them (such as an out-of-network anesthesiologist in a surgical procedure) -- with the patient then receiving an expensive medical bill covered minimally (if at all) by insurance.

To shield patients from such bills, the measure establishes a series of protections that limit patient out-of-network costs to the same amount they would pay for in-network care in cases where patients have no choice, and that provide patients with advance information about the cost of the care if they choose an out-of-network provider. These provisions take effect for health insurance plans that begin on or after Jan. 1, 2022. (CBO and JCT estimate the surprise billing provisions will produce savings of $17 billion over 10 years.)

Specifically, if a patient receives out-of-network care without their informed consent, their health insurance plan may only bill them the in-network cost sharing amount for those services -- with the health care provider being prohibited from seeking additional payment from the patient (i.e., through "balance billing"). Out-of-network surprise bills must count towards a patient's in-network deductible. The measure establishes a binding arbitration process to determine what health plans would then pay the providers for out-of-network services (see below).

Out-of-network health care providers must notify the patient that they are out-of-network and provide an estimate of charges 72 hours before the patient receives services, and the patient must consent to the care. Similarly, health insurance plans must provide patients with an advance explanation of benefits for scheduled services at least three days before the services are provided.

Health care providers and facilities must verify a patient's health insurance coverage within one day of scheduling service and provide an estimate of the cost to the insurance plan or the patient, whether or not the patient has health insurance. Health plans must provide patients with an explanation of benefits for scheduled services at least three days in advance of those services.

Finally, if a health care provider changes networks, patients of that provider who have complex care needs may continue to receive care from the provider at in-network cost sharing rates for up to 90 days to give them the opportunity to transition to an in-network provider.

Timely Billing

The agreement establishes timelines for providing patients with the actual bills for health services provided.

Specifically, health care facilities and providers must give patients a list of services received upon discharge or as soon as practicable, but no more than 15 calendar days after discharge. The bill for services provided must be sent to the patient's health insurance plan within 30 days of discharge.

Health insurance plans must make a determination of what it will pay and what the patient must pay within 30 calendar days of receiving the bill, with the health care facility or provider then sending its bill to the patient within 30 days. The patient must be allowed at least 45 days from the date of the billing postmark to pay the bill. If the patient receives a bill more than 90 calendar days after receiving care, the patient is not obligated to pay.

These billing provisions take effect six months after enactment.

Other Patient Protections

The agreement requires the Health and Human Services Department (HHS) to issue regulations that prevent insurers from designing plans that exclude particular types of facilities or providers, such as cancer or transplant centers. (Omitting these types of providers from plans can exclude patients who require these services, thus excluding patients with higher costs for medical care.)

It also requires HHS to establish a patient-provider dispute resolution process for uninsured individuals by Jan. 1, 2022.

All health insurance plans must include on their insurance identification cards the amount of in-network and out-of-network deductibles and out-of-pocket maximums. Plans must also establish price comparison tools for their enrollees and must maintain up-to-date directories of in-network providers. If a patient provides documentation that they received incorrect information from their insurer about a provider's network status prior to receiving services, the patient is responsible only for the in-network cost-sharing amount. These provisions take effect for health insurance plans that begin on or after Jan. 1, 2022.

Determining Provider Payments for Out-of-Network Services

The agreement establishes a process for health insurance plans and health care providers and facilities to determine how much the plans will pay the providers and facilities for out-of-network services that have been provided to the plan's enrollees.

Specifically, it calls for the provider and the plan to negotiate the payment -- but if they are unable to reach agreement it provides for binding arbitration (referred to as Independent Dispute Resolution) in which one side will prevail. Providers could combine similar services provided to enrollees of the same health insurance plan into a single Independent Dispute Resolution proceeding.

The arbitration process will be administered by independent, unbiased entities that have no affiliation with either health care providers or health insurance plans. In making their determination of which offer prevails, the entities must consider the following: relevant information submitted by either party, the median in-network rate, the provider's training and experience, and patient acuity and the complexity of furnishing the item or service. For resolutions involving facilities, the reviewing entities must also consider the teaching status, case mix and scope of services of the facility, demonstrations of good faith efforts (or lack of such efforts) to enter into a network agreement, and contracted rates during the previous four plan years. They may not consider billed charges or Medicare and Medicaid rates. The party whose offer is not selected will be responsible for paying for the arbitration process.

Ambulance Transportation

The agreement holds patients harmless from surprise air ambulance bills, providing that patients pay only the in-network cost-sharing amount for out-of-network air ambulances -- with the amount paid to count toward their in-network deductible. Air ambulance providers could not send balance bills to patients for amounts not covered by the patient's health insurance.

Similar to health providers and facilities, air ambulance services could negotiate or go to arbitration with health insurance plans to determine how much the plan will pay. These provisions take effect for health insurance plans that begin on or after Jan. 1, 2022.

State All Payer Claims Databases

The bill establishes a grant program to create and improve State All Payer Claims Databases, authorizing $50 million a year for FY 2022 and FY 2023 and $25 million for FY 2024 for the program. Grant recipients must make data available to authorized users, including researchers, employers, health insurance issuers, third-party administrators, and health care providers for quality improvement and cost-containment purposes.

Tax Extenders

The agreement extends almost 40 different tax provisions that had been temporary -- with some being made permanent, some extended for five years or two years, and some for just a single year. JCT estimates these provisions will reduce revenues by $103.8 billion over 10 years.

Tax Provisions Made Permanent

The agreement makes permanent for all people, regardless of age, the tax deduction for qualified unreimbursed medical care expenses that exceed 7.5% of adjusted gross income. (JCT estimates this provision will reduce revenues by $32.9 billion over 10 years.)

Other tax provisions made permanent include the commercial building energy efficiency tax deduction, with the credit indexed to inflation with updated efficiency standards, and the exclusion from income of tax stipends of up to $50 per month for volunteer firefighters or emergency medical responders. The short line railroad tax credit for track maintenance, currently at 45% through 2022, is also made permanent but is increased to 50% for expenditures prior to Jan. 1, 2023, and reduced to 40% in 2023.

It also makes permanent the reduced federal excise tax rate and simplified recordkeeping requirements for small craft brewers, wineries and distilleries first enacted as part of the 2017 tax law (PL 115-97). And it includes new associated provisions that disregard volume limits for distilled spirits subject to reduced tax rates, and excludes smuggled or illegally produced beer, wine and spirits from the reduced rates for imported alcohol. (JCT estimates these provisions will reduce revenues by $9.0 billion over 10 years.)

Five-Year Tax Extensions

The agreement extends for five years the Work Opportunity Tax Credit, an elective general business credit to employers who hire individuals who are members of one or more of 10 targeted groups. (JCT estimates this provision will reduce revenues by $16.2 billion over 10 years.)

It extends for five years a provision that allows individuals to exclude from gross income any debt forgiveness attributable to the sale of a primary residence whose mortgage was "underwater" (i.e., the house sold for less than the mortgage owed on it and the lender forgave that difference in debt, which is otherwise treated as income for tax purposes). The maximum forgiven debt that may be excluded is decreased from $2 million to $750,000.

It also extends for five years the New Market Tax Credit; the look-through rule for related controlled foreign corporations; the seven-year recovery for motorsports complexes; special expensing rules for film and television productions, as well as live theatrical productions; special tax incentives for businesses and employers within economically depressed census tracts known as Empowerment Zones; exclusion of employer repayment of student loans from income tax; and the employer tax credit for providing paid family and medical leave to employees.

Other Tax Extensions

The measure extends for two additional years, through 2025, tax credits awarded on a per-ton basis for carbon dioxide that is sequestered, and it extends through 2025 the 9 cents per barrel tax on oil that funds the Oil Spill Liability Trust Fund.

It delays the phasedown of the Solar Investment Tax Credit, maintaining the 26% tax credit for solar systems on residential and commercial through 2023 and then resuming the phasedown to 22% in 2024 and 10% in 2025. It also expands the credit to include qualified energy efficient biomass fuel property with a thermal efficiency rating of at least 75%; correspondingly, biomass stoves will no longer qualify for a tax credit, to prevent a double benefit. (JCT estimates these provisions will reduce revenues by $7.0 billion over 10 years.)

It extends for one year the following tax provisions: production tax credits for onshore wind power; treatment of mortgage insurance premiums as qualified residence interest; health coverage credit on premiums for qualified health insurance; mine rescue team training credit; depreciation deductions for racehorse owners; credits for U.S. firms that operate in American Samoa; second generation biofuel producer credit; credit for purchases of nonbusiness energy property; credits for purchases of new qualified fuel cell vehicles and for highway-capable, two-wheeled plug-in electric vehicles; energy efficient home construction credit, and alternative fuels and alternative fuels infrastructure credit.

It also extends through 2021 certain tax provisions intended to promote economic development for Native Americans, including the Indian employment credit, accelerated depreciation for qualified Indian reservation property, and a $2 per ton production tax credit for coal produced on land owned by an Indian tribe.

Finally the measure extends for one year the excise tax that funds the Black Lung Disability Trust Fund -- which is $1.10 per ton for coal from underground mines and 55 cents per ton for coal from surface mines.

Other Tax Provisions

The agreement includes a number of other tax provisions that JCT in December estimated will reduce revenues by $56.9 billion over 10 years ($20.6 billion of which is attributable to extending the CARES Act employee retention tax credit for employers; see Section XIV, Covid Relief).

It allows individuals when filing their 2020 tax returns to use the greater of either their 2019 or their 2020 earned income to compute the Earned Income Tax Credit and the refundable portion of the Additional Child Tax Credit (since the tax credit and refund are a percentage of earned income, using the larger number results in a higher tax credit).

It extends for 2021 a provision from the CARES Act that allows individuals to deduct up to $300 in cash contributions to churches and other charitable organizations, regardless of whether they itemize their deductions. It also extends for 2021 the increased amounts that can be deducted for charitable giving by corporations and individuals who itemize.

It allows flexible spending account (FSA) balances to carry over through 2022, providing 12 additional months to spend unused benefits in these accounts. It extends the maximum age of eligible dependents from 12 to 13 for dependent care FSAs for the 2020 plan year, and permits beneficiaries to change election amounts for these accounts through 2021.

The measure also does the following:

Makes the full cost of meals a deductible business expense for two years, 2021 and 2022. Currently only half the cost is available as a business deduction. (JCT estimates this will reduce revenues by $6.3 billion over 10 years.)

Provides a permanent 4% minimum tax credit rate for low-income housing properties acquired for rehabilitation or funded using tax-exempt bonds.

Establishes a new tax credit for converting waste heat to power, providing a credit of 26% for 2021 and 2022 and 22% for 2023, and extends the investment tax credit for offshore wind facilities that begin construction through 2025. Offshore wind facilities that begin construction during the 2017-2025 period are not subject to the onshore-wind facilities phase-out rates, and are eligible for the full credit amount.

Allows employees in the building and construction industry who have attained age 55 and are not separated from employment to make distributions from certain tax-exempt multiemployer pension plans, if they were participants in such plan on or before April 30, 2013.

Disaster Tax Provisions

The agreement provides tax relief for individuals and businesses in presidentially declared disaster areas where the disaster was declared between Jan. 1, 2020, through 60 days after enactment (excluding areas for which a major disaster has been declared only because of COVID-19) which JCT estimates that will reduce revenues by $9.6 billion over 10 years.

Most of the revenue loss occurs by increasing the 2021 federal allocation of Low Income Housing Tax Credits for residents of disaster zones (to $3.50 per capita instead of $2.70). What is not used in 2021 could be carried over to 2022. (JCT estimates this provision will reduce revenues by $8.3 billion over 10 years.)

It temporarily suspends limitations on the deduction for charitable contributions associated with qualified disaster relief, and for uncompensated losses arising in disaster areas it eliminates current law requirements that personal casualty losses must exceed 10% of adjusted gross income to qualify for deduction. It exempts from the early retirement plan withdrawal penalty those distributions for qualified disaster relief that do not cumulatively exceed $100,000; such distributions will be taxable over three years or could be recontributed to a retirement plan to avoid taxable income. It also provides flexibility for loans from retirement plans for qualified disaster relief.

For employers, it provides a tax credit for 40% of wages (up to $6,000 per employee) that is paid by a disaster-affected employer to a qualified employee.

Health Care Extenders

The agreement extends for roughly three years numerous federal health care programs administered by the Health and Human Services Department (HHS), including public health programs and Medicare and Medicaid programs.

(CBO and JCT estimate that the measure's public health provisions will increase direct spending by $12.9 billion over 10 years, while the Medicare provisions will increase direct spending by $11.4 billion and the Medicaid provisions by $6.4 billion. Meanwhile, numerous provisions will save money, such as requiring certain manufacturers to report drug pricing information with respect to drugs under the Medicare program, with those provisions together reducing direct spending by $14.3 billion over 10 years.)

Public Health Programs

The measure extends through FY 2021 current funding for the Temporary Assistance for Needy Families (TANF), the Child Care Entitlement to States, and other related programs including the Healthy Marriage and Responsible Fatherhood grants, and it provides $3.6 million for the Health Profession Opportunity Grants (HPOGs) program with funding to remain available through FY 2022 for costs related to evaluation and reporting.

It extends at current levels through FY 2023 funding for community health centers, the National Health Service Corps, the Teaching Health Center Graduate Medical Education Program, the Special Diabetes Program for Type I Diabetes, and the Special Diabetes Program for Indians.

It also extends through FY 2023 the Sexual Risk Avoidance Program, the Personal Responsibility Education Program, and the MaryLee Allen Promoting Safe and Stable Families Program and State court support.

It reauthorizes through FY 2026 the young women's breast health awareness and education program, the School-Based Health Center program, and the rare pediatric disease priority review voucher program.

Medicare Program Extensions

The agreement authorizes $50 million a year through FY 2023 for low-income Medicare activities through State Health Insurance Assistance Programs, Area Agencies on Aging, Aging and Disability Resource Centers, and the National Center for Benefits and Outreach and Enrollment. It authorizes $66 million through FY 2023 for the National Quality Forum.

It extends the Intravenous Immunoglobulin (IVIG) treatment demonstration and the geographic index floor under Medicare through Dec. 31, 2023. And it extends the Independence at Home demonstration for three additional years (through Dec. 31, 2023) and expands the size of the demonstration from 15,000 beneficiaries to 20,000 beneficiaries.

Medicaid Program Extensions

The measure eliminates the scheduled Medicaid Disproportionate Share Hospital (DSH) payment reductions for FY 2021 through FY 2023, but provides for greater reductions in FY 2026 and FY 2027.

It extends through FY 2023 certain Medicaid programs, including the Money Follows the Person Rebalancing Demonstration Project, Spousal Impoverishment Rules, and the Community Mental Health Services Demonstration Program.

Other Health Care Provisions

Transparency Requirements

The agreement bans gag clauses between providers and health plans so that enrollees, plan sponsors and referring providers can access cost and quality data on health care providers. Gag clauses that prevent plan sponsors from accessing non-personal claims data that could be used to improve plan administration and quality also are prohibited.

It requires health benefit consultants and brokers, such as pharmacy benefits managers, to disclose to plan sponsors any compensation they receive for referral of services. Similarly, health benefits brokers must disclose to enrollees in the individual market, or those purchasing short-term limited duration insurance, any compensation they receive for referral of coverage.

It authorizes a campaign to increase awareness and knowledge regarding vaccines and to combat vaccine misinformation, and it directs HHS to establish, expand and improve programs to collect and analyze vaccination coverage data. It authorizes grants for activities to address vaccine-preventable disease and for research on improving awareness of vaccine-related information.

The measure also does the following:

Requires all manufacturers of drugs covered under Medicare Part B to report average sales price information to HHS beginning on January 1, 2022.

Requires patent information for biological products to be submitted to the Food and Drug Administration and published in the so-called "Purple Book," and requires publication of the Purple Book as a single, searchable list of information about each licensed biological product, including marketing and licensure status, patent information, and relevant exclusivity periods.

Gives the Medicare Payment Advisory Commission (MedPAC) and the Medicaid and CHIP Payment and Access Commission (MACPAC) access to drug pricing and rebate data under Medicare Parts B and D, Medicare Advantage and Medicaid in order to monitor, analyze, and make program recommendations.

Requires HHS to improve public health data systems used by the Centers for Disease Control and Prevention (CDC), and requires HHS to award grants to state and local public health departments to modernize public health data systems and enhance the interoperability of the systems.

Expand Access to Health Care

The measure shortens the period between enrollment in Medicare Part B and when Part B coverage begins, and it provides for a Part A and Part B Special Enrollment Period for "exceptional circumstances" to mirror authority in Medicare Advantage and Medicare Part D. It also permanently authorizes (starting in 2024) the Limited Income Newly Eligible Transition (LI NET) demonstration under which individuals with low-income subsidies (LIS) may receive immediate temporary Part D coverage while their eligibility is being processed.

It gradually eliminates cost-sharing for Medicare beneficiaries with respect to colorectal cancer screening tests where a polyp is detected and removed. It establishes eligibility for immunosuppressive drug coverage through Medicare to post-kidney transplant individuals whose entitlement to benefits under Part A has ended and who don't have coverage of immunosuppressive drugs through other insurance.

It expands access to telehealth services in Medicare to allow beneficiaries to receive mental health services via telehealth, including from the beneficiary's home. To be eligible to receive such services via telehealth, the beneficiary must have been seen in person at least once by the physician or non-physician practitioner during the six-month period prior to the first telehealth service.

Finally, it restores Medicaid eligibility to individuals who are subject to the Compacts of Free Association between the U.S. and the Federated States of Micronesia, the Republic of the Marshall Islands, and the Republic of Palau. (After the U.S. used the Marshall Islands as a testing site for nuclear weapons in the mid-20th century, a 1980s compact gave islanders the right to resettle in the U.S. and receive Medicaid benefits, but a drafting error in the 1996 welfare reform law ended that access.)

Rural Hospitals

The measure creates a new, voluntary Medicare payment designation that allows either a Critical Access Hospital or a small, rural hospital with fewer than 50 beds to convert to a Rural Emergency Hospital to preserve beneficiary access to emergency medical care in rural areas that can no longer support a fully operational inpatient hospital.

It extends the Frontier Community Health Integration Project demonstration by five years to test new models of health care delivery for rural Critical Access Hospitals, and it implements a comprehensive Rural Health Clinic payment reform plan.

It also provides for additional graduate medical education (GME) residency positions in rural hospitals, hospitals that are already above their Medicare cap for residency positions, hospitals in states with new medical schools, and hospitals that serve Health Professional Shortage Areas.

Payments & Reimbursements

The measure prohibits, until Jan. 1, 2024, implementation of the new Centers for Medicare and Medicaid Services (CMS) add-on code for inherently complex evaluation and management visits in the physician fee schedule. (Various physician groups have analyzed the add-on code and believe it will generally decrease what physicians are paid.)

It also maintains the 5% incentive payment and the participant payment and patient count thresholds under Advanced Alternative Payment Models for Medicare for payment years 2023 and 2024. (Various provider groups analyzed the new payment rules and determined they would decrease health care provider pay.)

Aircraft Certification Reform

In response to the Boeing Max airline disasters, the agreement modifies the Federal Aviation Administration's (FAA) aircraft safety and certification process -- in particular the authority of aircraft manufacturers to approve and certify parts of their own aircraft, limiting what can be delegated to a manufacturer to certify. The measure authorizes a total of nearly $275 million over five years for the FAA to improve the safety and oversight of its certification system.

It authorizes $27 million to recruit and retain engineers, safety inspectors and other FAA employees who are tasked with overseeing safety, and it directs the agency to review its workforce to determine whether it has the needed expertise to certify new technologies.

Oversight of the ODA Process

The measure requires the FAA to convene an expert panel to identify and develop best practices for entities that are authorized by the FAA to self-certify aircraft -- known as "organization designation authorization" (ODA) holders.

Under the measure, the FAA must review and approve each new individual that is selected by an ODA holder to carry out safety or certification duties, and it must audit each manufacturing ODA unit at least once every seven years. The agency must assign FAA aviation safety advisers to monitor the performance of members of an ODA and educate them about FAA policies.

The measure increases the FAA's authority to approve or remove Boeing employees who conduct FAA certification tasks, and it requires that a panel be convened to review Boeing's ODA, safety culture, and capability to perform FAA-delegated functions.

Finally, it bars the FAA from giving aircraft manufacturers the authority to certify certain critical system design features of an aircraft, unless the FAA administrator provides explicit permission.

Whistleblower Protections

The measure imposes a civil penalty on any supervisor of a company that conducts ODA activities and who interferes with the performance of an ODA member in carrying out authorized functions on behalf of the FAA, and it requires all members of an ODA to promptly report any cases of interference experienced or witnessed at a company.

It prohibits the FAA and ODA holders from preventing ODA members from communicating with FAA personnel and vice-versa. It requires the FAA, in collaboration with labor groups representing certain FAA employees, to implement a confidential voluntary safety reporting program for FAA engineers, safety inspectors, systems safety specialists, and others.

The measure adds aviation manufacturing employees to existing whistleblower laws that protect airline employees from retaliation for reporting safety issues or violations.

It also strengthens and clarifies the role of the FAA's whistleblower office, including by authorizing it to investigate whistleblower retaliation and by creating an FAA whistleblower ombudsman to ensure FAA employees are properly educated on prohibited acts of retaliation.

"Human Factors"

The measure also aims to address "human factors" -- how people interact with complicated technology under duress -- authorizing $7.5 million to study how people interact with technology on aircraft and $2 million a year for an FAA Center of Excellence focused on automated systems and human factors. The FAA must incorporate a human factors education program into its employee training programs.

It bars the FAA from certifying a new airliner design unless the airplane has a centralized crew alerting system that would help a pilot differentiate and prioritize warnings and cautions on the airplanes.

And it expands the agency's role in reviewing and approving pilot training requirements for commercial aircraft, with an increased emphasis on how humans interact with technology.

Finally, the measure provides for fines of up to $1 million for aircraft manufacturers who fail to disclose to the FAA, airlines and pilots -- through aircraft or flight crew operating manuals -- all critical safety information related to an aircraft, including information about systems that manipulate flight controls without direct pilot input.

Water Projects

The agreement includes the Water Resources Development Act (WRDA) -- which authorizes new water projects for construction by the Corps of Engineers, authorizes the corps to conduct new feasibility studies, and modifies the budgetary treatment of spending from the Harbor Maintenance Trust Fund.

Under the measure, certain spending from the trust fund balances will not count against annual discretionary spending caps, although it establishes limits on such spending. Specifically, starting for FY 2021, corps spending derived from the trust fund that is exempt from caps will be the amount of receipts that was deposited into the fund two years prior -- plus an additional specified amount. For FY 2021 that additional amount will be $500 million, and it will increase by $100 million each year until FY 2030 where it will remain at $1.5 billion a year.

Through FY 2031 it increases from 50% to 65% the share of funding for inland waterway construction projects that will come from the general fund of the Treasury, with funding from the Inland Waterways Trust Fund to be reduced accordingly.

The measure authorizes the construction of all 46 pending corps reports that have been received since enactment of the previous water resources development act in 2018. It also authorizes 27 feasibility studies for water resources development projects, including those identified through the public review process, and it directs the corps to complete six comprehensive river basin studies for the Great Lakes, the Lower Mississippi River, the Upper Mississippi River, the Lower Missouri River Basin, the Upper Missouri River, and the Sacramento River.

Finally, it establishes a new process to deauthorize previously authorized water resources development projects, and requires the corps to identify $10 billion in previously authorized projects that should be deauthorized.

Social Justice & Environmental Provisions

The measure requires the corps to provide technical assistance to communities for greater resiliency planning, and to focus particularly on economically disadvantaged communities. The corps must update its policies on environmental justice considerations and promote "meaningful involvement" with minority communities, economically disadvantaged communities and Indian tribes.

It authorizes a new program to study, design and build water resources projects for communities that have experienced repeated flood events and that have received emergency flood-fighting assistance. It also authorizes the corps to prioritize the processing of permits and approvals for the repair and rebuilding of damaged flood control infrastructure.

It establishes a demonstration program to detect, prevent, treat and eliminate harmful algal blooms and authorizes studies of noxious weeds -- invasive species that are present in the Everglades, Alpine Lakes, the Upper Mississippi and Ohio River Basins, and other watersheds.

Finally, it requires the Interior Department to establish a five-year pilot program to help states eradicate the Asian giant hornet, more frequently known as the "murder hornet."

Pipelines & Hazardous Waste

The agreement reauthorizes the Pipeline and Hazardous Materials Safety Administration (PHMSA) for three years through FY 2023, authorizing about $228 million for FY 2021 and increasing to about $238 million for FY 2023. Funds are to come from the Oil Spill Liability Trust Fund for pipeline integrity research and development and for PHMSA hazardous liquid activities.

From the fees collected for underground natural gas storage facility safety, it authorizes $8 million a year through FY 2023 to establish minimum safety standards for underground natural gas storage facilities.

It increases the required number of full-time employees with subject matter expertise in pipeline safety, pipeline facilities and pipeline systems in order to finalize PHMSA's outstanding rulemakings, and provides recruitment and retention incentives -- including special pay rates, repayment of student loans, and tuition assistance.

Due Process Protections

The measure adds due process protections to existing enforcement proceedings by allowing the entity against which the proceeding is brought to request the use of a consent agreement and consent order to resolve matters of fact and law, as well as to meet with PHMSA and to request a hearing. All PHMSA records must be included in the case file, and the agency will have the burden of proof, presentation and persuasion.

The measure requires that all hearings be open to the public and posted on the PHMSA website, and that all agreements, orders and judgments also be open to the public.

Required Regulations

The measure requires the Transportation Department to provide updates on outstanding PHMSA final rules and to issue or revise rules, standards and guidance regarding drug and alcohol testing for operators and pipeline contractors who work for multiple operators in multiple states and on gathering pipelines.

It defines idled pipelines and requires the department to issue safety regulations for idled natural or other gas transmission and hazardous liquid pipelines. The regulations must be risk-based and must specify reinspection timelines and the conditions necessary for allowing an idled pipeline to resume operations.

The department also must issue final regulations that require operators of gas distribution pipelines to conduct leak detection and repair programs to meet gas pipeline safety standards and protect the environment. The leak detection programs must be able to identify, locate and categorize all leaks that are hazardous to human safety or the environment, or that could become hazardous. The rules must include a schedule for repairing or replacing leaking pipes, with appropriate deadlines.

Finally, it requires a series of regulations that address various aspects of overpressurization of natural gas distribution systems, procedures and protocols for safely maintaining natural gas distribution systems, and for reacting to overpressurization or an emergency resulting from a rupture of the pipelines.

LNG Operators

The measure establishes fees for compliance reviews of liquefied natural gas (LNG) facilities. An entity that applies to build an LNG facility costing $2.5 billion or more must cover the necessary expenses of any PHMSA review.

Within three years of enactment, the Transportation Department must update its standards for large-scale liquefied natural gas (LNG) facilities to achieve a higher level of safety, and LNG operators must submit to the department a plan on how they will implement the requirements. PHMSA could take enforcement actions against operators who don't adequately comply with approved plans.

The measure authorizes a three-year limited safety-enhancing testing program to evaluate innovative technologies and practices for testing the safe operation of an LNG or hazardous liquid pipeline.

Whistleblower Protections

The measure allows employees and former employees of pipeline operators who provide safety information to regulating agencies, and who then experience retaliation from their employers, to bring an action for de novo review of their complaint under certain circumstances.

The rights and remedies available to such employees cannot be waived, and any existing predispute arbitration agreements that would waive those rights and remedies will be invalidated.

Energy & Environmental Provisions

The agreement includes numerous provisions to promote the development of clean and renewable energy over the next five years by authorizing various Energy Department programs and activities. (CBO estimates the measure's energy title will increase direct spending by $722 million over 10 years.)

Under the measure, funds are authorized to develop wind, solar, hydropower, geothermal, marine and other clean energy sources, to increase energy efficiency, to improve and modernize the nation's electric grid, and to promote the development of carbon capture and greenhouse gas reduction technologies. Other programs will be focused on critical minerals and materials, industrial technologies and smart manufacturing, and modern fusion energy.

It authorizes $2.9 billion through FY 2025 for programs and activities of the Advanced Research Projects Agency - Energy (ARPA-E), which is tasked with promoting and funding research and development of advanced energy technologies. The measure expands the program to support projects that address nuclear waste clean-up and that will improve the reliability and security of the nation's energy infrastructure.

The measure creates new programs within the Energy Department to accelerate the adoption of "smart buildings" that provide the lowest energy costs and environmental impact over the building's lifecycle, as well as to develop new scalable advanced nuclear reactors (including the fuel needed for the initial reactors) and to develop more advanced energy storage technologies (which are seen as key to the further development of renewable energy sources).

It expresses the sense of Congress that the Energy Department must prioritize funding for research to power the United States with 100% "clean, renewable, or zero-emission energy sources."

Renewable Energy Projects on Federal Lands

The agreement requires the Interior Department to set national goals for wind, solar, and geothermal energy production on federal lands by Sept, 1, 2022, and to seek to permit at least 25 gigawatts of electricity from wind, solar, and geothermal projects by 2025.

Limit HFCs

The measure seeks to curtail planet-warming chemicals known as hydrofluorocarbons (HFCs) that are used in air-conditioners and refrigerators.

Specifically, it requires the nation's chemical manufacturers to phase down the production and use of these coolants, which while being a small percentage of greenhouse gases in the atmosphere have 1,000 times the heat-trapping capacity of carbon dioxide. The measure effectively binds the United States to the 2016 Kigali agreement, which requires companies to phase down production and consumption of HFCs to about 15% of 2012 levels by 2036.

Diesel Reduction Program

The measure reauthorizes the Energy Department's Diesel Emissions Reduction Program through FY 2024 at the current level of $100 million per year. The program awards grants and rebates for activities that protect human health and improve air quality by reducing harmful emissions from diesel engines.

It also establishes a new competitive prize program within EPA to encourage the development of technologies that reduce carbon dioxide from stationary sources, and it creates a research and development program to identify and evaluate novel uses for carbon that is captured.

FY 2021 Intelligence Authorization

The agreement authorizes classified amounts in FY 2021 for U.S. intelligence agencies and intelligence-related activities of the U.S. government, including the Office of the National Intelligence Director (ODNI), the CIA and the National Security Agency (NSA), as well as foreign intelligence activities of the Defense Department, FBI, State Department, Homeland Security Department and other agencies. The measure covers general intelligence operations (including signals intelligence), clandestine human intelligence programs and analysis, and covert action programs, as well as research and development and projects to improve information dissemination.

The DNI requested $61.9 billion in FY 2021 for the National Intelligence Program (NIP), which makes up the main portion of intelligence spending. The request for the Military Intelligence Program for FY 2021 (which primarily supports tactical military operations, including combat operations) was $23.1 billion. The DNI does not provide funding breakdowns for individual offices or programs. The total is roughly equal to the FY 2020 level.

Given that most of the intelligence budget involves highly classified programs, the bulk of the measure's funding recommendations each year are found in the classified annex to the agreement. (The classified annex contains the dollar amounts and personnel ceilings for each intelligence program and is available only to members and staff with appropriate clearance. Members and such staff can view the classified annex in Room HVC-304 of the Capitol Visitor Center.)

According to House Intelligence Committee Democrats, the agreement includes provisions related to global health and pandemics; the challenge posed by a rising China, emerging technologies like artificial intelligence and 5G; recruitment and retention for the workforce; and other regional priorities, including the Middle East, and Afghanistan.

It includes several provisions designed to strengthen cyber defenses, protect supply chains, and provide additional resources and capabilities for responding to cyber-attacks. Many of the most important elements of the bill are contained within the classified annex that governs the necessarily secret elements of the IC's work, according to the committee.

China & Russia

The measure prioritizes the collection and analytic capabilities against both China and Russia as well as strategic, transnational threats such as climate change and pandemics. It requires the DNI to submit an annual Worldwide Threats Assessment and then testify in public (which the Trump administration refused to do so). It also directs GAO to identify and mitigate risks posed to the intelligence community and the Pentagon by the use of direct-to-consumer genetic testing done by companies that may have ties to China, or by the sale of such data to companies owned by Chinese interests.

It directs intelligence agencies to increase scrutiny of Chinese activities in the United States as well as in the allied "Five Eyes" intelligence sharing nations of Australia, Canada, New Zealand and the United Kingdom. It requires the CIA, the Office of the Director of National Intelligence, and the Defense Intelligence Agency to report on efforts by foreign adversaries to build and supply telecom and cybersecurity equipment for U.S. allies (the United States has urged allies not to buy 5G equipment from China's Huawei Telecom, which U.S. intelligence agencies see as a national security risk to U.S. communications networks).

Finally, the measure directs intelligence agencies to study the feasibility of forming advisory councils focused on transnational threats stemming from disease outbreaks, pandemics and other global health threats; the effect of lifting the United Nations arms embargo on Iran; and corrupt activities of Russian and other Eastern European oligarchs who support Moscow.

Other Provisions

USMCA Corrections

The agreement makes technical corrections to the United States-Mexico-Canada Agreement (USMCA) to ensure the trade deal reflects the intentions of Congress and the three signatory nations. The USMCA replaced the 1994 North American Free Trade Agreement. (CBO and JCT estimate the USMCA provisions will increase revenues by $2.2 billion and increase direct spending by $416 million, for net deficit reduction of $1.7 billion over 10 years.)

The measure corrects inadvertent drafting errors to the USMCA Implementation Act enacted in Jan. 2021 (PL 116-113), including technical corrections and corresponding changes related to the North American Development Bank, drawback, retention of records, and merchandise processing fees.

It restores NAFTA treatment to Foreign Trade Zones (FTZs), which are areas located close to ports of entry where importers can unload, store or sort goods. The measure reinstates a provision, repealed in the USMCA implementation law, that required firms operating in foreign-trade zones to pay tariffs on components sourced from countries other than Canada or Mexico. The provision meant that FTZ manufacturers couldn't benefit from the pact's "rules of origin" making importers eligible for preferential duty treatment if a certain amount of a product's inputs originated in one of the three North American countries. (Critics of reinstating the NAFTA treatment say it could put U.S. manufacturers at a disadvantage relative to competitors in Mexico and Canada that don't face the same restrictions.)

It allows U.S. companies that bring in products from Mexico or Canada to request refunds of merchandise processing fees on qualifying goods after they import them. The USMCA implementing bill only allowed refunds if a company requested them at the time a product entered the United States.

It also reauthorizes the North American Development Bank, which is jointly funded by the U.S. and Mexico and primarily funds infrastructure projects up to about 62 miles north of the U.S.-Mexican border in Texas, New Mexico, Arizona and California and within 186 miles south of the border in Mexico.

Immigration & Border Provisions

The agreement extends through FY 2021 the E-Verify and Religious Worker Special Immigrant Visa programs, as well as the Conrad 30 Waiver program for physicians serving in underserved areas.

It extends the EB-5 Regional Center program until June 30, 2021, and allows the Homeland Security Department to increase the number of H-2B temporary visas that may be issued in FY 2021 if it determines that the needs of American businesses cannot be satisfied with U.S. workers who are willing, qualified, and able to perform temporary nonagricultural labor.

It also extends for one year, until Dec. 20, 2021, the deadline for applications under the Liberian Refugee Immigration fairness program.

On border issues, it extends for one year the U.S. Customs and Border Protection's (CBP) entry donation program, under which the agency can accept private donations to improve or expand inspection facilities at U.S. border crossings. And it bolsters protections for CBP officers, agents and other personnel who may be exposed by synthetic opioids when conducting screening activities by requiring CBP to establish specific protocols and procedures for the appropriate handling of such toxic substances.

It also requires the Homeland Security Department to prepare and submit to Congress an analysis of border security technology along the U.S. border with Mexico.

Homelessness & Housing Programs

To respond to disruptions caused by the COVID-19 pandemic, the measure authorizes the Housing and Urban Development (HUD) Department to renew for an addition 12 months, without competition, all grants for homelessness assistance programs that are set to expire in 2021.

It makes Indian tribes and tribal housing entities eligible to receive certain federal homelessness assistance grants, and it streamlines the process for HUD to guarantee mortgages in Indian Country under the Section 184 Home Loan Guarantee program.

It also authorizes $300 million to support a new requirement to install and maintain carbon monoxide detectors in public housing.

Foster Care

The agreement includes a number of provisions to bolster state foster care programs (which CBO estimates will increase direct spending by $825 million over 10 years).

It provides $350 million for the Health and Human Services (HHS) Department's Chafee foster care transition program, which provides support services for teens and young adults up to age 21 that are either in or have recently left foster care, and it temporarily waives state matching requirements for funds. It also provides $50 million for the Chafee educational voucher program, which provides funding for post-secondary education for foster youth, and it increases the maximum individual award from $5,000 to $12,000.

It prohibits states through the end of FY 2021 from forcing a child in foster care to leave foster care solely because they have reached the age of 18, and it allows individuals that have left foster care in FY 2020 or FY 2021 to voluntarily re-enter foster care. States could use emergency Chafee program funds to offset any associated cost. It directs HUD to provide an additional two years (for a total of five years) of housing voucher assistance and related supportive services for individuals aging out of foster care who are at risk of homelessness, if they participate in certain self-sufficiency programs.

The measure also provides $85 million in emergency funds for HHS's Promoting Safe and Stable Families program, which provides funds to help state child welfare agencies operate family support services. This amount includes $10 million to help courts handle child welfare cases during the COVID-19 pandemic.

Higher Education / FAFSA

The agreement reduces from 108 to 36 the number of questions in the Free Application for Federal Student Aid (FAFSA) used to help determine eligibility for student aid, and it streamlines the financial data verification process by using data from the IRS. It eliminates a restriction in current law that prohibits students who have drug-related offenses from receiving subsidized federal loans, repeals a requirement that limits how long students can borrow under the subsidized student loan program, and lifts the cap on the length of time students can attend school without accruing interest on subsidized federal student loans.

(CBO estimates the FAFSA simplification and related provisions will increase direct spending by $7 billion over 10 years.)

It expands the Pell Grant program to allow more students to be eligible and increases the amounts that can be awarded under the program. Incarcerated students will be eligible for Pell grants, and students who received Pell grants while attending for-profit schools that defrauded them will have their Pell eligibility restored. It also establishes simpler Pell Grant eligibility guidelines for maximum and minimum awards, so most applicants will know if they will get a maximum or minimum grant to go to college.

Finally, it discharges $1.3 billion in loans made to Historically Black Colleges and Universities under the HBCU Capital Financing Loan program.

COVID & Other Consumer Protections

The measure authorizes the Federal Trade Commission to impose civil penalties on companies and individuals who seek to exploit the COVID-19 pandemic for illegal purposes, including by selling fraudulent COVID treatments or protective equipment. It directs the Consumer Product Safety Commission (CPSC) to increase the number of inspectors at U.S. ports of entry for the duration of the COVID-19 pandemic.

It also requires the CPSC to adopt certain flammability standards for upholstered furniture, and to issue new safety rules on portable fuel containers.

Broadband & 5G Communications

The agreement directs the Federal Communications Commission (FCC), the National Telecommunications and Information Administration (NTIA) and the Agriculture Department to coordinate the distribution of federal funds for broadband programs and prevent duplication of support. It establishes the Office of Internet Connectivity and Growth within NTIA to promote access to high-speed broadband and to create a standard process for applying for federal broadband support programs.

It repeals a 2012 law that requires the FCC reallocate spectrum that makes up the so-called T-band, a range of wireless frequencies used by public safety agencies in many major metro areas.

It also directs the FCC before December 2021 to begin a process of competitive bidding to allow flexible non-federal services in the 3450 to 3550 megahertz bands in order to promote the development of next-generation 5G technologies.

Intellectual Property

The measure contains several provisions related to intellectual property protections, including by establishing a Copyright Claims Board within the U.S. Copyright Office to act as a low-cost, voluntary alternative to federal courts for small copyright infringement claims worth less $15,000 per claim or $30,000 per case (defendants will be able to choose to have their case heard before a federal court).

It makes it a felony penalty to offer streaming services whose primary purpose is to stream pirated material.

It also establishes an expedited process for third parties to challenge trademarks that are registered with the U.S. Patent and Trademark Office but are not in actual commercial use.

National Bio & Agro-Defense Facility

The agreement codifies the mission of the proposed National Bio and Agro-Defense Facility (NBAF), an Agriculture Department research facility under construction in Kansas that will research threats to the U.S. food supply, as well as on naturally occurring animal diseases and zoonotic bio-weapons that can affect public health. It directs USDA and the Homeland Security Department to evaluate the work of the facility for five years after its completion, and to develop and publish a strategic research plan.

The measure also repeals a 2009 law that required Congress to publicly auction Plum Island, N.Y., the site of the Plum Island Animal Disease Center, which is slated to be decommissioned following the completion of the new facility in Kansas (proceeds from the sale of the island to private bidders had been intended to help finance construction of the NBAF).

Other Government Operations

The measure creates an oversight.gov website to be managed by the Council of Inspectors General for Integrity and Efficiency, where each report issued by an agency's Inspector General must be posted, and it clarifies that subcontractors and subgrantees are covered by federal whistleblower protections laws.

It transfers authority to manage the ".gov" internet domain from the General Services Administration to the Homeland Security Department's Cybersecurity and Infrastructure Security Agency (CISA).

It prohibits the use of reverse auctions, where bidders can lower their bids to win a supply or service contract, for federal contracts that contain complex, specialized or substantial construction and design services.

It also statutorily codifies the AI Center of Excellence within the General Services Administration to improve efforts to develop innovative uses of artificial intelligence within the federal government.

Retired Miner Health Benefits

The measure authorizes the Treasury Department to transfer general revenue monies to multiemployer health benefits plans run by the United Mine Workers of America to cover retirees who would lose their health benefits due to future bankruptcies by coal mine operators. (In previous cases, Congress has authorized the transfer of federal funds to the health benefits plans for individual bankruptcies). It abolishes the $750 million cap for such transfers established by law in 2019.

It also authorizes transfers in cases where health benefits confirmed in prior bankruptcy proceedings have subsequently been denied or reduced. (CBO and JCT estimate these provision will cost $668 million over 10 years.)

Sudan Claims & Other Foreign Relations Provisions

In response to the United States' recent decision to remove Sudan from the list of state sponsors of terrorism following its transition towards more democratic governance in 2019, the agreement restores the government of Sudan's sovereign immunity from civil suits related to terrorism in U.S. courts and it guarantees compensation to victims of the 1998 East Africa embassy bombings through the Victims of State Sponsored Terrorism Fund. It extends the fund's authorization, currently set to expire in 2030, through 2039.

It also contains numerous foreign policy provisions, some of which were originally standalone bills, including the following:

Hostage Recovery -- Authorizes the President to sanction hostage-takers and those perpetrating wrongful detention, and codifies certain aspects of the existing U. S. government hostage recovery framework including the office of the Special Presidential Envoy for Hostage Affairs.

Taiwan -- Directs the State Department to review and reissue its guidance to other executive branch agencies on how to conduct relations between the United States and Taiwan, and to report to Congress on the updated guidance.

Tibet -- Reauthorizes programs and initiatives to address human rights, religious freedom and environmental challenges facing the people of Tibet, including programs to support civil society and cultural exchanges. It requires the State Department to take certain actions in support of Tibet, and it places restrictions on new Chinese consulates in the United States until a U.S. consulate has been established in Lhasa.

Belarus -- Reauthorizes sanctions against individuals complicit in political repression in Belarus, and it authorizes and expands federal programs to promote democracy, the rule of law, and freedom of information in Belarus. It states that the United States does not recognize President Alexander Lukashenko as the country's legitimate leader.

Central America -- Directs the State Department and USAID to develop a strategy to advance democratic governance, combat corruption, and improve security in El Salvador, Honduras and Guatemala (the so-called "Northern Triangle").

U.S.-Mexico Partnership -- Directs the State Department to develop a strategy to expand educational and professional exchange programs with Mexico.

Gandhi-King Exchange -- Establishes a U.S.-India public-private development foundation and several bilateral exchange initiatives intended to support the study and promotion of the nonviolent protest philosophies and civil rights legacies of Mohandas K. Gandhi and Dr. Martin Luther King Jr.

Miscellaneous Provisions

The agreement also includes numerous other provisions, including those that do the following:

Women's & Latino Museums -- Creates two new museums within the Smithsonian Institution, the Women's History Museum and the National Museum of the American Latino; both to be located on or near the National Mall in Washington, D.C.

E-Cigarette Online Sales -- Requires purchasers of any "electronic nicotine delivery system" to verify their age at the time of delivery, in order to make it harder for minors to purchase e-cigarettes online (except for FDA-approved tobacco cessation products), and prohibits the delivery by U.S. mail of e-cigarettes.

Real ID -- Simplifies the process of applying for a REAL ID by allowing states to accept identity documents that are transmitted electronically and by ending the requirement that separate documentation of Social Security numbers be provided, and allows TSA and other federal agencies to accept mobile or digital drivers licenses or identity cards for identification purposes.

Reduce Improper Payments --Allows the Social Security Administration to share information collected from state death records with the Treasury Department's Do Not Pay Program to reduce the number of improper federal payments to deceased individuals.

Horseracing Oversight -- Establishes a Horseracing Integrity and Safety Authority to develop and administer a national anti-doping, medication control and racetrack safety program.

Promote Advanced Manufacturing -- Directs the Commerce Department and Federal Trade Commission to conduct studies on innovative technologies that can help develop American manufacturing, including artificial intelligence, quantum computing, unmanned delivery systems, and 3D printing.

Financial Sector Cybersecurity -- Directs the Federal Reserve and other federal financial regulators to report to Congress every year for seven years on efforts to strengthen cybersecurity at financial institutions, third-party service providers, and the regulators themselves.

Teddy Roosevelt Library -- Authorizes the U.S. Forest Service to convey 93 acres of land in Billings County, N.D., to establish the Theodore Roosevelt Presidential Library.

Decriminalize Minor 'Crimes' -- Repeals several outdated criminal penalties for violations that do not involve serious wrongdoing such, as unauthorized use of the 4-H Club emblem and the "Smokey Bear" character.

Source: CQ House Action Reports [c]2020 Congressional Quarterly Inc. All Rights Reserved.

Reports - Defence - Europe Security Defense

Publication date: October 6, 2021 18699 mots

- - CJ07-AM-697621_EN.pdf

97 pages

Please note : This extract may not display a well formed paragraph

... AM\1240069EN.docx PE697.621v02-00 EN United in diversity EN European Parliament 2019-2024 Committee on Development Committee on Women’s Rights and Gender Equality 2021/2003(INI) 28.9...

Full report:
https://www.europarl.europa.eu/doceo/document/CJ07-AM-697621_EN.pdf

Reports - Defence - Europe Security Defense

Publication date: October 28, 2020 73922 mots

- - budg2021-doc5-txt-1-en.pdf

151 pages

Please note : This extract may not display a well formed paragraph

... EN EN 2021 BUDGETARY PROCEDURE Doc No: 5: (1) ******* 26.10.2020 COMMITTEE ON BUDGETS RAPPORTEURS: PIERRE LARROUTUROU - SECTION III (COMMISSION) OLIVIER CHASTEL - OTHER SECTIONS PARLIAMENT'S POSITION Amendments which have...

Full report:
https://www.europarl.europa.eu/sed/doc/news/flash/24642/budg2021-doc5-txt-1-en.pdf

Reports - Banks and Financial Institutions - World Bank

Publication date: December 14, 2020 31664 mots

- Bhutan FY21-24 - Bhutan-Country-Partnership-Framework-for-the-Period-FY2021-24.pdf

72 pages

Please note : This extract may not display a well formed paragraph

... Document of The World Bank Group FOR OFFICIAL USE ONLY Report No. 154927-BT INTERNATIONAL BANK FOR RECONSTRUCTION AND DEVELOPMENT INTERNATIONAL DEVELOPMENT ASSOCIATION INTERNATIONAL FINANCE CORPORATION MULTILATERAL INVESTMENT GUARANTEE AGENCY COUNTRY...

Full report:
https://documents1.worldbank.org/curated/en/620541608337280651/pdf/Bhutan-Country-Partnership-Framework-for-the-Period-FY2021-24.pdf

Reports - Defence - Europe Security Defense

Publication date: October 23, 2020 62070 mots

- - budg2021-doc6 (AMs adopted in BUDG)-txt-2-en.pdf

126 pages

Please note : This extract may not display a well formed paragraph

... EN EN 2021 BUDGETARY PROCEDURE Doc No: 6: (2) ******* 23.10.2020 COMMITTEE ON BUDGETS RAPPORTEURS: PIERRE LARROUTUROU - SECTION III (COMMISSION) OLIVIER CHASTEL - OTHER SECTIONS PARLIAMENT'S POSITION Amendments adopted by...

Full report:
https://www.europarl.europa.eu/sed/doc/news/flash/24646/budg2021-doc6 (AMs adopted in BUDG)-txt-2-en.pdf

Rapports - Santé - Santé IPE

Date de publication : 20 octobre 2021 68645 mots

PEI Climate Change Risk Assessment (2021) - pei_ccra_2021.pdf

176 pages

NB : cette extraction brute des 30 premiers mots ne forme peut-être pas un paragraphe bien construit

... 1 Prince Edward Island (PEI) Climate Change Risk Assessment July 27, 2021 FINAL 2 Contents Acknowledgements.............................................................................................................................. 4 Glossary ................................................................................................................................................ 5 Executive Summary ............................................................................................................................. 6 Key Findings ...................................................................................................................................... 7 Conclusions and Next Steps ............................................................................................................. 9 Introduction...

Pour voir le rapport :
https://www.princeedwardisland.ca/sites/default/files/publications/pei_ccra_2021.pdf

Reports - Energy - Natural Resources Canada - Energy

Publication date: October 20, 2021 68644 mots

Online - En ligne (PDF, 4.27 MB) - pei_ccra_2021.pdf

176 pages

Please note : This extract may not display a well formed paragraph

... 1 Prince Edward Island (PEI) Climate Change Risk Assessment July 27, 2021 FINAL 2 Contents Acknowledgements.............................................................................................................................. 4 Glossary ................................................................................................................................................ 5 Executive Summary ............................................................................................................................. 6 Key Findings ...................................................................................................................................... 7 Conclusions and Next Steps ............................................................................................................. 9 Introduction...

Full report:
https://www.princeedwardisland.ca/sites/default/files/publications/pei_ccra_2021.pdf

Reports - Labor and Unions - ILO

Publication date: December 26, 2022 79203 mots

The ILO, a key partner in Post Disaster Needs Assessments (PDNAs) - [pdf 10488KB] - wcms_863195.pdf

196 pages

Please note : This extract may not display a well formed paragraph

... PAKISTAN FLOODS 2022 Post-Disaster Needs Assessment S U P P L E M E N TA L R E P O R T Ministry of Planning Development & Special Initiatives PAKISTAN...

Full report:
http://www.ilo.org/wcmsp5/groups/public/---ed_emp/documents/publication/wcms_863195.pdf

Reports - Risk Management - KPMG

Publication date: November 20, 2020 41712 mots

- Measuring Stakeholder Capitalism - WEF_IBC_Measuring_Stakeholder_Capitalism_Report_2020.pdf

96 pages

Please note : This extract may not display a well formed paragraph

... Measuring Stakeholder Capitalism Towards Common Metrics and Consistent Reporting of Sustainable Value Creation W H I T E P A P E R S E P T E M B E...

Full report:
https://www3.weforum.org/docs/WEF_IBC_Measuring_Stakeholder_Capitalism_Report_2020.pdf

Reports - Risk Management - PricewaterhouseCoopers

Publication date: October 13, 2020 20823 mots

Doing Business in Viet Nam 2020 - Download Doing Business in Viet Nam 2020 - pwc-vietnam-dbg-2020.pdf

96 pages

Please note : This extract may not display a well formed paragraph

... Doing Business in Viet Nam A reference guide for entering the Viet Nam market 2 l Doing Business in Vietnam2 l Doing Business in Vietnam Contents 3 3 3 3 Viet...

Full report:
https://www.pwc.com/vn/en/publications/2020/pwc-vietnam-dbg-2020.pdf

Reports - Banks and Financial Institutions - World Bank

Publication date: October 3, 2023 15316 mots

- How to Protect, Build, and Use Human Capital to Address Climate Change - HCP-Policy-Brief-2023.pdf

32 pages

Please note : This extract may not display a well formed paragraph

... HOW TO PROTECT, BUILD, AND USE HUMAN CAPITAL TO ADDRESS CLIMATE CHANGE Photo credits: Cover: Pixdeluxe / istockphoto.com Page 08: Dominic Chavez / World Bank Page 09: Dominic Chavez / World Bank Page...

Full report:
https://thedocs.worldbank.org/en/doc/d536428f48dcca74af65417125444da5-0140062023/original/HCP-Policy-Brief-2023.pdf

Reports - Think Tanks - C. D. Howe Institute

Publication date: December 1, 2020 14539 mots

The Next Wave: Automation and Canada's Labour Market - - Commentary_585.pdf

40 pages

Please note : This extract may not display a well formed paragraph

... Institut C.D. HOWE Institute commentary NO. 585 The Next Wave: Automation and Canada’s Labour Market An updated estimate shows about one in five Canadians are at high risk of...

Full report:
https://www.cdhowe.org/sites/default/files/attachments/research_papers/mixed/Commentary_585.pdf

Reports - Think Tanks - C. D. Howe Institute

Publication date: December 1, 2020 14538 mots

The Next Wave: Automation and Canada's Labour Market - - Commentary_585_0.pdf

40 pages

Please note : This extract may not display a well formed paragraph

... Institut C.D. HOWE Institute commentary NO. 585 The Next Wave: Automation and Canada’s Labour Market An updated estimate shows about one in five Canadians are at high risk of...

Full report:
https://www.cdhowe.org/sites/default/files/attachments/research_papers/mixed/Commentary_585_0.pdf

Reports - Defence - Europe Security Defense

Publication date: October 22, 2020 36076 mots

- - A-9-2020-0197_EN.pdf

95 pages

Please note : This extract may not display a well formed paragraph

... RR 1216571EN.docx PE650.700v02-00 EN United in diversity EN European Parliament 2019-2024 Plenary sitting A9-0197/2020 22.10.2020 REPORT on a New Industrial Strategy for Europe...

Full report:
https://www.europarl.europa.eu/doceo/document/A-9-2020-0197_EN.pdf

Reports - Banks and Financial Institutions - World Bank

Publication date: October 29, 2021 24607 mots

Putting People at the Heart of Green, Resilient, and Inclusive Recovery - Report: Human Capital Project Year-3 Progress Report - Human-Capital-Project-Year-3-Progress-Report.pdf

37 pages

Please note : This extract may not display a well formed paragraph

... PROTECT AND INVEST in people YEAR 3 PROGRESS REPORT P ub lic D is cl os ur e A ut ho riz ed P ub lic D is cl os ur...

Full report:
https://documents1.worldbank.org/curated/en/152711635786365470/pdf/Human-Capital-Project-Year-3-Progress-Report.pdf

Reports - Banks and Financial Institutions - World Bank

Publication date: December 8, 2021 68123 mots

- English - Bulgaria-Systematic-Country-Diagnostic.pdf

161 pages

Please note : This extract may not display a well formed paragraph

... P ub lic D is cl os ur e A ut ho riz ed P ub lic D is cl os ur e A ut ho riz ed P ub lic...

Full report:
http://documents.worldbank.org/curated/en/727791642521506054/pdf/Bulgaria-Systematic-Country-Diagnostic.pdf

Reports - Defence - Europe Security Defense

Publication date: November 3, 2020 36777 mots

- PDF (464 KB) - A-9-2020-0206_EN.pdf

110 pages

Please note : This extract may not display a well formed paragraph

... RR 1217280EN.docx PE658.989v02-00 EN United in diversity EN European Parliament 2019-2024 Plenary sitting A9-0206/2020 Part 1 3.11.2020 REPORT on the Council position on...

Full report:
https://www.europarl.europa.eu/doceo/document/A-9-2020-0206_EN.pdf

Reports - Defence - Europe Security Defense

Publication date: October 23, 2020 50330 mots

- - budg2021-doc6 (AMs adopted in BUDG)-txt-1-en.pdf

124 pages

Please note : This extract may not display a well formed paragraph

... EN EN 2021 BUDGETARY PROCEDURE Doc No: 6: (1) ******* 23.10.2020 COMMITTEE ON BUDGETS RAPPORTEURS: PIERRE LARROUTUROU - SECTION III (COMMISSION) OLIVIER CHASTEL - OTHER SECTIONS PARLIAMENT'S POSITION Amendments adopted by...

Full report:
https://www.europarl.europa.eu/sed/doc/news/flash/24645/budg2021-doc6 (AMs adopted in BUDG)-txt-1-en.pdf

Reports - Banks and Financial Institutions - World Bank

Publication date: November 8, 2021 39141 mots

- Bangladesh - Bangladesh-Systematic-Country-Diagnostic-2021-Update.pdf

77 pages

Please note : This extract may not display a well formed paragraph

... Report No: 165362-BD Bangladesh Systematic Country Diagnostic 2021 Update November 8, 2021 P ub lic D is cl os ur e A ut ho riz ed P ub lic D...

Full report:
https://documents1.worldbank.org/curated/en/178451636728252454/pdf/Bangladesh-Systematic-Country-Diagnostic-2021-Update.pdf

Reports - Banks and Financial Institutions - World Bank

Publication date: November 22, 2023 39926 mots

- West Bank & Gaza Climate and Development Report - P179452029863f0e80a902031b18e72860c.pdf

84 pages

Please note : This extract may not display a well formed paragraph

... iWest Bank and Gaza Country Climate and Development Report West Bank and Gaza World Bank Group MIDDLE EAST AND NORTH AFRICA September 2023 P ub lic D is cl os ur...

Full report:
https://documents1.worldbank.org/curated/en/099112823094030933/pdf/P179452029863f0e80a902031b18e72860c.pdf

Reports - Banks and Financial Institutions - World Bank

Publication date: October 11, 2023 37542 mots

- Download: 2022 Joint Report on Multilateral Development Banks' Climate Finance - 2023-MDB-Report-2022.pdf

100 pages

Please note : This extract may not display a well formed paragraph

... 2 0 2 2 JOINT REPORT ON MULTILATERAL DEVELOPMENT BANKS’ C L IM A T E F IN A N C E 2022 JOINT REPORT ON MULTILATERAL DEVELOPMENT BANKS’ CLIMATE FINANCE...

Full report:
https://thedocs.worldbank.org/en/doc/3f11c64b507195dee3f9604898a60219-0020012023/original/2023-MDB-Report-2022.pdf

Reports - Defence - Europe Security Defense

Publication date: October 12, 2021 43243 mots

- PDF (501 KB) - A-9-2021-0281_EN.pdf

123 pages

Please note : This extract may not display a well formed paragraph

... RR\1241063EN.docx PE696.541v02-00 EN United in diversity EN European Parliament 2019-2024 Plenary sitting A9-0281/2021 Part 1 12.10.2021 REPORT on the Council position on...

Full report:
https://www.europarl.europa.eu/doceo/document/A-9-2021-0281_EN.pdf

Rapports - Santé - Santé Canada

Date de publication : 28 octobre 2020 61094 mots

Télécharger en format PDF - cpho-covid-report-fra.pdf

88 pages

NB : cette extraction brute des 30 premiers mots ne forme peut-être pas un paragraphe bien construit

... Rapport de l’administratrice en chef de la santé publique du Canada sur l’état de la santé publique au Canada 2020 Du risque à la résilience : UNE APPROCHE AXÉE SUR...

Pour voir le rapport :
https://www.canada.ca/content/dam/phac-aspc/documents/corporate/publications/chief-public-health-officer-reports-state-public-health-canada/from-risk-resilience-equity-approach-covid-19/cpho-covid-report-fra.pdf
CQ House Action Reports
Monday, July 26, 2021 41784 mots, p. NA

Fact Sheet No. 117-13: July 26, 2021 - Seven-Bill FY 2022 Appropriations Package.

Seven-Bill FY 2022 Appropriations Package

This Fact Sheet describes HR 4502, Initial FY 2022 Appropriations Minibus, which the House will begin considering on Tuesday.

The Democratic bill comprises seven of the 12 annual spending bills reported by the Appropriations Committee: Agriculture, Energy-Water, Financial Services, Interior, Labor-HHS-Education, Military Construction-VA, and Transportation-HUD.

The first FY 2022 appropriations measure to be considered by the House, it provides a total of $602.9 billion in scored discretionary funding, including $597.4 billion subject to discretionary caps and three categories of funding subject to their own cap adjustments: $2.54 billion for program integrity initiatives; $2.45 billion for wildfire suppression; and $143 million for disaster aid. Republicans oppose the measure because of its spending levels and its inclusion of numerous policy provisions.

The Rules Committee has made in order 229 amendments. Descriptions of those amendments will be included in the House Action Reports Legislative Day.

Section I

Background & Summary

Over the past decade, the ability of Congress to enact annual appropriations bills has been dictated by the 2011 Budget Control Act (BCA; PL 112-25), which was enacted as a result of a partisan showdown over increasing the statutory debt limit. In return for raising the debt limit, the BCA imposed statutory caps on discretionary spending over 10 years, caps which under that law were tightened further for both defense and non-defense spending after Congress was unable to reach a further agreement to reduce federal deficits.

The BCA's lower, sequester-reduced caps for defense and non-defense spending quickly became politically unpalatable to both parties -- particularly after March 2013 when automatic across-the-board cuts were made to much of FY 2013 discretionary spending to comply with the BCA's reduced caps. Congress in late 2013 subsequently enacted a two-year deal to partially roll back those caps, which eventually resulted in a series of two-year bipartisan deals to prevent painful cuts to both defense and non-defense and thereby enable eventual enactment of annual appropriations bills.

The last such deal was enacted in 2019 for FY 2020 and FY 2021 -- the current fiscal year, and the last year for BCA caps. For FY 2022 which begins Oct. 1, there are no statutory caps in place. And because the BCA caps will have expired there is also currently no motivating factor for the two parties to negotiate an agreement on spending levels for the coming fiscal year.

Current Situation

With Democrats in the 2020 elections gaining control of both Congress and the White House, they have felt emboldened to push for their priorities -- particularly with regard to spending -- despite their narrow margins of control.

President Biden in May released a FY 2022 budget that proposed $1.5 trillion in discretionary spending, with a 1.6% increase for defense programs and a 16.5% increase for non-defense. House Democrats in June paved the way for consideration of FY 2022 spending bills by adopting a "deeming" resolution (H Res 467) that set a top-line FY 2022 discretionary spending cap of $1.5 trillion (the resolution was automatically adopted by the House when an unrelated floor rule for other legislation was adopted).

Appropriations Action

Democratic House appropriators subsequently allocated that $1.5 trillion among the 12 annual appropriations bills consistent with the president's defense/non-defense split, and the House Appropriations Committee reported all 12 spending bills at those levels. Republicans have objected to the meager increase for defense compared to the increases for domestic spending, as well as to the policy provisions included in the bills.

Congressional Democrats this year also made two modifications to the appropriations process. For defense spending, they have eliminated the Overseas Contingency Operations (OCO) category of spending. OCO was supposed to be used for unexpected war costs and was therefore exempt from discretionary caps, but since being created after 9/11 it was increasingly used to circumvent annual budget caps to provide additional regular funding to the Pentagon and for other purposes.

They have also reinstituted the practice of allowing members to include spending earmarks in appropriations bills. As reported by House Appropriations, all but two bills (Legislative Branch and State-Foreign Operations) include earmarks.

House Democrats are bringing a number of their FY 2022 appropriations bills to the House floor to set markers for their spending priorities. In the Senate, where 60 votes would be needed to "deem" a discretionary spending cap in the absence of a final budget resolution adopted by both chambers, Democrats have yet to mark up any FY 2022 spending bills.

Floor Situation

The Biden White House on Monday announced its support for the bill. The recommended rule for the measure makes in order 229 amendments to the seven bills in the package. Descriptions of those amendments will be included in the House Action Reports Legislative Day for the days the measure is considered on the House floor.

Executive Summary of HR 4502

The floor rule for the bill, upon the rule's adoption, will automatically modify the bill to incorporate a manager's amendment by Appropriations Chairwoman Rosa DeLauro, D-Conn. This Fact Sheet reflects modifications made by the manager's amendment.

The bill consists of seven FY 2022 appropriations measures -- Agriculture, Energy and Water Development, Financial Service and General Government, Interior-Environment, Labor-HHS-Education, Military Construction-Veterans Affairs, and Transportation-Housing and Urban Development -- that combined provide a total of $602.9 billion in scored discretionary funding for FY 2022.

According to CBO, the total includes $597.4 billion subject to discretionary caps, as well as three categories of funding subject to their own cap adjustments: $2.54 billion for program integrity initiatives; $2.45 billion for wildfire suppression; and $143 million for disaster aid.

The seven bills include a total of 2,435 earmarks for projects in members' districts that total $3.33 billion.

Agriculture

The bill provides $26.55 billion in net discretionary funding subject to caps, $2.85 billion (12%) more than comparable FY 2021 funding (i.e., excluding FY 2021 emergency funding) but 1% less than requested. It also provides $170.2 billion in mandatory spending for programs such as food stamps and crop insurance -- thereby providing a total of $196.7 billion in net scored funding for FY 2022, 4% less than the comparable FY 2021 total. In addition, it authorizes up to $56.5 billion in loans for farmers and rural development programs.

Total "programmatic" funding that would be available to the bill's agencies equals $199.8 billion, $9.4 billion less than comparable FY 2021 amounts.

The bill provides a 48% increase for USDA rural development programs, including across the board increases for rural housing, rural infrastructure and utilities, and rural business development. It also increases funding for USDA research components by 10%, while also increasing funding for agricultural marketing activities (4% more), animal and plant health (5% more), and food safety inspection (7% more). It decreases funding for farm production and conservation programs by 11%. Additionally, the bill increases total funding for the Food and Drug Administration by 5%.

It provides $139.7 billion for domestic food programs (4% less than FY 2021), including $105.8 billion for the Supplemental Nutrition Assistance Program (SNAP; formerly known as food stamps), $26.9 billion for child nutrition programs (both mandatory spending), and $6.0 billion (equal to FY 2021) in discretionary funding for the Special Supplemental Nutrition Program for Women, Infants and Children (WIC). Funding for international food assistance programs would increase by 1%.

According to Democratic appropriators, the bill's total includes $347 million across the Agriculture Department for efforts to address the impacts of climate change.

The measure includes 111 member earmarks worth $195 million.

Energy & Water Development

The bill provides $53.2 billion in net discretionary spending subject to caps, $1.5 billion more than FY 2021 funding. On a programmatic basis after certain offsets and scorekeeping adjustments are factored out, however, the measure actually provides more than $56.5 billion for the agencies funded by the bill.

It provides $45.1 billion for the Energy Department -- 14% more than FY 2021 funding. That total includes $15.5 billion for weapons activities (1% more than FY 2021), and $2.3 billion for nuclear nonproliferation activities (3.5% more). It increases funding for science and climate-control activities, including $7.3 billion for science activities (4% more than FY 2021); energy efficiency and renewable energy programs increase by 32%, and Advanced Research Projects Agency-Energy (ARPA - E) by 41%. The measure provides $55 million for the department to respond to the SolarWinds hack of its systems.

For water project activities of the Army Corps of Engineers, the measure provides $8.7 billion, 11% more than FY 2021. It increases Corps' funding for its operation and maintenance activities by 25%, but reduces funding for construction activities by 4%. The measure provides $2.0 billion for activities of the Interior Department's Bureau of Reclamation (16% more than FY 2021), with the vast majority of the increased funding level to be used for the agency's water and related resources activities (an 18% increase).

The measure includes 108 member earmarks worth $351 million.

Financial Service & General Government

The bill provides $28.5 billion in net discretionary spending subject to caps along with cap adjustments of $417 million for IRS enforcement activities and $143 million for SBA disaster relief -- thereby providing a total of $29.1 billion in scored discretionary funding for FY 2022, 20% more than comparable FY 2021 funding.

However, it also assume $13.2 billion in offsetting collections that offset certain agency spending (so such spending doesn't count against scored discretionary spending), meaning the agencies funded by the bill would receive about $41.6 billion in programmatic discretionary funding for FY 2022. The measure also includes $22.6 billion in mandatory funding, including salaries for federal judges and contributions for federal employee retirement and health benefits.

The measure increases funding for both the Treasury Department and IRS by 14%, including additional funds to improve IRS tax collection and enforcement. It increases funding for the federal court system by 5%, for the Executive Office of the President by 11%, and for the federal payment to the District of Columbia by 6% while ending certain restrictions on how the District can use both appropriated and its own funds.

It provides a 15% increase for General Service Administration (GSA) building construction, repairs and operations -- along with a separate $300 million for GSA to begin procuring electric and zero emission vehicles for the federal fleet. It significantly increases funding for a number of independent federal agencies, including the Federal Trade Commission (11%), the National Archives and Records Administration (15%), and the Consumer Product Safety Commission (27%). It increases Small Business Administration funding by 12%.

The bill eliminates prior prohibitions on the use of funds for abortions, including under federal employee health plans and with respect to both local and federal funds received by the District of Columbia. It also makes DACA recipients eligible for federal employment.

The measure includes 55 member earmarks worth $32 million.

Interior-Environment

The bill provides $43.4 billion in net discretionary spending subject to budget caps along with $2.45 billion subject to its own fire suppression cap adjustment -- thereby providing a total of $45.85 billion in scored discretionary spending for FY 2022, 19% more than comparable FY 2021 funding. The measure also includes $64 million in mandatory funding.

It increases funding for EPA by 23% to $11.3 billion, including a 26% increase for scientific and regulatory work on toxic PFAS ("forever chemicals") needed to establish drinking water and cleanup standards. It provides an eight-fold increase for environmental justice activities, including the creation of six grant programs to begin implementing environmental justice "solutions." It also increases Interior Department funding by 17% to $15.6 billion, with all the major agencies receiving increases, and it takes some initial steps towards creation of a Civilian Climate Corps.

The measure also significantly increases funding for American Indian programs administered by the Bureau of Indian Affairs (14% more than FY 2021) and the Indian Health Service (30% more) -- in part to address severe health care deficiencies that were exposed by the COVID-19 pandemic.

The measure includes 308 member earmarks worth $445 million.

Labor-HHS-Education

The bill provides $237.5 billion in discretionary spending subject to spending caps as well as $2.1 billion subject to cap adjustments for program integrity initiatives for a total of $239.6 billion in scored discretionary spending. (On a programmatic basis the agencies funded by the bill would actually have $254.3 billion available for their use in FY 2022, $54.2 billion (27%) more than FY 2021.) It also provides $1.088 trillion in mandatory spending for Medicaid grants to states, Social Security Supplementary Security Income benefit payments, and other purposes.

It increases HHS discretionary spending by 24% to $119.8 billion, with major increases for public health (21%), the CDC (34%), and NIH (15%) including a 26% increase for the National Institute on Drug Abuse and $3.0 billion for a new initiative, Advanced Research Projects Agency for Health (ARPA - H). It increases funding the Substance Abuse and Mental Health Administration by 52% and for the Child Care Development Block Grant by 25%. It also ends two long-term restrictions on abortions: the Hyde amendment that generally prohibits the use of federal funds for abortions, and the Weldon amendment that prohibits the government from discriminating against health care professionals or entities that don't provide for abortions.

The measure increases Education Department spending by 38% to $106.5 billion -- more than doubling funding for Title I grants, increasing special education programs by 22%, increasing by 44% aid to higher education institutions that primarily serve minority populations, increasing national school safety activities eight-fold, and increasing the maximum Pell Grant by $400 to $6,895.

For the Labor Department, it increases spending by 17% to $14.7 billion -- with a 20% increase to job training and employment services under the Workforce Investment Act, a 17% increase for OSHA, and a 22% increase for state unemployment insurance and employment service operations.

The measure includes 861 member earmarks worth $675 million.

Military Construction-VA

The bill provides a total of $124.5 billion in discretionary funding subject to caps and $155.4 billion in mandatory funding for VA benefits and health care -- thereby providing a total of $279.9 billion for the year, 11% more than the FY 2021 level. The discretionary total for FY 2022 is 10% more than comparable FY 2021 funding.

Overall funding available for FY 2022 includes $239.5 billion in advance discretionary and mandatory VA appropriations provided by prior-year appropriations laws; the bill includes $267.9 billion in advance VA appropriations for FY 2023.

The measure provides a total of $10.9 billion for military construction activities, 35% more than FY 2021 and 11% more than requested. Of that total, $972 million is for military construction projects that were not included in the president's request, but which are part of each military service's "unfunded priority list" for FY 2022 or are near completion. It includes no Overseas Contingency Operations (OCO) funding; appropriators have eliminated that category of spending and instead provide all funding through regular accounts.

For the VA the bill provides a total of $268.6 billion for FY 2022 -- including $113.1 billion in discretionary funding for health care and other services and $155.4 billion in mandatory spending for veterans pensions and benefits. The discretionary total is 8% more than FY 2021. It increases VA health care spending by 8% to $97.6 billion, with increases for VA mental health care (28% more), VA opioid abuse care (32% more), and the VA Community Care account (26% more), through which medical care is to be provided to veterans outside the VA's medical network pursuant to the 2018 MISSION Act.

The measure includes 11 member earmarks worth $199 million.

Transportation-Housing and Urban Development

The bill provides $84.1 billion in net discretionary spending subject to caps, 12.6% more than comparable FY 2021 funding (i.e., excluding FY 2021 emergency funding) and 1% more than requested. It also provides for the release of $78.6 billion from the highway and aviation trust funds -- thereby providing a total of $162.6 billion in scored budgetary resources for FY 2022, 19.5% more than FY 2021.

On a programmatic basis, after certain scorekeeping adjustments that offset spending are factored out, the bill actually provides a total of $174.4 billion for use in FY 2022, 18% more than the comparable FY 2021 total.

It provides $105.7 billion for the Transportation Department, 22% more than FY 2021. It significantly increases funding for federal highway programs (27%), transit (19%), motor carrier safety (18%), traffic safety (30%), and for discretionary infrastructure grants (RAISE, previously known as BUILD and TIGER grants; 20%). In increases funding for the Federal Railroad Administration by 46%, including a 35% increase for Amtrak while replacing the railroad state of good repair grant program with a new PRIME grant program to expand passenger rail with triple the funding.

For HUD it provides $56.5 billion in scored funding, 14% more than FY 2021 (and a total of $68.2 billion in programmatic funding). It significantly increases funding for most housing programs, including tenant-based housing aid (by 13%) and public housing (11%), housing for the elderly (21%) and disabled (55%), and Community Development Block Grants (35%) and the HOME program (37%). It increases funding for HUD homeless assistance programs by 14%, and includes $1.0 billion for a new program to provide housing vouchers to the homeless.

The measure includes 981 member earmarks worth $1.4 billion.

References: The Appropriations Committee reported all seven of the spending bills that comprise this measure with minority views, as follows:

Agriculture, by voice vote (HR 4356; H Rept 117-82)

Energy and Water Development, by a 33-24 vote (HR 4549; H Rept 117-98)

Financial Service and General Government, by a 33-24 vote (HR 4345; H Rept 117-79)

Interior-Environment, by 32-24 vote (HR 4372; H Rept 117-83)

Labor-HHS-Education, by 33-25 vote (HR 4502; H Rept 117-96)

Military Construction-VA, by a 33-24 vote (HR 4355; H Rept 117-81)

Transportation-Housing and Urban Development, by a 33-24 vote (HR 4550; H Rept 117-99)

UPDATES / CORRECTIONS:

This Fact Sheet was updated on July 28 to correct the FY 2022 limitation on the expenses of the Farm Credit Administration, which is $84 million.

By Greg Tourial [email protected]

Section II

Agriculture

This section describes the provisions of HR 4502, Seven-Bill FY 2022 Appropriations Package, that provide funding for the Agriculture Department, the Food and Drug Administration, and related federal agencies. (These provisions were reported by the Appropriations Committee as HR 4356, Agriculture, Rural Development, Food and Drug Administration, and Related Agencies Appropriations for FY 2022.)

The bill provides $26.55 billion in net discretionary funding subject to caps, $2.85 billion (12%) more than comparable FY 2021 funding (i.e., excluding FY 2021 emergency funding) but 1% less than requested. It also provides $170.2 billion in mandatory spending for programs such as food stamps and crop insurance -- thereby providing a total of $196.7 billion in net scored funding for FY 2022, 4% less than the comparable FY 2021 total. In addition, it authorizes up to $56.5 billion in loans for farmers and rural development programs, an 18% increase.

(Total "programmatic" funding that would be available to the bill's agencies equals $199.8 billion, $9.4 billion less than comparable FY 2021 amounts -- with $225 million offset by rescissions and more than $2.8 billion from offsetting collections and user fees.)

The bill provides a 48% increase for USDA rural development programs, including across the board increases for rural housing, rural infrastructure and utilities, and rural business development. It also increases funding for USDA research components by 10%, while also increasing funding for agricultural marketing activities (4% more), animal and plant health (5% more), and food safety inspection (7% more). It decreases funding for farm production and conservation programs by 11%. Additionally, the bill increases total funding for the Food and Drug Administration by 5%.

It provides $139.7 billion for domestic food programs (4% less than FY 2021), including $105.8 billion for the Supplemental Nutrition Assistance Program (SNAP; formerly known as food stamps), $26.9 billion for child nutrition programs (both mandatory spending), and $6.0 billion (equal to FY 2021) in discretionary funding for the Special Supplemental Nutrition Program for Women, Infants and Children (WIC). Funding for international food assistance programs would increase by 1%.

According to Democratic appropriators, the bill's total includes $347 million across the Agriculture Department for efforts to address the impacts of climate change, including research on climate monitoring, developing new climate-friendly agricultural practices, efforts to reduce greenhouse gas emissions, and developing new clean energy technologies.

The measure includes 111 earmarks for projects in members' districts that total $195 million -- including $112 million for 86 rural community facility projects, $37 million for 19 rural broadband expansion projects, and $47 million for six agricultural research facilities.

Agriculture, Farm Production & Conservation Programs

The bill provides $38.5 billion for USDA farm support and conservation programs, including mandatory funds to reimburse federal crop insurance and Commodity Credit Corporation (CCC) activities. The total is $4.9 billion (11%) less than FY 2021 and slightly less than requested.

Within the total, $238 million is provided for the Farm Production and Conservation Business Center, a centralized operations office that provides administrative support to USDA component agencies and programs in this mission area. Another $60 million is transferred from the CCC, for a total operating budget of $298 million (2% more than FY 2021).

Corporations / Federal Crop Insurance

The Commodity Credit Corporation (CCC) is a government-owned entity, largely existing on paper, that provides financing for most major USDA-administered commodity support programs, including marketing assistance loans, loan deficiency payments, and fixed (direct) payments to farmers. The CCC is authorized each year to receive appropriations to reimburse the previous fiscal year's "net realized losses," or any losses that the corporation cannot recoup or offset through other means. The amounts needed to reimburse the CCC vary widely from year to year, depending on crop market prices and other factors.

The measure provides an estimated $25.9 billion ($5.9 billion, or 19%, less than FY 2021 levels) to reimburse the CCC for expenditures incurred in previous fiscal years to finance farm price supports, export promotion, disposition of surplus commodities and other programs.

The Federal Crop Insurance Corporation is another government-owned corporate entity, managed by the Agriculture Department's Risk Management Agency, that provides crop insurance protection to farmers and other agricultural entities. The committee estimates the bill would provide the requested $9.7 billion for crop insurance, $912 million (10%) more than FY 2021. Separately, the bill appropriates $67 million (11% more) for the Risk Management Agency to administer the federal crop insurance program.

Farm Service Agency

The Farm Service Agency (FSA) administers the commodity programs financed by the CCC and several loan programs, including farm operating and farm ownership loans. The bill provides a total of $1.5 billion for FSA salaries and expenses, including a direct appropriation of $1.2 billion and $294 million in transfers from other program accounts administered by the agency. The overall funding is 2% more than FY 2021.

It also provides $6.9 million for state mediation grants and $6.5 million for the grassroots source water protection program (both equal to FY 2021). The bill provides an estimated $500,000 for the Dairy Indemnity Program, and the committee, in its report, directs the department to expand the program to cover dairy farms that are unable to sell their milk due to contamination from so-called per- and polyfluoroalkyl substances (PFAS, also known as "forever" chemicals).

Separately, the measure provides $3 million for a program that helps reimburse farmers and agricultural producers in Hawaii, Alaska, or U.S. insular territories for the extra costs of transporting commodities and supplies.

FSA Farm Loans

The Farm Service Agency, using the Agricultural Credit Insurance Fund (ACIF), offers a variety of loans to farmers. The measure provides $315 million for ACIF administrative expenses (2.5% more than FY 2021), although $294 million of this amount is transferred for FSA salaries and expenses. The bill appropriates $62 million in up-front subsidies (9% less than FY 2021) to support an overall loan level of $10.4 billion -- $528 million (5%) more than FY 2021.

The vast majority (97%) of the overall loan level for FY 2022 would go toward farm ownership loans that help farmers acquire, enlarge or develop their lands, and farm-operating loans that help pay for essential expenses such as the purchase of livestock, equipment and seed. Specifically, the measure sets the requested total loan level of $3.8 billion for farm-operating loans (equal to FY 2021), including $1.6 billion in direct loans and $2.1 billion in unsubsidized loan guarantees. For farm ownership loans, the loan level is set at the requested $6.3 billion ($500 million more than FY 2021), including $2.8 billion in direct loans and $3.5 billion in loan guarantees.

As requested, the bill also maintains FY 2021 loan levels for Indian tribe land acquisition ($20 million), conservation loan guarantees ($150 million), boll weevil eradication ($60 million), emergency loans ($38 million), and for a loan program that assists Indian tribes and tribal members obtain capital to purchase fractionated land titles ($5 million). It sets a $61 million loan limit (82% more than FY 2021) for a relending program established in the 2018 Farm Bill (PL 115-334) that provides loans to intermediary lenders to help resolve ownership and succession on farmland with multiple owners.

Conservation Programs

The Natural Resources Conservation Service (NRCS) administers a number of conservation programs that help private landowners reduce erosion, improve soil and water quality and quantity, improve and conserve wetlands, and enhance fish and wildlife habitat. Most of these programs are authorized by various Farm Bills and receive mandatory funding through the Commodity Credit Corporation (CCC), while others receive discretionary funding through the annual appropriations process.

The measure provides a total of $1.1 billion for NRCS discretionary programs and activities, 5% more than FY 2021 but 3% less than requested. Within the total, $895 million is for NRCS conservation operations (7% more than FY 2021) including $760 million for general conservation technical assistance, $84 million for the soil survey program, $14.5 million for the snow survey and water forecasting program, $11.5 million for the Plant Materials Centers, $10 million is for the Healthy Forests program, and $9.5 million is for the NRCS Office of Urban Agriculture.

The total also provides $160 million (9% less than FY 2021) for the watershed and flood prevention operations program and $10 million (equal to FY 2021) for the watershed rehabilitation program.

Agricultural Research, Inspections, and Marketing

The bill provides a net total of $8.2 billion for Agriculture Department farm inspection and food safety activities, farming and agricultural research and education, agricultural marketing programs, and departmental administration (9% more than FY 2021).

Safety & Inspection Activities

Animal & Plant Health Inspection Service

The Animal and Plant Health Inspection Service (APHIS) conducts inspection and quarantine activities to protect animals and plants from diseases and pests. The bill provides $1.1 billion for APHIS -- 5% more than FY 2021 and 2% more than requested.

Within the APHIS total, the measure provides $382 million for animal health activities, $388 million for plant health, $140 million for wildlife services, $36 million for regulatory services, $44 million for emergency management, $43 million for safe trade, and $35 million for animal welfare.

Food Safety & Inspection Service

The bill provides $1.2 billion for the Food Safety and Inspection Service, which enforces laws requiring meat and poultry products to be wholesome, unadulterated and properly packaged and labeled (7% more than FY 2021 but slightly less than requested). According to appropriators, the funding will support more than 8,700 food safety inspectors nationwide.

Agricultural Research & Education

The measure provides $3.7 billion for various USDA agencies that conduct farming and agricultural research and education.

The total includes a one-time appropriation of $2 million for the Office of the Chief Scientist to begin organizing and hiring management for the Agriculture Advanced Research and Development Authority (AGARDA) -- a USDA research initiative to conduct food science research modeled on the Defense Advanced Research Projects Agency (DARPA). AGARDA was authorized as part of the 2018 Farm Bill.

In its report, the committee expresses concern that the Economic Research Service and the National Institute of Food and Agriculture, both of which the Trump Administration moved from the Washington, D.C. area to Kansas City in 2019, remain understaffed as a likely result of the move. The committee urges the department to prioritize actions that would restore these agencies to their full employment levels.

Agricultural Research Service

The Agricultural Research Service (ARS) conducts basic and applied research in a number of fields, including animal, plant, soil, water and air sciences; entomology; agricultural engineering; nutrition; consumer use; marketing; and eradication of narcotic-producing plants.

The measure provides $1.6 billion for ARS operations and expenses, 10% more than FY 2021 but 11% less than requested.

It provides another $127 million for ARS buildings and facilities, nearly $91 million more than FY 2021. Within that funding, $47 million is earmarked for six specified agricultural research facilities.

National Institute of Food & Agriculture

The measure appropriates $1.7 billion for the National Institute of Food and Agriculture (NIFA) -- 5% more than FY 2021 but 15% less than requested. The institute works in partnership with universities to advance research, extension activities and higher education in the food, agricultural, human and environmental sciences. Extension activities refer to Agriculture Department instructions, demonstrations and publications relating to agricultural practices and home economics, and other education activities in communities.

Within the total, it provides $1.1 billion (7% more than FY 2021) for NIFA's research and education activities, including: $450 million for the agriculture and food research initiative; $265 million for the Hatch grant program; $93 million for research; $29 million for grants; $10 million for scholarships at 1890 institutions (i.e. historically black land-grant universities); $38 million for the McIntyre-Stennis Cooperative Forestry Act; and $50 million for sustainable agriculture research and education.

The NIFA total also includes $553 million for NIFA extension activities (3% more than FY 2021) and $40 million (3% more) for integrated activities.

Separately from the baseline appropriation, the measure provides an additional $10 million to support NIFA centers of excellence at partner colleges and universities, $6 million to establish a Farm of the Future testbed and demonstration site within the land-grant university system, and $5 million for a pilot program to provide grants to nonprofit organizations for programs that create farming and ranching opportunities for veterans.

Other Research Agencies

The bill provides $189 million (3% more than FY 2021) for the National Agricultural Statistics Service, which conducts hundreds of surveys every year and prepares reports covering virtually every aspect of U.S. agriculture. Within the total, $47 million is allocated for the Census of Agriculture.

It also provides $89 million (3.6% more) to the Economic Research Service (ERS), which conducts research programs to inform public and private decision-making on economic and policy issues involving food, farming, natural resources and rural development.

Agricultural Marketing Service

The Agricultural Marketing Services (AMS) administers programs that promote the domestic and international marketing of U.S.-grown crops and commodities, including cotton, tobacco, poultry, dairy, fruits and vegetables, and livestock. AMS administers regulatory standards and testing for covered commodities, oversees marketing agreements and orders, and administers research and promotion programs. The agency also purchases many of the agricultural commodities distributed by USDA food and nutrition programs.

The bill provides $1.7 billion for the agency (4% more than FY 2021 and 0.4% more than requested) -- including $223 million for marketing services (18.5% more than FY 2021) and $62 million in administrative expenses (which are fully offset by collected fees).

The total also includes $1.4 billion in so-called "Section 32" funds, which are derived from the prior calendar year's customs receipts and used by the Agriculture Department to purchase surplus agricultural commodities that are not covered by other USDA farm support programs; these commodities are typically used to provide food for USDA nutrition assistance programs, including school lunch programs.

Of the $1.4 billion (which is treated as mandatory spending) $485 million is allocated for "entitlement" commodity purchases for school lunch programs; $393 million is for fruit, vegetable, and nut purchases; $443 million is contingency funding for estimated future needs; and $58 million is for administrative expenses. (Another $20.0 billion from the Section 32 account is transferred to the Food and Nutrition Service for Child Nutrition Programs.)

Department Administration

For Agriculture Department administration, the measure appropriates $632 million -- 32% more than FY 2021 and 1% more than requested -- including $65 million for the Office of the Secretary (38% more than FY 2021); $181 million for buildings and facilities (67% more); $85 million for the chief information officer (27% more); $61 million for the office of general counsel (34% more); and $35 million for the Civil Rights Office (55% more).

The bill also provides a separate $25 million to continue relocating USDA employees out of the Goodfellow Federal Center in St. Louis, due to environmental hazards at the site.

Rural Housing & Development

The Agriculture Department administers a number of loan and grant programs to provide assistance in rural areas for single and multifamily housing, community facilities and infrastructure, and business development. The bill includes $4.7 billion for the department's rural development activities -- $1.5 billion (48%) more than FY 2021 and 2% more than requested. Within the total, $798 million is for salaries and expenses, including a direct appropriations of $248 million (32% more); the remainder is provided via transfer from other rural development accounts.

The measure also authorizes a $46.1 billion overall loan level for various rural development loans, 21% more than FY 2021.

Rural Housing Service

The Agriculture Department's Rural Housing Service helps rural residents and communities by providing loans to construct, repair or improve affordable housing and farm facilities, as well as rental assistance to help low-income families. The measure appropriates a total of $2.4 billion for the Rural Housing Service (11% more than FY 2021 and 10% more than requested). Provided funding would support a total loan level of $35.3 billion ($6.7 billion more) for housing and community facility loans.

Within the total, $95 million is for up-front subsidies and technical assistance grants to support $31.8 billion in loans for the Rural Housing Insurance Fund -- including $31.5 billion in loans and guarantees for single-family homes (26% more than FY 2021). Other support would be at FY 2021 levels, including $230 million in loan guarantees for multi-family rental properties, $40 in rental housing loans, $28 million in single-family home repair loans, and $28 million for farm labor housing loans. The measure also provides $15 million for farm labor housing grants (50% more than FY 2021), $65 million for rural housing preservation grants (44% more), and $32 million for mutual and self-help housing grants.

The measure includes $1.45 billion (3% more than FY 2021) for the Rental Assistance Program, under which payments are made to the owners of rental housing to cover the difference between the tenant's payment and the approved rental rate established for the unit. It also provides $45 million for rural housing vouchers, which are awarded directly to a renter for the same purpose; no funding for this program was provided in FY 2021.

The bill also authorizes $3.5 billion for rural community facility loans and loan guarantees (4.5% more), and it provides $238 million for community facility and development grants (more than triple the FY 2021 level). Within that amount, $112 million is earmarked for 86 specified rural community facility projects, including funding for schools, community centers, clinics, fire stations, parks, senior and child care centers, flood mitigation infrastructure, and municipal buildings.

Separately from the RHS baseline funding, the bill provides $2 million for a pilot program to provide technical assistance to rural hospitals, and $2 million for a pilot program for grants to facilitate the acquisition of USDA-financed rental housing by non-profits or public housing authorities that would continue to provide affordable housing under USDA requirements.

Rural Business-Cooperative Service

The Rural Business-Cooperative Service provides loans to businesses and cooperatives located in rural communities. The measure appropriates $170 million (76% more than FY 2021) for grants and other activities by the service, including the up-front credit subsidy to support up to $2.1 billion in RBCS loans.

Of that loan total, up to $2 billion in guaranteed business and industry loans could be made under the Rural Business Program (double the FY 2021 loan level). Other loan levels include $50 million under the Rural Economic Development Loans program, $19 million under the Intermediary Relending Program Fund (which aims to improve economic conditions and create jobs in rural communities by providing 1% low-interest loans to local intermediaries that re-lend to businesses), and $50 million under the Rural Energy for America Program.

For grants, the Rural Business Program could issue $37 million in rural business development grants and $5 million for rural innovation grants, while $29 million in various grants could be issued under the Rural Cooperative Development program.

Rural Utilities Service

The Rural Utilities Service (RUS) provides funding and support services for electric, telephone, water and waste utilities in rural communities. The bill provides for a loan level of up to $8.7 billion (3% more than FY 2021 but 4% less than requested), and it appropriates $1.8 billion for loan subsidies and grants that may be provided to rural communities, more than doubling existing support (143% more than FY 2021 but 6% less than requested).

For rural water and waste disposal infrastructure, the measure supports up to $1.4 billion in direct loans and $50 million in loan guarantees, both equal to FY 2021. It appropriates $722 million (16% more) for subsidies, grants, and other water and wastewater assistance -- including $533 million for rural community water and waste disposal grants (15% more than FY 2021), $93 million for grants to Colonias along the southern border as well as Alaskan and Hawaiian communities (37% more), and $40 million for water and waste system technical assistance (14% more).

Separately, the measure provides a one-time appropriation of $5 million to establish a pilot program to support construction of regional wastewater systems in historically impoverished rural communities.

For Rural Electrification and Telecommunications programs, the bill authorizes a loan level of $7.2 billion (a 4% increase) -- including $5.5 billion in direct loans for electric projects and $750 million in guaranteed underwriting, $690 million in subsidized loans for telecommunications projects, and $255 million in loans for the Rural Energy Savings Program, which provides loans for energy efficiency improvements of rural homes and businesses.

For the Rural Broadband Program, it appropriates $2 million to support up to $12 million in direct loans (equal to FY 2021). It also provides $35 million for rural broadband grants and $60 million for grants to improve access to telemedicine and distance learning in rural areas (both equal to FY 2021).

Finally, the bill provides $787 million (plus an additional $50 million derived from the RUS revolving electrification fund) for the RUS ReConnect program. Created in 2018, the program provides loans and grant funding to assist states, local and tribal governments, nonprofit corporations, or private companies deploy or upgrade broadband infrastructure in rural areas lacking access to adequate service. Within the funding for the ReConnect program, $37 million is earmarked for 19 specified rural broadband expansion projects.

Food & Nutrition Programs

The bill funds the Agriculture Department's domestic food assistance and nutrition programs, as well as international food aid programs.

Domestic Food Programs

The measure provides a total of $139.3 billion for domestic food assistance programs, including the Supplemental Nutrition Assistance Program (SNAP, previously known as food stamps), the school lunch and breakfast programs, and the Special Supplemental Nutrition Program for Women, Infants and Children (WIC).

The overall funding for these programs, of which $133 billion is scored as mandatory spending, is $6.4 billion (4%) less than FY 2021 and $17.8 billion (11%) less than requested. The total includes $192 million in discretionary funding for the administration of nutrition programs (22% more than FY 2021).

Supplemental Nutrition Assistance Program (SNAP)

The Agriculture Department estimates that in July 2021 (the most recent month with complete data) there were 42.2 million people enrolled in SNAP, which helps low-income people and families purchase food by means of electronic cards or paper vouchers that can be used in retail stores.

The bill provides $105.8 billion in mandatory funding for the food stamp program, $8.2 billion (7%) less than FY 2021. Appropriators rejected the administration's proposal to provide an additional $17.8 billion to forward fund SNAP for FY 2023.

However, it would appropriate "such sums as necessary" during the final three months of FY 2022 to ensure that SNAP recipients may continue to use benefits in case the program's contingency funds are exhausted.

The SNAP total includes $3.0 billion to act as a contingency reserve fund that may only be used when necessary, $7 billion for administrative costs, and $2 billion for Puerto Rico's food aid program which is based on SNAP. The SNAP total also includes nutrition assistance for American Samoa, the Northern Mariana Islands, and Indian Reservations.

Child Nutrition Programs

The measure provides $26.9 billion in mandatory funding for various child nutrition programs that provide food to children in preschool, daycare, and elementary and secondary schools (as well as some adults with disabilities enrolled in qualifying care facilities). The total is $1.8 billion (7%) more than FY 2021 and slightly more than requested.

The largest accounts within the total are $14.7 billion for the school lunch program, $5.2 billion for the school breakfast program, and $4.3 billion for the child- and adult-care food program. The total includes $581 million for the Summer Meals Program, which provides access to food for children during the summer when schools are not in session; $35 million for grants to school districts to purchase school cafeteria equipment; and $20 million for the Team Nutrition initiative, a multi-disciplinary program for children to promote healthy eating and physical activity.

The measure separately provides an additional $10 million for School Breakfast Program Expansion grants, which are awarded to state education departments to help low-income schools expand their school breakfast program. Within this amount, $2 million is allocated for grants in U.S. territories.

The bill prohibits the purchase of poultry products imported from China for use in Child Nutrition Programs.

Women, Infants & Children

The Special Supplemental Nutrition Program for Women, Infants and Children (WIC) provides assistance to children up to five years of age and to pregnant, postpartum and breast-feeding women who are nutritionally at risk because of inadequate nutrition and income. WIC provides them with food packages containing nutritional supplements that are typically lacking in eligible participants' diets.

The bill provides the requested $6.0 billion in discretionary funding for WIC -- equal to the FY 2021 level. The total includes $90 million for breast-feeding support counseling and $14 million for infrastructure. The committee estimates that $834 million within the total will be used to increase the amount of fresh fruit and vegetables covered by WIC benefits.

Finally, the measure rescinds $225 million in unobligated prior year WIC funding, which is used to offset spending elsewhere in the measure.

Commodity Assistance Program Funding

The measure appropriates $448 million in discretionary funding for USDA commodity assistance programs (5% more than FY 2021), which provide foods purchased by USDA to vulnerable populations.

This total includes $332 million for the Commodity Supplemental Food Program which provides assistance to senior citizens (2% more than FY 2021), $85 million for the Emergency Food Assistance Program which provides foods to food banks and other nonprofit groups (7% more), and $30 million for the Farmers Market Nutrition Program (43% more).

Foreign Aid/Commodity Export Programs

The bill appropriates $2.2 billion for USDA foreign food aid and related programs, 1% more than FY 2021 and 9% more than requested.

The department's international programs are administered by the Foreign Agricultural Service (FAS), which helps maintain and expand foreign markets for U.S. agricultural products, develops special export programs, and works to secure international trade conditions that are favorable to U.S. products. The measure provides $228 million for FAS salaries and expenses (3% more than FY 2021), while another $6 million is provided by transfer from the CCC.

It appropriates $1.7 billion for the Title II of the Food for Peace Program (equal to FY 2021), which provides surplus agriculture commodities to developing nations to combat malnutrition and meet other emergency requirements (Title I of the program, which provides commodities on credit terms, has not received new appropriations since FY 2006 due to a lack of demand for this program).

It also provides $245 million (7% more than FY 2021) for the McGovern-Dole International Food for Education and Child Nutrition Program, which provides donations of U.S. agricultural products, as well as financial and technical assistance, for school meals and maternal and child nutrition projects in low-income, food-deficit countries that are committed to universal education.

FDA & Independent Agencies

The bill also funds certain independent agencies, including the Food and Drug Administration, the Farm Credit Administration (FCA), and the Commodity Futures Trading Commission (CFTC).

Food & Drug Administration

The Food and Drug Administration (FDA), which is part of the Health and Human Services Department, regulates food, cosmetics, human and animal drugs, and medical devices. Funding for the FDA includes both direct appropriations and funding from user fees.

The bill provides the FDA with a direct appropriation of $3.5 billion (8% more than FY 2021) and it assumes $2.8 billion in user fees (2% more) -- thereby providing the FDA with a total of $6.3 billion for operations in FY 2022. The agency total is 5% more than FY 2021 but 3% less than requested.

Within the total, more than 99% is for FDA salaries and expenses, while another $22 million (70% more than FY 2021) is provided for buildings and facilities. According to the committee, the measure includes $12.9 million for activities to reduce metals present in baby food and $3 million to educate consumers on nutritional labeling. It increases funding for programs to trace foodborne illness (by $9.5 million), research on rare cancer therapeutics (by $1 million), and for pilot programs to inspect drug manufacturers located in India and China (by $5 million).

The bill provides an additional $50 million for research as a transfer from the FDA Innovation account, which supports research into new drugs and medical devices authorized by the 21st Century Cures Act (PL 114-225).

The committee in its report directs the FDA to conduct additional research on ways to detect so-called PFAS chemicals in the food supply.

Commodity Futures Trading Commission

The measure provides $363 million for the Commodity Futures Trading Commission (CFTC), which is responsible for regulating and managing the U.S. futures and options markets. The total provided is 19% more than FY 2021 and 30% more than requested.

(Appropriations for the CFTC alternate each year between the Financial Services and Agriculture spending bills, and for FY 2021 was provided through the Financial Services Appropriations Act).

Farm Credit Administration

The measure imposes a limitation of $84 million on the expenses of the Farm Credit Administration, which provides credit and related services for all creditworthy and eligible persons in agriculture and rural America.

Other Provisions

Separately from other bill accounts and amounts, the measure provides $29.4 million for various USDA programs or initiatives that were authorized by the 2018 Farm Bill (PL 115-334), including:

$10 million for the food security microgrant program, which state and territorial departments of agriculture can use to award competitive subgrants to eligible entities to increase the quantity and quality of locally grown food in food insecure communities

$5 million to provide outreach and training to socially disadvantaged farmers and ranchers, veteran farmers and ranchers, and beginning farmers and ranchers.

$5 million for a scholarship program to support Native American students at land-grant universities.

$3 million for a grant program to provide support and shelter to victims of domestic violence, stalking, or sexual assault who have pets or service animals, and to ensure safe accommodation for such animals.

$1 million for a program to help make additional dairy products available to recipients of SNAP benefits.

Funding Directives

The measure directs the Agriculture Department to take necessary actions to prohibit the purchase of agricultural land in the United States by companies that are partly or fully owned by the Chinese, Russian, Iranian, or North Korean governments, and to ensure that any agricultural lands already owned by such companies are ineligible for USDA programs.

It includes language to ensure that industrial hemp can be transported, processed, sold and used within and outside the United States, and it extends the department's industrial hemp marketing pilot program, first authorized by the 2018 Farm Bill, through the end of calendar year 2022.

Finally, it requires the department to revoke waivers that were issued during the COVID-19 pandemic that allow meat and poultry processing plants to exceed standard processing speeds. While these waivers were granted to help reduce disruptions in the meat and poultry supply chain caused by processing plant closures, Democratic appropriators say that the increased speed of a meat processing line could create safety hazards for workers. The measure authorizes USDA to issue new waivers if the Occupational Safety and Health Administration (OSHA) determines that the increased speeds do not pose a safety hazard.

By Daniel Peake [email protected]

Section III

Energy-Water

This section describes the provisions of HR 4502, Seven-Bill Appropriations Package, that provide funding for the Energy Department, Army Corps of Engineers, Bureau of Reclamation and related agencies. (These provisions were reported by the Appropriations Committee as HR 4549, Energy and Water Development Appropriations Bill, 2022.)

The bill provides $53.2 billion in net discretionary spending subject to caps, $3.8 billion (7.6%) more than comparable FY 2021 funding (i.e., excluding FY 2021 emergency spending). On a programmatic basis, however, after rescissions, offsetting receipts, and other scorekeeping adjustments are factored out (such as recent budgetary changes that exempt certain expenditures from the Harbor Maintenance Trust Fund from discretionary caps), the measure actually provides a total of $58.1 billion for use by the agencies funded by the bill.

The bill provides a total of $45.1 billion in net appropriations for programs and activities of the Energy Department, $5.5 billion (14%) more than FY 2021 but 4% less than requested (programmatic spending actually equals $46.3 billion). Of the total, $20.2 billion (2% more than FY 2021) is for nuclear weapons activities conducted by the National Nuclear Security Administration; $7.8 billion (2% more) is for continued environmental cleanup of defense and non-defense nuclear facilities, and $16.8 billion (35% more) is for Energy Department non-defense science and energy programs.

It significantly increases funding for most clean energy programs, including renewable energy technology research (29% more, with a 55% increase for wind energy research and 25% for solar energy) as well as for energy efficiency programs (36% more). Fossil fuel research increases by 9% but shifts towards reducing carbon emissions. Programs to promote cybersecurity and make the energy sector more secure are increased by 13%. Funding for the Advanced Research Projects Agency-Energy (ARPA-E) research program increases by 41%.

The measure provides $8.7 billion for water projects and associated activities conducted the Army Corps of Engineers (11% more than FY 2021), with spending for waterway operation and maintenance increasing by 25%. Under new budget rules enacted last year, $2.1 billion of the spending from the Harbor Maintenance Trust Fund is not subject to discretionary budget caps.

It also provides $1.9 billion for activities of the Interior Department's Bureau of Reclamation, an increase of 16.5%.

The measure includes 108 earmarks for projects in members' districts that total $351 million.

Army Corps of Engineers

The Army of Engineers is responsible for civil flood control, navigation and ecosystem restoration projects. The committee, in its report, notes that in addition to building and maintaining flood protection infrastructure that prevents almost $9 in damage for every dollar spent, the Corps maintains 1,067 harbors and 25,000 miles of commercial channels serving 40 states, which is critical to U.S. commerce and international economic competitiveness.

The bill provides $8.7 billion for Corps operations, investigations and construction -- $863 million (11%) more than FY 2021 and $1.9 billion more than requested.

Under changes enacted last year as part of the CARES Act and 2020 Water Resources Development Act (PL 116-136 and PL 116-260, respectively), the budgetary treatment of the Harbor Maintenance Trust Fund was modified to exempt certain trust fund expenditures from discretionary budget caps. The committee estimates that those budgetary rules will apply to $2.05 billion of Corps spending under the bill, which the committee says will enable the Corps to make significant progress on the backlog of dredging needs. Similarly, limits on discretionary spending will not apply to $50 million provided for certain activities at donor ports and energy transfer ports under provisions of the 2014 WRDA law.

Overall, according to the committee, $2.1 billion of spending in the bill will be eligible for reimbursement from the Harbor Maintenance Trust Fund -- $370 million more than FY 2021.

The measure also rejects the administration's proposal to restructure the agency's accounts and shift a variety of activities between the.

Operation & Maintenance

The Operation and Maintenance account provides funding for the Corps to clear and maintain U.S. harbors and inland waterways, including through dredging, and to operate and maintain lock and dam facilities around the country.

The measure provides $4.8 billion for waterway operation and maintenance for hundreds of specified projects, $967 million (25%) more than FY 2021.

Water Project Construction

The measure provides general construction funding for projects relating to navigation, flood and storm damage mitigation and aquatic ecosystem restoration that have been authorized by Congress and approved by the Corps and are identified in the explanatory statement accompanying the bill.

Specifically, it provides $2.6 billion for general water project construction, $101 million (4%) less than FY 2021 funding. It includes nine new study starts and seven new construction starts.

Of the total, $40 million must be used for projects with riverfront development components, $40 million must be used to address drainage in urban areas, and $20 million must be used for shore protection projects.

Separately, the measure provides $370 million for specified waterway-related projects along the Mississippi River and its tributaries -- 3% less than FY 2021.

Other Activities

The measure provides $212 million for the Corps regulatory program, which oversees activities affecting U.S. waters, including wetlands, in accordance with various laws -- including the 1899 Rivers and Harbors Appropriation Act, the Clean Water Act, and the 1972 Marine Protection, Research, and Sanctuaries Act. The amount provided is $12 million more than FY 2021.

It appropriates $250 million (equal to FY 2021) for the continued cleanup of certain low-level radioactive materials and mixed wastes located at Energy Department sites that were contaminated during the nation's past efforts to develop atomic weapons. The measure rejects the administration's proposal to transfer the account to the Energy Department.

Finally, the measure provides $155 million (1% more than FY 2021) for general investigations, under which the Corps conducts studies to determine the feasibility of constructing a water project. It also provides $35 million for training programs to prepare for and respond to floods, hurricanes and other natural disasters, equal to FY 2021.

Energy Department

The bill provides a total of $45.1 billion in net appropriations for programs and activities of the Energy Department -- $5.5 billion (14%) more than FY 2021 but $1.5 billion (4%) less than requested.

However, total programmatic spending for the department for FY 2022 actually equals $46.3 billion, with rescissions and offsetting receipts offsetting just over $1.1 billion of the total.

Within the total provided for the department, $20.2 billion is for nuclear weapons activities conducted by the National Nuclear Security Administration (NNSA); $7.8 billion is for continued environmental cleanup of defense facilities where nuclear weapons activities were conducted, as well as of non-defense nuclear facilities, and $16.8 billion is for Energy Department non-defense science and energy programs.

According to the committee, the bill includes $14 billion in investments in clean energy and science to help develop clean, affordable, and secure American energy.

DOE Military Nuclear Programs

The National Nuclear Security Administration (NNSA) is a semiautonomous agency within the Energy Department that is responsible for the development, maintenance and disposal of U.S. nuclear weapons, and for preventing the proliferation of weapons of mass destruction. NNSA accounts include weapons activities, defense-oriented nuclear proliferation, and research on naval nuclear reactors.

The bill provides $20.2 billion for the NNSA -- $423 million (2%) more than FY 2021 and 2% more than requested.

Weapons Activities

Within the NNSA total, the bill provides $15.5 billion for nuclear weapons activities, 1% more than FY 2021 funding.

The weapons total includes $4.6 billion (6% more than FY 2021) for stockpile management work including maintenance, operations, surveillance, dismantlement, and weapon acquisition programs -- including life extensions, modifications, and alterations. Within this amount, $2.8 billion is for stockpile modernization activities (5% more than FY 2021) and $1.1 billion is for stockpile sustainment efforts (13% more).

It provides $2.9 billion for NNSA production modernization activities, including $1.8 billion for plutonium and other primary capability modernization programs (25% more than FY 2021), $488 million for uranium and secondary capability modernization (7% more), and $489 million for tritium and domestic uranium enrichment (11% less). At least $10 million must be used for workforce development and training partnerships with Historically Black Colleges and Universities, Hispanic-Serving Institutions, and Tribal Colleges and Universities in South Carolina and New Mexico to support plutonium pit production ($3 million more than FY 2021).

The measure reduces funding for NNSA Stockpile Research, Technology, and Engineering activities, providing $2.8 billion to strengthen science-based stockpile stewardship capabilities to annually certify and assess the stockpile (1% less than FY 2021), as well as NNSA's nuclear weapons infrastructure and operations activities, providing $3.6 billion for (12% less).

Nuclear Nonproliferation Programs

Nonproliferation programs seek to prevent the development and spread of nuclear weapons worldwide. Some of these programs are designed specifically to secure and decommission weaponry and technology of the former Soviet Union.

The bill appropriates $2.3 billion for NNSA defense nuclear nonproliferation activities, $80 million (3.5%) more than FY 2021 and 21% more than requested.

The total includes $531 million for global material security programs and activities ($2.5 million more than FY 2021), $185 million for nonproliferation and arms control activities (0.5% more), $715 million for defense nuclear nonproliferation research and development (19% more), $343 million for material management and minimization (14% less), and $371 million for the department's nuclear counterterrorism and incident response program to respond to and mitigate nuclear and radiological incidents worldwide (2% less).

Naval Reactors

The measure provides the requested $1.9 billion for the agency's naval reactor program, $183 million (11%) more than FY 2021. The department's naval reactor program is responsible for all aspects of naval nuclear propulsion, including technology development, reactor operations, and disposal.

It fully funds the request to continue development of reactors for the Columbia-class submarine and to refuel the S8G prototype reactor.

It also includes $641 million for naval reactors development (13% more than FY 2021), $594 million for reactor operations and infrastructure activities (12% more), and $395 million for construction projects (18% more) -- including $349 million for the department's spent nuclear fuel handling recapitalization project (6% more).

DOE Environmental Cleanup Activities

The bill provides a total of $7.8 billion for a variety of Energy Department programs focused on environmental cleanup of both former government sites as well as civilian nuclear sites. The total provided is $171 million more than FY 2021 funding.

The largest portion, $6.6 billion, is for the general defense environmental cleanup program, which focuses on the cleanup of contaminated areas, primarily at current and former Defense Department sites. That funding is 166 million (3%) more than FY 2021.

Within that amount, it provides $2.6 billion for cleanup activities in and around the Hanford site in Washington state, including $927 million for the Richland Operations Office (slightly more than FY 2021) and $1.6 billion for the Office of River Protection (equal to FY 2021). It also provides $1.6 billion for the Savannah River site in South Carolina (4% more), $424 million for various National Laboratories and associated facilities (24% more), and $434 million for the Idaho National Laboratory and $475 million for the Oak Ridge Tennessee facility (both equal to FY 2021). For the Waste Isolation Pilot Plant in New Mexico, it provides $430 million (12% more than FY 2021).

The measure also provides $334 million for the cleanup and remediation of civilian nuclear sites (5% more than FY 2021), including $124 million for cleanup of small sites (12% more). It provides $831 million from the Uranium Enrichment Decontamination and Decommissioning Fund for the continued cleanup of non-defense gaseous diffusion plants at Portsmouth, Ohio; Paducah, Ky.; and Oak Ridge, Tenn.

DOE Energy Programs

The bill provides a total of $16.8 billion for a variety of energy and science programs administered by the Energy Department -- $4.4 billion (35%) more than FY 2021 but $1.9 billion (10%) less than requested.

It funds the Advanced Research Projects Agency-Energy (ARPA-E) research program at $600 million -- $173 million (41%) more than FY 2021. ARPA-E supports research and related projects attempting to rapidly develop energy technologies that are too risky to attract substantial private investment but are capable of significantly changing the energy sector to address energy-related economic and security challenges. ARPA-E support is usually provided through partnerships with universities that supply personnel and assist in project and research funding.

The committee notes in its report that it has rejected the administration's proposal to create a separate program for climate to be known as ARPA-C, for which $200 million was requested. Instead, it directs the department to address its energy and environmental missions through the existing ARPA-E program.

It also directs the Energy Department to work with the Interior and Agriculture departments on a Civilian Climate Corps initiative to help address climate change, especially with communities that wish to pursue a "green energy economy." Within 30 days the department must brief the committee regarding its coordination with Interior and USDA to ensure that the department's capabilities, technology development, and technical assistance can be utilized by the Civilian Climate Corps, and it must identify the steps it can take to ensure that its deployed programs inspire a new generation of conservationists and the adoption of clean energy technologies.

Science Programs

The measure provides $7.3 billion for the Energy Department's science account -- $294 million (4%) more than FY 2021 (which included $2.3 billion in emergency funding) but 2% less than requested. The account funds the department's work on basic energy research, nuclear physics, biological and environmental sciences, fusion and other related endeavors.

The total includes $805 million for biological and environmental research (7% more than FY 2021) and $1.0 billion for research on advanced scientific computing (1% more) -- including $115 million for research on artificial intelligence and machine learning and $129 million for Exascale Computing Initiative construction. Exascale computers would exceed the existing generation of supercomputing power by 10,000% and provide computing power necessary to meet future national security, scientific and health care needs.

The total also includes $2.3 billion for basic energy sciences (2% more than FY 2021) of which $304 million is for construction; $1.1 billion for high energy physics (5% more) of which $268 million is for construction; $698 million for fusion energy sciences (5% more) of which $247 million is for construction; and $665 million for nuclear physics (5% more) of which $5 million is for construction. Finally, it provides $249 million for other science laboratories infrastructure (4% more than FY 2021), with $190 million for construction and $59 million for laboratory infrastructure support.

In its report, the committee says it recognizes the potential impacts and delays in research caused by the effects of the COVID - 19 pandemic and notes that the department has taken some steps to engage scientific professional societies and universities on the impacts to institutions and research communities. However, it expresses concern that the response is uneven and therefore directs the department to report on the impacts of the COVID - 19 pandemic on institutions and research communities.

Energy Efficiency & Renewable Energy

The bill provides $3.8 billion for the Energy Department's energy efficiency and renewable-energy account -- $906 million (32%) more than FY 2021.

Within the total, it provides $832 million for renewable energy technology research (29% more than FY 2021), increasing funding for wind energy technologies by 55%, solar energy by 25%, geothermal by 29% and water power by 17%. For sustainable transportation research it provides $1.0 billion (28% more than FY 2021), with funding for general vehicle technologies increasing by 33% and research on hydrogen and fuel cell technologies increasing by 30%.

It provides $1.5 billion for energy efficiency programs, $394 million (36%) more than FY 2021 but 31% less than requested. Within that amount, it increases funding for advanced manufacturing energy efficiency research by 26% and building technologies research by 21%. That amount also includes $588 million for weatherization and intergovernmental programs, with weatherization programs increasing by 26% and two new intergovernmental programs being created: $100 million for a Build Back Better Challenge Grant program and $20 million for a Local Government Clean Energy Workforce program.

Fossil Fuels / Carbon Management

The bill provides $820 million for fossil fuel research and development, increasing funding by 9% but shifting the emphasis of departmental programs more towards reducing carbon emissions in the economy.

The committee says it supports the request to refocus program funding from traditional fossil combustion-centric activities to climate-centric activities -- in particular by advancing carbon reduction and mitigation in sectors and applications that are difficult to decarbonize, including the industrial sector, with technologies and methods such as carbon capture and storage, hydrogen, and direct air capture, while also assisting in facilitating the transition toward a net-zero carbon economy and rebuilding a U.S. critical minerals supply chain.

Among the changes, the measure ends funding for transformational coal pilot programs and an oil focused research program while increasing funding for carbon reduction programs, including the carbon capture research program (a 74% increase), carbon utilization research (52% more), carbon storage (27% more), and carbon dioxide removal technology research (28% more).

Energy Security

The bill includes funding to help secure the nation's energy infrastructure against natural hazards as well as to reduce the risks of, and impacts from, cybersecurity events -- as well as to help restore energy infrastructure that is impacted.

It provides $177 million for Energy Department cybersecurity, energy security and emergency response programs, 13% more than FY 2021. Within this total, $112 million is for risk management technology and tools (17% more than FY 2021). It also provides $25 million each for two new programs requested by the administration: one focused on hazard response and energy delivery restoration, and the other on information sharing and partnerships between federal, state and local governments and the energy sector.

It also creates a new cyber research and development research program within the department's broader electricity technologies program. That cyber program would receive $14 million.

The broader electricity technologies program, meanwhile, would receive a 26% increase to $267 million, with another new program (funded at $23 million) to focus on energy delivery grid operations technologies. Funding for the existing resilient electricity distribution program would be increased by 20%, with energy storage research and construction programs increasing by 26%.

The committee says the bill's electricity program funding will advance technologies to increase the resiliency and efficiency of the nation's electricity delivery system with capabilities to incorporate growing amounts of clean energy technologies.

Clean Energy Demonstrations & Other Energy Programs

The bill appropriates $200 million for a new clean energy demonstrations program as proposed by the administration (although the administration requested $400 million for the program).

Specifically the administration proposed creating an Office of Clean Energy Demonstrations (OCED) to accelerate the maturation of near and mid-term clean energy technologies and systems, with the goal of quicker commercial adoption and increased availability. The program would be informed by, and integrated with, existing clean energy innovation initiatives across the Energy Department.

In its report, the committee expresses support for creating such an office, and it directs the department to conduct those activities on a competitive basis and include cost-share requirements associated the 2005 Energy Policy Act. It also encourages the department to conduct those activities through technology neutral solicitations that are focused on crosscutting energy challenges.

Other Energy Department energy programs would be funded as follows:

Nuclear Energy -- $1.7 billion (11% more than FY 2021) for nuclear power development and research. Nuclear energy funding covers multiple programs, including as spacecraft propulsion systems, cancer treatment technology and reactor technologies. The total includes $945 million for research and development activities.

Strategic Petroleum Reserve -- $197 million (5% more FY 2021) for continued operations and maintenance of the SPR. The bill forbids the department from establishing any new regional petroleum product reserves unless funding for such a proposed regional reserve is explicitly requested in advance in an annual budget submission and approved by Congress.

Other Existing Oil Reserves -- $14 million ($1 million more than FY 2021) for remaining activities related to naval petroleum and oil shale reserves, and $6.5 million (equal to FY 2021) for the Northeast Home Heating Oil Reserve. The bill rejects the administration's proposal to terminate that heating oil reserve, which is intended to ensure that home heating oil supplies are available for northeastern states during times of very low inventories or significant threats to heating oil supplies.

DOE Administration & Other Activities

The bill provides $496 million for administrative expenses of the Energy Department, 23% more than FY 2021. After miscellaneous revenues and funding from other defense activities are factored in, the bill provides a net appropriation of $372 million.

Within the total provided, $55 million is to be used for the department to respond to the SolarWinds hack of its systems by Russian actors. The total also includes $20 million (double FY 2012 funding) for the department's Office of Economic Impact and Diversity; the committee says the additional funding is to carry out President Biden's executive orders on energy equity and environmental justice.

The measure also provides $129 million for the Energy Information Agency, $2 million more than FY 2021. The EIA is a quasi-independent agency in the department responsible for providing timely, objective, and accurate energy-related information to Congress, the executive branch, state governments, industry, and the public.

The committee in its report expresses concern about the security and economic implications of the nation's dependence on foreign nations to fulfill the rare earth mineral needs of America's energy and defense sectors, as well as the potential influence of foreign owned and controlled assets in the United States related to critical minerals. It directs the department to report on any financial or technical support provided by the department to domestic critical minerals assets, and the status of such financial or technical support.

Power Marketing Administration

The measure provides the requested $101 million in net funding for regional power marketing administrations, 1% more than FY 2021.

The total includes a net $91 million for the Western Area Power Administration (WAPA) that serves 15 states, and a net $10 million for the Southwestern Power Administration (SPA) that serves six states. For each entity, all but those amounts for operations and maintenance are covered through power sales and other income.

The bill allows $828 million in actual spending by the WAPA and $105 million in spending by the SPA. In the case of the Southeastern Power Administration, which serves 11 states, power sales and other revenue would cover its entire $74 million budget.

Bureau of Reclamation

The Bureau of Reclamation is charged with developing water supplies and reclaiming arid lands in the Western United States. The bureau, which is part of the Interior Department, is responsible for more than 475 dams and 337 reservoirs and supplies water to 31 million people and 10 million acres of farmland in 17 western states. It also supplies hydroelectric power, and is the second largest supplier of hydropower behind the Army of Engineers.

The measure provides $1.9 billion for activities of the Bureau of Reclamation, $276 million (16.5%) more than FY 2021 and $413 million (27%) more than requested.

Most of the total, $1.8 billion, is for activities that support the development, construction, management and restoration of water and related natural resources. That amount is $271 million (18%) more than FY 2021 funding.

Central Valley Project Restoration Fund

The measure provides the requested $56 million for the Central Valley Project Restoration Fund, 1% more than FY 2021.

The fund was established to provide money from project beneficiaries for habitat restoration, improvement and acquisition in the Central Valley Project area in California. Funds are derived from a collection of revenue sources, including voluntary water transfers and tiered water pricing, as well as mitigation and restoration payment collections.

California Bay-Delta Ecosystem Restoration

The bill provides $33 million for the California Bay-Delta Ecosystem Restoration account, which funds the federal share of restoration activities being developed for the San Francisco Bay/Sacramento-San Joaquin Delta by a federal-state partnership. The total is equal to both FY 2021 and the request.

Central Utah Project

The bill appropriates $20 million for continued work on the Central Utah Project, a large Interior Department water infrastructure project designed to provide irrigation and municipal water and to restore wildlife habitats. The amount provided is $1 million less than provided in FY 2021.

The measure authorizes funding for fish, wildlife and recreation mitigation and conservation; establishes an account in the Treasury for the deposit of these funds and of other contributions for mitigation and conservation activities; and establishes a Utah Reclamation Mitigation and Conservation Commission to administer funds in that account.

The total includes $13 million for project construction, $5 million for transfer to the Utah Reclamation Mitigation and Conservation Account for use by the Utah Reclamation Mitigation and Conservation Commission, and $1.5 million for program expenses.

Independent Agencies

Nuclear Regulatory Commission

The measure provides $874 million for salaries and expenses of the Nuclear Regulatory Commission (NRC), 5% more than FY 2021. Most of the commission's funding, however, would be offset by receipts from user fees paid by nuclear utilities and other entities regulated by the commission. It is assumed that the commission would receive $745 million from such receipts, resulting in a net appropriation of $129 million. The NRC's inspector general, meanwhile, would receive $14 million, all but $2 million of which would be offset by agency revenues.

Federal Energy Regulatory Commission

The measure provides $466 million for the Federal Energy Regulatory Commission, $62 million more than FY 2021. All of the commission's funding would be offset by fees paid by regulated energy companies and providers, resulting in no net appropriation.

Other Offices & Regional Commissions

The bill appropriates $210 million for the Appalachian Regional Commission, $30 million more than FY 2021. Of the total, $10 million is directed towards high-speed broadband deployment in distressed counties within the Central Appalachian region that have been most negatively impacted by the downturn in the coal industry, and $15 million is for economically distressed counties within the North Central and Northern Appalachian regions.

The measure provides $30 million for the Delta Regional Authority and $15 million Denali Commission (both equal to 2021). For the Northern Border Regional Commission, it provides $32 million (7% more than FY 2021).

It also provides $31 million for the Defense Nuclear Facilities Safety Board, which is equal to FY 2021 funding and the request.

By Greg Tourial [email protected]

Section IV

Financial Services

This section describes the provisions of HR 4502, Seven-Bill FY 2022 Appropriations Package, that provides funding for the Treasury Department, the federal judiciary, the White House and numerous other federal agencies. (These provisions were reported by the Appropriations Committee as HR 4345, Financial Services and General Government Bill for FY 2022)

The bill provides $28.5 billion in net discretionary spending subject to caps along with cap adjustments of $417 million for IRS enforcement activities and $143 million for SBA disaster relief -- thereby providing a total of $29.1 billion in scored discretionary funding for FY 2022, $4.8 billion (20%) more than comparable FY 2021 funding.

However, it also assume $13.2 billion in offsetting collections that offset certain agency spending (such spending doesn't count against scored discretionary spending), meaning the agencies funded by the bill would receive about $41.6 billion in programmatic discretionary funding for FY 2022. The measure also includes $22.6 billion in mandatory funding, including salaries for federal judges and contributions for federal employee retirement and health benefits.

The measure increases funding for both the Treasury Department and the IRS by 14%, including additional funds to improve IRS tax collection and enforcement. It increases funding for the federal court system by 5%, for the Executive Office of the President each by 11%, and for the federal payment to the District of Columbia by 6% while ending certain restrictions on how the District can use both appropriated and its own funds.

It provides a 15% increase for General Service Administration (GSA) building construction, repairs and operations -- along with a separate $300 million for GSA to begin procuring electric and zero emission vehicles for the federal fleet -- and increases Office of Personnel Management by 13%. It also increases funding for a number of independent federal agencies, including the Federal Communications Commission (4%), the Federal Trade Commission (11%), the Securities and Exchange Commission (4%), the National Archives and Records Administration (15%), and the Consumer Product Safety Commission (27%). It increases Small Business Administration funding by 12%, and the only earmarks in the bill are 55 local small business development programs for which $32 million in SBA funding is provided.

On policy provisions, the measure makes DACA recipients eligible for federal employment, it protects the ability of federal employees to unionize, and it establishes a new federal commission to identify and recommend the removal of names or displays on federal property that are inconsistent with diversity, equity, and inclusion. Finally, it eliminates prior prohibitions on the use of funds for abortions, including under federal employee health plans and with respect to both local and federal funds received by the District of Columbia.

Treasury Department / IRS

Consistent with the president's request, the bill provides a total of $15.4 billion for Treasury programs and activities -- $1.9 billion (14%) more than FY 2021 and equal to the administration's request. It increases funding for most Treasury and IRS programs and activities, while also rescinding rescinds $20 million in unobligated balances from the Treasury Forfeiture Fund.

Internal Revenue Service

Roughly 88% of funding provided to the Treasury Department goes to the IRS, which would receive $13.6 billion -- $1.7 billion (14%) more than FY 2021. The increase includes $417 million in new "program integrity" funds under a budget cap adjustment to improve compliance with IRS regulations and help reduce tax fraud. The Appropriations Committee estimates that the investments in tax enforcement and IRS operations will generate roughly $38.6 billion in additional revenue over the next by decade by reducing the so-called "tax gap," i.e. the difference between taxes owed under current law and the actual amount collected.

According the committee, the bill's funding increase for the IRS also will provide sufficient funding to implement the 2019 Taxpayer First Act (PL 116-25), which modifies IRS enforcement authorities, reorganizes IRS taxpayer services, requires the IRS to develop a comprehensive customer service strategy, and requires actions to protect taxpayer privacy and reduce tax fraud.

Within the IRS total, funding is provided for major activities as follows:

Taxpayer Services -- $2.9 billion (15% more than FY 2021) for taxpayer services, including forms and publications, tax return processing, advocacy and services to assist taxpayers. The total includes $11 million for the Tax Counseling for the Elderly Program, $13 million for low-income taxpayer clinic grants, $30 million for Community Volunteer Income Tax Assistance grants, and $213 million for the operating expenses of the IRS Taxpayer Advocate Service.

IRS Enforcement -- $5.75 billion (10% more than FY 2021) for overall tax enforcement activities, including $287 million in "program integrity" funds (for which there was no comparable FY 2021 funding). This account funds the examination of tax returns, settling taxpayer appeals regarding their returns, monitoring employee pension plans, reviewing the tax-exempt status of organizations and collecting unpaid taxes.

IRS Operations Support -- $4.6 billion (16.5% more than FY 2021) to support IRS overall planning and administration, including $129 million in program integrity funds (for which there was no FY 2021 funding). This account funds shared service support related to facilities services, rent payments, printing, postage, security, strategic planning, communications and liaison, finance, human resources, research, information technology and telecommunications.

Business Systems Modernization -- $305 million for efforts to modernize key IRS business systems, 37% more than FY 2021. This funding would remain available through the end of FY 2024.

The measure continues a number of policy provisions that restrict IRS activities, including those that prohibit the targeting of groups for regulatory scrutiny based on their ideological belief or of individuals for exercising their First Amendment rights, as well as provisions that prohibit the payment of bonuses to IRS employees or the hiring of former employees unless their conduct and tax compliance has been considered.

Unlike prior appropriations laws, the measure does not include language prohibiting the IRS from using funds to issue, revise, or finalize any standard for determining whether an organization is a tax-exempt non-profit social welfare organization (also known as Section 501c(4) organizations). The tax code lets such organizations maintain their tax-exempt status only if political activities are not their primary purpose, but some government accountability and transparency activists argue that a 2018 change in IRS reporting requirements effectively allows individuals to use 501c(4) groups to donate "dark money" for political purposes without having to disclose their personal information.

Finally, it includes new language that would prohibit the Treasury from penalizing a financial institution for providing financial services to legitimate cannabis related businesses that operate pursuant to a state or local law.

Other Treasury Offices

The bill funds a number of other offices within the Treasury Department that deal with a variety of issues, including U.S. finances and debt, imposing financial sanctions against entities, and promoting economic development.

Bureau of the Fiscal Service -- $360 million for the Bureau of the Fiscal Service (4% more than FY 2021), which was established in 2021 to perform the accounting, borrowing, collections, payments, and shared services functions of the federal government. It collects most of the non-tax debt owed to the federal government and is responsible for all public debt operations and for promoting the sale of U.S. securities.

Terrorism Office -- $185 million for the Office of Terrorism and Financial Intelligence (6% more than FY 2021), which enforces economic and financial sanctions against terrorist groups, drug traffickers, and rogue nations and provides intelligence and counterintelligence services for the department, including analysis of terrorist financing.

FinCEN -- $191 million for the Financial Crimes Enforcement Network (50% more than FY 2021), which supports Federal, state, local, and international law enforcement agency investigations of money laundering and other financial crimes, and is responsible for implementing anti-money laundering allegations.

Alcohol/Tobacco/Trade -- $131 million for the Alcohol and Tobacco Tax and Trade Bureau (6% more than FY 2021), which enforces laws that regulate lawful activities relating to alcohol products and tobacco.

Foreign Investment/CFIUS -- $20 million (equal to FY 2021) for the CFIUS Fund. The fund was established in 2018 to support certain activities of the Committee on Foreign Investment in the United States, which coordinates federal policy on foreign investment in the United States and monitors its impact. Unlike in previous years, the committee expects this amount to be fully offset by collected filing fees, resulting in no net appropriation.

CDFI Fund-- $330 million for the Community Development Financial Institutions Fund ($60 million, or 22%, more than FY 2021) which provides competitive grants, loans, equity investments, and technical assistance to community development banks, community development credit unions, and housing and micro-enterprise loan funds that provide financial services in underserved areas. Within the total, $212 million is for financial and technical assistance grants, $28 million is for the Bank Enterprise Award program, $25 million is for the Healthy Food Financing initiative, $22 million is for Native Initiatives, and $10 million is for the small-dollar loan program.

Department Administration & Policy Provisions

The bill appropriates the requested $829 million for Treasury Department's departmental offices -- $152 million (22%) more than FY 2021. (This amount includes the funding for both the terrorism office and CFIUS.)

Of that total, $271 million is for general Treasury Department salaries and expenses (16% more than FY 2021) and $6 million is for the Treasury Department's systems and capital investments account (equal to FY 2021) which funds capital investments that support the department. It includes $132 million for department's Cybersecurity Enhancement Account (more than six times the FY 2021 level), including $114 million for department-wide efforts to improve cybersecurity and address the impacts of the "SolarWinds" cyberattack, a massive months-long data breach that affected the Treasury Department and numerous other government agencies.

Departmental funding also includes $235 million for the Treasury's three Inspector General Offices: $42 million for the Department's Inspector General (3% more than FY 2021); $17 million (11% less) for the Special Inspector General for the Troubled Asset Relief Program (TARP), which coordinates the audits and investigations of Treasury assets under TARP; and $176 million (3% more) for the Treasury Inspector General for Tax Administration (TIGTA), which assesses IRS operations and programs. Additionally, the measure directs the IRS to transfer $4 million from its accounts to TIGTA, subject to further congressional approval.

Finally, the measure continues several policy provisions from previous years, including a prohibition on using funds to redesign the One Dollar bill and a prohibition on consolidating the U.S. Mint (which produces coins) and the Bureau of Engraving and Printing (which produces paper currency) without the approval of Congress.

The Judiciary

The bill provides $8.6 billion for the federal court system, including the salaries of judges, magistrates, support personnel, and other expenses for the federal judiciary -- $413 million (5%) more than FY 2021 and $30 million more than requested. Within the total, the $458 million for the salaries of Supreme Court justices and other federal judges is mandatory spending.

Supreme Court

The measure includes $101 million for salaries and expenses of the Supreme Court (including $2.8 million for Justices' salaries), 3.5% more than FY 2021. A separate $10 million (3% more than FY 2021) is provided for care of the buildings and grounds.

Federal Courts & Judicial Services

The bill appropriates $6.2 billion for the U.S. Courts of Appeals, U.S. District Courts, Bankruptcy Courts, Federal Claims Court, as well as probation and pretrial services offices -- 5% more than FY 2021 and 1% more than requested. This amount includes $450 million in mandatory spending for the salaries of judges ($19 million less than FY 2021).

Separately, it provides a 3% increase for the U.S. Court of Appeals for the Federal Circuit ($38 million for FY 2022, including $3.2 million for mandatory judges' salaries), and a 4% increase for the U.S. Court of International Trade ($23 million for FY 2022, including $2.2 million for judges' salaries).

Another $1.4 billion is provided for defender services (4% more than FY 2021) and $682 million is provided for court security (3% more). The bill also provides $47 million for juror fees (44% more).

The measure extends certain temporary federal judgeships in the following court districts: Northern Alabama, Arizona, Central California, Southern Florida, Hawaii, Kansas, Eastern Missouri, New Mexico, Western North Carolina, and Eastern Texas. It also continues a pilot program for the U.S. Marshals Services to provide security at certain federal courthouses.

Other Judicial Operations

The measure also provides $104 million (8% more than FY 2021) for the Administrative Office of U.S. Courts, which provides administrative and management support for federal courts; $32 million (11% more) for the Federal Judicial Center, which improves the management of federal judicial dockets and court administration; and $21 million (4% more) for the U.S. Sentencing Commission, which reviews and revises sentencing guidelines and practices for the federal criminal justice system.

White House / Executive Office of the President

The bill appropriates $841 million for the White House and the Executive Office of the President -- 11% more than FY 2021 and 2% more than requested.

The President & White House Operations

The measure provides the requested $222 million for the White House, 14% more than FY 2021. Within that total, it provides $76 million for core White House staff and administrative services that directly support the president (almost 39% more than FY 2021) and $18 million (10% more) for operating and restoration expenses of the White House residence. (The president's $450,000 salary is provided elsewhere as a separate mandatory expense).

The White House total also includes $111 million for general administrative services to the overall Executive Office of the President, including financial, personnel, library, information management and general office services. Within this amount, $4.5 million is allocated to provide stipends and other payment to White House and EOP interns.

Additionally, the total provides $13 million (6% more than FY 2021) for the staff of the National Security Council and Homeland Security Council, and $4.7 million (18% more) for the president's Council of Economic Advisers.

Separately, the measure provides the requested $5.7 million for the Vice President's office and staff, (21% more than FY 2021), and $313,000 for the operating expenses of the vice president's residence.

Office of Management & Budget

The bill provides $123 million for the Office of Management and Budget (OMB), 15% more than FY 2021. OMB assists the president in the discharge of budgetary, economic, management and other executive responsibilities.

The measure requires OMB to implement a system that would make publicly available, in an automated fashion, a description of how appropriated funds are apportioned or allocated within an agency. The total includes $1 million for OMB to develop a system for this purpose.

Cybersecurity Office

The bill includes $19 million to establish the Office of the National Cyber Director within the White House, a position created by the FY 2021 defense authorization to advise the President on cybersecurity issues and to coordinate federal cybersecurity strategy and policy. The committee directs the new office to report to Congress on how it plans to coordinate with other federal agencies with existing government-wide cybersecurity roles.

Drug-Related Programs

The measure appropriates a total of $458 million for the Office of National Drug Control Policy (ONDCP), which is responsible for developing policies, objectives and priorities for the National Drug Control Program. The total is 5% more than FY 2021 and 2.4% more than requested.

Within the total, the bill provides $300 million (3.4% more than FY 2021) for the High Intensity Drug Trafficking Areas (HIDTA) Program, which provides assistance to federal, state and local law enforcement units operating in areas that are most adversely affected by drug trafficking. It also includes $137 million (7% more than FY 2021) for other federal drug control programs -- including $110 million for the drug free communities program, $14 million for anti-doping activities, and $5.2 million for grants to help communities fight prescription drug abuse.

Other Federal Agencies

The bill funds a wide range of other federal agencies, including the General Services Administration (GSA), the Office of Personnel Management, the Small Business Administration, the Securities and Exchange Commission, and the Federal Communications Commission.

General Services Administration

The committee authorizes the General Services Administration (GSA) to spend $10.4 billion from the Federal Buildings Fund (15% more than FY 2021 but 5% less than requested), which derives most of its revenue from rents paid to GSA by federal agencies and funds most GSA activities. The committee estimates that this appropriation will be fully offset by the $10.6 billion in income the fund is anticipated to receive in the coming fiscal year (the $231 million difference between the fund's income and allowed expenses is scored as savings that is used to offset spending elsewhere in the bill).

Spending from the Federal Buildings Fund includes $5.9 billion for the rental of private space for federal agencies, $2.8 billion building operations and maintenance, and $1.0 billion for building repairs and alterations -- including $433 million for major repairs and $220 million for a new special programs initiative (which includes $100 million for climate resilience projects and $45 million to improve child care facilities in GSA buildings). The total also includes $617 million for GSA construction and acquisition (more than double FY 2021) -- including $254 million for the Homeland Security Department headquarters in southeast D.C., $103 million for the Calexico land port of entry on the California-Mexico border, and $222 million for high priority federal courthouse construction projects nationwide.

The measure requires GSA to transmit a new prospectus for consolidation of a new FBI headquarters, and it prohibits GSA from implementing a Trump administration executive order establishing a preferred architectural style for federal buildings and courthouses.

In addition to amounts from the Federal Buildings Fund, the bill directly appropriates $650 million for other GSA operations, accounts, and activities -- including $300 million in new funding for an Electric Vehicle Fund to be used to begin procuring zero emission and electric vehicles and associated charging infrastructure for federal agencies.

. That includes $72 million (12% more than FY 2021) for the Office of Government-Wide Policy, which establishes guidelines and conducts and evaluation activities; $52 million (6% more) for GSA's operating expenses; $50 million for technology modernization (100% more); $4 million for the Asset Proceeds and Space Management Fund, which is used to implement recommendations made by the Public Buildings Reform Board (see below); and $5 million for the pensions and related expenses of former presidents.

Office of Personnel Management

The Office of Personnel Management (OPM) is responsible for management of federal human resources policy and oversight of the merit civil service system. It administers the retirement, health benefits and life insurance programs affecting most federal employees, retired federal employees and their survivors.

The bill provides $408 million for OPM (a 12% increase), including $36 million for OPM's inspector general (11% more than FY 2021).

The vast majority of the bill's $22.6 billion in mandatory spending is for benefits administered by OPM, including federal employee and retiree health benefits and civil service retirement.

Securities & Exchange Commission

The bill provides the requested $2.0 billion for the Securities & Exchange Commission (SEC) -- 4% more than FY 2021 -- which protects investors and oversees U.S. securities markets. Within the total, $7 million is provided to cover relocation costs for the SEC's Fort Worth regional office. All SEC funds are offset by fees and collections, resulting in no net appropriation.

Unlike previous appropriations measures, the bill does not prohibit the SEC from issuing a rule to required publicly traded companies to disclose political contributions, contributions to tax-exempt organizations, and dues paid to trade associations.

It does, however, include a new provision that prohibits the SEC from implementing a Trump administration rule establishing new requirements for proxy advisory firms that often represent institutional investors during shareholder meetings of publicly traded companies.

Election Assistance Commission

The bill provides $523 million for the Election Assistance Commission -- including $500 million for new grants for state and local efforts to improve election security and integrity (no grant funds were appropriated for FY 2021; the administration requested $100 million for such grants for FY 2022).

It provides $23 million for EAC salaries and expenses, 34% more than FY 2021. The commission is charged with improving the administration of elections in the United States by developing voluntary voting systems guidelines, certifying and testing voting systems, and providing election assistance grants to states.

<p> Federal Communications Commission

The measure provides the requested $388 million for the Federal Communications Commission (FCC) -- 4% more than FY 2021 -- all of which would be derived from offsetting collections.

Federal Trade Commission

The Federal Trade Commission (FTC) enforces a variety of federal antitrust and consumer protection laws. The FTC's appropriations are partially offset by Do-Not-Call registry fees and by corporate pre-merger filing fees.

The measure provides $390 million for the FTC, 11% more than FY 2021 and equal to the request. It is estimated that $158 million of that amount would be offset by collected fees, for a net direct appropriation of $232 million.

Consumer Product Safety Commission

The bill includes $172 million for the CPSC -- $37 million (27%) more than FY 2021. The CPSC is responsible for reducing the risk of injury associated with consumer products. The committee says the funding increase will address chronic underfunding at the agency, expand its operational capabilities to address changes in the marketplace, and allow improved consumer education on hidden hazards, especially in relation to toys and other products that pose a disproportionate risk for children.

The measure continues a prohibition on implementing new safety standards for off-road recreational vehicles until after the National Academy of Sciences completes a study on these vehicles.

Small Business Administration

The measure provides a total of $1.0 billion for the Small Business Administration -- 12% more than FY 2021 and 4% more than requested. This amount includes $294 million (9% more) for baseline salaries and expenditures.

It includes $323 million for SBA's Entrepreneurial Development Programs (19% more than FY 2021), which provide training, counseling and resources to help small-business owners compete in global markets. Programs funded under this account include SBA Small Business Development Centers ($140 million), Microloan Technical Assistance ($41 million), the SCORE mentorship program ($14 million), the State Trade Expansion Program ($20 million), Women's Business Centers ($26 million), and Veterans Outreach ($19 million).

The SBA total also includes $165 million for administrative costs of SBA business loans and loan guarantees, as well as $6 million in direct loan subsidies. The bill authorizes $30 billion in lending under the SBA's 7(a) loan program, which guarantees loans made by banks and other third-party lenders to small businesses that might otherwise be too risky for traditional loans, as well as $110 million in lending under the SBA microloan program, which provides loans to intermediary lenders that make small working capital loans in their community.

Another $178 million is provided for administrative costs of the SBA Disaster Loan Program, which is mostly financed through loan repayments. Within this amount, $143 million is available through the disaster budget cap adjustment, and would be used to provide relief for major disasters.

Finally, the measure provides an additional $32 million for small business development and entrepreneurship initiatives. These amounts are earmarked for 55 specified local governments, universities, and other nonprofit organizations (such as chambers of commerce and community partnerships) that administer SBA-funded small business development, counseling, and financing programs.

National Archives & Records Administration

The National Archives and Records Administration (NARA) is responsible for management of the federal government's archives and records, services to the public, operation of presidential libraries, review for declassification of classified security information, and the preservation, storage, and management of digital federal records.

The bill provides $404 million for NARA operating expenses, 7% more than FY 2021. Appropriators note that $2 million of within this amount is provided to implement the Civil Rights Cold Case Record Collections Act (PL 115-426), which requires public disclosure of records relating to civil rights cold cases.

It also provides $38 million for NARA repair and restoration activities, of which $30 million is provided as one-time funding to prepare for the 250th anniversary of the founding of the United States in 2026. Another $9.5 million is provided for the National Historical Publications and Records Commission Grants program (46% more than FY 2021), including $3 million for a program to preserve and digitize the records of Historically Black Colleges and Universities.

U.S. Postal Service

The U.S. Postal Service is a self-financed, semi-autonomous entity whose operations are funded primarily through postage rates paid by consumers. Congress, however, each year provides funds to the Postal Service to cover the costs of revenue forgone on free and reduced-rate mail for the blind and overseas voters.

The bill includes $59 million in such payments for the Postal Service Fund (6% more than FY 2021 and 11% more than requested), as well as the requested $263 million for the Postal Service's inspector general (5% more than FY 2021). The measure continues to direct USPS to issue semipostal charity stamps, which are sold above their postal value to raise funds for international wildlife conservation.

In its report, the committee allocates $6 million for the Postal Service to carry out a pilot program to provide certain nonbank financial services, including wire transfers, check cashing, and free ATMs in at least five rural and five non-rural Post Offices.

A separate appropriation of $20 million (15% more than FY 2021) is provided out of the Postal Service Fund for the Postal Regulatory Commission, a separate government agency that maintains USPS ratemaking systems, measures its performance, and conducts oversight and enforcement actions.

Other Independent Agencies

Funding for other independent agencies is provided as follows:

Federal Election Commission -- $77 million (7% more than FY 2021) for administering the disclosure of campaign finance information and enforcing limitations on contributions and expenditures.

Merit Systems Protection Board -- $48 million (3% more) for activities of the board in maintaining the Civil Service merit system.

Federal Labor Relations Authority -- $29 million (10% more) for the agency that serves as a neutral arbiter in the labor activities of the federal workforce.

Office of Government Ethics -- $20 million (10% more) for the office that oversees executive branch policies to prevent conflicts of interest and to ensure high ethical standards.

Office of Special Counsel -- $32 million (7% more than FY 2021) for investigations into federal employee allegations of prohibited practices, providing a channel for whistle-blowers and enforcing the Hatch Act.

Selective Service System -- $29 million (12% more) for the service to continue its draft registration activities.

U.S. Tax Court -- $58 million for activities of the Tax Court (4% more).

Public Buildings Reform Board -- $4.5 million for the board ($1 million more than FY 2021), which was established by the 2016 Federal Assets Sale & Transfer Act (PL 114-287) to identify opportunities for the federal government to reduce its inventory of underutilized property.

Commission on Naming & Displays

The measure appropriates $1.5 million to establish a Commission on Federal Naming and Displays, to identify and publish a list of federal monuments, statues, public artworks, historical markers, and property names owned by the federal government or located on federal property that are inconsistent with the values of diversity, equity, and inclusion. It requires the commission, within 180 days, to provide a report to the president and Congress with recommendations on whether the buildings or items in question should be renamed or removed.

The commission would consist of two members appointed by the President, two appointed by the Speaker of the House, two appointed by the Senate Majority Leader, and one each appointed by the House and Senate minority leaders, as well as the Secretary of the Smithsonian and the House and Senate Historians. The commission would disband 60 days after publishing its report.

Mandatory Items & General Provisions

The bill provides a total of $22.6 billion in mandatory spending, including $458 million for salaries of Supreme Court justices and other federal judges and an estimated $22.5 billion for other appropriated mandatory accounts where authorizing language requires the payment of funds.

These mandatory funds include payments for federal employee and retiree health benefits, the civil service retirement and disability fund, federal employee life insurance benefits, and judicial retirement funds. This total also includes $450,000 for the president's salary.

Policy Provisions

The bill includes a range of policy provisions, many of which have been included in past appropriations laws such as a requirement that all federal computers purchased with these funds block the viewing of pornography. It also continues a pay freeze for the Vice President and other senior political appointees (including ambassadors), blocking the automatic statutory pay increase for these officials.

Unlike prior appropriations acts, however, the bill does not prohibit the funding of abortions under federal employee health benefit plans and through multi-state qualified health plans negotiated by OPM that are offered under the 2010 health care law. It also does not include a prohibition on federal agencies requiring businesses to disclose their political contributions or expenditures when soliciting a federal contract.

New legislative provisions include the following:

'Dreamers' -- Allows federal agencies to employ "Dreamers" (U.S. residents that came into the country as children without proper immigration status) who hold employment authorizations under the Deferred Action for Childhood Arrivals (DACA) program.

GAO Audits -- Requires federal agencies to provide requested information to the Government Accountability Office within 20 days, unless GAO's written request specifies otherwise, and empowers GAO to bring civil action against an agency to compel their compliance if it does not meet this requirement. The measure also requires federal agencies to maintain records on any earmarked funds appropriated in FY 2022 for at least three years after they are obligated in order to facilitated GAO audits of such programs.

Federal Employee Unionization -- Prohibits federal agencies from implementing a collective bargaining agreement that was not mutually agreed to by all parties, and prohibits agencies from preventing workers from using official time or space in federal buildings for union activities. It also requires all federal agencies to comply with the 1978 Federal Service Labor-Management Relations statute, which guarantees collective bargaining rights for federal employees.

District of Columbia

The bill provides $794 million in federal payments to the District of Columbia for FY 2022 -- 6% more than FY 2021 and equal to the request.

Within the total, it provides $274 million for the D.C. court system (9% more than FY 2021), including $14 million for the D.C. Court of Appeals, $134 million for the Superior Court, $83 million for the general court system, and $42 million for capital improvements. It also provides $283 million for D.C. Court Services and Offender Supervision Agency, $46 million for defender services in D.C. courts, and $58 million for the Public Defender Service.

For D.C. education, it provides $53 million for the school improvement account, under which scholarships are provided for low-income youth to attend private schools, and $40 million to help college-bound District residents offset out-of-state college tuition costs (both equal to FY 2021). Another $600,000 is provided for tuition assistance for D.C. National Guard members.

Additionally, the measure provides $25 million for D.C. emergency planning and security costs; $5 million for HIV/AIDS Prevention activities; and $8 million to the D.C. Water and Sewer Authority to continue implementation of a long-term development plan, on the condition that the authority provide a 100% matching payment.

D.C. Policy Provisions

The bill includes new language that would prohibit the president from federalizing the D.C. Metropolitan Police Department for federal activities.

It also ends D.C.-related bans from that were included in prior appropriations laws, including by eliminating bans on the use of local and federal funds for abortion services, on the use of local funds to legalize marijuana, and on the use of funds for needle exchange programs.

By Daniel Peake [email protected]

Section V

Interior-Environment

This section describes the provisions of HR 4502, Seven-Bill FY 2022 Appropriations Package, that provide funding for the Interior Department, EPA, Forest Service and related agencies. (These provisions were reported by the Appropriations Committee as HR 4372, Interior, Environment and Related Agencies Appropriations Bill, 2022.

The bill provides $43.4 billion in net discretionary spending subject to caps along with $2.45 billion subject to its own fire suppression cap adjustment -- thereby providing a total of $45.85 billion in scored discretionary spending for FY 2022, $7.4 million (19%) more than comparable FY 2021 spending but $253 million less than requested. The measure also includes $64 million in mandatory funding.

It increases funding for EPA by 23% to $11.3 billion, boosting EPA funding for enforcement and compliance, research, state and tribal grant programs, and the Superfund program. EPA funding includes a 26% increase for scientific and regulatory work on toxic PFAS ("forever" chemicals) needed to establish drinking water and cleanup standards, and an eight-fold increase for environmental justice activities, including the creation of six grant programs to begin implementing environmental justice "solutions."

It provides a total of $15.6 billion for the Interior Department (17% more than comparable FY 2021 funding), with all the major agencies receiving increases, including the National Park Service (11% more), U.S. Geological Survey (25%), U.S. Fish and Wildlife Service (19%), and the Bureau of Land Management (22%). The measure requires the Interior Department, in concert with the Agriculture Department, to take some initial steps towards creation of a Civilian Climate Corps.

The measure also provides $8.4 billion for the U.S. Forest Service, including $4.1 billion in core Forest Service activities (20% more than FY 2021, with a 25% increase for the National Forest System) and $4.2 billion for fighting wildfires. Combined Interior and Forest Service wildfire funding would provide a total of $5.7 billion for fighting wildfires, 7% more than comparable FY 2021 funding.

It also significantly increases funding for American Indian programs administered by the Bureau of Indian Affairs (14% more than FY 2021) and the Indian Health Service (30% more) -- in part to address severe health care deficiencies that were exposed by the COVID-19 pandemic.

Finally, the bill includes 308 earmarks for projects in members' districts that total $445 million, with most the projects under EPA's clean water and drinking water state revolving funds.

Environmental Protection Agency

The bill provides $11.3 billion for EPA -- $2.1 billion (23%) more than FY 2021 funding and $111 million (1%) more than requested.

The measure increases funding for most EPA programs, including Superfund cleanups and state and tribal assistance grants. The committee report for the bill encourages the agency to report any linkages between exposure to pollution and increased risk for adverse health outcomes from communicable respiratory diseases, such as COVID-19.

EPA Enforcement & Environmental Management Activities

The bill appropriates $3.4 billion for EPA environmental programs and management accounts, through which EPA performs its general environmental oversight activities -- $603 million (22%) more than FY 2021.

Within this account, it increases funding for numerous enforcement and associated activities, including: EPA enforcement actions ($273 million, 10% more than FY 2021); EPA's compliance activities ($132 million, 29% more); EPA clean air activities ($435 million, 54% more); EPA activities under the Resource Conservation and Recovery Act ($123 million, 4% more); and water-related activities to protect human health ($119 million, 10% more).

It also increases funding for legal, science, regulatory and economic reviews (providing $147 million, 38% more than FY 2021), EPA's toxics risk review and prevention activities ($109 million, 17% more), EPA's pesticide licensing activities ($110 million, 1% more) and the underground storage tanks program ($13 million, 19% more).

A total $643 million is provided for EPA geographic programs -- i.e., environmental restoration and preservation initiatives for specified areas -- $101 million (19%) more than FY 2021. The total includes $375 million for the Great Lakes Restoration Initiative (14% more than FY 2021); $91 million for the Chesapeake Bay initiative (3.4% more); $50 million for the Pugent Sound (48% more); $40 million for the Long Island Sound (32% more); and $25 million for San Francisco Bay (almost double the FY 2021 level).

EPA Grant Programs

EPA administers numerous grant and funding programs that offer assistance to states, Native American tribes and municipal governments for environment-related infrastructure and cleanup projects, or for specific categories of projects such as air quality management, brownfields cleanup and wetland programs.

The measure provides $5.3 billion for these EPA state and tribal assistance grants, $1.0 billion (23%) more than FY 2021.

For infrastructure assistance grants it provides a base total of $4.0 billion, $747 million (23%) more than FY 2021. Included in this total is $1.9 billion for the Clean Water State Revolving Fund and $1.4 billion for the Drinking Water State Revolving Fund -- both equal to the request but 14% and 21% more than FY 2021 funding, respectively.

Within those two totals, $222 million of the Clean Water State Revolving Fund and $202 million of the Drinking Water State Revolving Fund is earmarked for specified drinking water, waste water, storm water, and water quality protection projects. Under the measure, each project must provide at least 20% in matching funds from non-federal sources, unless a waiver is granted. (The bill specifies, however, that Community Development Block Grants from the Housing and Urban Development Department, Agriculture Department Rural Development funding, and Appalachian Regional Commission grants could be used for the local matching requirement, while any funding provided under the American Rescue Plan Act (PL 117 - 2) could not.)

For other state and tribal grant programs, the measure provides $131 million for Brownfields projects (44% more than FY 2021); $150 million for diesel emission grants (67% more); $60 million for sewer overflow control grants (50% more); $40 million for grants to small and disadvantaged communities (52% more); $37 million for lead testing in schools (38% more); and $82 million reducing lead in drinking water (almost three times the FY 2021 level). It provides $35 million for water infrastructure for communities along the border with Mexico (17% more than FY 2021) and $36 million for Alaska Native villages (equal to FY 2021). It also provides $55 million for a new recycling infrastructure grant program authorized under the Save Our Seas 2.0 Act (PL 116-224) for improvements to municipal recycling programs and local waste management systems.

For EPA categorical grants, it provides a total of $1.3 billion -- $163 million (15%) more than FY 2021 -- with every program but one receiving a funding increase. Among those programs, it provides $320 million for state and local air quality management grants (39% more than FY 2021); $235 million for pollution control grants (2% more); $180 million for nonpoint source pollution grants (almost 2% more); $112 million for hazardous waste financial assistance (10% more); $49 million for Brownfields (6% more); $80 million for the tribal general assistance program (21% more); and $24 million for tribal air quality management grants (80% more).

Promote Environmental Justice

The bill provides a total of $100 million for six new grant programs to address the disproportionate environmental or public health harms and risks that impact minority or low-income populations -- which the committee says are designed to "begin implementing environmental justice solutions on the ground in frontline and fenceline communities."

Grant programs include $35 million for a competitive grant program, $30 million for a state grant program, $15 million for a Tribal grant program, and $10 million for an environmental justice training program.

The committee also notes that $148 million in other EPA programmatic funds are provided to expand EPA's ability to incorporate environmental justice considerations into all aspects of its work, and to support the environmental justice efforts of other federal agencies.

WIFIA Program

The measure provides $80 million for the Water Infrastructure Finance and Innovation Act (WIFIA) program, which helps finance long-term, low-cost supplemental loans for the construction of regionally and nationally significant water infrastructure projects. The total is $15 million (23%) more than provided for FY 2021 and equal to the request.

Within the total provided, $8 million could be used to cover program administrative expenses and the remaining $72 million (21% more than FY 2021) would be used to subsidize direct loans.

Superfund

The measure provides $1.5 billion for EPA's Hazardous Substance Superfund -- $330 million (27%) more than FY 2021 and slightly more than requested.

Of the total, $1.1 billion in base funding is for hazardous-waste site cleanup activities ($299 million, or 37%, more than FY 2021) with all cleanup-related accounts being funded at or above FY 2021 levels and the remedial cleanup account receiving a 50% to $822 million.

It also provides $176 million for EPA Superfund enforcement activities (1% more than FY 2021), $141 million for operations and administration of the program (10% more), and almost $6 million for new environmental justice activities.

Separately, it provides $92 million for activities associated with the cleanup of underground storage tanks through the Leaking Underground Storage Tank (LUST) Trust Fund, a slight increase compared to FY 2021 but equal to the request.

Science & Technology

The bill provides $807 million in funding for EPA's science and technology programs -- $78 million (11%) more than FY 2021, and it increases funding for all activities.

Within the total, it provides $139 million for the clean air program (17% more than FY 2021), $14 million for enforcement activities (1% more), and $40 million for homeland security activities (13% more).

For research programs, it provides $125 million for air and energy issues (31% more than FY 2021), $135 million for chemical safety and sustainability (6% more), $117 million for safe and sustainable water resources (4% more), and $137 million for sustainable and healthy communities (3% more).

In its report, the committee urges EPA to act expeditiously in setting drinking water standards for per- and polyfluoroalkyl substances (PFAS) and in designating PFAS as a hazardous substance under CERCLA. The committee in a press release says that among EPA accounts the measure provides $62 million (26% more than FY 2021) for scientific and regulatory work to establish drinking water and cleanup standards.

The report also notes the linkage between exposure to pollution and increased risk for adverse health outcomes from communicable respiratory diseases, such as COVID-19, and it directs EPA to brief the committee on its ongoing work in this area, including efforts underway to coordinate its research efforts with other federal agencies.

Interior Department

The bill provides a total of $16.0 billion for the Interior Department and related agencies. The total includes $15.6 billion in discretionary funding subject to caps and $330 million for fighting wildfires under a separate wildland fire suppression cap adjustment. It also includes $64 million in mandatory funding. The discretionary total (excluding the cap adjustment) is $2.3 billion (17%) more than FY 2021 but $250 million (2%) less than requested.

(Under legislation cleared by Congress last year (PL 116-152), funding for activities under the Land and Water Conservation Fund (LWCF) became mandatory and is no longer count against discretionary caps, nor is the funding provided by this appropriations bill.)

The measure supports the establishment of a Civilian Climate Corps, as proposed by President Biden. The president in an Executive Order in January directed the Interior Department, in collaboration with the Agriculture Department and other relevant agencies, to develop a strategy for creating a Civilian Climate Corps initiative to help address climate change -- including by taking actions to conserve and restore public lands and waters and increase reforestation. The committee in its report expresses support for the proposal, and directs that about $6 million in departmental funding be used for associated activities and that $10 million in Bureau of Indian Affairs funding be used to create a Tribal Civilian Climate Corps. It also directs the Interior and Agriculture departments, within 90 days of enactment, to provide a written plan for how CCC funding would be used along with an analysis of the impacts of creating a dedicated budget line for the CCC.

Major Interior Agencies & Bureaus

National Park Service

The bill provides $3.5 billion for the National Park Service -- $347 million (11%) more than FY 2021 but 1% less than requested.

The vast majority, $3.0 billion, is for operation and maintenance of national parks, $277 million (10%) more than FY 2021. Included in that amount is $915 million for facility operations and maintenance (2% more than FY 2021), $561 million for resource stewardship (55% more), and $415 million for park protection (8% more).

The total also includes $253 million for Park Service construction projects, $29 million (13%) more than FY 2021. Of that amount, $139 million ($7 million more than FY 2021) is for specific projects detailed in the Park Service's budget and $20 million ($17 million more) is for emergency and unscheduled construction.

It also provides $80 million for national recreation and preservation activities (8% more than FY 2021) and $156 million for Historic Preservation Fund activities (also 8% more) -- of which $58 million is for state historic preservation offices (3.6% more), $28 million is for competitive grants (31% more), and $30 million is for Save America's Treasures grants (20% more).

Finally, the measure includes the requested $15 million for the Centennial Challenge to fund joint public-private infrastructure investments in honor of the National Park Service's centennial, equal to FY 2021 funding.

Bureau of Land Management

The bill provides $1.6 billion in discretionary funding for Bureau of Land Management (BLM) activities -- $285 million (22%) more than FY 2021. It also includes $36 million in mandatory spending.

Within the total, it provides $1.4 billion for BLM land management programs, 21% more than FY 2021. That amount includes $241 million for managing energy and mineral activities on BLM lands (21.5% more than FY 2021), including $16 million for coal mining (2% more), $167 million for oil and gas activities (19% more), and $43 million for renewable energy (41% more).

The land management total also includes $178 million for resource protection and maintenance (33% more than FY 2021), $233 million for wildlife and fisheries management (23% more), $95 million for recreation management (24% more), and $66 million for the National Landscape Conservation System (45% more) -- which consists of about 35 million acres designated by Congress and the president to conserve special features. It includes $162 million for wild horse and burro management (40% more), which appropriators say includes $11 million for research on reversible immunocontraceptive fertility control. Appropriators note that $80 million of BLM land management funding is to be used for sage grouse conservation.

The measure also provides $124 million for managing certain lands in Oregon known as Oregon and California grant lands (8% more than FY 2021).

The committee in its report encourages BLM to evaluate carbon storage as a potential activity on public lands as a means to reduce carbon emissions and mitigate climate change.

U.S. Fish & Wildlife Service

The bill provides a total of $1.9 billion for the U.S. Fish and Wildlife Service (FWS) -- $301 million (19%) more than FY 2021 but 2% less than requested.

The vast majority, $1.7 billion, is for FWS resource management activities, including management of critical habitat, fisheries and endangered species. That amount is 20% more than FY 2021.

Resource management funding includes $582 million (15.5% more than FY 2021) for operating the National Wildlife Refuge System, $80 million for habitat conservation (14% more), and $66 million for migratory bird management (39% more).

It provides $250 million for fish and aquatic conservation activities (21% more than FY 2021), of which $76 million is to operate the national fish hatchery system (15% more). The measure prohibits the termination or closure of any national fish hatchery, and no hatchery could be downsized or terminated without advance consultation with affected states. It includes the requested $26 million to stop the spread of Asian carp in the Great Lakes, of which $4 million is to be used to perfect the combined use of contract fishing and deterrents to extirpate Asian carp, including grass carp, and $3.5 million is to prevent the spread of quagga and zebra mussels in the West.

In its report, the committee requires the agency to incorporate climate change adaptation actions and activities into new and revised recovery plans and recovery implementation strategies and to brief the committee on how it is prioritizing recovery actions that improve a species' resiliency, redundancy, and representation so that a species is able to withstand the impacts of climate change and show direct evidence that these actions are incorporated into new and revised recovery plans.

Outside of FWS resource management, the bill provides $82 million for state and tribal wildlife grants (14% more than FY 2021), $50 million for the North American Wetlands Conservation Fund (8% more), $24 million for the Cooperative Endangered Species Conservation Fund (2% more), and $6.5 million for neotropical migratory bird conservation (32% more).

It also provides $22 million for the Multinational Species Conservation Fund (22% more than FY 2021), which provides technical and financial assistance to local communities, wildlife authorities, and non-governmental organizations in foreign countries for on-the-ground conservation work to protect African and Asian elephants, rhinoceroses, tigers, great apes, and marine turtles, and their habitats. In its report, the committee says it is aware of how the coronavirus is devastating ecotourism, thus impacting the enforcement of wildlife trafficking prohibitions and the ability to protect wildlife, and that is supports aiding key wildlife populations.

U.S. Geological Survey

The bill provides $1.6 billion for the U.S. Geological Survey, the federal government's largest earth-science research agency -- $327 million (25%) more than FY 2021 funding but equal to the request.

The total includes $355 million for USGS ecosystems studies and research (38% more than FY 2021), including $116 million for climate adaptation and land change science activities (92% more), $71 million for land management research (26% more), and $69 million for species management research (29% more).

It also includes $293 million for USGS water resources activities (11% more than FY 2021), including $113 million (12% more) for the agency's groundwater and streamflow information program and $69 million for water availability and use science (18% more). USGS is the primary source of data on the nation's surface and ground water resources.

It provides $145 million for the agency's energy and mineral resources programs (61% more than FY 2021) and $208 million for its natural hazards programs (18% more) -- including $34 million for the volcano hazards program (11% more), $57 million for the coastal/marine hazards program (42% more), and $93 million for the earthquake hazards program (8% more). The committee directs that $29 million is to be used for continued development and expansion of the ShakeAlert West Coast earthquake early warning (EEW) system including capital costs associated with the buildout of the system.

Interior Department Regulatory Agencies

Bureau of Ocean Energy Management

The Bureau of Ocean Energy Management (BOEM) is the primary authority for permitting offshore energy exploration and extraction activities.

The bill provides $224 million for BOEM activities, $31 million (16%) more than FY 2021 funding. Approximately $43 million of the funding is assumed to be provided through fees and receipts collected on oil and natural gas leases on the outer continental shelf, resulting in a net appropriation of $181 million.

The total includes $46 million for the agency's Renewable Energy Program (61% more than FY 2021) and $87 million for environmental assessments (14% more), but $58 million ($2 million less) for its conventional energy program.

Bureau of Safety and Environmental Enforcement

The Bureau of Safety and Environmental Enforcement (BSEE) is responsible for enforcing offshore environmental regulations as they relate to energy extraction and exploration. BSEE is also responsible for oil spill research and response plan development.

The measure provides $213 million for core BSEE activities in FY 2021, $19 million (10%) more than FY 2021 funding, including $5 million in new funding to begin decommissioning abandoned offshore infrastructure. It also provides $15 million for BSEE oil spill research activities, equal to current funding. About $58 million is assumed to be provided through lease payments, and fees, resulting in a net total appropriation of $170 million.

Office of Surface Mining, Reclamation & Enforcement

The Office of Surface Mining, Reclamation and Enforcement regulates surface coal-mining operations to ensure that the environment is protected during those operations and that the land is adequately reclaimed once mining is completed.

The bill provides the requested $312 million for the office, $89 million (40%) more than FY 2021. The total includes $165 million for state grants under the Abandoned Mine Reclamation Fund (43% more than FY 2021) and $28 million for other Mine Reclamation Fund activities (12% more).

Other Interior Activities

The bill also funds several other activities within the Interior Department (including for fighting wildfires and for certain American Indian programs, both of which are discussed in other sections below).

Payments in Lieu of Taxes Program

The Payments in Lieu of Taxes (PILT) program provides federal payments to local governments that have large tracts of federal land that can't be locally taxed, in order to help those governments carry out vital services such as firefighting and police protection, as well as construction of public schools and roads.

The measure provides "such sums as may be necessary" for the program through FY 2022, which are estimated to provide a total of $515 million.

Land & Water Conservation Fund (LWCF)

Because of changes enacted in 2020 that made the public lands acquisition and preservation program a mandatory funding program, the bill does not contain either discretionary or mandatory funding for the LWCF -- but rather, it allocates how the estimated $900 million that will be made available for FY 2022 will be distributed.

The fund is financed primarily from royalties from offshore oil and gas leasing, and is supposed to be used by federal, state and local governments to help acquire or preserve lands and waters for recreational and other purposes.

Office of Insular Affairs

The measure provides $128 million to the Office of Insular Affairs, $13 million (11%) more than FY 2021. Of that total, $28 million is mandatory funding.

The Office of Insular Affairs administers U.S. responsibilities with respect to its four territories -- Guam, American Samoa, the U.S. Virgin Islands and the Commonwealth of the Northern Mariana Islands -- as well as the three freely associated states (the Federated States of Micronesia, the Republic of the Marshall Islands and the Republic of Palau) and provides certain assistance.

U.S. Forest Service & Wildfire Funding

The Agriculture Department's U.S. Forest Service manages 193 million acres of national forests and grasslands in 44 states and Puerto Rico. The National Forest System includes 155 national forests, 20 national grasslands, 20 national recreation areas, a national tallgrass prairie, and six national monuments. Forest Service lands are managed for multiple uses, including timber production, recreation, wilderness, minerals, grazing, fish and wildlife habitat management, and soil and water conservation.

The bill provides a total of $8.4 billion for the U.S. Forest Service, $931 million (12.5%) more than FY 2021 and slightly less than requested. Almost half the funding for the Forest Service, however, is for fighting wildfires (see below).

Core Forest Service Activities

The measure provides $4.1 billion for core (non-wildfire) Forest Service activities -- $680 million (20%) more than FY 2021 funding and slightly less than requested.

Within the total for core Forest Service activities, $2.2 billion is for operation and maintenance of the national forest system, $445 million (25%) more than FY 2021 funding but 6% less than requested. Forest system funding includes $321 million for hazardous fuels reduction activities (78% more than FY 2021), $98 million for vegetation and watershed management (more than triple FY 2021), $71 million for recreation, heritage and wilderness activities (more than double FY 2021), and $60 million for collaborative forest landscape restoration (more than four times the FY 2021 level). It also increases funding for national forest system wildlife and fish habitat management (by 40%), for grazing management (by more than triple FY 2021), for minerals and geology management (by almost triple), and for forest products management (by just 2%).

For state and private forestry the bill provides $325 million, $64 million (24%) more than FY 2021, including $68 million for cooperative forestry (42% more than FY 2021), $59 million for forest health management (28% more), and $20 million for landscape scale restoration (43% more).

For forest and rangeland research the bill provides $364 million (41% more than FY 2021), and it provides $153 million for capital improvements and maintenance (9% more) with increases provided only for trails and certain legacy trails and roads.

In its report, the committee directs the agency to submit an annual estimate of carbon accounting on Forest Service lands broken down by region. The committee says it expects that funding increases given to numerous programs throughout the Forest Service (including to combat wildfires and invasive species and diseases, and to rehabilitate burned areas) will help contribute to an increase in the amount of carbon that is stored in our National Forests.

Forest Service / Interior Department Wildfire Funding

The measure provides a total of $5.66 billion for fighting wildfires, including $1.4 billion in Interior Department funding and $4.2 billion in Forest Service funding. Of those amounts, $330 million of the Interior wildfire funding and $2.1 billion in Forest Service wildfire funding is covered by the fire suppression cap adjustment. According to the committee, the bill's total for wildfire funding is $386 million more than FY 2021 but $380,000 less than requested.

The total includes $548 million for wildland fire preparedness activities ($192 million Forest Service and $356 million Interior) and $1.4 billion for wildland fire suppression operations, including funds under the cap adjustment ($1.0 billion Forest Service and $384 million Interior). The total also includes $371 million in Interior funding for other activities -- including $304 million for fuels management and $40 million for burned area rehabilitation.

In its committee report, appropriators note that returning fire to the landscape can be a successful tool for reducing wildfire risk and they encourage the Forest Service to improve its use of prescribed fire practices. They also direct the service at the end of each fiscal year to detail the number of acres treated using prescribed fire as well as the costs associated with such activities, and to report to the committee. The report must also detail the barriers to implementing prescribed burns in the western United States, possible solutions, and an estimate of fire damage in 2020 that could have potentially been avoided had the agencies implemented a more robust prescribed burn regime.

The committee also directs the Interior Department and Forest Service to explore the possibility of allowing formerly incarcerated individuals to qualify for federal wildland firefighting positions, and to brief the committee within 180 days on the viability of a pilot program.

Native American Programs

The bill significantly increases funding for American Indian programs administered by the Interior Department and Health and Human Services (HHS) Department.

Bureaus of Indian Affairs & Indian Education

The measure appropriates $4.0 billion for the operation of American Indian programs administered by the Interior Department -- primarily the Bureau of Indian Affairs (BIA) and the Bureau of Indian Education -- including social services, education, employment development, law enforcement and natural resources development. The total provided is $507 million (14%) more than FY 2021 but 2% less than requested.

The Bureau of Indian Affairs delivers services to about 1.9 million American Indians and Alaska Natives, including the operation of 183 schools and the administration of 55 million acres of land held in trust for individuals or tribes.

Under the measure, the Bureau of Indian Education would receive $1.35 billion, of which $1.1 billion (11% more than FY 2021) would be for education programs -- including elementary, secondary and post-secondary programs and activities. It also provides $267 million for school and facilities construction, repair and improvements, 1% more than FY 2021.

For the Bureau of Indian Affairs (BIA) the bill provides $2.55 billion, of which $1.9 billion is for operation of Indian programs -- $308 million (19%) more than FY 2021. Within that funding, the measure provides $355 million for tribal government support (4% more than FY 2021), $510 million for public safety and justice (14% more), and $177 million for human services activities (10% more).

The measure also provides $188 million for BIA construction activities, 46% more than FY 2021.

In its report the committee expresses concern about staff shortages at BIA and its inability to fulfill its trust and treaty obligations to Indian Tribes because of the shortages, saying it expects the agency to prioritize filling full-time positions expeditiously.

Finally, the measure also provides $110 million for the new Office of Special Trustee for American Indians. The office, established by the Indian Trust Asset Reform Act (PL 114-178), is responsible for managing the approximately 55 million surface acres of land, 57 million acres of subsurface mineral interests, and approximately $5.5 billion held in trust by the federal government on behalf of American Indians, Alaska Natives, and federally recognized Indian Tribes. The committee rejects the administration's request to create of a new bureau and proposed budget structure.

Indian Health Service

The Indian Health Service (IHS) within HHS provides health care to American Indians through 28 hospitals, 61 health care centers and 34 health stations. Through contracts with the service, tribes operate 17 additional hospitals, 249 health centers, six school health centers, 70 health stations and 164 Alaska village clinics.

The bill provides $8.1 billion for the Indian Health Service -- $1.9 billion (30%) more than FY 2021. The committee in its report notes that the coronavirus pandemic highlighted deficiencies in health care delivery in Indian country, including antiquated buildings, poor water infrastructure, and numerous vacancies that contributed to the spread of the virus and has hindered the ability to fully respond. It requires the IHS to report on the challenges it and tribes faced over the course of the pandemic and how they were resolved, as well as weaknesses that will persist beyond the pandemic's conclusion.

The IHS total includes $5.2 billion for clinical services ($1.3 billion, or 33%, more than FY 2021), including $2.7 billion (22% more than FY 2021) for the operation of hospitals and health clinics. That clinical services total also includes $317 million for the Indian Health Care Improvement Fund to help reduce health care disparities across the IHS system (more than triple FY 2021 funding), while increasing funding for dental health by 34% and mental health by 8%.

The measure more than triples funding for urban Indian health services (providing $201 million), while within the IHS's preventive health program it provides $105 million for public health nursing (13% more than FY 2021).

It also provides $1.3 billion for maintenance and construction of Indian Health facilities (40% more than FY 2021), including $414 million for health care facilities construction (60% more).

Other Agencies

The bill provides $84 million for the Agency for Toxic Substances and Disease Registry within HHS (3% more than FY 2021), and it provides $84 million for the National Institute of Environmental Health Sciences within the National Institutes of Health (2% more).

It also provides the following:

NEA & NEH -- $201 million each for the National Endowment for the Arts and the National Endowment for the Humanities, each $34 million (20%) more than FY 2021.

Smithsonian -- $1.1 billion for the Smithsonian Institution, $69 million (9%) more than FY 2021, including $3.4 million to begin planning and design work on the new National Museum of the American Latino and similarly $2.5 million for the new Smithsonian American Women's History Museum.

National Gallery of Art -- $184 million for the National Gallery, 4% more than FY 2021.

Kennedy Center -- $40 million for the John F. Kennedy Center for the Performing Arts, slightly more than FY 2021.

Holocaust Museum -- $63 million for the U.S. Holocaust Memorial Museum, 2% more than FY 2021.

<p> By Karin Fuog [email protected]

Section VI

Labor-HHS-Education

This section describes the provisions of HR 4502, Seven-Bill FY 2022 Appropriations Package, that provides funding for programs and activities of the Labor, Health and Human Services, and Education departments and related agencies. (These provisions were originally reported by the Appropriations Committee as HR 4502, Labor-HHS-Education Appropriations for FY 2022.)

The bill provides $237.5 billion in discretionary spending subject to spending caps as well as $2.1 billion subject to cap adjustments for program integrity initiatives for a total of $239.6 billion in scored discretionary spending -- although on a programmatic basis (after certain scorekeeping adjustments are factored out) the agencies funded by the bill would actually have $254.3 billion available for their use in FY 2022, $54.2 billion (27%) more than FY 2021. The measure also provides $1.088 trillion in mandatory spending for Medicaid grants to states, Social Security Supplementary Security Income benefit payments, and other purposes for FY 2022.

It increases HHS discretionary spending by 24% to $119.8 billion, with major increases for public health (21%), the CDC (34%), and NIH (15%), including a 26% increase for the National Institute on Drug Abuse and $3.0 billion for a new initiative, Advanced Research Projects Agency for Health (ARPA - H). It also increases funding for programs of the Substance Abuse and Mental Health Administration by 52%, and for the Child Care Development Block Grant by 25%. The measure ends two long-term restrictions on abortions: the Hyde amendment that generally prohibits the use of federal funds for abortions, and the Weldon amendment that prohibits the government from discriminating against health care professionals or entities that don't provide for abortions.

It increases Education Department spending by 38% to $106.5 billion, -- more than doubling funding for Title I grants, increasing special education programs by 22%, increasing by 44% aid to higher education institutions that primarily serve minority populations, increasing national school safety activities eight-fold, and increasing the maximum Pell Grant by $400 to $6,895.

For the Labor Department, it increases spending by 17% to $14.7 billion, with a 20% increase to job training and employment services under the Workforce Investment Act, a 17% increase for OSHA, and a 22% increase for state unemployment insurance and employment service operations.

The measure includes 861 earmarks for projects in members' districts that total $675 million.

(The measure includes $210.7 billion in advance funding for future years, including $24.9 billion in discretionary funding and $185.8 billion in mandatory funding. Funding available for FY 2022 includes $24.8 billion in previously appropriated discretionary funding and $172.7 billion in mandatory funding.)

Health and Human Services Department

The bill provides $119.8 billion in discretionary spending to HHS, according to the committee, for programs and activities of the Health and Human Services (HHS) Department -- (24% more than FY 2021).

It also provides $1.088 trillion in mandatory spending for Medicaid grants to states, Social Security Supplementary Security Income benefit payments, and other purposes for FY 2022. It rescinds $13.7 billion from the child enrollment contingency fund and $500 million of unobligated balances from the nonrecurring expenses fund.

Public Health Service Programs

The measure provides $78.6 billion for programs and activities of HHS Public Health Service agencies for FY 2022 -- including the Centers for Disease Control (CDC), National Institutes of Health (NIH), Health Resources and Services Administration (HRSA), Substance Abuse and Mental Health Services Administration (SAMHSA), and Agency for Healthcare Research and Quality (AHRQ).

The public health service total is $13.7 billion (21%) more than the comparable FY 2021 total, but 1% less than requested.

National Institutes of Health

The bill provides $49.4 billion (16% more than FY 2021 but 4% less than requested) for the NIH, including $225 million from transfers.

Included in the NIH total is funding for accounts established by the 21st Century Cures Act (PL 114-255), including $194 million for the Cancer Moonshot Initiative, $541 million for the All of Us initiative, and $612 million for the Brain Research through Application of Innovative Neurotechnologies (BRAIN) Initiative.

The measure provides $7.0 billion for the National Cancer Institute (7% more than FY 2021). In its report, the committee urges NCI to focus research on metastatic breast cancer to address the racial disparities that cause Black women to die 40% more frequently from these cancers than white women, as well as research addressing why Black men are 80% more likely than white men to contract prostate cancer.

It provides $2.8 billion for the National Institute of Neurological Disorders and Stroke (11% more than FY 2021), including $405 million for the Helping to End Addiction Long-Term (HEAL) Initiative, a trans-NIH effort to speed scientific solutions to stem the national opioid public health crisis. For the National Institute on Aging it provides $4.3 billion (9% more than FY 2021).

It provides $6.6 billion for the National Institute of Allergy and Infectious Diseases (NIAID), 8% more than FY 2021. Within that total, $50 million is to support research and development of rapid vaccine platform technologies and $250 million is for research on a universal influenza vaccine.

For the other major institutes the measure provides the following: $3.9 billion for the National Heart, Lung and Blood Institute (5.5% more than FY 2021); $2.4 billion for the National Institute of Diabetes and Digestive and Kidney Diseases (5% more); $1.7 billion for the National Institute of Child Health and Human Development (6% more); $1.9 billion for the National Institute on Drug Abuse (26% more); $2.1 billion for the National Institute of Mental Health (4.5% more); and $3.1 billion for the National Institute of General Medical Sciences (5% more).

The committee urges CDC to prioritize research into long COVID and diseases that result from contracting COVID-19. It also encourages research on cannabis and cannabidiols to determine their beneficial medicinal effects, and directs NIDA to facilitate access to Schedule I drugs for research. The measure provides $25 million (double the FY 2021 level) to support research on the prevention of gun violence. The committee also requires NIH and CDC to collaborate with the National Institute of Justice to compile, share, and improve firearm violence data.

Finally, the measure provides $3.0 billion to establish the Advanced Research Projects Agency for Health (ARPA - H), less than half the request.

Centers for Disease Control & Prevention

The bill provides a total of $10.6 billion for activities of the Centers for Disease Control and Prevention (CDC), $2.7 billion (34%) more than FY 2021 and 11% more than requested.

Within the total, $862 million is for public health preparedness and response activities related to bioterror attacks and pandemic diseases (2% more than FY 2021), and $951 million is for immunization and respiratory disease activities (16% more) -- including an additional $100 million to enhance adult immunization and $25 million more to enhance influenza activities. The committee urges the CDC to engage parents and community groups and to prioritize immunization reminders.

It provides $1.6 billion for CDC's chronic disease prevention and health promotion activities, (22% more than FY 2021), including $153 million for a social determinants of health program; $1.3 billion for CDC-wide public health leadership and support activities (more than four times the FY 2021 level); and $1.5 billion for CDC's HIV/AIDS, viral hepatitis, sexually transmitted diseases and tuberculosis prevention activities (14% more).

It also provides $343 million for CDC environmental health activities (54% more than FY 2021), and $1.1 billion for injury prevention and control activities (56% more) which include the prevention of rape, domestic violence, teen violence and illicit opioid use. That includes $100 million for a new evidence-based community violence intervention initiative.

Finally, it provides $843 million for CDC's global health activities (42% more than FY 2021), with most of the increase ($245 million) to support and enhance CDC's mission to protect the health of our nation by working across the globe.

Health Resources & Services Administration

The measure provides $9.1 billion (21% more than FY 2021 and 11% more than requested) for programs and activities of HHS's Health Resources and Services Administration (HRSA). Of that amount, $1.8 billion is for community health centers -- which when combined with $4.0 billion in mandatory funding would provide a total of $5.8 billion for community health centers (3% more than FY 2021).

It provides $1.6 billion for programs aimed at addressing shortages of health professionals (28% more than FY 2021). That total includes $314 million for nursing programs (16% more) and $400 million for graduate medical education programs at children's hospitals (14% more). It also includes $75 million for medical student education (50% more) to expand existing medical student education programs for health care professionals in an effort to address a projected future shortage of primary care physicians, and $116 million for a variety of Health Professions programs to support diversity in the health workforce (27% more).

For maternal and child health programs, it provides $1.2 billion (22% more than FY 2021), and it provides $2.7 billion for Ryan White HIV/AIDS programs (10% more) including an 81% increase for domestic HIV/AIDS initiatives and a 32% increase for education and training centers.

It also provides $147 million (14% more than FY 2021) for various health care systems such as Poison Control Centers, recruiting bone marrow donors, the 340B drug discount program and the National Cord Blood Inventory, as well as $400 million (22% more) for rural health programs -- including $140 million (27% more) for the rural communities opioid response program.

Finally, it provides $400 million for the department's Title X family planning programs, 40% more than FY 2021; Planned Parenthood would be eligible for Title X family planning funding.

Substance Abuse & Mental Health Services Administration

The bill provides $9.2 billion for programs and activities of the Substance Abuse and Mental Health Services Administration (SAMHSA), 52% more than FY 2021 but 6% less than requested.

The total includes $5.5 billion for substance abuse treatment programs (43% more than FY 2021) -- including $2.9 billion for block grants to states (53% more than FY 2021), $654 million for programs of regional and national significance (32% more), and $2.0 billion for state opioid response grants (33% more).

The committee requires SAMHSA to report on gaps in care regarding PTSD among first responders, including prevalence, risk factors, symptoms, and rates of suicidal thoughts and actions.

For SAMHSA mental health programs, the measure provides a total of $3.2 billion (76% more than FY 2021). That total includes the requested $1.6 billion for community block grants (more than double FY 2021); $739 million for programs of regional and national significance (52% more); $375 million for Certified Community Behavioral Health Clinics (50% more); and $150 million for children's mental health services. It also includes $100 million for the National Child Traumatic Stress Initiative (20% more).

The bill includes $100 million for a pilot program to create or enhance mobile behavioral health crisis response teams that respond to mental health crises rather than law enforcement.

Agency for Healthcare Research and Quality

The measure provides the requested $380 million (12% more than FY 2021) for the Agency for Healthcare Research and Quality (AHRQ), which includes $5 million to establish the Center for Primary Care Research.

Centers for Medicare & Medicaid Services

The Centers for Medicaid and Medicare Services (CMS) oversees those two entitlement programs and is responsible for administering portions of the 2010 health care overhaul (the ACA; PL 111-148 and PL 111-152). All of its funding is mandatory spending or comes from the Medicare Trust Fund.

The bill provides a total of $4.3 billion from the Medicare Trust Fund for CMS management activities (18% more than FY 2021), as well as $873 million from the trust fund for health care fraud and abuse control activities carried out by CMS, the HHS Inspector General, and the Justice Department (8% more).

Medicare & Medicaid

The bill provides a total of $517.4 billion in mandatory funding (including advance funds from last year) for grants to states for the joint federal-state Medicaid program, 14% more than comparable FY 2021 funding. It also provides $165.7 billion in advance mandatory funding for FY 2023.

That state grant total for FY 2022 includes $490.0 billion for the federal share for Medicaid benefits (15% more than FY 2021), $22.3 billion for state and local administration of the program, and $5.1 billion for vaccines for children.

The measure also provides $487.9 billion in mandatory funding payments to Medicare's trust funds for various programs and purposes in FY 2022 (11% more than FY 2021). Those payments include $101.0 billion for Medicare's Part D prescription drug program benefits (10% less) and $384.6 billion for supplemental medical insurance (18% more). In both those cases, those payments represent the general fund subsidies to the program -- to cover those benefits that have not been financed by payroll taxes or premium contributions.

CMS Directives

The bill directs CMS to use up to $400 million of user fees generated by the Affordable Care Act for grants to educate consumers about their health coverage options, ensure consumers have access to accurate information, and help consumers navigate the system to find the most affordable and secure coverage that meets their needs.

The committee requires CMS to report on how it is addressing homelessness and domestic violence, which are known social determinants of health, and on the feasibility of demonstration programs to address this problem. It also requires CMS to report on how Medicaid could further provide interventions to children suffering from adverse childhood experiences.

Families & Children / LIHEAP

The bill provides a total of $47.6 billion for programs and activities of HHS's Administration for Children & Families (ACF) -- 16% more than FY 2021 and 1% more than requested.

It requires ACF to distribute, at a minimum, the same amount of funding to each state, territory, and Tribe as was appropriated for FY 2021.

Head Start / Family Services

Within the total, $15.3 billion (17% more than FY 2021) is for various children and family services programs, including $12.2 billion (13% more) for the Head Start program, which provides comprehensive early childhood services to children and families from before birth through age 5. The increase for Head Start includes $200 million for longer hours of service to better align with K - 12 schedules and support working parents.

The total also includes $450 million for preschool development grants (64% more than FY 2021), $125 million for child abuse state grants (39% more), and $127 million for runaway and homeless youth (9% more).

It provides $800 million for Community Services Block Grants (7% more than FY 2021), as well as $275 million for child welfare services (2% more); $463 million for family violence prevention and services, including support of shelters for battered women (more than double FY 2021); and $26 million for the domestic violence hotline (about double).

Child Care and Development Block Grant

The measure provides the requested $7.4 billion for Child Care and Development Block Grants (25% more than FY 2021), which gives states, territories and tribes funding to provide direct financial assistance to low-income working families and families taking school or training so that the adults can access child care. The grants can also be used to improve the quality of child care for all children.

Refugee & Entrant Assistance

The bill provides $4.5 billion for HHS refugee and entrant assistance programs (more than double the FY 2021 level) -- of which $450 million is for refugee support services (more than double FY 2021), $605 million is for transitional and medical services (71% more), and $3.4 billion is for unaccompanied alien children (nearly triple FY 2021).

It includes numerous directives regarding unaccompanied children, including requiring that all unaccompanied children be housed in state-licensed facilities except in the case of a surge of individuals; clarifying that members of Congress can visit sites; and requiring that siblings be placed in the same facility.

The committee requires the Office of Refugee Resettlement (ORR) to establish an ombudsperson to advocate for upholding the rights of immigrant children in custody, and to independently advise HHS on the challenges of, and ways to systemically evaluate, refocus and rebuild the unaccompanied children program.

Mandatory Programs

The bill provides the requested $4.2 billion for FY 2022 in mandatory funding for state child-support enforcement programs to help promote safe and stable families, 6% less than FY 2021.

It provides the requested $10.2 billion for FY 2022 in mandatory funding for foster care and adoption assistance programs -- including $5.8 billion for foster care (0.6% more than FY 2021) and $3.7 billion for adoption assistance (2% less). (Both the foster care and child support programs above are partly funded each year with advance appropriations.)

Finally, it provides $1.7 billion in mandatory funding (equal to FY 2021) for the social services block grant program; the total includes $200 million for a diaper distribution grant program.

LIHEAP

The measure provides $3.9 billion (4% more than FY 2021) for the program; funds are distributed entirely through formula grants. The bill includes language to provide states with at least 100% of the funding level they received in FY 2021.

Administration for Community Living

The measure provides $3.1 billion for HHS's Administration for Community Living -- 37% more than FY 2021 and 3% more than requested. The agency coordinates the efforts of the Administration on Aging, the Administration on Intellectual and Developmental Disabilities, and the HHS Office on Disability to increase access to community supports and to focus attention and resources on the needs of older individuals and people with disabilities throughout their lifespan.

The total includes $2.3 billion in grants to states for programs that serve aging individuals and individuals with disabilities (42% more than FY 2021) -- including $1.4 billion for nutrition programs (46% more) and $551 million for home and community-based supportive services programs (40% more).

It also includes $209 million for a variety of programs that help those with developmental disabilities (14% more than FY 2021), and $317 million for Workforce Innovation and Opportunity Act programs (19% more).

Office of the Secretary

The bill provides a total of $5.3 billion for HHS' Office of the Secretary -- 19% more than FY 2021 but slightly less than requested.

The total includes $658 million for general departmental management (19% more than FY 2021) and $100 million for HHS' office of inspector general (25% more).

The committee directs the department to count the deaths among health care workers and direct service workers during the COVID-19 emergency, and it urges HHS to dedicate a specific percentage of COVID - 19 funding to community-based organizations, proportional to the needs of people living in medically underserved areas.

It directs HHS to establish a Children's Interagency Coordinating Council with other federal agencies. The council will report annually to Congress on how federal policies have affected child poverty and will examine and report on a broad array of issues affecting child well-being.

Public Health and Social Services Emergency Fund

The total for the Secretary's office includes $3.5 billion for the Public Health and Social Services Emergency Fund (24% more than FY 2021). The fund supports a comprehensive program to prepare for and respond to the health and medical consequences of public health emergencies, including bioterrorism, and also supports HHS cybersecurity efforts.

Included in the total is $335 million for pandemic flu preparedness (17% more than FY 2021), $770 million for Project Bioshield (equal to FY 2021), $905 million for the Strategic National Stockpile (SNS; 28% more), and $823 million for the Biomedical Advanced Research and Development Authority (BARDA; 38% more). It also includes $320 million for hospital preparedness cooperative agreements (14% more).

The committee directs HHS to re-envision the SNS to improve real-time inventory transparency, risk mitigation strategies, elasticity to scale responses, and supply chain risk management. HHS must report monthly on the current inventory of ventilators and personal protective equipment in the SNS.

Hyde Amendment & Other Provisions

The bill does not include two long-standing abortion riders: the Hyde amendment, which restricts the use of federal funding for abortions, except in cases of rape, incest or protecting the life of the mother, and the Weldon amendment that prohibits the government from discriminating against entities that do not cover, provide or pay for abortions.

It also does not include a long-standing provision that prohibited federal funds from being used to purchase syringes as part of public health campaigns involving individuals who inject drugs.

It prohibits the use of funds for adoption or foster care programs that permit discrimination on the basis of age, disability, sex, race, color, national origin, religion, gender identity, or sexual orientation.

It also prohibits funds from being made available to the Wuhan Institute of Virology in China, and prohibits funds from being used to support any gain-of-function research involving a potential pandemic pathogen by a foreign adversary including China, Russia, Iran and North Korea.

Education Department

The bill provides the requested $102.8 billion in discretionary funding for programs and activities of the Education Department for FY 2022 -- $29.3 billion (38%) more than FY 2021 but equal to the request. It also provides $3.7 billion in mandatory funding for vocational rehabilitation state grants.

It rescinds $229 million from unobligated FY 2021 Pell grant funding.

Education for the Disadvantaged

The measure provides $36.8 billion (more than double FY 2021) for Title I Education Grants and associated programs (including advance funding from previous years). It also provides $10.8 billion in advance funding for FY 2023.

Of the total, $36.0 billion is for Title I grants to local school districts to help disadvantaged children become proficient in reading and math (more than double FY 2021) -- including $5.7 billion for basic grants to local school districts (equal to FY 2021), $14.1 billion for targeted grants (more than triple FY 2021), and $14.1 billion for education incentive finance grants (also more than triple FY 2021).

The total also includes $383 million for grants to states for the education of migrant children (2% more than FY 2021), and $192 million for comprehensive literacy development grants (equal to FY 2021).

Impact Aid

The measure provides $1.6 billion for Impact Aid grants to school districts with military installations to support the education of children of U.S. servicemembers as well as schools with students who live on Native American land. Families living on military bases or on tribal lands do not pay property tax, which leaves schools that educate the children of these families without a source of income. The total provided is 3% more than FY 2021.

School Improvement

The bill provides $5.8 billion for a variety of school improvement programs (including advance funding from previous years), 7% more than FY 2021. It provides $1.7 billion in advance funding for FY 2023.

Within the total, $1.4 billion is provided for Community Learning Centers (8% more than FY 2021), which funds after-school and before-school centers for children. It also includes $2.3 billion for state grants to support effective instruction (7% more).

Also included is $378 million for state education performance assessments (equal to FY 2021), $193 million for rural education (3% more), $117 million for education of homeless children and youth (9% more), and $1.3 billion for student support and academic enrichment grants (7% more).

Safe School Programs

The bill provides $1.7 billion for the Safe Schools and Citizenship Education programs (almost eight times more than 2021) would support low-income, high poverty schools, as well as certain school safety programs. Within the total, $1.1 billion is for school safety national activities, with $1.0 billion of that amount for the School-based Mental Health Professionals demonstration program and the School-Based Mental Health Services Grants program.

Innovation & Improvement Programs

The bill provides $1.4 billion (25% more than FY 2021) for a variety of programs intended to foster innovation and educational improvement. (25% more than FY 2021)

The total includes $400 million for grants for charter schools (9% less than FY 2021), $149 million for magnet schools (37% more), $200 million for teacher incentive grants (equal to FY 2021), and $254 million for the Education Innovation and Research program (31% more) -- of which $112 million is for the Social-Emotional Learning (SEL) initiative to address student social, emotional and cognitive needs.

It also includes $100 million for a new program, Fostering Diverse Schools, for competitive grants to reduce racial and socioeconomic segregation.

The bill prohibits federal funds from going to charter schools run by for-profit entities.

Indian Education

The bill provides $188 million for Indian Education programs, 4% more than FY 2021. Of the total, $110 million is for grants to local education agencies to improve primary and secondary school programs that serve Native American students, including preschool children (5% more), and $77 million is for federal programs (2% more).

Special Education, English Language Acquisition & Rehabilitation

The bill provides a total of $17.2 billion for special education programs (including advance funding from prior years), 22% more than FY 2021. The measure provides $9.3 billion in advance funding for FY 2023.

Of the total, $16.8 billion is for special education grants to states (21% more than FY 2021) -- including $15.5 billion for Part B grants (20% more), $503 million for preschool grants (26% more), and $732 million for grants to states to provide early intervention for families who have babies and toddlers with disabilities (52% more).

The bill prohibits funding from going to private schools that use electric shock devices for student discipline.

Separately, the bill provides $1.0 billion for English language programs (25% more than FY 2021), and $3.9 billion for rehabilitation services (2% more).

The rehabilitation total includes $3.7 billion in mandatory spending for vocational rehabilitation state grants, which help individuals with mental and physical disabilities prepare for and engage in gainful employment. On the discretionary side, $23 million is for supported employment state grants, $33 million is for independent living grants for blind individuals, and $18.5 million is for the Helen Keller National Center for Deaf/Blind Youth and Adults.

Also separately, the measure provides $37 million for the American Printing House for the Blind, $85 million for the National Technical Institute for the Deaf, and $143 million for Gallaudet University in Washington, D.C.

Higher Education & Financial Aid

The bill provides $27.2 billion for student financial aid programs, primarily for Pell Grants.

Specifically, it provides $24.7 billion in discretionary funding for Pell Grants (10% more than FY 2021), and it increases the maximum Pell Grant by $400 in FY 2022 to $6,895. The measure extends Pell eligibility to DACA-eligible students.

The total for student financial aid also includes $1.4 billion for federal work-study grants (21% more than FY 2021), and $1.0 billion (17% more) for supplemental educational opportunity grants. The measure provides $2.1 billion for administering student aid (11% more).

The bill reduces from 90% to 85% the limit on revenues that for-profit colleges and other post-secondary institutions can derive from federal student aid programs.

For other higher education programs, the bill provides a total of $3.4 billion (35% more than FY 2021), including $1.1 billion (44% more than FY 2021) for a variety of programs intended to strengthen colleges that serve certain minority populations. Separately it provides $24 million for the Historically Black College and University Capital Financing Program for repair and renovation of facilities at HBCUs (half the FY 2021 level), and $411 million for Howard University in Washington, D.C. (64% more).

The higher education total also includes $1.3 billion for TRIO programs that help low-income and first-generation college students plan, prepare for and succeed in college (18% more than FY 2021), as well as $408 million for the GEAR UP program that provides grants to provide students with skills, encouragement and scholarships to pursue postsecondary education (11% more).

It also includes $95 million (73% more than FY 2021) for a program to provide child care for parents who are attending post-secondary schools and $132 million (more than double) for Teacher Quality Partnerships -- which improves the quality of teachers in high-need schools through model teacher preparation and residency programs.

Adult Career and Technical Training

The bill provides $2.2 billion (10% more than FY 2021) for career education programs (including previously appropriated amounts). It provides $791 million in advance appropriations for FY 2023.

Of the total, $1.4 billion (4% more than FY 2021) is for basic grants to states, and $700 million (4% more) is for state grants for adult education activities such as literacy education.

Other Activities

The bill provides $762 million for the Institute of Education Sciences to support education research, statistics, dissemination, evaluation and assessment activities, 19% more than FY 2021.

It also provides $694 million for departmental management (11% more), including $467 million for salaries and expenses (9% more) and $144 million is for the Office of Civil Rights (10% more).

Labor Department

The bill provides $16.0 billion in discretionary spending for programs and activities of the Labor Department in FY 2022, including advance appropriations from prior years. The discretionary total is 15% more than FY 2021 and 3% more than requested.

Employment and Training Administration

The measure provides a total of $14.7 billion for programs and activities of the Employment and Training Administration -- $2.2 billion (17%) more than FY 2021 and 3% more than requested.

Training & Employment Services

The total includes $4.4 billion (20% more than FY 2021) for assistance programs under the Workforce Investment Act to provide job training skills and assistance to youth and adults, as well as to dislocated workers.

Of that total, $3.1 billion is for grants to states, including $923 million for adult employment and training (7% more than FY 2021), $989 million for youth employment and training (7% more), and $1.1 billion for dislocated worker assistance (11% more). States can use the funds to provide core and intensive services, training and supportive services, as well as for rapid response assistance for workers affected by mass layoffs and plant closures.

For national programs, the bill provides $1.3 billion (60% more than FY 2021) -- including $436 million (55% more) for dislocated-worker assistance programs, $150 million (50% more) for the reintegration of ex-offenders, $97 million (3% more) for migrant- and seasonal-worker programs, and $145 million (49% more) for Youth Build activities. It provides $285 million for apprenticeship programs (54% more), and provides that these funds only be used for registered apprenticeships. The measure prohibits the implementation or enforcement of the rule for Industry-Recognized Apprenticeship Programs (IRAPs).

The committee allocates $100 million for the Strengthening Community College Training grant program (more than double FY 2021) to leverage community colleges in supporting local workforce development and industry needs and collaborating with employers to design and implement courses and programs. The funding increase is for a new grant competition to better align workforce development efforts with postsecondary education. It also sets aside $25 million for competitive grants to help prepare for employment young adults with criminal records, who have been involved with the justice system, or who have dropped out of school.

It also establishes and funds three new programs: $100 million for a new program to assist communities experiencing dislocations occurring in fossil fuel and other energy related industries; $50 million for a national youth employment program; and $20 million for a veterans clean energy training program.

Job Corps

The bill provides $1.8 billion (3% more than FY 2021) for the Job Corps, the nationwide network of residential facilities that provide training, job placement and support services to at-risk young adults. Of that total, $1.7 billion is for operations; $138 million is for construction, rehabilitation and acquisition; and $39 million is for administrative expenses.

Separately, the measure provides $450 million for community service employment for older Americans, 11% more than FY 2021.

Unemployment Insurance & Employment Services

The measure provides $4.2 billion for State Unemployment Insurance and Employment Service Operations activities, 22% more than FY 2021.

The total includes $2.9 billion (22% more) for state operations of unemployment insurance programs and $117 million (equal to FY 2021) for state re-employment eligibility assessments. The committee says funding increase for state operations of unemployment insurance programs is to increase staffing capacity and accommodate sustained increases in workload.

The bill provides that in FY 2022, for every 100,000 increase above 2 million in the total average number of individuals receiving unemployment each week, an additional $29 million will be made available to states from the Unemployment Trust Fund.

The measure provides $118 million for unemployment compensation national activities (six times more than FY 2021) to help modernize information technology systems and support states in administering the UI program.

It also provides $94 million for the Foreign Labor Certification program (21% more than FY 2021), including $68 million for federal administration (17% more) and $26 million for grants to states (30% more). The program administers temporary foreign worker programs, including the H-2A and the H-2B temporary visa programs.

Worker Protection Agencies

The bill provides a total of $1.9 billion for Labor Department worker protection agencies -- 16% more than FY 2021.

Of the total, $692 million is for the Occupational Safety and Health Administration (OSHA, 17% more than FY 2021), including $275 million for federal enforcement (20% more).

It provides $405 million for administration, salaries and expenses of the Mine Safety and Health Administration (MSHA; 7% more), and $44 million for the Office of Labor Management Standards (equal to 2021 but 13% less than requested).

It also provides $141 million for the Office of Federal Contract and Compliance Programs (33% more than FY 2021), which ensures equal employment opportunity in the federal contracting community.

Wage & Hour Division

The measure provides $300 million for the department's wage and hour division, 22% more than FY 2021. The division enforces federal minimum wage, overtime pay, recordkeeping and child labor requirements of the Fair Labor Standards Act, as well as enforcing other worker protections under additional laws.

The bill directs the agency to establish a national hotline to support domestic workers, and the committee encourages the agency to hire investigators who can communicate with workers in their native languages.

Labor Departmental Management & Directives

The bill provides $457 million for the salaries and expenses of staff responsible for operations, management and policy development at the Labor Department, 31% more than FY 2021. Within that total it provides $136 million for the International Labor Affairs Bureau (42% more than FY 2021) and $25 million for the Women's Bureau (66% more).

Separately, the bill provides the requested $37 million (37% more than FY 2021) for the department's information technology modernization.

The measure requires the Labor Department to publicly disclose information on post-secondary credentials and competencies earned through Registered Apprenticeships, as well as information on occupational and professional licenses and certifications. The committee says this would help individuals navigate the intricate network of diplomas, licenses, certifications, and badges.

The committee also directs the department to work with the Attorney General and Federal Law Enforcement Training Centers to implement improved, mandatory training for all federal law enforcement officers on racial profiling, implicit bias, procedural justice, and the use of force, and to develop related standards that can be applied in hiring and performance assessments.

Other Labor Agencies & Activities

The bill provides a total of $824 million in mandatory funding for various workers' compensation programs administered by the Labor Department.

Those programs include the Black Lung Disability Trust Fund, which pays black-lung compensation, medical- and survivor-benefit expenses when no responsible mine operator can be assigned liability ($331 million for benefit payments, 13% less than FY 2021); special benefit payments for disabled coal miners ($47 million, 15% less); the Energy Employees Occupational Illness Compensation Fund for Energy Department employees and contractors who suffer from diseases such as cancer or chronic silicosis as a result of their work with nuclear weapons ($63 million, 1% more); and federal employee compensation benefits ($242 million, 2% more).

Other agencies funded by the bill include the following:

Veterans Employment & Training -- $335 million for veterans employment and training (6% more than FY 2021), including $180 million for state grants and $31 million for the Homeless Veterans Reintegration Program (both equal to FY 2021).

Bureau of Labor Statistics -- $701 million for the BLS (7% more), including $231 million for employment statistics (1% more) and $233 million for prices and cost-of-living research (8% more).

Employee Benefits Security Administration -- $218 million for activities of the EBSA (20% more than FY 2021), which is responsible for the security of retirement, health and other workplace-related benefits of working Americans.

Pension Benefits Guaranty Corporation -- $473 million for administrative expenses of the PBGC (2% more than FY 2021), which protects the retirement incomes of nearly 35 million American workers in almost 25,000 private-sector defined benefit pension plans.

Related Agencies

Corporation for National & Community Service

The measure provides $1.3 billion for the Corporation for National and Community Service, including for AmeriCorps and the Volunteers in Service to America (VISTA) program.

The total includes $104 million for the VISTA program (7% more than FY 2021), which provides capacity building for small, community-based organizations that combat poverty, and whose members establish and expand housing, employment, health and economic development programs.

It provides $245 million for the Senior Volunteers Corps (9% more than FY 2021), a collection of programs to connect older individuals with opportunities to contribute their skills and expertise to community projects and organizations. The programs include foster grandparents and senior companions.

It also provides $673 million for several national and community service programs, including $601 million for AmeriCorps (32% more than FY 2021), which addresses community needs in education, public safety, health and the environment, and $38 million for the National Civilian Community Corps (13% more).

Corporation for Public Broadcasting

The measure provides advance funding for the Corporation for Public Broadcasting for two years ahead -- $565 million for FY 2024 -- which is 19% more than the $475 million in advance funding provided last year for FY 2023.

It also provides $20 million for public television interconnection systems in FY 2022.

Social Security Supplemental Security Income (SSI) Program

The bill provides for the Social Security Administration to use $65.8 billion in mandatory funding for FY 2022 from the Social Security Trust Fund (including prior advance appropriations) for the Supplemental Security Income (SSI) Program -- including $60.7 billion in payments to SSI beneficiaries (9% more than FY 2021) and $4.8 billion to administer the program (7% more).

That total also includes $205 million for beneficiary services (more than four times the FY 2021 level) and $86 million for research and demonstration activities (equal to FY 2021). It provides a $15.6 billion advance appropriation for the program for FY 2023. It also includes $1.7 billion in discretionary program integrity funding for continuing disability reviews and determinations.

National Labor Relations Board & Other Agencies

The bill appropriates $317 million for the National Labor Relations Board (16% more than FY 2021). Included in that total is $1 million to develop a system and procedures to conduct union representation elections electronically.

It also provides the following for other related agencies: $282 million for the Institute of Museum and Library Services (10% more than FY 2021); $130 million for administrative expenses of the Railroad Retirement Board (5% more); $50 million for the Federal Mediation and Conciliation Service (3% more); $18 million for the Federal Mine Safety and Health Review Commission (2% more); $16 million for the National Mediation Board (9% more); $15 million for the Occupational Safety and Health Review Commission (14% more); and $13 million for the Medicare Payment Advisory Commission (MedPAC; 3% more than FY 2021).

<p> By Robert Tomkin [email protected]

Section VII

Military Construction & Veterans Affairs

This section describes the provisions of HR 4502, Seven-Bill FY 2022 Appropriations Package, that provide funding for military construction and for programs and activities of the Veterans Affairs (VA) Department. (These provisions were reported by the Appropriations Committee as HR 4355, Military Construction, Veterans Affairs, and Related Agencies Appropriations for FY 2022.)

The bill provides a total of $124.5 billion in discretionary funding subject to caps for FY 2022 and $155.4 billion in mandatory funding for VA benefits and health care -- thereby providing a total of $279.9 billion for the year, 11% more than the FY 2021 level. The discretionary total for FY 2022 is 10% more than comparable FY 2021 funding.

Overall funding available for FY 2022 includes $239.5 billion in advance discretionary and mandatory VA appropriations for FY 2022 provided by prior-year appropriations laws; the bill includes $267.9 billion in advance VA appropriations for FY 2023.

The measure provides a total of $10.9 billion for military construction activities, $2.9 billion (35%) more than FY 2021 and $1.1 billion (11%) more than requested. Of that total, $972 million is for military construction projects that were not included in the president's request, but which are part of each military service's "unfunded priority list" for FY 2022 or are near completion. It includes no Overseas Contingency Operations (OCO) funding; appropriators have eliminated that category of spending and instead provide all funding through regular accounts.

For the VA the bill provides a total of $268.6 billion for FY 2022 (including advance appropriations from prior years) -- including $113.1 billion in discretionary funding for health care and other services and $155.4 billion in mandatory spending for veterans pensions and benefits. The discretionary total is $8.7 billion (8%) more than FY 2021.

According to the committee, within the VA total, the measure provides $97.6 billion for VA health care programs, 8% more than FY 2021, with increases for VA mental health care (28% more), VA opioid abuse care (32% more), and the VA Community Care account (26% more), through which medical care is to be provided to veterans outside the VA's medical network pursuant to the 2018 MISSION Act (PL 115-182).

The measure includes 11 earmarks for projects in members' districts that total $199 million, all involving military construction.

Military Construction

The bill provides a net total of $10.9 billion for military construction spending in FY 2022, $2.9 billion (35%) more than FY 2021 and $1.1 billion (11%) more than requested.

Military construction accounts provide funds for new construction, construction improvements, planning and design, and host nation support. Projects funded by these accounts include facilities for operations, training, maintenance, research and development, supply, medical care and force protection, as well as unaccompanied housing, utilities infrastructure and land acquisition.

The measure provides increased climate change and resiliency funding to help military installations adapt to rising sea levels and worsening natural disasters, it increases spending on NATO infrastructure and child development centers, and it restricts funds to be used in the construction, planning or design of Space Force facilities until the Defense Department completes site selection reviews.

Unlike previous years, the measure does not include language that would prohibit the use of funds to close the U.S. prison housing detainees in Guantanamo Bay or to construct new facilities to house the detainees in the United States.

The bill includes 11 earmarks totaling $199 million for military construction projects in members' districts, including $36 million for a new entrance road and gate at Barksdale Airbase in Louisiana.

Core Military Construction

The bill appropriates $8.4 billion for core military construction activities, $2.1 billion (34%) more than FY 2021 and $51 million less than requested.

The total includes $475 million to enhance and modernize shipyard infrastructure, $383 million to increase energy resilience and conservation investment, and added funds to support a global immediate response force.

Active-Duty Units

Within the total for core military construction, the bill provides $6.8 billion for construction activities for the active military services, $1.8 billion (35%) more than FY 2021 and 7% less than requested. Funding would be provided as follows:

Army -- $899 million, 43% more than FY 2021 and 8% more than requested. The committee directs the Army to prioritize facilities that support the global mission of the Immediate Response Force, which must be able to deploy anywhere in the world within 18 hours.

Navy & Marine Corps -- $1.9 billion, 13% more than FY 2021 but 18% less than requested. The committee expresses concern that the Navy's Shipyard Infrastructure Optimization Plan is falling behind schedule because details on multiple projects that are needed to properly assess and evaluate this recapitalization effort have not been provided to the committee, and it therefore directs the Navy to suspend further expenditure of previously provided funds until a detailed status report on plan implementation is transmitted to Congress.

Air Force -- $1.9 billion, more than triple the FY 2021 level but 10% less than requested. The committee urges the Air Force to prioritize funding for the Air Education and Training Command (AETC) to updated outdated and inadequate AETC facilities for basic military training, flight training, and the other training missions.

Defense-wide -- $2.0 billion, 1% less than FY 2021 but 3% more than requested. Within that total is $383 million is for the energy resilience and conservation investment program, 55% more than requested.

In its report, the committee directs the Missile Defense Agency to report on potential locations on Guam that could host either a large fixed or mobile platform capable of fulfilling air and missile defense requirements and the associated military construction costs. Guam is home to over 170,000 U.S. citizens, over 21,700 military members and their families, and vital defense assets.

Guard & Reserve Projects

The bill provides a total of $849 million for construction activities for National Guard and Reserve components, 42% more than FY 2021 and 27% more than requested.

Specifically, it provides $336 million for Army National Guard projects (4% less than FY 2021 but 31% more than requested), as well as $247 million for the Air National Guard (almost four times more than FY 2021); $77 million for the Army Reserve (13% less); $85 million for the Navy Reserve (20% more); and $105 million for the Air Force Reserve (nearly four times more than 2021).

Unrequested & Unfinished Projects

The bill also provides a total of $1.1 billion for military construction projects that either were not included in the president's request but were on the military's "unfunded priority list" ($972 million), or need additional funding to be completed ($150 million). Unfunded priorities must be more than 35% complete in design and be able to be executed in FY 2022, while projects that need completion are those for which funding was previously appropriated but have experienced a cost increase since the original contract award.

Funding for the unfunded priority projects includes $337 million for Army, Army Reserve and Army National Guard projects $163 million for natural disaster related projects, $225 million for overseas Navy and Marine Corps projects, and $100 million for child development centers (see below).

For incomplete projects, it provides $54 million for the Army, $50 million for the Air Force, $14 million for the Army Reserve, and $32 million for Army family housing.

Family Housing

The bill appropriates a total of $1.4 billion for family and military personnel housing -- $87 million (7%) more than 2021 but equal to the request.

Family housing construction accounts provide funds for new construction, construction improvements, the federal government's costs for family housing privatization projects, and planning and design. The operation and maintenance accounts provide funds to pay for maintenance and repair, furnishings, management, services, utilities, leasing, interest, mortgage insurance and miscellaneous expenses. Over two million military families live in military family housing.

In 1996 the Defense Department began to transfer the administration and operation of military family housing to a public-private venture under which private entities have responsibility for managing the construction, renovation, maintenance and services for these units. The department has mandated that eventually all military family housing will be privatized. However, the change has generated numerous complaints about substandard and dangerous conditions -- including lack of repairs, rodents, toxic mold, cracks in walls and peeling paint.

The total includes $116 million to address issues such as mold, vermin, and lead in military family housing, and $237 million in unrequested funds for seven additional barracks projects to ensure that servicemembers who live in unaccompanied personnel housing have safe, modern, and secure living facilities. The measure also requires the Defense Department to maintain a maintenance database to track any issues that may be prevalent in the future.

The bill provides the following for family housing, each equal to the request:

Army -- $100 million for housing construction (17% less than FY 2021) and $391 million for operation and maintenance (11% more);

Navy and Marine Corps -- $78 million for housing construction (81% more) and $357 million for operation and maintenance (3% more);

Air Force -- $116 million for construction (20% more) and $325 million for operation and maintenance (3% more); and

Defense-wide Housing -- $50 million for operation and maintenance (9% less than FY 2021).

The amounts provided include $550 million for barracks for unaccompanied soldiers at various locations, $237 million more than requested. The added funds are for seven additional barracks projects.

It also provides that no more than $15,000 may be spent annually per unit for the maintenance and repair of the quarters of any general or flag officer without prior notification to Congress. And as with previous appropriations acts, it requires that any savings in family housing operation and maintenance funding that results from foreign currency re-estimates be used for maintaining and repairing existing family units.

Other Military Construction Activities

NATO Security Investment Program

The bill appropriates $206 million for the North Atlantic Treaty Organization (NATO) Security Investment Program, $33 million more than FY 2021 and equal to the request.

Under the program, annual contributions by NATO member countries finance the cost of construction needed to support major NATO commands. The investments cover facilities such as airfields, fuel pipelines and storage, harbors, communications and information systems, radar and navigational aids, and military headquarters, both within NATO nations and for "out of area" operations such as Afghanistan.

Base Closings & Consolidations

The bill provides $565 million for continued activities under the 1990 and 2005 base realignment and closure (BRAC) rounds -- 18% more than FY 2021 and almost double the request. Funding for both the 1990 and 2005 BRAC accounts are provided in a single line item.

The $280 million provided above the administration's request is to be used to address Per- and Polyfluoroalkyl Substances (PFAS) and Perfluorooctanoic acid (PFOA) cleanup and to accelerate Army and Navy environmental remediation activities, of which $150 million is to increase the pace of cleanups.

Climate Change

Amounts included for military construction include $100 million in unrequested funds for climate change and resiliency projects on military installations and bases, $86 million more than FY 2021 according to the committee. The bill prohibits the use of funds to construct facilities that do not meet resiliency standards.

In addition, the $163 million in disaster funding for the "unfunded priorities list" is to be distributed amongst the Air Force and Navy & Marine Corps for Natural Disaster Recovery Construction activities.

The committee says it supports the military's continued focus on building lasting and resilient military installations, including methods that update hurricane-resistant building codes for bases, barracks, hospitals, and airfields -- but states that the military should also consider the impact of severe drought and desertification as high potential instability areas, and how those two hazards impact bases and missions.

Child Development Centers (CDCs)

Amounts provided also include $213 million for seven child development center projects, $193 million more than requested. The total includes $33 million for planning and design for future facilities.

The committee says it is disappointed by the lack of attention paid to this issue in the budget requests, and directs the department to assign greater priority to CDC construction projects in future budget requests.

Prohibitions and Directives

The bill prohibits the use of military construction funds to begin construction of new bases in the United States for which specific appropriations have not been made, or for the planning, design and construction of projects at Arlington National Cemetery.

It includes a number of provisions intended to boost U.S. businesses, including by prohibiting the procurement of steel for military construction projects unless American producers, fabricators and manufacturers have been allowed to compete.

It also provides a preference for U.S. architectural and engineering services for projects in Japan, NATO member countries, or countries bordering the Arabian Gulf, and it provides a preference for U.S. contractors for projects in the U.S. Pacific territories and possessions (and on Kwajalein Atoll) as well as in countries bordering the Arabian Gulf (except bids by Marshallese contractors for military construction on Kwajalein Atoll).

Veterans Programs

The VA serves more than 43 million people: nearly 20 million veterans and 24 million family members of living veterans or survivors of deceased veterans. The department employs almost 425,000 people, making it one of the largest federal employers.

For the VA the bill provides a total of $268.6 billion for FY 2022 -- including $113.1 billion in discretionary funding for health care and other services and $155.4 billion in mandatory spending for veterans pensions and benefits. The discretionary total is $8.7 billion (8%) more than FY 2021.

Of the total for FY 2022, $239.5 billion represents advance appropriations for FY 2022 provided by prior-year appropriations laws. In addition, the measure provides $267.9 billion in advance appropriations for FY 2023 -- $111.3 billion for VA's medical accounts and $156.6 billion for mandatory VA benefits.

Veterans Health Programs

The VA operates the largest federal medical care delivery system in the United States. In 2022, it will treat an estimated 7.1 million patients in its 146 hospitals, 120 residential rehabilitation programs, 134 nursing homes, 300 Vet Centers, 83 mobile Vet Centers and 783 outpatient clinics.

The bill provides a total of $97.6 billion in funding for health care programs of the Veterans Health Administration (VHA) in FY 2022, according to the committee -- $7.6 billion (8%) more than comparable FY 2021 funding and $100 million more than the request.

Another $3.4 billion for VA health care will be provided from reimbursements that the VA collects from veterans and other insurers (so-called medical care cost recovery collections) for non-service-connected care that the VA provides to veterans, $1.0 billion more than FY 2021 collections.

The total for FY 2022 includes $94.2 billion in advance FY 2022 appropriations from prior years and $4.3 billion in regular appropriations. As requested by the administration, the measure provides $111.3 billion in advance FY 2023 appropriations for VA health care accounts.

Medical Services

The medical services account provides funding for medical services to eligible veterans and beneficiaries in VA medical centers, outpatient clinics, contract hospitals, state homes and outpatient programs on a fee basis.

The bill provides a total of $59.0 billion for VA medical services for FY 2022 -- 4% more than FY 2021 and 0.2% more than the requested. Of that total, $58.9 billion is provided through advance funding from prior-year appropriations; the measure includes a $70.3 billion advance appropriation for FY 2023.

Within the total, $13.2 billion is for mental health programs (see below); the total for VA medical services also includes the following:

Telehealth -- $2.6 billion for telehealth and connected care, including home telehealth, home telehealth prosthetics and clinic-based telehealth. The committee directs the VA to continue to expand telehealth availability to include additional mental health, primary care, and rehabilitation services as a means to deliver care in rural and underserved communities.

Women's Care -- $779 million for gender-specific care for women to service the 561,000 female veterans, 18% more than FY 2021.

Caregivers -- $1.4 billion for the caregivers program that provides stipends to the family caregiver of a veteran seriously injured in the line of duty in post-9/11 services.

Opioid Abuse -- $621 million for opioid abuse treatment and prevention, 32% more than FY 2021.

Rural Care -- $307 million (2% more than FY 2021) to improve access and quality of care for the 2.9 million veterans accessing 600 facilities in rural and highly rural areas. To address the rural health provider gap, the committee encourages the VA to continue to consider expanded use of physician assistants and to report to Congress on hiring needs in rural areas.

Whole Health -- $84 million (17.5% more than FY 2021) for the Whole Health Initiative, which is a holistic look at the many areas of life that can affect health and encourages veterans to take charge of their health and well-being.

The committee estimates that $623 million of amounts received through the Medical Care Collections Fund will be available for use under VA Medical Services.

Medical Services / Mental Health

The total for VA Medical Services includes $13.2 billion for VA mental health programs, of which $2.3 billion is for suicide prevention and treatment programs, including $599 million for suicide prevention outreach (almost twice the current level). In its report, the committee continues to direct the department to focus on efforts to address parking lot suicides and connect veterans to care.

According to the committee, the funds will support the nearly 2 million veterans who receive mental health services in a VA specialty mental health setting, as well as support suicide prevention services like the Veterans Crisis Line (funded at $256 million), which saw an increase in demand by over 59% in the last year. The bill continues the requirement that the VA's toll-free suicide hotline provide immediate assistance from a trained professional; the administration requested that the requirement be ended.

The committee also notes that an increasing number of states have programs that assist veterans in starting farms, particularly those suffering from PTSD, and it encourages the VA to work with the Agriculture Department on providing agritherapy programs to veterans and supports a pilot program to train veterans in agricultural vocations, including urban and vertical farming.

Community Care Programs

The bill provides $23.4 billion for FY 2022 for the medical community care account, which was created in FY 2017 to consolidate into a single appropriation all community care programs under which the VA pays for medical care provided to veterans by private health care professionals outside of the VA's medical network. The VA MISSION Act (PL 115-182) merged together the VA Choice Program with all external community care programs into a single, permanent Veterans Community Care Program, through which medical care is provided to veterans outside the VA's network. The program launched in July 2019.

That total is $4.9 billion (26%) more than FY 2021 and includes $20.1 billion in advance funding provided by prior-year appropriations law; the measure provides $24.2 billion in advance appropriations for FY 2023.

Medical Support & Compliance

Medical support and compliance funds are used for management expenses and administration of the department's health care system. Funds are provided for financial management, public health and environmental hazards, quality and performance management, medical inspection, human research oversight, training programs and continuing education, security, volunteer operations and human resources.

The bill provides a total of $8.4 billion for FY 2022 -- 2% more than FY 2021. The entire amount is provided through a prior-year advance appropriation; the measure includes a $9.7 billion advance appropriation for FY 2023.

Medical Facilities

The medical facilities account provides funds for the operation and maintenance of the department's health care system's capital infrastructure, including utilities, engineering, capital planning, leases, laundry, grounds keeping, housekeeping, facility repair, and property disposition and acquisition.

The bill provides $6.7 billion for FY 2022 -- 2% more than FY 2021. Of that total, all is provided through a prior-year advance appropriation; the measure includes $7.1 billion in advance appropriations for FY 2023.

Of the funds provided for non-recurring maintenance, the committee directs the VA to prioritize projects that expand women's access to gender-specific care and that repurpose vacant and under utilized space for mental health needs, particularly projects that increase the number of beds available for overnight mental health treatment for veterans.

Medical & Prosthetic Research

The bill appropriates $902 million for medical, rehabilitative and prosthetic research for FY 2022, 11% more than FY 2021.

The committee directs the VA to prioritize medical and prosthetic research for women, and to continue to fund efforts and research that will develop neural-enabled prosthetics by partnering with colleges and universities.

It also directs the VA to continue collaborating with the Defense Department to monitor research activities, results and publications on the health effects from PFAS; to expand its research on the effects of and treatments for veterans exposed to toxins, such as Agent Orange, burn pits, PFOS/PFOA, radiation, and asbestos during the course of their active duty service; and to use existing data to determine the percentage of veterans exposed to Agent Orange who may suffer from more frequent or unexplained diseases.

Homeless Programs

Within the VA Medical Services account, the measure provides $2.2 billion for homeless assistance programs according to the committee, $168 million more than FY 2021 and equal to the president's budget request. The committee notes the most recent homelessness survey showed that on a given night in January 2020, an estimated 37,252 veterans were experiencing homelessness.

The committee also notes that an estimated $8.2 billion is provided for homeless veterans treatment costs, $247 million more than FY 2021. In addition, $486 million in funds made available by the American Rescue Plan (PL 117 - 2) will support VA homelessness programs in FY 2022.

Programs to assist homeless Veterans include the Homeless Providers Grant and Per Diem (GPD), Health Care for Homeless Veterans (HCHV), the Domiciliary Care for Homeless Veterans, the Supportive Services for Low Income Veterans and Families (SSVF), Veterans Justice Outreach Homeless Prevention (VJO), and the Department of Housing and Urban Development-Department of Veterans Affairs Supported Housing (HUD - VASH) programs, among others.

Veterans Benefits Administration

In addition to veterans medical benefits provided by the Veterans Health Administration, the VA provides veterans compensation and pensions as well as readjustment benefits to eligible veterans through the Veterans Benefits Administration (VBA).

The bill provides a total $159.1 billion for the Veteran's Benefit Administration for use in FY 2022-- including $155.4 billion in mandatory spending for veterans compensation and pensions, readjustment benefits and housing loans, and $3.65 billion in discretionary funding for VBA operating and other administrative expenses (see below). The FY 2022 funding for mandatory VA benefits is $16.7 billion more than the comparable FY 2021 level.

Of the VBA total, the $148.1 billion is provided through prior-year advance mandatory appropriations; the measure includes $156.6 billion in advance mandatory appropriations for FY 2023 for VA benefits.

Veterans Compensation & Pensions

The bill provides $137.6 billion for veterans service-connected compensation benefits and pensions for FY 2022 -- $13.2 billion (11%) more than 2021 funding and equal to the request. Of that total, $130.2 billion is provided through advance appropriations from prior spending acts; the measure includes a $147.6 billion advance mandatory appropriation for FY 2023.

This account provides funds for service-connected compensation payments to almost 6 million veterans, survivors and dependents, and pension payments for over 350,000 veterans and survivors. It provides educational assistance for nearly 900,000 individuals and interment services for more than 130,000 veterans and family members. According to the committee, the average cost per compensation case for veterans in 2022 is estimated at $20,403 and the average pension payment is projected to be $13,760.

Readjustment Benefits

The measure provides $14.9 billion for veterans readjustment benefits for FY 2022, all of which is advance appropriations from prior spending bills. The total is $2.4 billion (19%) more than 2021 funding.

Funding in this account provides education and training assistance to veterans and service personnel; vocational rehabilitation; special housing and transportation grants to certain disabled veterans; and educational assistance to eligible dependents of deceased and seriously disabled veterans, as well as dependents of servicemembers who were captured or are missing in action. More than 80% of the funds support the Post-9/11 GI bill.

The measure provides a $8.9 billion advance mandatory appropriation for FY 2023.

The committee encourages the VA, in consultation with the departments of Labor and Defense, to coordinate efforts and resources to ensure veterans have a successful transition to civilian life, including sharing information on community resources and job placement services. It also urges the departments to ensure that veterans are aware of all student loan forgiveness options or repayment programs.

Veterans Insurance & Indemnities

The bill provides $137 million in mandatory funding to finance veterans insurance programs for certain veterans of World War I, World War II and the Korean War, as well as the veterans mortgage life insurance for those veterans who have a grant for specially adapted housing.

The total provided is 4% more than FY 2021 and consists entirely of prior-year appropriations; the measure includes $110 million in advance mandatory appropriations for FY 2023.

VA Housing Benefit Program

The measure provides the requested $230 million in discretionary funding for administrative expenses under the VA Home Loan Guaranty program (12% more than FY 2021), and it provides $2.8 billion in mandatory funding for the credit subsidy to support VA home loan guarantees ($1.1 billion, or 67%, more than FY 2021).

Loan guarantees under the program are made to servicemembers, veterans, reservists and single surviving spouses for the purchase of homes, condominiums and manufactured homes, as well as for refinancing loans. Under the program, the VA guarantees part of the total loan, permitting the purchaser to obtain a mortgage with a competitive interest rate, even without a down payment. With a VA guarantee, the lender is protected against loss, up to the amount of the guarantee, if the borrower fails to repay the loan.

The bill sets a $500,000 cap on direct loans for specially adapted housing.

Other VA Benefits

The measure also includes discretionary funding for the following programs:

Native American Veteran Housing Loan Program -- $1.4 million for administrative expenses of the Native American Veteran Housing Loan Program, 18% more than FY 2021. Under the program, the VA makes direct housing loans to Native American veterans to purchase, construct or improve dwellings on trust lands.

Vocational Rehabilitation Loans -- $429,000 for administrative expenses under the vocational rehabilitation loans program account, 1% more than FY 2021. The bill sets a $1.7 million cap on such loans. Under the program, loans of up to $1,260 are available to service-connected disabled veterans enrolled in vocational rehabilitation programs when the veteran is temporarily in need of additional assistance. Repayment is made in monthly installments, without interest, through deductions from future VA benefits or retirement pay.

VA Department Administration

The bill provides $3.4 billion for general operating expenses of the VBA and $10.6 billion (5% more than FY 2021) for various VA operating and administrative expenses, including VA construction activities.

Within the VA total, $397 million (8% more than FY 2021) is for general administration of the VA Department, including the Office of the Secretary, the general counsel, six assistant secretaries and two independent staff offices.

The committee directs the VA to report on VA performance bonuses for the previous five years. It also requires the Office of Accountability and Whistleblower Protection to report on its compliance with the VA Accountability and Whistleblower Protection Act of 2017.

VBA General Operating Expenses

The total provided for the Veterans Benefits Administration (above) includes $3.4 billion for general VBA operating expenses, 8% more than 2021 funding but slightly less than requested.

The committee says that claims under the Blue Water Navy Vietnam Veterans Act (PL 116-23) should be given greater priority, and that VBA should prioritize use of funds to process claims, including claims related to new Agent Orange presumptive conditions, to reduce the claims backlog.

It also expresses concern with the lack of data on veteran exposure to open burn pits, and directs the VA to partner with the Defense Department, Tricare, private sector health providers, and the Centers for Medicare & Medicaid Services (CMS) system to prepare a report on current efforts to compile such data.

Finally, it urges the VA to continue to report to Congress on information relating to claims for disabilities incurred or aggravated by Military Sexual Trauma (MST).

Information Technology & Integrated Health Records

The bill provides $4.8 billion for VA information technology, 1% less than FY 2021 but equal to the request.

That total includes $3.1 billion for operations and maintenance, $1.4 billion for staff salaries and expenses, and $297 million for program development.

Separately, the measure provides $2.6 billion (slightly more than FY 2021) for final development and implementation of a new VA electronic health record (EHR) to support continued, robust deployment of the new electronic health record system at VA medical centers and allow for intensive staff training.

VA Construction

The bill appropriates the requested $2.2 billion for VA construction, including major modernization projects and alteration and improvement of VA facilities.

The total includes $1.6 billion (22% more than FY 2021) for "major" construction projects where the estimated cost is $20 million or more, and $553 million (42% more) for "minor" construction projects (i.e., those costing less than $20 million).

The funds will support the VA's highest priority projects and correct critical seismic and safety deficiencies and address other performance gaps at VA facilities, according to the committee. The measure prohibits funding from any account other than major and minor construction to be used for the purchase of any site for, or construction of, any new VA hospital or home.

For construction of state extended care facilities, the bill provides $90 million, equal to FY 2021 funding. This account provides grants to assist states in building state home facilities, furnishing domiciliary or nursing home care to veterans, and expanding, remodeling or altering existing buildings to supply domiciliary, nursing home or hospital care to veterans.

National Cemetery Administration & Other VA Activities

The bill appropriates $392 million for the VA's National Cemetery Administration (NCA), 11% more than FY 2021. The agency supports operation and maintenance of 158 national cemeteries, 11 cemeteries transferred from the Army and 34 other cemeterial installations.

The committee says it appreciates VA actions to replace headstones of prisoners of war buried in Fort Sam Houston National Cemetery and Fort Douglas National Cemetery that feature swastikas and inscriptions glorifying the Nazi regime, and directs the VA to provide monthly reports on the status of this process.

It also expresses concern that NCA is not adequately serving veterans in rural areas, and therefore directs the VA to continue to pursue efforts to ensure that a burial option (including those utilizing public-private partnerships) within 75 miles of all veteran homes is available and accessible.

The bill also provides funding for the following other VA activities:

Inspector General -- $239 million for the VA's Office of Inspector General, 5% more than FY 2021.

Board of Veterans Appeals -- $228 million for the Board of Veterans Appeals, 16% more than FY 2021.

Grants for Construction of Veterans Cemeteries -- $47 million for such grants, 5% more than FY 2021.

Other Related Agencies

In addition to funding military construction and the VA, the bill funds four other agencies and accounts.

Arlington National Cemetery

The bill provides the requested $228 million for Arlington National Cemetery and the Soldiers' and Airmen's Home National Cemetery in FY 2022 -- almost double the FY 2021 level. The measure continues to allow Arlington to use funds derived from concessions.

The total includes $87 million for salaries and expenses and $141 million to complete the $360 million Southern Expansion project that will create 80,000 additional burial spaces and preserve Arlington National Cemetery as an active burial ground into the 2050 timeframe.

Court of Appeals for Veterans Claims

The measure includes the requested of $42 million for the U.S. Court of Appeals for Veterans' Claims, 12% more than FY 2021. The court reviews appeals from claimants seeking review of a benefit denial by the VA, and it has the authority to overturn findings of fact, regulations and interpretations of law. According to the committee, caseloads at the court continue to increase.

Armed Forces Retirement Home

The Armed Forces Retirement Home consists of two retirement communities: one in Washington, D.C., and the other in Gulfport, Miss.

The measure provides $77 million for the Armed Forces Retirement Home, 2% more than FY 2021 funding. The total includes $25 million from the general fund of the Treasury, rather than the trust fund that supports the retirement communities. Expenditures from the trust fund have exceeded revenues for several years.

American Battle Monuments Commission

The bill includes $88 million for salaries and expenses of the American Battle Monuments Commission, 5% more than FY 2021.

The commission administers and maintains cemeteries and war memorials located overseas and in the United States to commemorate the sacrifices of those who lost their lives in combat since World War I. It maintains 25 cemetery memorials and 26 monuments, memorials and markers.

<p> By Karin Fuog [email protected]

Section VIII

Transportation-HUD

This section describes the provisions of HR 4502, Seven-Bill FY 2022 Appropriations Package, that provides funding for transportation, infrastructure and low-income housing assistance programs. (These provisions were reported by the Appropriations Committee as HR 4550, Transportation-HUD Appropriations for FY 2022.)

The bill provides $84.1 billion in net discretionary spending subject to caps, $9.4 billion (12.6%) more than comparable FY 2021 funding (i.e., excluding FY 2021 emergency funding) and 1% more than requested. It also provides for the release of $78.6 billion from the highway and aviation trust funds -- thereby providing a total of $162.6 billion in scored budgetary resources for FY 2022, 19.5% more than comparable FY 2021 funding.

On a programmatic basis, however, after certain scorekeeping adjustments that offset spending are factored out, such as offsetting receipts collected by the Federal Housing Administration and Ginnie Mae, the bill actually provides a total of $174.4 billion for use by federal agencies in FY 2022, 18% more than the comparable FY 2021 total.

It provides $105.7 billion for the Transportation Department, 22% more than FY 2021. It significantly increases funding for federal highway programs (27%), transit (19%), the Federal Motor Carrier Safety Administration (18%) and National Highway Traffic Safety Administration (30%), and for discretionary infrastructure grants (RAISE, previously known as BUILD and TIGER grants; 20%). In increases funding for the Federal Railroad Administration by 46%, including a 35% increase for Amtrak while replacing the railroad state of good repair grant program with a new PRIME grant program to expand passenger rail with triple the funding.

For the Housing and Urban Development Department (HUD) it provides $56.5 billion in scored funding, 14% more than FY 2021 (and a total of $68.2 billion in programmatic funding). It significantly increases funding for most housing programs, including tenant-based housing aid (by 13%) and public housing (11%), housing for the elderly (21%) and disabled (55%), and Community Development Block Grants (35%) and the HOME program (37%). It increases funding for HUD homeless assistance programs by 14%, and includes $1.0 billion for a new program to provide housing vouchers to the homeless.

The measure includes 981 earmarks in members' districts that total $1.4 billion -- including $428 million for highway projects, $80 million for airport grants, and $936 million for HUD-related economic development projects.

In its report, the committee outlines resilience and equity principles it expects agencies to follow, including that all projects address the risk from natural hazards throughout the lifetime of the project and that transportation and housing construction focus on best practices for sustainable and equitable community growth that encourages efficient land use, transit-oriented development, and "complete streets" design.

Transportation Department

The bill provides a total of $105.7 billion in budgetary resources for programs and activities of the Transportation Department -- including $78.6 billion to be released from transportation trust funds for federal highway, transit and aviation programs. That total is $19.0 billion (22%) more than comparable FY 2021 funding, and occurs mostly because of a $17.2 billion increase in trust fund obligation authority.

The committee notes that the increased level of trust fund obligations for many transportation accounts is consistent with the INVEST in America Act (HR 3684), the Democratic infrastructure bill the House passed on July 1. The committee also says that more than $250 million is included to reduce transportation emissions, increase resiliency, and address historical inequities.

Federal Highway Administration

The measure provides $62.5 billion in total budgetary resources for programs and activities of the Federal Highway Administration (FHWA) -- 27% more than FY 2021 and 33% more than requested.

It allows up to $61.1 billion in funding obligations from the Highway Trust Fund for federal-aid highway programs, 32% more than FY 2021. Another $739 million in contract authority that is exempt from the obligation limit (equal to both 2021 funding and the request) would also be available -- thereby providing a total program level of $61.9 billion for the regular federal-aid highway program in FY 2022.

It also appropriates $592 million from the general fund of the Treasury for certain highway programs funded by formula by the 2015 highway authorization law (the FAST Act; PL 114-94). The amount provided is 70% less than the FY 2021 level.

The committee encourages the Transportation Department to accelerate research and deployment of permeable pavements to mitigate flooding, reduce pollutants and stormwater runoff, conserve the environment and increase resilience, and to disseminate information to states on prioritizing resilient and sustainable materials. And it encourages the adoption of a "complete streets" design model to enable safe access for all users as well as projects that promote safe student access to schools.

It also encourages the department to address the systemic destruction of communities by prioritizing projects that reconnect neighborhoods cut off by the interstate highway system and to ensure new projects increase opportunity, advance racial equity and environmental justice, and promote affordable access.

Mass Transit

The bill provides a total of $15.5 billion in budgetary resources for the Federal Transit Administration (FTA) -- 20% more than FY 2021 and 15% more than requested. The total includes $12.2 billion from the Mass Transit Account of the Highway Trust Fund ($2.0 billion more than FY 2021) and a net appropriation of $3.3 billion from the general fund of the Treasury (19% more).

Transit Formula & Appropriated Grants

The measure allows up to $12.2 billion in funding obligations from the trust fund's Mass Transit Account for various transit formula grant programs, 20% more than both FY 2021 and the request. Of the total, at least $10 million is set aside for transit-oriented development planning.

Formula grant programs funded under this account include urbanized area formula grants, bus and bus facility formula grants, state of good repair grants, formula grants for rural areas, and mobility for seniors and persons with disabilities.

It also appropriates a separate $580 million from the general fund of the Treasury for transit infrastructure grants, 12% more than FY 2021.

Of the total provided, $203 million is for bus and bus facilities, $240 million is for low- or zero-emission buses, $20 million is for the zero-emission passenger ferry program, and $25 million is for innovative mobility. It also includes $30 million for climate resilience and adaptation and $50 million for integrated smart mobility pilot grants.

Capital Investment Grants

The bill appropriates the requested $2.5 billion (23% more than FY 2021) for Capital Investment Grants to build or improve rail and other fixed-guideway transit systems.

Within that total, $1.3 billion is for "new starts" projects, $442 million is for core capacity projects, $303 million is for small starts projects, and $100 million is for the expedited project delivery pilot program.

Washington Metro System

The measure provides $150 million for grants to the Washington Metropolitan Area Transportation Authority (Metro) to address safety deficiencies and maintain the capital's subway system. The amount provided is equal to both FY 2021 and the request.

Under the Passenger Rail Investment and Improvement Act of 2008 (PL 110-432), Virginia, Maryland and the District of Columbia must annually match federal funds by contributing $50 million each.

Federal Aviation Administration

The bill provides $18.9 billion in total budgetary resources for programs and activities of the Federal Aviation Administration (FAA) -- $896 million (5%) more than FY 2021 and 2% more than requested. The total includes $3.35 billion in obligations from the Airport and Airway Trust Fund for airport grants.

FAA Operations

The measure provides the requested $11.4 billion for FAA operations, 4% more than FY 2021.

Within the total provided for FAA operations, $8.5 billion is for air traffic control operations (3% more than FY 2021), and it provides a separate $64 million for continued implementation of the NextGen air traffic control system (2% more than FY 2021).

It provides the requested $1.5 billion for aviation safety activities (4% more than FY 2021). The committee notes that this is the third increase for the aviation safety account to support the review and response to recommendations by multiple entities regarding the Boeing 737 MAX accidents and the aircraft certification process in general. It further notes that a significant amount of the funding increase is dedicated to the hiring of inspectors, engineers, human factors specialists, and software and cybersecurity experts, as well as for the training of current personnel.

Grants to Airports

The measure allows up to $3.35 billion to be obligated from the Airport and Airway Trust Fund for federal grants-in-aid for airport planning, construction and development under the Airport Improvement Program (AIP). This amount is equal to both FY 2021 funding and the request.

It also provides an additional $400 million in discretionary funding from the general fund of the Treasury for grants for high priority airport construction projects, equal to FY 2021.

Facilities & Equipment / Research & Development

The bill provides $3.4 billion from the Airport and Airway Trust Fund for the facilities and equipment program, which provides funds for the procurement and installation of new equipment and for the construction and modernization of facilities in the national airway system, including aids to navigation, radar and communications systems, air traffic control centers and airport control towers. The level provided is 13% more than FY 2021 funding.

Within the facilities and equipment total, $15 million is for precision landing lights. For remote telecommunications infrastructure replacement, it provides $17 million from the facilities and equipment account and $21 million from the operations account.

For the FAA's long-term research, engineering and development program, it provides $261 million (32% more than FY 2021), also from the aviation trust fund. The total includes $50 million to reduce greenhouse gas emissions, $46 million to reduce noise and emissions by modifying aircraft engines, $30 million for fuels to reduce noise and emissions, and at least $2 million to study the effect of aviation noise on community annoyance, sleep, health, and children's learning.

Essential Air Service Program

The bill provides the requested $248 million (75% more than FY 2021) within the Transportation Secretary's Office for the Essential Air Service (EAS) program, which subsidizes airline carriers for service to smaller communities.

In addition, the administration has estimated that overflight fees by aircraft crossing U.S. airspace, which can be applied to the EAS program, would be $116 million in FY 2022 -- which would provide the EAS program with a total of $364 million for the year.

Railroads / Amtrak

The bill provides $4.1 billion for the Federal Railroad Administration (FRA) -- 46% more than FY 2021 and 3% more than requested -- of which $2.7 billion would be for Amtrak. In addition to administering grants for Amtrak, the FRA regulates rail safety, administers railroad assistance programs and conducts research and development.

The measure significantly boosts funding for Amtrak while also seeking to further expand passenger rail service in the nation.

Amtrak Funding

The bill provides the requested $2.7 billion for Amtrak (formally the National Railroad Passenger Corporation) -- $700 million (35%) more than FY 2021.

Of the total provided, $1.2 billion is for Amtrak's Northeast Corridor operations (71% more than FY 2021) and $1.5 billion is for Amtrak's National Network (15% more). Within the total provided, $75 million is to bring Amtrak-served facilities into full compliance with the Americans with Disabilities Act (ADA).

The measure continues to limit overtime to $35,000 per employee, but it allows Amtrak's president to waive this restriction for specific employees for safety or operational efficiency reasons. Amtrak must report to Congress on overtime payments made in FY 2021 and the three previous years. It directs Amtrak to maintain a station agent at each Amtrak station that had a ticket agent in FY 2018, and also directs Amtrak to maintain a dedicated customer service workforce at the contact center in Philadelphia.

Passenger Rail Expansion

The bill replaces the FRA's state of good repair rail grant program with funding for passenger rail improvement, modernization and expansion (PRIME) grants as authorized under the House-passed INVEST in America Act. The PRIME program would provide grants to improve mobility, operational performance, and the growth of passenger rail in the United States.

Specifically, the bill appropriates $625 million for PRIME grants -- more than triple the $200 million provided in FY 2021 for state of good repair grants, which would not be funded by this bill.

Other Railroad Activities

For other activities of the Federal Railroad Administration, the measure provides the following:

Operations and Safety -- $248 million for FRA operations and safety activities, 6% more than FY 2021. The total includes an unrequested $2 million for safety measures associated with the transportation of crude oil, ethanol, liquefied natural gas and other fuels.

Research and Development -- $54 million, 32% more than FY 2021. The total includes $2.5 million to research and mitigate risks associated with the transportation of crude oil, ethanol, liquefied natural gas and other hazardous materials.

Rail Infrastructure & Safety -- $500 million (33% more than FY 2021) for grants under the Consolidated Rail Infrastructure and Safety Improvement (CRISI) program to improve the safety, efficiency and reliability of passenger and freight rail systems. Within that total, $150 million is for the development of new intercity passenger routes.

Magnetic Levitation Systems -- $5 million ($3 million more than FY 2021) to develop magnetic levitation systems for trains to travel more than 240 miles per hour. The administration requested no funding for this account.

Commercial Vehicle & Highway Safety

National Highway Traffic Safety Administration

The bill provides a total of $1.3 billion for NHTSA activities, 30% more than FY 2021 and 26% more than requested. The total includes $1.0 billion from the Highway Trust Fund and $253 million in general appropriations.

Of the trust fund money, $855 million would be provided for various grant programs, including $385 million for highway safety grants (38% more than FY 2021), $391 million for national priority safety programs (37% more), and $50 million for high-visibility enforcement (61% more).

It provides $426 million (22% more than FY 2021) for NHTSA operations and research, including $246 million from the general fund and $181 million from the Highway Trust Fund. Within that total, $10 million is set aside for NHTSA to work with the Federal Railroad Administration on highway-rail grade crossing safety.

The committee continues to direct NHTSA to form a commission to implement GAO truck underride recommendations and to complete rulemaking on rearguard standards.

Federal Motor Carrier Safety Administration

The bill provides $886 million for FMCSA, which oversees federal truck and bus safety enforcement programs and is responsible for ensuring that commercial Mexican vehicles entering the United States under trade agreements meet all U.S. hazardous-material and trucking safety regulations. The total provided is 18% more FY 2021 funding and 31% more than requested. All of the funding comes from the Highway Trust Fund.

The total includes $380 million for Motor Carrier Safety Operations and Programs (16% more than FY 2021), and $506 million for Motor Carrier Safety Grants (21% more).

The bill requires FMCSA to update inspection regulations to require that rear underride guards on large commercial trucks be inspected annually.

Office of the Secretary / RAISE Infrastructure Grants

The bill provides $1.8 billion for activities of the Office of the Secretary of Transportation, 28% more than FY 2021 and 13% more than requested.

It allows up to $419 million to be spent from the Working Capital Fund (31% more than FY 2021) to support the department's shared services initiative in commodity information technology. The Working Capital Fund is a fee-for-service revolving fund that finances various technical and administrative services within the department.

In addition to funding for the Essential Air Services Program, the Office total includes $143 million for salaries and expenses (13% more than FY 2021), $11 million for planning, research and development (21% more), $14 million for the National Surface Transportation and Innovative Finance Bureau (more than double the FY 2021 level), and $57 million for research and technology (also more than double).

The committee directs the department to coordinate different modes of road transportation in order to ensure safety for all modes, and it directs GAO to examine policies and procedures the department has established to promote transportation equity. It also encourages the department to integrate consideration of climate impacts into all aspects of transportation planning and funding, and directs the department to prioritize funding for projects that improve racial and economic equity and reduce greenhouse gas emissions.

RAISE Infrastructure Grants

Within the total for the Office of the Secretary, the bill provides the requested $1.2 billion (20% more than FY 2021) for National Infrastructure Investment RAISE grants for transportation infrastructure projects (previously called BUILD and TIGER grants).

Under the measure, grants must be between $5 million and $100 million (a minimum of $1 million for rural area) and no more than 15% of the funds may be awarded to projects in a single state, except for port infrastructure. The federal share of a project's costs may be up to 80%, although the federal share could be higher for rural areas and at least 30% of funds would be reserved for rural projects. Up to $40 million could be used to fund the planning, preparation or design of eligible projects, with an emphasis on transit, transit-oriented development and multimodal projects, with at least $20 million for planning in areas of persistent poverty and $10 million for planning in urbanized areas.

The committee in its report urges prioritization of projects that address multimodal, transformative projects that increase competitiveness.

Other Transportation Department Activities

Maritime Administration

The bill provides a total of $1.3 billion for programs and activities of the Maritime Administration (MarAd) -- 7% more than FY 2021 and 11% more than requested.

Within the total provided, $318 million (1% more than FY 2021) is for MarAd's maritime security program, which provides annual payments to operators of U.S.-flag merchant ships engaged in U.S.-foreign commerce in order to help maintain the U.S.-flag merchant fleet and preserve it for national security needs.

It also provides $10 million (equal to FY 2021) to help maintain a U.S. cable fleet (deep-sea vessels designed and used to lay underwater cables for telecommunications and electric power) and $20 million to support small shipyards (equal to FY 2021), as well as $60 million for a new program to help maintain a fleet of commercially viable, militarily useful, privately owned product tank vessels to meet national defense and other U.S. security requirements.

The measure provides the requested $300 million (30% more than FY 2021) for the port infrastructure development program under which MarAd provides grants for infrastructure improvement projects at coastal seaports (or for intermodal connections to a seaport) that improves the safety, efficiency or reliability of the movement of goods through seaports.

It appropriates $171 million for MarAd operations and training (10% more than FY 2021), including $84 million for operations and $56 million for MarAd headquarters, and it provides $363 million (16% less) for state maritime academy operations to fund six state maritime academies, including $321 million for the national security multi-mission vessel program to replace five training vessels.

Pipeline & Hazardous Materials Safety Administration

The bill provides a total of $306 million for the Pipeline & Hazardous Materials Safety Administration (PHMSA), 6% more than FY 2021 and 9% more than requested.

Within the total, $29 million is for operational expenses (slightly more than FY 2021), $66 million is for hazardous-materials safety activities (7% more), and $28 million is for emergency preparedness grants (equal to FY 2021).

It also provides $183 million for continued enforcement of federal pipeline safety regulations and grants to support state pipeline safety programs -- including $147 million to be derived from the Pipeline Safety Fund, $28 million from the Oil Spill Liability Fund, and $8 million from the Underground Natural Gas Storage Facility Safety Fund. Of the total provided, $60 million is for state pipeline safety grants.

Housing & Community Development

The measure provides $56.5 billion in scored discretionary funding subject to caps for programs and activities of the Housing and Urban Development Department (HUD) -- $6.8 billion (14%) more than FY 2021 but 0.5% less than requested.

However, total programmatic spending for HUD for FY 2022 actually equals $68.2 billion, 13% more than the comparable FY 2021 level, with $11.8 billion of HUD spending offset by revenues collected by the Federal Housing Administration (FHA) and Ginnie Mae.

(The FHA and Ginnie Mae collect certain payments and fees that are scored as offsetting receipts, and which can be used by appropriators to provide funding for programs and activities that is not counted toward the measure's discretionary spending cap. Appropriators project that together, FHA and Ginnie Mae for FY 2022 would collect a net total of $11.8 billion in offsetting receipts that are used to fund other programs under the measure.)

Public & Indian Housing Programs

The bill provides $39.4 billion for HUD public and Indian housing programs for FY 2022 -- 13% more than FY 2021 but 3% less than requested.

Section 8 Tenant-Based Assistance

The bill provides $29.2 billion -- 13% more than FY 2021 but 4% less than requested -- for rental assistance under the Section 8 program, through which housing vouchers are provided by public housing authorities to low-income individuals and families. The total for Section 8 vouchers includes $4 billion in advance appropriations included in last year's spending measure; the bill provides a similar $4 billion advance appropriation for FY 2023.

Of the total provided, $25.0 billion (8% more than FY 2021) is for the renewal of expiring Section 8 vouchers.

The account also provides funding for two new initiatives: $1.0 billion for a new program to provide an estimated 125,000 housing vouchers to homeless individuals (the program replaces a similar program that was funded at $43 million in FY 2021); and $150 million for a housing and economic mobility demonstration program to help families with children move to areas of opportunity. The committee says research has found that when families with young children use housing vouchers to locate in areas with quality schools and other opportunities, their children are much more likely to attend college and earn more income as adults.

The following is also funded through this account:

Administrative Expenses -- $2.5 billion for administrative and other expenses of local public housing authorities (14% more than FY 2021), with the funds to be distributed on the basis of the number of leased units.

Veterans Affairs Supportive Housing (VASH) Vouchers -- $20 million for additional vouchers for vulnerable veteran households (half the FY 2021 level), to continue the effort to eliminate homelessness among veterans. No funding was requested for this account.

Tenant Protection -- $100 million (14% less than FY 2021) for tenant protection vouchers for families displaced from project-based units as a result of relocation or renovation.

'Mainstream' Vouchers & Renewals -- $500 million (59% more than FY 2021) for Section 811 mainstream vouchers and renewals for the nonelderly disabled to find housing. Of the total, $5 million is for a pilot program to provide supportive housing for individuals with mental illness who would benefit from wrap-around services.

Family Unification Vouchers -- $25 million (equal to FY 2021) for additional family unification vouchers. Of the amount provided, $10 million is for public housing authorities that partner with their local public child welfare agency to ensure youth referrals for these vouchers.

Public Housing

The bill provides $8.6 billion (11% more than FY 2021) for the Public Housing Fund, which subsidizes the operation and maintenance, as well as modernization and capital expenses, of public housing units. Within that total $4.9 billion is for operating expenses and $3.4 billion is for maintenance.

The total also includes up to $65 million for emergency capital needs, of which $45 million is for public housing authorities under receivership and $10 million is for safety and security measures; $23 million is for public housing financial and physical assessment activities; and $65 million is for competitive grants under the Healthy Homes initiative to address carbon monoxide poisoning, mold, and other household hazards.

Finally, the total includes $100 million for competitive grants for capital improvements to reduce utility consumption or improve the climate resilience of public housing and $10 million for a pilot program to support recycling and zero-waste programs in public housing.

Native American & Native Hawaiian Housing

The bill provides $950 million for Native American Housing block grants, 15% more than FY 2021.

Of the total, $722 million is for Native American Housing formula grants (12% more than FY 2021), 150 million is for competitive grants (50% more), and $70 million is for Indian community development block grants (equal to FY 2021). The committee encourages HUD to prioritize grants to coastal Tribes that are relocating housing to increase resilience and avoid flooding.

It provides $3.5 million to support the loan guarantee program for Native Americans, along with the requested $1.4 billion limit on loan guarantees (40% more than the 2021 limit).

For Native Hawaiian Housing block grants, it provides $4 million (double the FY 2021 level) and allows up to $28 million in loan guarantees.

Other Activities

The bill provides $200 million (29% more than FY 2021) for the family self-sufficiency program to help HUD-assisted residents achieve economic independence by increasing their income and moving out of assisted housing.

It also provides $400 million for the Choice Neighborhoods initiative, double the FY 2021 level.

Other Major Housing Programs

The bill provides $15.5 billion (6% more than FY 2021) for other major housing programs administered by HUD's Office of Housing.

Section 8 Project-Based Assistance

The measure appropriates $14.0 billion (4% more than FY 2021) for the Section 8 project-based rental assistance account. Funding is used by local housing authorities to provide rental subsidies to landlords who enter into contracts with HUD and rent their properties to low-income families; the subsidies cover the portion of rent that is not paid by the tenant. The assistance is therefore tied to a property, rather than an individual.

Of the funding provided, $13.6 billion is for the renewal of expiring contracts, $355 million is for contract administrators, and $30 million is for service coordinators for the elderly.

The total includes $400 million in advance appropriations included in last year's spending measure; the bill provides a similar $400 million advance appropriation for FY 2023.

Housing for the Elderly & Individuals with Disabilities

The bill appropriates $1.0 billion (21% more than FY 2021) for the Section 202 housing program for the elderly. The program provides capital grants to eligible private nonprofit organizations to finance the acquisition, rehabilitation or construction of housing intended for low-income elderly, along with project-based rental assistance contracts.

Of the total provided, up to $125 million is for service coordinators and congregate services to provide supportive services for frail residents, and $205 million is for new construction of affordable senior housing, including up to $10 million for intergenerational housing.

It also provides $352 million (55% more than FY 2021) for the Section 811 program, which provides eligible nonprofit organizations with capital grants to acquire, rehabilitate or construct supportive housing for individuals with disabilities along with project-based rental assistance for such units. The total includes $160 million for new construction.

Housing Counseling

The measure provides $100 million (29% more than FY 2021) for housing counseling assistance programs to provide help for low- and moderate-income families before they purchase a home. Included in that total is $20 million for legal assistance grants and a minimum of $5 million for pre- and post-purchase homeownership counseling.

Community Planning & Development Programs

The bill appropriates $10.6 billion (28% more than FY 2021) for programs under HUD's Office of Community Planning and Development.

Community Development Block Grants

The measure provides $4.7 billion (35% more than FY 2021) for community development activities financed by HUD's Community Development Fund, through which money is provided to state and local governments as well as other entities. It includes $25 million to support stable transitional living environments for individuals in recovery from substance misuse disorder.

The committee says grant recipients should refocus investment in low- and moderate-income families and neighborhoods, including to rebuild and revitalize areas affected by civil unrest.

HOME Investments Partnership Program

The measure provides the requested $1.85 billion for the HOME Investments Partnership program (37% more than FY 2021), which provides funding to state and local governments, tribes and insular areas to expand the supply of affordable housing.

Included in that total is $50 million for down payment assistance to support sustainable homeownership among first-generation, first-time home buyers.

Homeless Assistance Programs

The bill appropriates $3.4 billion (14% more than FY 2021) for HUD homeless-assistance programs to provide permanent and transitional housing for homeless families and individuals.

Within the total, $225 million is for new Continuum of Care project renewals, $290 million is for emergency solutions grants, $92 million is for youth experiencing homelessness, and $52 million is for rapid re-housing projects and to assist survivors of domestic violence, dating violence and stalking.

The committee directs HUD to report to Congress on the impact COVID - 19 has had on homelessness or housing-instability, including youth, and ways to address and reduce long-term homelessness and housing instability exacerbated by the pandemic.

Other Programs

The measure provides $600 million (40% more than FY 2021) for the Housing Opportunities for Persons with AIDS program, under which state and local governments receive assistance to develop comprehensive long-term strategies for meeting the housing needs of people with AIDS and their families.

It also provides $65 million for the Self-Help and Assisted Homeownership Program (SHOP) account (8% more than FY 2021), which includes several programs that were previously funded as set-asides from the CDBG program.

Federal Housing Administration

The Federal Housing Administration (FHA) promotes the issuance of home loans by providing federal mortgage insurance on loans made by approved lenders. As in the past, it is projected that FHA's income from insurance premiums exceeds its expenses, resulting in a "negative subsidy" that is used to offset appropriations made by the bill for other programs. The measure estimates that $9.4 billion in net FHA revenues can be used for such offsets.

Mutual Mortgage Insurance Programs

The Mutual Mortgage Insurance Program account covers FHA's unsubsidized mortgage insurance programs, primarily the single-family-home mortgage program and the cooperative-housing insurance program, which provides mortgages for certain cooperative housing projects.

The measure permits the FHA to guarantee up to $400 billion in loans and to offer up to $1 million in direct loans (both equal to FY 2021). It appropriates the requested $150 million for administrative expenses, 15% more than FY 2021.

General & Special Risk Program Account

The FHA General and Special Risk Program Account funds a wide variety of special purpose single-family and multifamily mortgage insurance programs, including those for riskier properties. The measure limits the guarantee loan commitments to $30 billion in loans made under the General and Special Risk Program, and to offer up to $1 million in direct loans (both equal to FY 2021).

Government National Mortgage Association

The Government National Mortgage Association, also known as Ginnie Mae, guarantees investors the timely payment of principal and interest on securities that are backed by federally insured or federally guaranteed mortgage loans, including those issued by the FHA or the Veterans Affairs Department.

The bill limits to $900 billion the guaranteed commitments that may be made by Ginnie Mae ($400 billion, or 31%, less than FY 2021) and it provides $35 million for administrative expenses. The measure estimates that Ginnie Mae will generate $2.3 billion in net revenues that can be used to offset other appropriations.

Other HUD Activities

The bill appropriates $460 million for the Healthy Homes and Lead Hazard Control program (28% more than FY 2021), which provides grants to state and local governments to perform lead hazard reduction activities in housing occupied by low-income families.

It also provides funding for the following programs:

HUD Management and Administration -- $1.6 billion for HUD management and administration, 4% more than FY 2021.

Fair-Housing Programs -- $85 million for fair-housing activities of HUD's Office of Fair Housing and Equal Opportunity, 17% more than FY 2021.

Policy Development and Research -- $185 million for HUD to conduct research and evaluation relating to the department's mission and programs, 76% more than FY 2021.

Information Technology Fund -- $278 million for information technology systems that support HUD programs and operations (7% less than FY 2021), including FHA mortgage insurance, housing assistance and grant programs, core financial operations and general operations.

HUD Directives

The committee urges HUD to update its standards regarding energy efficiency for HUD-owned and subsidized properties. It directs the department to identify and implement opportunities to improve energy efficiency, resilience, and healthfulness of public and assisted housing, and lower energy costs for low- and moderate-income residents.

It also directs HUD to examine its procedures for assisting families whose rent and utilities combined exceed 30% of their income, and to examine how to reduce the financial burden for such families.

In order to better understand the increases in the cost of building affordable housing, the committee directs GAO to report to Congress regarding how the per-unit costs have changed throughout the country and how the increases impacted affordable housing development. GAO must include recommendations on how to address the challenge.

Related Agencies & Other Provisions

The bill provides the requested $39 million for salaries and expenses of the Surface Transportation Board (STB), 4% more than FY 2021. The measure assumes the board will collect $1.25 million in user fees in FY 2022, which would reduce the agency's appropriation to a net total of $38 million.

It also funds numerous independent agencies, including the following:

National Transportation Safety Board -- $121 million for the NTSB (3% more than FY 2021), which is responsible for investigating transportation accidents and developing recommendations to prevent accidents, including aircraft and railroad accidents.

Neighborhood Reinvestment Corporation -- $185 million for the corporation (12% more than FY 2021), which helps local communities create partnerships between residents and representatives of the public and private sectors.

Federal Maritime Commission -- $31 million for the FMC (4% more than FY 2021), which is responsible for regulating and overseeing U.S. foreign shipping trades in order to protect U.S. shippers.

<p>Source: CQ House Action Reports ©2021 Congressional Quarterly Inc. All Rights Reserved.

Reports - Think Tanks - BPC

Publication date: October 31, 2023 35307 mots

- -

73 pages

Please note : This extract may not display a well formed paragraph

... Cleaner Health Care: Hospital Emissions Mitigation November 2023 2 H E A LT H P R O G R A M Under the leadership of former Senate Majority Leaders Tom Daschle...

Full report:
https://bipartisanpolicy.org/wp-content/uploads/2023/11/BPC_Cleaner-Health-Care_Hospital-Emissions-Mitigation_WEB.pdf

Reports - Banks and Financial Institutions - World Bank

Publication date: November 17, 2023 38141 mots

- Download: 2022 Joint Report on Multilateral Development Banks' Climate Finance - 2023-0128-MDB-Report-2022-NEW.pdf

100 pages

Please note : This extract may not display a well formed paragraph

... 2 0 2 2 C L IM A T E F IN A N C E JOINT REPORT ON MULTILATERAL DEVELOPMENT BANKS’ 2022 JOINT REPORT ON MULTILATERAL DEVELOPMENT BANKS’ CLIMATE FINANCE...

Full report:
https://thedocs.worldbank.org/en/doc/3258e1d4c1e84fd961b79fe54e7df85c-0020012023/original/2023-0128-MDB-Report-2022-NEW.pdf

Reports - Defence - Europe Security Defense

Publication date: October 28, 2020 69061 mots

- - budg2021-doc5-txt-3-en.pdf

167 pages

Please note : This extract may not display a well formed paragraph

... EN EN 2021 BUDGETARY PROCEDURE Doc No: 5: (3) ******* 26.10.2020 COMMITTEE ON BUDGETS RAPPORTEURS: PIERRE LARROUTUROU - SECTION III (COMMISSION) OLIVIER CHASTEL - OTHER SECTIONS PARLIAMENT'S POSITION Amendments which have...

Full report:
https://www.europarl.europa.eu/sed/doc/news/flash/24644/budg2021-doc5-txt-3-en.pdf

Reports - Health - Nunavut Health

Publication date: November 27, 2020 18061 mots

Inuit Employment Plan to 2023 - Department of Health Inuit Employment Plan to 2023 - hea_iep_to_2023_final__0.pdf

60 pages

Please note : This extract may not display a well formed paragraph

... Department of Health Inuit Employment Plan Department of Health Inuit Employment Plan 2017 to 2023 2017-2018 Updated July 2019 Department of Health Inuit Employment Plan Page 1 Table of Contents...

Full report:
http://www.gov.nu.ca/sites/default/files/hea_iep_to_2023_final__0.pdf

Rapports - Santé - Santé IPE

Date de publication : 10 octobre 2023 64038 mots

final report - employment standards act comprehensive review - web_ready_dpcec-4266_employment_standards_act_panel_review_phase_three_oct_6_v2_2023.pdf

120 pages

NB : cette extraction brute des 30 premiers mots ne forme peut-être pas un paragraphe bien construit

... Phase Three: Final Report and Recommendations E M P L O Y M E N T S TA N D A R D S A C T C O M P...

Pour voir le rapport :
https://www.princeedwardisland.ca/sites/default/files/publications/web_ready_dpcec-4266_employment_standards_act_panel_review_phase_three_oct_6_v2_2023.pdf

Reports - Health - Health PEI

Publication date: October 10, 2023 64034 mots

final report - web_ready_dpcec-4266_employment_standards_act_panel_review_phase_three_oct_6_v2_2023.pdf

120 pages

Please note : This extract may not display a well formed paragraph

... Phase Three: Final Report and Recommendations E M P L O Y M E N T S TA N D A R D S A C T C O M P...

Full report:
https://www.princeedwardisland.ca/sites/default/files/publications/web_ready_dpcec-4266_employment_standards_act_panel_review_phase_three_oct_6_v2_2023.pdf

Reports - Labor and Unions - ILO

Publication date: November 3, 2022 86443 mots

How did the ILO perform during the COVID-19 pandemic? - [pdf 7194KB] - wcms_854253.pdf

188 pages

Please note : This extract may not display a well formed paragraph

... Strategy and policy (2022) X Independent High-Level Evaluation of ILO’s COVID-19 response 2020-22 Copyright © International Labour Organization 2022 First published 2022 Publications of the International Labour Organization...

Full report:
http://www.ilo.org/wcmsp5/groups/public/---ed_mas/---eval/documents/publication/wcms_854253.pdf

Reports - Labor and Unions - ILO

Publication date: December 26, 2022 22859 mots

The ILO, a key partner in Post Disaster Needs Assessments (PDNAs) - [pdf 6635KB] - wcms_862500.pdf

72 pages

Please note : This extract may not display a well formed paragraph

... PAKISTAN FLOODS 2022 Post-Disaster Needs Assessment M A IN R E P O R T Ministry of Planning Development & Special Initiatives PAKISTAN FLOODS 2022 Post-Disaster Needs Assessment MAIN REPORT...

Full report:
http://www.ilo.org/wcmsp5/groups/public/---ed_emp/documents/publication/wcms_862500.pdf

Reports - Labor and Unions - ILO

Publication date: October 11, 2022 62108 mots

Peak-level social dialogue and COVID-19: The European experience - Peak-level social dialogue and COVID-19: The European experiencepdf - 2.0 MB - wcms_857214.pdf

126 pages

Please note : This extract may not display a well formed paragraph

... Peak-level social dialogue and COVID-19: The European experience XPeak-level social dialogue and COVID-19: The European experience May 2022 International Labour Office Edited by Youcef Ghellab, David Mosler...

Full report:
https://www.ilo.org/wcmsp5/groups/public/---europe/---ro-geneva/documents/publication/wcms_857214.pdf

Reports - Think Tanks - Pembina Institute

Publication date: October 14, 2020 14656 mots

B.C. Greens pledge to accelerate climate actionPembina Institute reacts to B.C. Green Party election platform - B.C. Green Party election platform - 2020-bc-greens-platform.pdf

36 pages

Please note : This extract may not display a well formed paragraph

... THE BC GREENS’ PLAN FOR A MORE EQUITABLE AND SUSTAINABLE BC 2 1. Introduction 2. Affordability and equity a. Public education b. Childcare, and flexibility for families c. Income security d...

Full report:
https://www.pembina.org/reports/2020-bc-greens-platform.pdf

Reports - Telecommunication - FCC

Publication date: October 22, 2020 36721 mots

Consumer Advisory Committee - Acrobat - cac_transcript_12-11-2019.pdf

189 pages

Please note : This extract may not display a well formed paragraph

... 1 NEAL R. GROSS COURT REPORTERS AND TRANSCRIBERS 1323 RHODE ISLAND AVE., N.W. (202) 234-4433 WASHINGTON, D.C. 20005-3701 www.nealrgross.com UNITED STATES OF AMERICA FEDERAL COMMUNICATIONS...

Full report:
https://www.fcc.gov/sites/default/files/cac_transcript_12-11-2019.pdf

Reports - Labor and Unions - ILO

Publication date: December 8, 2022 80033 mots

Nature-based Solutions can generate 20 million new jobs, but 'just transition' policies are needed - Decent Work in Nature-based Solutions - wcms_863035.pdf

268 pages

Please note : This extract may not display a well formed paragraph

... Decent Work in Nature-based Solutions 2022 Decent Work in Nature-based Solutions 2022 © International Labour Organization and the United Nations Environment Programme 2022 Some rights reserved. This work is available...

Full report:
http://www.ilo.org/wcmsp5/groups/public/---ed_emp/documents/publication/wcms_863035.pdf

Reports - Defence - Europe Security Defense

Publication date: October 8, 2021 57169 mots

- Text 2 - PPPA and Other Sections (PDF - 1 MB) - budg2022-doc6-txt-2_en.pdf

116 pages

Please note : This extract may not display a well formed paragraph

... EN EN 2022 BUDGETARY PROCEDURE Doc No: 6: (2) ******* 08.10.2021 COMMITTEE ON BUDGETS RAPPORTEURS: KARLO RESSLER - SECTION III (COMMISSION) DAMIAN BOESELAGER - OTHER SECTIONS PARLIAMENT'S POSITION Amendments adopted by...

Full report:
http://www.europarl.europa.eu/cmsdata/240516/budg2022-doc6-txt-2_en.pdf

Reports - Banks and Financial Institutions - World Bank

Publication date: October 20, 2020 69688 mots

- Kenya - Kenya-Systematic-Country-Diagnostic.pdf

104 pages

Please note : This extract may not display a well formed paragraph

... Kenya Systematic Country Diagnostic 10190-Kenya SCD.indd 110190-Kenya SCD.indd 1 10/20/20 10:49 AM10/20/20 10:49 AM P ub lic D is cl os...

Full report:
https://documents1.worldbank.org/curated/en/531731600090213005/pdf/Kenya-Systematic-Country-Diagnostic.pdf

Reports - Banks and Financial Institutions - World Bank

Publication date: December 21, 2020 55104 mots

- Eswatini - Eswatini-Systematic-Country-Diagnostic-Toward-Equal-Opportunity-Accelerating-Inclusion-and-Poverty-Reduction.pdf

120 pages

Please note : This extract may not display a well formed paragraph

... THE KINGDOM OF ESWATINI Toward Equal Opportunity: Accelerating Inclusion and Poverty Reduction Systematic Country Diagnostic December 14, 2020 Eswatini Country Team Africa Region P ub lic D is cl os ur...

Full report:
https://documents1.worldbank.org/curated/en/966931608603154612/pdf/Eswatini-Systematic-Country-Diagnostic-Toward-Equal-Opportunity-Accelerating-Inclusion-and-Poverty-Reduction.pdf

Reports - Banks and Financial Institutions - Scotia Bank

Publication date: December 12, 2022 82069 mots

Focus 2023 - Balancing Risk vs. Reward - Focus-2023.pdf

165 pages

Please note : This extract may not display a well formed paragraph

... Focus 2023 Balancing Risk vs. Reward For Reg AC Certification and important disclosures see Appendix A of this report. Analysts employed by non-U.S. affiliates are not registered/ qualified as...

Full report:
https://www.gbm.scotiabank.com/content/dam/scotiabank/gbm/market-insights/research-and-market-commentary/Focus-2023.pdf

Reports - Banks and Financial Institutions - World Bank

Publication date: November 3, 2021 36672 mots

- Official PDF - Multi-Partner-Fund-Progress-Report-January-June-2021.pdf

87 pages

Please note : This extract may not display a well formed paragraph

... P ub lic D is cl os ur e A ut ho riz ed P ub lic D is cl os ur e A ut ho riz ed P ub lic...

Full report:
http://documents.worldbank.org/curated/en/107911636040166296/pdf/Multi-Partner-Fund-Progress-Report-January-June-2021.pdf

Reports - Risk Management - PricewaterhouseCoopers

Publication date: October 1, 2021 4972 mots

- Download the full report (PDF) Centre Stage The Twelfth Malaysia Plan (RMK-12) Overview - pwc-centre-stage-the-twelfth-malaysia-plan-rmk-12-overview.pdf

19 pages

Please note : This extract may not display a well formed paragraph

... 1PwC | Centre Stage RMK-12 overview Centre Stage Twelfth Malaysia Plan (RMK-12) overview 2PwC | Centre Stage RMK-12 overview Content Highlights from RMK-12 Page 3 Theme 1: Resetting the...

Full report:
https://www.pwc.com/my/en/assets/publications/2021/pwc-centre-stage-the-twelfth-malaysia-plan-rmk-12-overview.pdf

Reports - Defence - Europe Security Defense

Publication date: October 8, 2020 52332 mots

- PDF (558 KB) - A-9-2020-0186_EN.pdf

130 pages

Please note : This extract may not display a well formed paragraph

... RR 1215422EN.docx PE650.508v02-00 EN United in diversity EN European Parliament 2019-2024 Plenary sitting A9-0186/2020 8.10.2020 REPORT with recommendations to the Commission on a...

Full report:
https://www.europarl.europa.eu/doceo/document/A-9-2020-0186_EN.pdf

Reports - Banks and Financial Institutions - Credit Agricole

Publication date: December 8, 2022 15251 mots

Find out more on governance - Download file . (5.23 Mo) - 196243

104 pages

Please note : This extract may not display a well formed paragraph

... F I N A N C I A L C O M M U N I C A T I O N S D E P A R T M E...

Full report:
https://www.credit-agricole.com/en/pdfPreview/196243

Reports - Banks and Financial Institutions - World Bank

Publication date: October 21, 2020 28235 mots

- Rwanda FY21-26 - Rwanda-Country-Partnership-Framework-for-the-Period-of-FY21-FY26.pdf

76 pages

Please note : This extract may not display a well formed paragraph

... Report No. 148876-RW P ub lic D is cl os ur e A ut ho riz ed P ub lic D is cl os ur e A ut ho riz...

Full report:
https://documents1.worldbank.org/curated/en/645111594605654868/pdf/Rwanda-Country-Partnership-Framework-for-the-Period-of-FY21-FY26.pdf

Reports - Banks and Financial Institutions - World Bank

Publication date: December 1, 2022 34852 mots

- World Bank Country Economic Memorandum for Georgia - P17548605921fd062093cb077bd2d45cd13.pdf

78 pages

Please note : This extract may not display a well formed paragraph

... CHARTING GEORGIA’S FUTURE Competitive, Connected, Capable CHARTING GEORGIA’S FUTURE Competitive, Connected, Capable P ub lic D is cl os ur e A ut ho riz ed P ub lic...

Full report:
https://documents1.worldbank.org/curated/en/099435012022237049/pdf/P17548605921fd062093cb077bd2d45cd13.pdf?fbclid=IwAR0LNCa6FIdoglGKL6BfM9Luj5J62auoUxXdrsGs-n4KuSIeHeS_-zMEaWc